require "temboo"

module DarkSky



  ##############################################################################
  #
  # GetForecastByAddress
  #
  # Returns the current weather conditions for a specified location by address.
  #
  # Copyright 2014, Temboo Inc.
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing,
  # software distributed under the License is distributed on an
  # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
  # either express or implied. See the License for the specific
  # language governing permissions and limitations under the License.
  #
  ##############################################################################

  class GetForecastByAddress < Choreography

    ####
    #  Create a new instance of the GetForecastByAddress Choreo. A TembooSession object, containing a valid
    #  set of Temboo credentials, must be supplied.
    ####
    def initialize(session)
      super(session, "/Library/DarkSky/GetForecastByAddress")
    end

    #### 
    # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
    #
    # @return GetForecastByAddressInputSet
    ####
    def new_input_set()
      return GetForecastByAddressInputSet.new()
    end

    def make_result_set()
      return GetForecastByAddressResultSet.new()
    end

    ####
    # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
    # and return a ResultSet containing the execution results.
    # @param choreoInputs
    # @return
    # @throws TembooException
    ####
    def execute(input_set = nil)
      resp = super(input_set)
      results = GetForecastByAddressResultSet.new(resp)
      return results
    end

    ####
    # An InputSet with methods appropriate for specifying the inputs to the GetForecastByAddress
    # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    ####
    class GetForecastByAddressInputSet < Choreography::InputSet

      #### 
      # Set the value of the APIKey input for this Choreo. 
      # 
      # @param String - (required, string) The API Key provided by Dark Sky.
      ###

      def set_APIKey(value)
        set_input("APIKey", value)
      end
      #### 
      # Set the value of the Address input for this Choreo. 
      # 
      # @param String - (required, string) The address of the location.
      ###

      def set_Address(value)
        set_input("Address", value)
      end
      #### 
      # Set the value of the Exclude input for this Choreo. 
      # 
      # @param String - (optional, string) Exclude some number of data blocks from the API response. Valid values are: currently, minutely, hourly, daily, alerts, and flags.
      ###

      def set_Exclude(value)
        set_input("Exclude", value)
      end
      #### 
      # Set the value of the Extend input for this Choreo. 
      # 
      # @param String - (optional, string) When present, returns hour-by-hour data for the next 168 hours, instead of the next 48. Valid value: hourly.
      ###

      def set_Extend(value)
        set_input("Extend", value)
      end
      #### 
      # Set the value of the GeocodingAPIKey input for this Choreo. 
      # 
      # @param String - (required, string) Your Google Geocoding API Key.
      ###

      def set_GeocodingAPIKey(value)
        set_input("GeocodingAPIKey", value)
      end
      #### 
      # Set the value of the Language input for this Choreo. 
      # 
      # @param String - (optional, string) The language in which to return results e.g., es, fr, it, en (the default). See Choreo notes for a link to a full list of supported languages.
      ###

      def set_Language(value)
        set_input("Language", value)
      end
      #### 
      # Set the value of the Units input for this Choreo. 
      # 
      # @param String - (optional, string) Return weather conditions in the requested units. Valid values are: auto, ca, uk2, us (use for Farenheit), and si (use for Celsius).
      ###

      def set_Units(value)
        set_input("Units", value)
      end

    end

    ####
    # A ResultSet with methods tailored to the values returned by the GetForecastByAddress Choreo.
    # The ResultSet object is used to retrieve the results of a Choreo execution.
    ####
    class GetForecastByAddressResultSet < Choreography::ResultSet
    	####
    	# Retrieve the value for the "HourlySummary" output from this Choreo execution
    	#
    	# @return String - (string) The hourly summary.
    	####
    	def get_HourlySummary()
    	  return @outputs["HourlySummary"]
    	end
    	####
    	# Retrieve the value for the "Humidity" output from this Choreo execution
    	#
    	# @return String - (decimal) The current humidity.
    	####
    	def get_Humidity()
    	  return @outputs["Humidity"]
    	end
    	####
    	# Retrieve the value for the "Pressure" output from this Choreo execution
    	#
    	# @return String - (decimal) The current pressure.
    	####
    	def get_Pressure()
    	  return @outputs["Pressure"]
    	end
    	####
    	# Retrieve the value for the "Summary" output from this Choreo execution
    	#
    	# @return String - (string) The current weather summary.
    	####
    	def get_Summary()
    	  return @outputs["Summary"]
    	end
    	####
    	# Retrieve the value for the "Temperature" output from this Choreo execution
    	#
    	# @return String - (decimal) The current temperature.
    	####
    	def get_Temperature()
    	  return @outputs["Temperature"]
    	end
    	####
    	# Retrieve the value for the "UVIndex" output from this Choreo execution
    	#
    	# @return String - (integer) The current uv index.
    	####
    	def get_UVIndex()
    	  return @outputs["UVIndex"]
    	end
    	####
    	# Retrieve the value for the "Visibility" output from this Choreo execution
    	#
    	# @return String - (decimal) The current visibility.
    	####
    	def get_Visibility()
    	  return @outputs["Visibility"]
    	end
    	####
    	# Retrieve the value for the "Response" output from this Choreo execution
    	#
    	# @return String - (json) The response from Dark Sky.
    	####
    	def get_Response()
    	  return @outputs["Response"]
    	end
    end

  end # class GetForecastByAddress



  ##############################################################################
  #
  # GetForecastByCoordinates
  #
  # Returns the current weather conditions for a specified location by geo-coordinates.
  #
  # Copyright 2014, Temboo Inc.
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing,
  # software distributed under the License is distributed on an
  # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
  # either express or implied. See the License for the specific
  # language governing permissions and limitations under the License.
  #
  ##############################################################################

  class GetForecastByCoordinates < Choreography

    ####
    #  Create a new instance of the GetForecastByCoordinates Choreo. A TembooSession object, containing a valid
    #  set of Temboo credentials, must be supplied.
    ####
    def initialize(session)
      super(session, "/Library/DarkSky/GetForecastByCoordinates")
    end

    #### 
    # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
    #
    # @return GetForecastByCoordinatesInputSet
    ####
    def new_input_set()
      return GetForecastByCoordinatesInputSet.new()
    end

    def make_result_set()
      return GetForecastByCoordinatesResultSet.new()
    end

    ####
    # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
    # and return a ResultSet containing the execution results.
    # @param choreoInputs
    # @return
    # @throws TembooException
    ####
    def execute(input_set = nil)
      resp = super(input_set)
      results = GetForecastByCoordinatesResultSet.new(resp)
      return results
    end

    ####
    # An InputSet with methods appropriate for specifying the inputs to the GetForecastByCoordinates
    # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    ####
    class GetForecastByCoordinatesInputSet < Choreography::InputSet

      #### 
      # Set the value of the APIKey input for this Choreo. 
      # 
      # @param String - (required, string) The API Key provided by Dark Sky.
      ###

      def set_APIKey(value)
        set_input("APIKey", value)
      end
      #### 
      # Set the value of the Exclude input for this Choreo. 
      # 
      # @param String - (optional, string) Exclude some number of data blocks from the API response. Valid values are: currently, minutely, hourly, daily, alerts, and flags.
      ###

      def set_Exclude(value)
        set_input("Exclude", value)
      end
      #### 
      # Set the value of the Extend input for this Choreo. 
      # 
      # @param String - (optional, string) When present, returns hour-by-hour data for the next 168 hours, instead of the next 48. Valid value: hourly.
      ###

      def set_Extend(value)
        set_input("Extend", value)
      end
      #### 
      # Set the value of the Language input for this Choreo. 
      # 
      # @param String - (optional, string) The language in which to return results e.g., es, fr, it, en (the default). See Choreo notes for a link to a full list of supported languages.
      ###

      def set_Language(value)
        set_input("Language", value)
      end
      #### 
      # Set the value of the Latitude input for this Choreo. 
      # 
      # @param BigDecimal - (required, decimal) The latitude of the location.
      ###

      def set_Latitude(value)
        set_input("Latitude", value)
      end
      #### 
      # Set the value of the Longitude input for this Choreo. 
      # 
      # @param BigDecimal - (required, decimal) The longitude of the location.
      ###

      def set_Longitude(value)
        set_input("Longitude", value)
      end
      #### 
      # Set the value of the Units input for this Choreo. 
      # 
      # @param String - (optional, string) Return weather conditions in the requested units. Valid values are: auto, ca, uk2, us (use for Farenheit), and si (use for Celsius).
      ###

      def set_Units(value)
        set_input("Units", value)
      end

    end

    ####
    # A ResultSet with methods tailored to the values returned by the GetForecastByCoordinates Choreo.
    # The ResultSet object is used to retrieve the results of a Choreo execution.
    ####
    class GetForecastByCoordinatesResultSet < Choreography::ResultSet
    	####
    	# Retrieve the value for the "HourlySummary" output from this Choreo execution
    	#
    	# @return String - (string) The hourly summary.
    	####
    	def get_HourlySummary()
    	  return @outputs["HourlySummary"]
    	end
    	####
    	# Retrieve the value for the "Humidity" output from this Choreo execution
    	#
    	# @return String - (decimal) The current humidity.
    	####
    	def get_Humidity()
    	  return @outputs["Humidity"]
    	end
    	####
    	# Retrieve the value for the "Pressure" output from this Choreo execution
    	#
    	# @return String - (decimal) The current pressure.
    	####
    	def get_Pressure()
    	  return @outputs["Pressure"]
    	end
    	####
    	# Retrieve the value for the "Summary" output from this Choreo execution
    	#
    	# @return String - (string) The current weather summary.
    	####
    	def get_Summary()
    	  return @outputs["Summary"]
    	end
    	####
    	# Retrieve the value for the "Temperature" output from this Choreo execution
    	#
    	# @return String - (decimal) The current temperature.
    	####
    	def get_Temperature()
    	  return @outputs["Temperature"]
    	end
    	####
    	# Retrieve the value for the "UVIndex" output from this Choreo execution
    	#
    	# @return String - (integer) The current uv index.
    	####
    	def get_UVIndex()
    	  return @outputs["UVIndex"]
    	end
    	####
    	# Retrieve the value for the "Visibility" output from this Choreo execution
    	#
    	# @return String - (decimal) The current visibility.
    	####
    	def get_Visibility()
    	  return @outputs["Visibility"]
    	end
    	####
    	# Retrieve the value for the "Response" output from this Choreo execution
    	#
    	# @return String - (json) The response from Dark Sky.
    	####
    	def get_Response()
    	  return @outputs["Response"]
    	end
    end

  end # class GetForecastByCoordinates



  ##############################################################################
  #
  # TimeMachineRequest
  #
  # Returns the observed (in the past) or forecasted (in the future) hour-by-hour weather and daily weather conditions for a particular date.
  #
  # Copyright 2014, Temboo Inc.
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing,
  # software distributed under the License is distributed on an
  # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
  # either express or implied. See the License for the specific
  # language governing permissions and limitations under the License.
  #
  ##############################################################################

  class TimeMachineRequest < Choreography

    ####
    #  Create a new instance of the TimeMachineRequest Choreo. A TembooSession object, containing a valid
    #  set of Temboo credentials, must be supplied.
    ####
    def initialize(session)
      super(session, "/Library/DarkSky/TimeMachineRequest")
    end

    #### 
    # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
    #
    # @return TimeMachineRequestInputSet
    ####
    def new_input_set()
      return TimeMachineRequestInputSet.new()
    end

    def make_result_set()
      return TimeMachineRequestResultSet.new()
    end

    ####
    # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
    # and return a ResultSet containing the execution results.
    # @param choreoInputs
    # @return
    # @throws TembooException
    ####
    def execute(input_set = nil)
      resp = super(input_set)
      results = TimeMachineRequestResultSet.new(resp)
      return results
    end

    ####
    # An InputSet with methods appropriate for specifying the inputs to the TimeMachineRequest
    # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    ####
    class TimeMachineRequestInputSet < Choreography::InputSet

      #### 
      # Set the value of the APIKey input for this Choreo. 
      # 
      # @param String - (required, string) The API Key provided by Dark Sky.
      ###

      def set_APIKey(value)
        set_input("APIKey", value)
      end
      #### 
      # Set the value of the Exclude input for this Choreo. 
      # 
      # @param String - (optional, string) Exclude some number of data blocks from the API response. Valid values are: currently, minutely, hourly, daily, alerts, and flags.
      ###

      def set_Exclude(value)
        set_input("Exclude", value)
      end
      #### 
      # Set the value of the Extend input for this Choreo. 
      # 
      # @param String - (optional, string) When present, returns hour-by-hour data for the next 168 hours, instead of the next 48. Valid value: hourly.
      ###

      def set_Extend(value)
        set_input("Extend", value)
      end
      #### 
      # Set the value of the Language input for this Choreo. 
      # 
      # @param String - (optional, string) The language in which to return results e.g., es, fr, it, en (the default). See Choreo notes for a link to a full list of supported languages.
      ###

      def set_Language(value)
        set_input("Language", value)
      end
      #### 
      # Set the value of the Latitude input for this Choreo. 
      # 
      # @param BigDecimal - (required, decimal) The latitude of the location.
      ###

      def set_Latitude(value)
        set_input("Latitude", value)
      end
      #### 
      # Set the value of the Longitude input for this Choreo. 
      # 
      # @param BigDecimal - (required, decimal) The longitude of the location.
      ###

      def set_Longitude(value)
        set_input("Longitude", value)
      end
      #### 
      # Set the value of the Time input for this Choreo. 
      # 
      # @param String - (required, date) A UNIX timestamp (seconds since midnight GMT on 1 Jan 1970) or a string formatted date e.g., 2016-03-05T15:48:56Z.
      ###

      def set_Time(value)
        set_input("Time", value)
      end
      #### 
      # Set the value of the Units input for this Choreo. 
      # 
      # @param String - (optional, string) Return weather conditions in the requested units. Valid values are: auto, ca, uk2, us (use for Farenheit), and si (use for Celsius).
      ###

      def set_Units(value)
        set_input("Units", value)
      end

    end

    ####
    # A ResultSet with methods tailored to the values returned by the TimeMachineRequest Choreo.
    # The ResultSet object is used to retrieve the results of a Choreo execution.
    ####
    class TimeMachineRequestResultSet < Choreography::ResultSet
    	####
    	# Retrieve the value for the "HourlySummary" output from this Choreo execution
    	#
    	# @return String - (string) The hourly summary.
    	####
    	def get_HourlySummary()
    	  return @outputs["HourlySummary"]
    	end
    	####
    	# Retrieve the value for the "Humidity" output from this Choreo execution
    	#
    	# @return String - (decimal) The current humidity.
    	####
    	def get_Humidity()
    	  return @outputs["Humidity"]
    	end
    	####
    	# Retrieve the value for the "Pressure" output from this Choreo execution
    	#
    	# @return String - (decimal) The current pressure.
    	####
    	def get_Pressure()
    	  return @outputs["Pressure"]
    	end
    	####
    	# Retrieve the value for the "Summary" output from this Choreo execution
    	#
    	# @return String - (string) The current weather summary.
    	####
    	def get_Summary()
    	  return @outputs["Summary"]
    	end
    	####
    	# Retrieve the value for the "Temperature" output from this Choreo execution
    	#
    	# @return String - (decimal) The current temperature.
    	####
    	def get_Temperature()
    	  return @outputs["Temperature"]
    	end
    	####
    	# Retrieve the value for the "UVIndex" output from this Choreo execution
    	#
    	# @return String - (integer) The current uv index.
    	####
    	def get_UVIndex()
    	  return @outputs["UVIndex"]
    	end
    	####
    	# Retrieve the value for the "Visibility" output from this Choreo execution
    	#
    	# @return String - (decimal) The current visibility.
    	####
    	def get_Visibility()
    	  return @outputs["Visibility"]
    	end
    	####
    	# Retrieve the value for the "Response" output from this Choreo execution
    	#
    	# @return String - (json) The response from Dark Sky.
    	####
    	def get_Response()
    	  return @outputs["Response"]
    	end
    end

  end # class TimeMachineRequest




end # module DarkSky