require "temboo"

module Dropbox




  module Account



    ##############################################################################
    #
    # AccountInfo
    #
    # Retrieves information about the user's account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class AccountInfo < Choreography

      ####
      #  Create a new instance of the AccountInfo Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Account/AccountInfo")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AccountInfoInputSet
      ####
      def new_input_set()
        return AccountInfoInputSet.new()
      end

      def make_result_set()
        return AccountInfoResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AccountInfoResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the AccountInfo
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AccountInfoInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the AccountInfo Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AccountInfoResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class AccountInfo




  end # module Account

  module FileOperations



    ##############################################################################
    #
    # CopyFileOrFolder
    #
    # Copies a file or folder to a new location in the Dropbox tree.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CopyFileOrFolder < Choreography

      ####
      #  Create a new instance of the CopyFileOrFolder Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FileOperations/CopyFileOrFolder")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CopyFileOrFolderInputSet
      ####
      def new_input_set()
        return CopyFileOrFolderInputSet.new()
      end

      def make_result_set()
        return CopyFileOrFolderResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CopyFileOrFolderResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CopyFileOrFolder
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CopyFileOrFolderInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the FromCopyRef input for this Choreo. 
        # 
        # @param String - (conditional, string) Specifies a CopyRef previously generated by running the CreateCopyRef choreo. If you specify this value, you must leave FromPath empty.
        ###

        def set_FromCopyRef(value)
          set_input("FromCopyRef", value)
        end
        #### 
        # Set the value of the FromPath input for this Choreo. 
        # 
        # @param String - (conditional, string) Specifies the file or folder to be copied. If you specify this value, you must leave the FromCopyRef blank.
        ###

        def set_FromPath(value)
          set_input("FromPath", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Root input for this Choreo. 
        # 
        # @param String - (optional, string) Defaults to "auto" which automatically determines the root folder using your app's permission level. Other options are "sandbox" (App Folder) and "dropbox" (Full Dropbox).
        ###

        def set_Root(value)
          set_input("Root", value)
        end
        #### 
        # Set the value of the ToPath input for this Choreo. 
        # 
        # @param String - (required, string) Specifies the destination path, including the new name for the file or folder.
        ###

        def set_ToPath(value)
          set_input("ToPath", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CopyFileOrFolder Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CopyFileOrFolderResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CopyFileOrFolder



    ##############################################################################
    #
    # CreateFolder
    #
    # Creates a Dropbox folder.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateFolder < Choreography

      ####
      #  Create a new instance of the CreateFolder Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FileOperations/CreateFolder")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateFolderInputSet
      ####
      def new_input_set()
        return CreateFolderInputSet.new()
      end

      def make_result_set()
        return CreateFolderResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateFolderResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateFolder
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateFolderInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the NewFolderName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the new folder to create. A path with a root folder is also valid (i.e. /RootFolder/NewFolderName).
        ###

        def set_NewFolderName(value)
          set_input("NewFolderName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Root input for this Choreo. 
        # 
        # @param String - (optional, string) Defaults to "auto" which automatically determines the root folder using your app's permission level. Other options are "sandbox" (App Folder) and "dropbox" (Full Dropbox).
        ###

        def set_Root(value)
          set_input("Root", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateFolder Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateFolderResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateFolder



    ##############################################################################
    #
    # DeleteFileOrFolder
    #
    # Deletes a Dropbox file or folder that you specify.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteFileOrFolder < Choreography

      ####
      #  Create a new instance of the DeleteFileOrFolder Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FileOperations/DeleteFileOrFolder")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteFileOrFolderInputSet
      ####
      def new_input_set()
        return DeleteFileOrFolderInputSet.new()
      end

      def make_result_set()
        return DeleteFileOrFolderResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteFileOrFolderResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteFileOrFolder
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteFileOrFolderInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) The path to the file or folder you want to delete (i.e. /RootFolder/SubFolder/FileToDelete.txt).
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Root input for this Choreo. 
        # 
        # @param String - (optional, string) Defaults to "auto" which automatically determines the root folder using your app's permission level. Other options are "sandbox" (App Folder) and "dropbox" (Full Dropbox).
        ###

        def set_Root(value)
          set_input("Root", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteFileOrFolder Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteFileOrFolderResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteFileOrFolder



    ##############################################################################
    #
    # MoveFileOrFolder
    #
    # Moves a file or folder to a new location in the Dropbox tree.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class MoveFileOrFolder < Choreography

      ####
      #  Create a new instance of the MoveFileOrFolder Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FileOperations/MoveFileOrFolder")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return MoveFileOrFolderInputSet
      ####
      def new_input_set()
        return MoveFileOrFolderInputSet.new()
      end

      def make_result_set()
        return MoveFileOrFolderResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = MoveFileOrFolderResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the MoveFileOrFolder
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class MoveFileOrFolderInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the FromPath input for this Choreo. 
        # 
        # @param String - (required, string) Specifies the file or folder to be copied.
        ###

        def set_FromPath(value)
          set_input("FromPath", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Root input for this Choreo. 
        # 
        # @param String - (optional, string) Defaults to "auto" which automatically determines the root folder using your app's permission level. Other options are "sandbox" (App Folder) and "dropbox" (Full Dropbox).
        ###

        def set_Root(value)
          set_input("Root", value)
        end
        #### 
        # Set the value of the ToPath input for this Choreo. 
        # 
        # @param String - (required, string) Specifies the destination path, including the new name for the file or folder.
        ###

        def set_ToPath(value)
          set_input("ToPath", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the MoveFileOrFolder Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class MoveFileOrFolderResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class MoveFileOrFolder



    ##############################################################################
    #
    # ZipFile
    #
    # Creates a zipped version of the specified Dropbox file and returns a shareable link to the new compressed file.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ZipFile < Choreography

      ####
      #  Create a new instance of the ZipFile Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FileOperations/ZipFile")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ZipFileInputSet
      ####
      def new_input_set()
        return ZipFileInputSet.new()
      end

      def make_result_set()
        return ZipFileResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ZipFileResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ZipFile
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ZipFileInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the FileName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the Dropbox file you want to zip.
        ###

        def set_FileName(value)
          set_input("FileName", value)
        end
        #### 
        # Set the value of the Folder input for this Choreo. 
        # 
        # @param String - (conditional, string) The name of the folder that contains the file you want to zip. A path to a sub-folder is also valid (i.e. RootFolder/SubFolder). Not required if the file is at the root level.
        ###

        def set_Folder(value)
          set_input("Folder", value)
        end
        #### 
        # Set the value of the Root input for this Choreo. 
        # 
        # @param String - (optional, string) Defaults to "auto" which automatically determines the root folder using your app's permission level. Other options are "sandbox" (App Folder) and "dropbox" (Full Dropbox).
        ###

        def set_Root(value)
          set_input("Root", value)
        end
        #### 
        # Set the value of the ZipFileLocation input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the folder to put the new zip file in.A path to a sub-folder is also valid (i.e. RootFolder/SubFolder).  When not specified, the zip file will be put in the root folder.
        ###

        def set_ZipFileLocation(value)
          set_input("ZipFileLocation", value)
        end
        #### 
        # Set the value of the ZipFileName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the zip file that will be created. If not specified, the original file name will be used with a .zip extension.
        ###

        def set_ZipFileName(value)
          set_input("ZipFileName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ZipFile Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ZipFileResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "URL" output from this Choreo execution
      	#
      	# @return String - (string) The shared link for the new zip file.
      	####
      	def get_URL()
      	  return @outputs["URL"]
      	end
      end

    end # class ZipFile



    ##############################################################################
    #
    # ZipFolder
    #
    # Creates a zip file containing all files within the specified folder and returns a shareable link to the new compressed file.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ZipFolder < Choreography

      ####
      #  Create a new instance of the ZipFolder Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FileOperations/ZipFolder")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ZipFolderInputSet
      ####
      def new_input_set()
        return ZipFolderInputSet.new()
      end

      def make_result_set()
        return ZipFolderResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ZipFolderResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ZipFolder
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ZipFolderInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the Folder input for this Choreo. 
        # 
        # @param String - (required, string) The name of the folder that contains the files you want to retrieve and zip. A path to a sub-folder is also valid (i.e. RootFolder/SubFolder).
        ###

        def set_Folder(value)
          set_input("Folder", value)
        end
        #### 
        # Set the value of the Root input for this Choreo. 
        # 
        # @param String - (optional, string) Defaults to "auto" which automatically determines the root folder using your app's permission level. Other options are "sandbox" (App Folder) and "dropbox" (Full Dropbox).
        ###

        def set_Root(value)
          set_input("Root", value)
        end
        #### 
        # Set the value of the ZipFileLocation input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the folder to put the new zip file in. A path to a sub-folder is also valid (i.e. RootFolder/SubFolder). When not specified, the zip file will be put in the root folder.
        ###

        def set_ZipFileLocation(value)
          set_input("ZipFileLocation", value)
        end
        #### 
        # Set the value of the ZipFileName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the zip file that will be created. If not specified, the original folder name containing the files to zip will be used with a .zip extension.
        ###

        def set_ZipFileName(value)
          set_input("ZipFileName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ZipFolder Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ZipFolderResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "URL" output from this Choreo execution
      	#
      	# @return String - 
      	####
      	def get_URL()
      	  return @outputs["URL"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ZipFolder




  end # module FileOperations

  module Files



    ##############################################################################
    #
    # Copy
    #
    # Copies a file or folder to a different location in the user's Dropbox.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Copy < Choreography

      ####
      #  Create a new instance of the Copy Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/Copy")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CopyInputSet
      ####
      def new_input_set()
        return CopyInputSet.new()
      end

      def make_result_set()
        return CopyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CopyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Copy
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CopyInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AllowSharedFolder input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true, contents are copied into a shared folder, otherwise an error will be returned if the FromPath contains a shared folder. The default for this field is false.
        ###

        def set_AllowSharedFolder(value)
          set_input("AllowSharedFolder", value)
        end
        #### 
        # Set the value of the AutoRename input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If there's a conflict, have the Dropbox server try to autorename the file to avoid the conflict. The default for this field is false.
        ###

        def set_AutoRename(value)
          set_input("AutoRename", value)
        end
        #### 
        # Set the value of the FromPath input for this Choreo. 
        # 
        # @param String - (required, string) Path in the user's Dropbox to be copied or moved.
        ###

        def set_FromPath(value)
          set_input("FromPath", value)
        end
        #### 
        # Set the value of the ToPath input for this Choreo. 
        # 
        # @param String - (required, string) Path in the user's Dropbox that is the destination.
        ###

        def set_ToPath(value)
          set_input("ToPath", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Copy Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CopyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Dropbox.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Copy



    ##############################################################################
    #
    # CopyReferenceGet
    #
    # Gets a copy reference to a file or folder.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CopyReferenceGet < Choreography

      ####
      #  Create a new instance of the CopyReferenceGet Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/CopyReferenceGet")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CopyReferenceGetInputSet
      ####
      def new_input_set()
        return CopyReferenceGetInputSet.new()
      end

      def make_result_set()
        return CopyReferenceGetResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CopyReferenceGetResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CopyReferenceGet
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CopyReferenceGetInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) The path to the file or folder you want to get a copy reference to.
        ###

        def set_Path(value)
          set_input("Path", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CopyReferenceGet Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CopyReferenceGetResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Dropbox.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CopyReferenceGet



    ##############################################################################
    #
    # CopyReferenceSave
    #
    # Saves a copy reference returned by CopyReferenceGet to the user's Dropbox.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CopyReferenceSave < Choreography

      ####
      #  Create a new instance of the CopyReferenceSave Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/CopyReferenceSave")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CopyReferenceSaveInputSet
      ####
      def new_input_set()
        return CopyReferenceSaveInputSet.new()
      end

      def make_result_set()
        return CopyReferenceSaveResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CopyReferenceSaveResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CopyReferenceSave
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CopyReferenceSaveInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the CopyReference input for this Choreo. 
        # 
        # @param String - (required, string) A copy reference returned by CopyReferenceGet.
        ###

        def set_CopyReference(value)
          set_input("CopyReference", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) Path in the user's Dropbox that is the destination.
        ###

        def set_Path(value)
          set_input("Path", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CopyReferenceSave Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CopyReferenceSaveResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Dropbox.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CopyReferenceSave



    ##############################################################################
    #
    # CreateFolder
    #
    # Creates a folder at a given path.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateFolder < Choreography

      ####
      #  Create a new instance of the CreateFolder Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/CreateFolder")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateFolderInputSet
      ####
      def new_input_set()
        return CreateFolderInputSet.new()
      end

      def make_result_set()
        return CreateFolderResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateFolderResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateFolder
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateFolderInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AutoRename input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If there's a conflict, have the Dropbox server try to autorename the file to avoid the conflict. The default for this field is false.
        ###

        def set_AutoRename(value)
          set_input("AutoRename", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) Path in the user's Dropbox to create.
        ###

        def set_Path(value)
          set_input("Path", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateFolder Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateFolderResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Dropbox.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateFolder



    ##############################################################################
    #
    # Delete
    #
    # Deletes the file or folder at a given path.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Delete < Choreography

      ####
      #  Create a new instance of the Delete Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/Delete")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteInputSet
      ####
      def new_input_set()
        return DeleteInputSet.new()
      end

      def make_result_set()
        return DeleteResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Delete
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) Path in the user's Dropbox to delete.
        ###

        def set_Path(value)
          set_input("Path", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Delete Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Dropbox.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Delete



    ##############################################################################
    #
    # Download
    #
    # Downloads a file from a user's Dropbox.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Download < Choreography

      ####
      #  Create a new instance of the Download Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/Download")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DownloadInputSet
      ####
      def new_input_set()
        return DownloadInputSet.new()
      end

      def make_result_set()
        return DownloadResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DownloadResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Download
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DownloadInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the Encode input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Binary files must be returned as Base64-encoded data. If the file you are donwloading is plain text, you can set this to false to return the raw data. Defaults to true. 
        ###

        def set_Encode(value)
          set_input("Encode", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) The path of the file to download.
        ###

        def set_Path(value)
          set_input("Path", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Download Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DownloadResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Download



    ##############################################################################
    #
    # GetLatestCursor
    #
    # Gets a cursor for the folder's state.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetLatestCursor < Choreography

      ####
      #  Create a new instance of the GetLatestCursor Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/GetLatestCursor")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetLatestCursorInputSet
      ####
      def new_input_set()
        return GetLatestCursorInputSet.new()
      end

      def make_result_set()
        return GetLatestCursorResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetLatestCursorResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetLatestCursor
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetLatestCursorInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the IncludeDeleted input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true, the results will include entries for files and folders that used to exist but were deleted. The default for this field is false.
        ###

        def set_IncludeDeleted(value)
          set_input("IncludeDeleted", value)
        end
        #### 
        # Set the value of the IncludeHasExplicitSharedMembers input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true, the results will include a flag for each file indicating whether or not that file has any explicit members. The default for this field is false.
        ###

        def set_IncludeHasExplicitSharedMembers(value)
          set_input("IncludeHasExplicitSharedMembers", value)
        end
        #### 
        # Set the value of the IncludeMediaInfo input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true, FileMetadata.media_info is set for photo and video. The default for this field is false.
        ###

        def set_IncludeMediaInfo(value)
          set_input("IncludeMediaInfo", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) The path to the folder you want to see the contents of. This should be empty to list contents at the root level.
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the Recursive input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true, the list folder operation will be applied recursively to all subfolders and the response will contain contents of all subfolders. The default for this field is false.
        ###

        def set_Recursive(value)
          set_input("Recursive", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetLatestCursor Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetLatestCursorResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Cursor" output from this Choreo execution
      	#
      	# @return String - (string) A cursor used to retrieve the next set of results with ListFolderContinue.
      	####
      	def get_Cursor()
      	  return @outputs["Cursor"]
      	end
      end

    end # class GetLatestCursor



    ##############################################################################
    #
    # GetMetadata
    #
    # Returns the metadata for a file or folder.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetMetadata < Choreography

      ####
      #  Create a new instance of the GetMetadata Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/GetMetadata")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetMetadataInputSet
      ####
      def new_input_set()
        return GetMetadataInputSet.new()
      end

      def make_result_set()
        return GetMetadataResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetMetadataResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetMetadata
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetMetadataInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the IncludeDeleted input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true, DeletedMetadata will be returned for deleted file or folder, otherwise LookupError.not_found will be returned. The default for this field is false.
        ###

        def set_IncludeDeleted(value)
          set_input("IncludeDeleted", value)
        end
        #### 
        # Set the value of the IncludeHasExplicitSharedMembers input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true, the results will include a flag for each file indicating whether or not that file has any explicit members. The default for this field is false.
        ###

        def set_IncludeHasExplicitSharedMembers(value)
          set_input("IncludeHasExplicitSharedMembers", value)
        end
        #### 
        # Set the value of the IncludeMediaInfo input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true, FileMetadata.media_info is set for photo and video. The default for this field is false.
        ###

        def set_IncludeMediaInfo(value)
          set_input("IncludeMediaInfo", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) The path of a file or folder on Dropbox.
        ###

        def set_Path(value)
          set_input("Path", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetMetadata Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetMetadataResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Dropbox.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetMetadata



    ##############################################################################
    #
    # GetThumbnail
    #
    # Gets a thumbnail for an image.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetThumbnail < Choreography

      ####
      #  Create a new instance of the GetThumbnail Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/GetThumbnail")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetThumbnailInputSet
      ####
      def new_input_set()
        return GetThumbnailInputSet.new()
      end

      def make_result_set()
        return GetThumbnailResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetThumbnailResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetThumbnail
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetThumbnailInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the Format input for this Choreo. 
        # 
        # @param String - (optional, string) The format for the thumbnail image, jpeg (default) or png.
        ###

        def set_Format(value)
          set_input("Format", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) The path of the file to download.
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the Size input for this Choreo. 
        # 
        # @param String - (optional, string) The size for the thumbnail image. The default for this union is w64h64.
        ###

        def set_Size(value)
          set_input("Size", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetThumbnail Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetThumbnailResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetThumbnail



    ##############################################################################
    #
    # ListFolder
    #
    # Starts returning the contents of a folder.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListFolder < Choreography

      ####
      #  Create a new instance of the ListFolder Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/ListFolder")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListFolderInputSet
      ####
      def new_input_set()
        return ListFolderInputSet.new()
      end

      def make_result_set()
        return ListFolderResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListFolderResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListFolder
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListFolderInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the IncludeDeleted input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true, the results will include entries for files and folders that used to exist but were deleted. The default for this field is false.
        ###

        def set_IncludeDeleted(value)
          set_input("IncludeDeleted", value)
        end
        #### 
        # Set the value of the IncludeHasExplicitSharedMembers input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true, the results will include a flag for each file indicating whether or not that file has any explicit members. The default for this field is false.
        ###

        def set_IncludeHasExplicitSharedMembers(value)
          set_input("IncludeHasExplicitSharedMembers", value)
        end
        #### 
        # Set the value of the IncludeMediaInfo input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true, FileMetadata.media_info is set for photo and video. The default for this field is false.
        ###

        def set_IncludeMediaInfo(value)
          set_input("IncludeMediaInfo", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) The path to the folder you want to see the contents of. This should be empty to list contents at the root level.
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the Recursive input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true, the list folder operation will be applied recursively to all subfolders and the response will contain contents of all subfolders. The default for this field is false.
        ###

        def set_Recursive(value)
          set_input("Recursive", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListFolder Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListFolderResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Cursor" output from this Choreo execution
      	#
      	# @return String - (string) A cursor used to retrieve the next set of results with ListFolderContinue.
      	####
      	def get_Cursor()
      	  return @outputs["Cursor"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Dropbox.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListFolder



    ##############################################################################
    #
    # ListFolderContinue
    #
    # Once a cursor has been retrieved from ListFolder, use this to paginate through all files and retrieve updates to the folder.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListFolderContinue < Choreography

      ####
      #  Create a new instance of the ListFolderContinue Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/ListFolderContinue")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListFolderContinueInputSet
      ####
      def new_input_set()
        return ListFolderContinueInputSet.new()
      end

      def make_result_set()
        return ListFolderContinueResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListFolderContinueResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListFolderContinue
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListFolderContinueInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the Cursor input for this Choreo. 
        # 
        # @param String - (required, string) A cursor used to retrieve the next set of results.
        ###

        def set_Cursor(value)
          set_input("Cursor", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListFolderContinue Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListFolderContinueResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "LatestCursor" output from this Choreo execution
      	#
      	# @return String - (string) The latest cursor which can be used to retrieve the next set of results.
      	####
      	def get_LatestCursor()
      	  return @outputs["LatestCursor"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Dropbox.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListFolderContinue



    ##############################################################################
    #
    # ListRevisions
    #
    # Returns revisions of a file.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListRevisions < Choreography

      ####
      #  Create a new instance of the ListRevisions Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/ListRevisions")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListRevisionsInputSet
      ####
      def new_input_set()
        return ListRevisionsInputSet.new()
      end

      def make_result_set()
        return ListRevisionsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListRevisionsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListRevisions
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListRevisionsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the Limit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The number of revisions to return. The default for this field is 10.
        ###

        def set_Limit(value)
          set_input("Limit", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (conditional, string) The path to the file you want to see the revisions of.
        ###

        def set_Path(value)
          set_input("Path", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListRevisions Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListRevisionsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Dropbox.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListRevisions



    ##############################################################################
    #
    # Move
    #
    # Moves a file or folder to a different location in the user's Dropbox.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Move < Choreography

      ####
      #  Create a new instance of the Move Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/Move")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return MoveInputSet
      ####
      def new_input_set()
        return MoveInputSet.new()
      end

      def make_result_set()
        return MoveResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = MoveResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Move
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class MoveInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AllowSharedFolder input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true, contents are copied into a shared folder, otherwise an error will be returned if the FromPath contains a shared folder. The default for this field is false.
        ###

        def set_AllowSharedFolder(value)
          set_input("AllowSharedFolder", value)
        end
        #### 
        # Set the value of the AutoRename input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If there's a conflict, have the Dropbox server try to autorename the file to avoid the conflict. The default for this field is false.
        ###

        def set_AutoRename(value)
          set_input("AutoRename", value)
        end
        #### 
        # Set the value of the FromPath input for this Choreo. 
        # 
        # @param String - (required, string) Path in the user's Dropbox to be copied or moved.
        ###

        def set_FromPath(value)
          set_input("FromPath", value)
        end
        #### 
        # Set the value of the ToPath input for this Choreo. 
        # 
        # @param String - (required, string) Path in the user's Dropbox that is the destination.
        ###

        def set_ToPath(value)
          set_input("ToPath", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Move Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class MoveResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Dropbox.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Move



    ##############################################################################
    #
    # Restore
    #
    # Restores a file to a specific revision.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Restore < Choreography

      ####
      #  Create a new instance of the Restore Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/Restore")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RestoreInputSet
      ####
      def new_input_set()
        return RestoreInputSet.new()
      end

      def make_result_set()
        return RestoreResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RestoreResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Restore
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RestoreInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (conditional, string) The path to the file you want to see the revisions of.
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the Revision input for this Choreo. 
        # 
        # @param String - (required, string) The number of revisions to return. The default for this field is 10.
        ###

        def set_Revision(value)
          set_input("Revision", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Restore Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RestoreResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Dropbox.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Restore



    ##############################################################################
    #
    # Search
    #
    # Searches for files and folders.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Search < Choreography

      ####
      #  Create a new instance of the Search Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/Search")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return SearchInputSet
      ####
      def new_input_set()
        return SearchInputSet.new()
      end

      def make_result_set()
        return SearchResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = SearchResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Search
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class SearchInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the MaxResults input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) The maximum number of search results to return. The default for this field is 100.
        ###

        def set_MaxResults(value)
          set_input("MaxResults", value)
        end
        #### 
        # Set the value of the Mode input for this Choreo. 
        # 
        # @param String - (optional, string) The search mode (filename, filename_and_content, or deleted_filename). Note that searching file content is only available for Dropbox Business accounts. The default for this union is filename.
        ###

        def set_Mode(value)
          set_input("Mode", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (conditional, string) Path in the user's Dropbox to search. This should be empty to search at the root level.
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the Query input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) The string to search for. 
        ###

        def set_Query(value)
          set_input("Query", value)
        end
        #### 
        # Set the value of the Start input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The starting index within the search results (used for paging). The default for this field is 0.
        ###

        def set_Start(value)
          set_input("Start", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Search Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class SearchResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Dropbox.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Search



    ##############################################################################
    #
    # Upload
    #
    # Creates a new file with the contents provided in the request.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Upload < Choreography

      ####
      #  Create a new instance of the Upload Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/Upload")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UploadInputSet
      ####
      def new_input_set()
        return UploadInputSet.new()
      end

      def make_result_set()
        return UploadResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UploadResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Upload
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UploadInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AutoRename input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If there's a conflict, as determined by mode, have the Dropbox server try to autorename the file to avoid conflict. The default for this field is false.
        ###

        def set_AutoRename(value)
          set_input("AutoRename", value)
        end
        #### 
        # Set the value of the ContentType input for this Choreo. 
        # 
        # @param String - (optional, string) The content type of the file being uploaded. Defaults to application/octet-stream.
        ###

        def set_ContentType(value)
          set_input("ContentType", value)
        end
        #### 
        # Set the value of the FileContent input for this Choreo. 
        # 
        # @param String - (conditional, string) The Base64-encoded file content of the file you want to upload. Required unless uploading a file from a URL using the FileURL input. Encoding is not required when ContentType is set to "text/plain".
        ###

        def set_FileContent(value)
          set_input("FileContent", value)
        end
        #### 
        # Set the value of the FileURL input for this Choreo. 
        # 
        # @param String - (optional, string) The public URL for file you want to upload. This can be used as an alternative to uploading Base64 encoded data.
        ###

        def set_FileURL(value)
          set_input("FileURL", value)
        end
        #### 
        # Set the value of the Mode input for this Choreo. 
        # 
        # @param String - (optional, string) Selects what to do if the file already exists. Valid values are: add (default), overwrite, and update.
        ###

        def set_Mode(value)
          set_input("Mode", value)
        end
        #### 
        # Set the value of the Mute input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true, this tells the clients that this modification shouldn't result in a user notification. The default for this field is false.
        ###

        def set_Mute(value)
          set_input("Mute", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) Path in the user's Dropbox to save the file, including the filename.
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the Revision input for this Choreo. 
        # 
        # @param String - (optional, string) The revision identifier. Used only when Mode is set to "update".
        ###

        def set_Revision(value)
          set_input("Revision", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Upload Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UploadResultSet < Choreography::ResultSet
      end

    end # class Upload



    ##############################################################################
    #
    # UploadSessionAppend
    #
    # Appends more data to an upload session.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UploadSessionAppend < Choreography

      ####
      #  Create a new instance of the UploadSessionAppend Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/UploadSessionAppend")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UploadSessionAppendInputSet
      ####
      def new_input_set()
        return UploadSessionAppendInputSet.new()
      end

      def make_result_set()
        return UploadSessionAppendResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UploadSessionAppendResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UploadSessionAppend
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UploadSessionAppendInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the Close input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true, the current session will be closed, at which point you won't be able to call UploadSessionAppend anymore with the current session. The default for this field is false.
        ###

        def set_Close(value)
          set_input("Close", value)
        end
        #### 
        # Set the value of the ContentType input for this Choreo. 
        # 
        # @param String - (optional, string) The content type of the file being uploaded. Defaults to application/octet-stream.
        ###

        def set_ContentType(value)
          set_input("ContentType", value)
        end
        #### 
        # Set the value of the FileContent input for this Choreo. 
        # 
        # @param String - (conditional, string) The next file segment to upload. Binary files should be Base64-encoded. Encoding is not required when ContentType is set to "text/plain".
        ###

        def set_FileContent(value)
          set_input("FileContent", value)
        end
        #### 
        # Set the value of the Offset input for this Choreo. 
        # 
        # @param Integer - (required, integer) The amount of data that has been uploaded so far.
        ###

        def set_Offset(value)
          set_input("Offset", value)
        end
        #### 
        # Set the value of the SessionID input for this Choreo. 
        # 
        # @param String - (conditional, string) The upload session ID returned from UploadSessionStart.
        ###

        def set_SessionID(value)
          set_input("SessionID", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UploadSessionAppend Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UploadSessionAppendResultSet < Choreography::ResultSet
      end

    end # class UploadSessionAppend



    ##############################################################################
    #
    # UploadSessionFinish
    #
    # Finishes an upload session and save the uploaded data to the given file path.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UploadSessionFinish < Choreography

      ####
      #  Create a new instance of the UploadSessionFinish Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/UploadSessionFinish")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UploadSessionFinishInputSet
      ####
      def new_input_set()
        return UploadSessionFinishInputSet.new()
      end

      def make_result_set()
        return UploadSessionFinishResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UploadSessionFinishResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UploadSessionFinish
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UploadSessionFinishInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AutoRename input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If there's a conflict, as determined by mode, have the Dropbox server try to autorename the file to avoid conflict. The default for this field is false.
        ###

        def set_AutoRename(value)
          set_input("AutoRename", value)
        end
        #### 
        # Set the value of the ContentType input for this Choreo. 
        # 
        # @param String - (optional, string) The content type of the file being uploaded. Defaults to application/octet-stream.
        ###

        def set_ContentType(value)
          set_input("ContentType", value)
        end
        #### 
        # Set the value of the FileContent input for this Choreo. 
        # 
        # @param String - (conditional, string) The remaining file content. Encoding is not required when ContentType is set to "text/plain". This can be left empty if the last file chunk was sent using UploadSessionAppend.
        ###

        def set_FileContent(value)
          set_input("FileContent", value)
        end
        #### 
        # Set the value of the Mode input for this Choreo. 
        # 
        # @param String - (optional, string) Selects what to do if the file already exists. Valid values are: add (default), overwrite, and update.
        ###

        def set_Mode(value)
          set_input("Mode", value)
        end
        #### 
        # Set the value of the Mute input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true, this tells the clients that this modification shouldn't result in a user notification. The default for this field is false.
        ###

        def set_Mute(value)
          set_input("Mute", value)
        end
        #### 
        # Set the value of the Offset input for this Choreo. 
        # 
        # @param Integer - (required, integer) The amount of data that has been uploaded so far.
        ###

        def set_Offset(value)
          set_input("Offset", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) Path in the user's Dropbox to save the file.
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the Revision input for this Choreo. 
        # 
        # @param String - (optional, string) The revision identifier. Used only when Mode is set to "update".
        ###

        def set_Revision(value)
          set_input("Revision", value)
        end
        #### 
        # Set the value of the SessionID input for this Choreo. 
        # 
        # @param String - (required, string) The upload session ID returned from UploadSessionStart.
        ###

        def set_SessionID(value)
          set_input("SessionID", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UploadSessionFinish Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UploadSessionFinishResultSet < Choreography::ResultSet
      end

    end # class UploadSessionFinish



    ##############################################################################
    #
    # UploadSessionStart
    #
    # Allows you to upload a single file in one or more requests. This call starts a new upload session with the first chunk of data.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UploadSessionStart < Choreography

      ####
      #  Create a new instance of the UploadSessionStart Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Files/UploadSessionStart")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UploadSessionStartInputSet
      ####
      def new_input_set()
        return UploadSessionStartInputSet.new()
      end

      def make_result_set()
        return UploadSessionStartResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UploadSessionStartResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UploadSessionStart
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UploadSessionStartInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the Close input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true, the current session will be closed, at which point you won't be able to call UploadSessionAppend anymore with the current session. The default for this field is false.
        ###

        def set_Close(value)
          set_input("Close", value)
        end
        #### 
        # Set the value of the ContentType input for this Choreo. 
        # 
        # @param String - (optional, string) The content type of the file being uploaded. Defaults to application/octet-stream.
        ###

        def set_ContentType(value)
          set_input("ContentType", value)
        end
        #### 
        # Set the value of the FileContent input for this Choreo. 
        # 
        # @param String - (conditional, string) The first file segment to upload. Binary files should be Base64-encoded. Encoding is not required when ContentType is set to "text/plain".
        ###

        def set_FileContent(value)
          set_input("FileContent", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UploadSessionStart Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UploadSessionStartResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "SessionID" output from this Choreo execution
      	#
      	# @return String - (string) The upload session ID that can be used to append to the upload or finish the upload.
      	####
      	def get_SessionID()
      	  return @outputs["SessionID"]
      	end
      end

    end # class UploadSessionStart




  end # module Files

  module FilesAndMetadata



    ##############################################################################
    #
    # ChunkedUpload
    #
    # Uploads larger files to Dropbox in multiple chunks, and offers a way to resume if an upload gets interrupted.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ChunkedUpload < Choreography

      ####
      #  Create a new instance of the ChunkedUpload Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FilesAndMetadata/ChunkedUpload")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ChunkedUploadInputSet
      ####
      def new_input_set()
        return ChunkedUploadInputSet.new()
      end

      def make_result_set()
        return ChunkedUploadResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ChunkedUploadResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ChunkedUpload
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ChunkedUploadInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the Chunk input for this Choreo. 
        # 
        # @param String - (conditional, string) A Base64 encoded chunk of data from the file being uploaded. If resuming and upload, the chunk should begin at the number of bytes into the file that equals the NextOffset.
        ###

        def set_Chunk(value)
          set_input("Chunk", value)
        end
        #### 
        # Set the value of the Offset input for this Choreo. 
        # 
        # @param String - (conditional, string) The byte offset of this chunk, relative to the beginning of the full file. This is not required when uploading the first chunk of a file.
        ###

        def set_Offset(value)
          set_input("Offset", value)
        end
        #### 
        # Set the value of the UploadID input for this Choreo. 
        # 
        # @param String - (conditional, string) The ID of the upload session returned after uploading the initial file chunk. This is not required when uploading the first chunk of a file. This value is returned in the UploadSessionID output.
        ###

        def set_UploadID(value)
          set_input("UploadID", value)
        end
        #### 
        # Set the value of the VaultFile input for this Choreo. 
        # 
        # @param TembooPath - (optional, vault file) The path to a vault file you want to upload. Required unless using the FileContents input.
        ###

        def set_VaultFile(value)
          set_alias("VaultFile", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ChunkedUpload Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ChunkedUploadResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Expires" output from this Choreo execution
      	#
      	# @return String - (string) The expiration time of the upload.
      	####
      	def get_Expires()
      	  return @outputs["Expires"]
      	end
      	####
      	# Retrieve the value for the "NextOffset" output from this Choreo execution
      	#
      	# @return String - (string) The current byte offset that the server will expect. This value can be passed to the Offset input on subsequent requests when uploading chunks repeatedly.
      	####
      	def get_NextOffset()
      	  return @outputs["NextOffset"]
      	end
      	####
      	# Retrieve the value for the "UploadSessionID" output from this Choreo execution
      	#
      	# @return String - (string) The upload ID returned after uploading an initial file chunk. This can be passed to the UploadID input for uploading subsequent chunks, and finally to the CommitChunkedUpload Choreo.
      	####
      	def get_UploadSessionID()
      	  return @outputs["UploadSessionID"]
      	end
      end

    end # class ChunkedUpload



    ##############################################################################
    #
    # CommitChunkedUpload
    #
    # Completes an upload initiated by the ChunkedUpload Choreo.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CommitChunkedUpload < Choreography

      ####
      #  Create a new instance of the CommitChunkedUpload Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FilesAndMetadata/CommitChunkedUpload")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CommitChunkedUploadInputSet
      ####
      def new_input_set()
        return CommitChunkedUploadInputSet.new()
      end

      def make_result_set()
        return CommitChunkedUploadResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CommitChunkedUploadResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CommitChunkedUpload
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CommitChunkedUploadInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the Locale input for this Choreo. 
        # 
        # @param String - (optional, string) The metadata returned on successful upload will have its size field translated based on the given locale.
        ###

        def set_Locale(value)
          set_input("Locale", value)
        end
        #### 
        # Set the value of the Overwrite input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Indicates what happens when a file already exists at the specified path. If true (the default), the existing file will be overwritten. If false, the new file will be automatically renamed.
        ###

        def set_Overwrite(value)
          set_input("Overwrite", value)
        end
        #### 
        # Set the value of the ParentRevision input for this Choreo. 
        # 
        # @param String - (optional, string) The revision of the file you're editing. If this value matches the latest version of the file on the user's Dropbox, that file will be replaced, otherwise a new file will be created.
        ###

        def set_ParentRevision(value)
          set_input("ParentRevision", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) The path to the file you want to write to (i.e. /RootFolder/SubFolder/MyFile.txt).
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Root input for this Choreo. 
        # 
        # @param String - (optional, string) Defaults to "auto" which automatically determines the root folder using your app's permission level. Other options are "sandbox" (App Folder) and "dropbox" (Full Dropbox).
        ###

        def set_Root(value)
          set_input("Root", value)
        end
        #### 
        # Set the value of the UploadID input for this Choreo. 
        # 
        # @param String - (required, string) Used to identify the chunked upload session you'd like to commit. This is returned from the ChunkedUpload Choreo.
        ###

        def set_UploadID(value)
          set_input("UploadID", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CommitChunkedUpload Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CommitChunkedUploadResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CommitChunkedUpload



    ##############################################################################
    #
    # CreateCopyRef
    #
    # Allows you to create a copy reference (copy_ref) that you can later reference to copy files or folders to another user's Dropbox using the CopyFileOrFolder choreo. 
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateCopyRef < Choreography

      ####
      #  Create a new instance of the CreateCopyRef Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FilesAndMetadata/CreateCopyRef")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateCopyRefInputSet
      ####
      def new_input_set()
        return CreateCopyRefInputSet.new()
      end

      def make_result_set()
        return CreateCopyRefResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateCopyRefResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateCopyRef
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateCopyRefInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) The path to the file you want to make available as a copy reference, i.e.  "testfile.txt" or "/Folder/testfile.txt".
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Root input for this Choreo. 
        # 
        # @param String - (optional, string) Defaults to "auto" which automatically determines the root folder using your app's permission level. Other options are "sandbox" (App Folder) and "dropbox" (Full Dropbox).
        ###

        def set_Root(value)
          set_input("Root", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateCopyRef Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateCopyRefResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateCopyRef



    ##############################################################################
    #
    # Delta
    #
    # Allows you keep up with changes to files and folders in a user's Dropbox.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Delta < Choreography

      ####
      #  Create a new instance of the Delta Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FilesAndMetadata/Delta")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeltaInputSet
      ####
      def new_input_set()
        return DeltaInputSet.new()
      end

      def make_result_set()
        return DeltaResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeltaResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Delta
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeltaInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the Cursor input for this Choreo. 
        # 
        # @param String - (optional, string) A string that is used to keep track of your current state. On the next call pass in this value to return delta entries that have been recorded since the cursor was returned.
        ###

        def set_Cursor(value)
          set_input("Cursor", value)
        end
        #### 
        # Set the value of the IncludeMediaInfo input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If set to true, each file will include a photo_info dictionary for photos and a video_info dictionary for videos with additional media info.
        ###

        def set_IncludeMediaInfo(value)
          set_input("IncludeMediaInfo", value)
        end
        #### 
        # Set the value of the Locale input for this Choreo. 
        # 
        # @param String - (optional, string) The metadata returned will have its size field translated based on the given locale.
        ###

        def set_Locale(value)
          set_input("Locale", value)
        end
        #### 
        # Set the value of the PathPrefix input for this Choreo. 
        # 
        # @param String - (optional, string) Filters the response to only include entries at or under the specified path.
        ###

        def set_PathPrefix(value)
          set_input("PathPrefix", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Delta Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeltaResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Delta



    ##############################################################################
    #
    # GetDownloadLink
    #
    # Retrieves a direct download link allowing an application to stream the contents of the media.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetDownloadLink < Choreography

      ####
      #  Create a new instance of the GetDownloadLink Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FilesAndMetadata/GetDownloadLink")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetDownloadLinkInputSet
      ####
      def new_input_set()
        return GetDownloadLinkInputSet.new()
      end

      def make_result_set()
        return GetDownloadLinkResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetDownloadLinkResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetDownloadLink
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetDownloadLinkInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) The path to the file or folder you want to return a download link for (i.e. /RootFolder/SubFolder/MyFile.txt).
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Root input for this Choreo. 
        # 
        # @param String - (optional, string) Defaults to "auto" which automatically determines the root folder using your app's permission level. Other options are "sandbox" (App Folder) and "dropbox" (Full Dropbox).
        ###

        def set_Root(value)
          set_input("Root", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetDownloadLink Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetDownloadLinkResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "URL" output from this Choreo execution
      	#
      	# @return String - (string) The file's download URL.
      	####
      	def get_URL()
      	  return @outputs["URL"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetDownloadLink



    ##############################################################################
    #
    # GetFile
    #
    # Gets the content and metadata for a specified file.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetFile < Choreography

      ####
      #  Create a new instance of the GetFile Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FilesAndMetadata/GetFile")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetFileInputSet
      ####
      def new_input_set()
        return GetFileInputSet.new()
      end

      def make_result_set()
        return GetFileResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetFileResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetFile
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetFileInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the EncodeFileContent input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) File content is returned as Base64 encoded data by default. Text files can be returned as Base64 decoded by setting this input to "false". Note that binary files should always be Base64 encoded.
        ###

        def set_EncodeFileContent(value)
          set_input("EncodeFileContent", value)
        end
        #### 
        # Set the value of the IncludeMetadata input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If set to true, metadata about the file is returned. Defaults to false, indicating that only the file content is returned.
        ###

        def set_IncludeMetadata(value)
          set_input("IncludeMetadata", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) The path to file you want to retrieve (i.e. RootFolder/SubFolder/MyFile.txt). Only the file name is necessary when the file is at the root level.
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the Root input for this Choreo. 
        # 
        # @param String - (optional, string) Defaults to "auto" which automatically determines the root folder using your app's permission level. Other options are "sandbox" (App Folder) and "dropbox" (Full Dropbox).
        ###

        def set_Root(value)
          set_input("Root", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetFile Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetFileResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "FileMetadata" output from this Choreo execution
      	#
      	# @return String - (json) The metadata for the file. This only returned when IncludeMetadata is set to true.
      	####
      	def get_FileMetadata()
      	  return @outputs["FileMetadata"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (string) The response from Dropbox. The response will contain the contents of the file you are retrieving as Base64 encoded data.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetFile



    ##############################################################################
    #
    # GetFileRevisions
    #
    # Retrieves metadata for the previous revisions of a file
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetFileRevisions < Choreography

      ####
      #  Create a new instance of the GetFileRevisions Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FilesAndMetadata/GetFileRevisions")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetFileRevisionsInputSet
      ####
      def new_input_set()
        return GetFileRevisionsInputSet.new()
      end

      def make_result_set()
        return GetFileRevisionsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetFileRevisionsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetFileRevisions
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetFileRevisionsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) The path to the file that you want to return revisions for (i.e. /RootFolder/SubFolder/MyFile.txt).
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the RevisionLimit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Default is 10. Max is 1,000. When listing a file, the service will not report listings containing more than the amount specified here.
        ###

        def set_RevisionLimit(value)
          set_input("RevisionLimit", value)
        end
        #### 
        # Set the value of the Root input for this Choreo. 
        # 
        # @param String - (optional, string) Defaults to "auto" which automatically determines the root folder using your app's permission level. Other options are "sandbox" (App Folder) and "dropbox" (Full Dropbox).
        ###

        def set_Root(value)
          set_input("Root", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetFileRevisions Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetFileRevisionsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetFileRevisions



    ##############################################################################
    #
    # GetShareableLink
    #
    # Retrieves a shareable link to files or folders.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetShareableLink < Choreography

      ####
      #  Create a new instance of the GetShareableLink Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FilesAndMetadata/GetShareableLink")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetShareableLinkInputSet
      ####
      def new_input_set()
        return GetShareableLinkInputSet.new()
      end

      def make_result_set()
        return GetShareableLinkResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetShareableLinkResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetShareableLink
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetShareableLinkInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) The path to the file or folder you want to return a shareable link for (i.e. /RootFolder/SubFolder/MyFile.txt).
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Root input for this Choreo. 
        # 
        # @param String - (optional, string) Defaults to "auto" which automatically determines the root folder using your app's permission level. Other options are "sandbox" (App Folder) and "dropbox" (Full Dropbox).
        ###

        def set_Root(value)
          set_input("Root", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetShareableLink Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetShareableLinkResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetShareableLink



    ##############################################################################
    #
    # GetThumbnail
    #
    # Retrieves a thumbnail for a specified image.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetThumbnail < Choreography

      ####
      #  Create a new instance of the GetThumbnail Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FilesAndMetadata/GetThumbnail")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetThumbnailInputSet
      ####
      def new_input_set()
        return GetThumbnailInputSet.new()
      end

      def make_result_set()
        return GetThumbnailResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetThumbnailResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetThumbnail
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetThumbnailInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the ImageFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The thumbnail format to return for the specified image. Accepted values are: jpeg (default) or png.
        ###

        def set_ImageFormat(value)
          set_input("ImageFormat", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) The path to the file that you want to generate a thumbnail for (i.e. /RootFolder/SubFolder/MyFile.txt).
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the Root input for this Choreo. 
        # 
        # @param String - (optional, string) Defaults to "auto" which automatically determines the root folder using your app's permission level. Other options are "sandbox" (App Folder) and "dropbox" (Full Dropbox).
        ###

        def set_Root(value)
          set_input("Root", value)
        end
        #### 
        # Set the value of the Size input for this Choreo. 
        # 
        # @param String - (optional, string) The size of the thumbnail to generate. Accepted values are: small, medium, s, m, l, xl. See Choreo documentation for exact dimensions. Defaults to "small".
        ###

        def set_Size(value)
          set_input("Size", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetThumbnail Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetThumbnailResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (string) The base64 encoded image content of the thumbnail.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetThumbnail



    ##############################################################################
    #
    # LatestCursor
    #
    # Allows you to quickly get a cursor for the server's state, for use with the Delta Choreo.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class LatestCursor < Choreography

      ####
      #  Create a new instance of the LatestCursor Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FilesAndMetadata/LatestCursor")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return LatestCursorInputSet
      ####
      def new_input_set()
        return LatestCursorInputSet.new()
      end

      def make_result_set()
        return LatestCursorResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = LatestCursorResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the LatestCursor
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class LatestCursorInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the IncludeMediaInfo input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true, the returned cursor will be encoded with include_media_info set to true for use with the Delta Choreo.
        ###

        def set_IncludeMediaInfo(value)
          set_input("IncludeMediaInfo", value)
        end
        #### 
        # Set the value of the PathPrefix input for this Choreo. 
        # 
        # @param String - (optional, string) If present, the returned cursor will be encoded with a path_prefix for the specified path for use with the Delta Choreo.
        ###

        def set_PathPrefix(value)
          set_input("PathPrefix", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the LatestCursor Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class LatestCursorResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class LatestCursor



    ##############################################################################
    #
    # ListFolderContents
    #
    # Retrieves metadata (including folder contents) for a folder or file in Dropbox.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListFolderContents < Choreography

      ####
      #  Create a new instance of the ListFolderContents Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FilesAndMetadata/ListFolderContents")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListFolderContentsInputSet
      ####
      def new_input_set()
        return ListFolderContentsInputSet.new()
      end

      def make_result_set()
        return ListFolderContentsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListFolderContentsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListFolderContents
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListFolderContentsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the FileLimit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Dropbox will not return a list that exceeds this specified limit. Defaults to 10,000.
        ###

        def set_FileLimit(value)
          set_input("FileLimit", value)
        end
        #### 
        # Set the value of the Folder input for this Choreo. 
        # 
        # @param String - (optional, string) The path to a folder for which to retrieve metadata (i.e. /RootFolder/SubFolder). Note that a path to file can also be passed.
        ###

        def set_Folder(value)
          set_input("Folder", value)
        end
        #### 
        # Set the value of the Hash input for this Choreo. 
        # 
        # @param String - (optional, string) The value of a hash field from a previous request to get metadata on a folder. When provided, a 304 (not Modified) status code is returned instead of a folder listing if no changes have been made.
        ###

        def set_Hash(value)
          set_input("Hash", value)
        end
        #### 
        # Set the value of the IncludeDeleted input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Only applicable when List is set. If this parameter is set to true, contents will include the metadata of deleted children.
        ###

        def set_IncludeDeleted(value)
          set_input("IncludeDeleted", value)
        end
        #### 
        # Set the value of the List input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If true (the default), the folder's metadata will include a contents field with a list of metadata entries for the contents of the folder.
        ###

        def set_List(value)
          set_input("List", value)
        end
        #### 
        # Set the value of the Locale input for this Choreo. 
        # 
        # @param String - (optional, string) If your app supports any language other than English, insert the appropriate IETF language tag, and the metadata returned will have its size field translated based on the given locale (e.g., pt-BR).
        ###

        def set_Locale(value)
          set_input("Locale", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Revision input for this Choreo. 
        # 
        # @param String - (optional, string) When including a particular revision number, only the metadata for that revision will be returned.
        ###

        def set_Revision(value)
          set_input("Revision", value)
        end
        #### 
        # Set the value of the Root input for this Choreo. 
        # 
        # @param String - (optional, string) Defaults to "auto" which automatically determines the root folder using your app's permission level. Other options are "sandbox" (App Folder) and "dropbox" (Full Dropbox).
        ###

        def set_Root(value)
          set_input("Root", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListFolderContents Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListFolderContentsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ResponseStatusCode" output from this Choreo execution
      	#
      	# @return String - (integer) The response status code returned from Dropbox.
      	####
      	def get_ResponseStatusCode()
      	  return @outputs["ResponseStatusCode"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListFolderContents



    ##############################################################################
    #
    # LongPollDelta
    #
    # Used in conjunction with the Delta Choreo, this allows you to perform a long-poll request to wait for changes on an account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class LongPollDelta < Choreography

      ####
      #  Create a new instance of the LongPollDelta Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FilesAndMetadata/LongPollDelta")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return LongPollDeltaInputSet
      ####
      def new_input_set()
        return LongPollDeltaInputSet.new()
      end

      def make_result_set()
        return LongPollDeltaResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = LongPollDeltaResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the LongPollDelta
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class LongPollDeltaInputSet < Choreography::InputSet

        #### 
        # Set the value of the Cursor input for this Choreo. 
        # 
        # @param String - (required, string) A delta cursor as returned from a call to the Delta Choreo.
        ###

        def set_Cursor(value)
          set_input("Cursor", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Timeout input for this Choreo. 
        # 
        # @param String - (optional, string) An integer indicating the amount of time, in seconds, to wait for a response. The default value is 30 seconds, which is also the minimum allowed value. The maximum is 480 seconds.
        ###

        def set_Timeout(value)
          set_input("Timeout", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the LongPollDelta Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class LongPollDeltaResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class LongPollDelta



    ##############################################################################
    #
    # RestoreFileToRevision
    #
    # Restores a specified file to a previous revision.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RestoreFileToRevision < Choreography

      ####
      #  Create a new instance of the RestoreFileToRevision Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FilesAndMetadata/RestoreFileToRevision")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RestoreFileToRevisionInputSet
      ####
      def new_input_set()
        return RestoreFileToRevisionInputSet.new()
      end

      def make_result_set()
        return RestoreFileToRevisionResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RestoreFileToRevisionResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RestoreFileToRevision
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RestoreFileToRevisionInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) The path to the file that you want to return revisions for (i.e. /RootFolder/SubFolder/MyFile.txt).
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Revision input for this Choreo. 
        # 
        # @param String - (required, string) The revision of the file to restore. The revision ID can be retrieved by running the GetFileRevision Choreo.
        ###

        def set_Revision(value)
          set_input("Revision", value)
        end
        #### 
        # Set the value of the Root input for this Choreo. 
        # 
        # @param String - (optional, string) Defaults to "auto" which automatically determines the root folder using your app's permission level. Other options are "sandbox" (App Folder) and "dropbox" (Full Dropbox).
        ###

        def set_Root(value)
          set_input("Root", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RestoreFileToRevision Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RestoreFileToRevisionResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class RestoreFileToRevision



    ##############################################################################
    #
    # SearchFilesAndFolders
    #
    # Allows you to search Dropbox for files or folders by a keyword search.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class SearchFilesAndFolders < Choreography

      ####
      #  Create a new instance of the SearchFilesAndFolders Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FilesAndMetadata/SearchFilesAndFolders")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return SearchFilesAndFoldersInputSet
      ####
      def new_input_set()
        return SearchFilesAndFoldersInputSet.new()
      end

      def make_result_set()
        return SearchFilesAndFoldersResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = SearchFilesAndFoldersResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the SearchFilesAndFolders
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class SearchFilesAndFoldersInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the FileLimit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Dropbox will not return a list that exceeds this specified limit. Defaults to 10,000.
        ###

        def set_FileLimit(value)
          set_input("FileLimit", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (optional, string) The path to the folder you want to search from (i.e. /RootFolder/SubFolder). Leave blank to search ALL.
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the Query input for this Choreo. 
        # 
        # @param String - (required, string) The search string. Must be at least three characters long.
        ###

        def set_Query(value)
          set_input("Query", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Root input for this Choreo. 
        # 
        # @param String - (optional, string) Defaults to "auto" which automatically determines the root folder using your app's permission level. Other options are "sandbox" (App Folder) and "dropbox" (Full Dropbox).
        ###

        def set_Root(value)
          set_input("Root", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the SearchFilesAndFolders Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class SearchFilesAndFoldersResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class SearchFilesAndFolders



    ##############################################################################
    #
    # UploadFile
    #
    # Uploads a file to your Dropbox account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UploadFile < Choreography

      ####
      #  Create a new instance of the UploadFile Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/FilesAndMetadata/UploadFile")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UploadFileInputSet
      ####
      def new_input_set()
        return UploadFileInputSet.new()
      end

      def make_result_set()
        return UploadFileResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UploadFileResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UploadFile
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UploadFileInputSet < Choreography::InputSet

        #### 
        # Set the value of the FileContents input for this Choreo. 
        # 
        # @param String - (conditional, string) The Base64-encoded contents of the file you want to upload. Required UNLESS uploading a file from a URL using the FileContentsFromURL input variable.
        ###

        def set_FileContents(value)
          set_input("FileContents", value)
        end
        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the FileContentsFromURL input for this Choreo. 
        # 
        # @param String - (conditional, string) URL for file you want to upload. Alternative to uploading Base64Encoded data. If specifiying URL, leave FileContents blank. Valid URLs: http(s) requests only.
        ###

        def set_FileContentsFromURL(value)
          set_input("FileContentsFromURL", value)
        end
        #### 
        # Set the value of the FileName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the file you are uploading to Dropbox.
        ###

        def set_FileName(value)
          set_input("FileName", value)
        end
        #### 
        # Set the value of the Folder input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the folder that that you want to upload a file to. A path to a sub-folder is also valid (i.e. /RootFolder/SubFolder).
        ###

        def set_Folder(value)
          set_input("Folder", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Root input for this Choreo. 
        # 
        # @param String - (optional, string) Defaults to "auto" which automatically determines the root folder using your app's permission level. Other options are "sandbox" (App Folder) and "dropbox" (Full Dropbox).
        ###

        def set_Root(value)
          set_input("Root", value)
        end
        #### 
        # Set the value of the VaultFile input for this Choreo. 
        # 
        # @param TembooPath - (optional, vault file) The path to a vault file you want to upload. Required unless using the FileContents input.
        ###

        def set_VaultFile(value)
          set_alias("VaultFile", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UploadFile Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UploadFileResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Dropbox. Corresponds to the ResponseFormat input. Defaults to json.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UploadFile




  end # module FilesAndMetadata

  module OAuth



    ##############################################################################
    #
    # FinalizeOAuth
    #
    # Completes the OAuth process by retrieving a Dropbox access token and access token secret for a user, after they have visited the authorization URL returned by the InitializeOAuth choreo and clicked "allow."
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class FinalizeOAuth < Choreography

      ####
      #  Create a new instance of the FinalizeOAuth Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/OAuth/FinalizeOAuth")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return FinalizeOAuthInputSet
      ####
      def new_input_set()
        return FinalizeOAuthInputSet.new()
      end

      def make_result_set()
        return FinalizeOAuthResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = FinalizeOAuthResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the FinalizeOAuth
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class FinalizeOAuthInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccountName input for this Choreo. 
        # 
        # @param String - (optional, string) Deprecated (retained for backward compatibility only).
        ###

        def set_AccountName(value)
          set_input("AccountName", value)
        end
        #### 
        # Set the value of the AppKeyName input for this Choreo. 
        # 
        # @param String - (optional, string) Deprecated (retained for backward compatibility only).
        ###

        def set_AppKeyName(value)
          set_input("AppKeyName", value)
        end
        #### 
        # Set the value of the AppKeyValue input for this Choreo. 
        # 
        # @param String - (optional, string) Deprecated (retained for backward compatibility only).
        ###

        def set_AppKeyValue(value)
          set_input("AppKeyValue", value)
        end
        #### 
        # Set the value of the CallbackID input for this Choreo. 
        # 
        # @param String - (required, string) The callback token returned by the InitializeOAuth Choreo. Used to retrieve the callback data after the user authorizes.
        ###

        def set_CallbackID(value)
          set_input("CallbackID", value)
        end
        #### 
        # Set the value of the DropboxAppKey input for this Choreo. 
        # 
        # @param String - (required, string) The APP Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_DropboxAppKey(value)
          set_input("DropboxAppKey", value)
        end
        #### 
        # Set the value of the DropboxAppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_DropboxAppSecret(value)
          set_input("DropboxAppSecret", value)
        end
        #### 
        # Set the value of the OAuthTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The OAuthTokenSecret returned by the InitializeOAuth Choreo.
        ###

        def set_OAuthTokenSecret(value)
          set_input("OAuthTokenSecret", value)
        end
        #### 
        # Set the value of the SuppressErrors input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to true, errors received during the OAuth redirect process will be suppressed and returned in the ErrorMessage output.
        ###

        def set_SuppressErrors(value)
          set_input("SuppressErrors", value)
        end
        #### 
        # Set the value of the Timeout input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The amount of time (in seconds) to poll your Temboo callback URL to see if your app's user has allowed or denied the request for access. Defaults to 20. Max is 60.
        ###

        def set_Timeout(value)
          set_input("Timeout", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the FinalizeOAuth Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class FinalizeOAuthResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "AccessToken" output from this Choreo execution
      	#
      	# @return String - (string) The Access Token retrieved during the OAuth process.
      	####
      	def get_AccessToken()
      	  return @outputs["AccessToken"]
      	end
      	####
      	# Retrieve the value for the "AccessTokenSecret" output from this Choreo execution
      	#
      	# @return String - (string) The Access Token Secret retrieved during the OAuth process.
      	####
      	def get_AccessTokenSecret()
      	  return @outputs["AccessTokenSecret"]
      	end
      	####
      	# Retrieve the value for the "ErrorMessage" output from this Choreo execution
      	#
      	# @return String - (string) Contains an error message if an error occurs during the OAuth redirect process and if SuppressErrors is set to true.
      	####
      	def get_ErrorMessage()
      	  return @outputs["ErrorMessage"]
      	end
      	####
      	# Retrieve the value for the "UserID" output from this Choreo execution
      	#
      	# @return String - (integer) The Dropbox user ID associated with the access token and secret returned.
      	####
      	def get_UserID()
      	  return @outputs["UserID"]
      	end
      end

    end # class FinalizeOAuth



    ##############################################################################
    #
    # FromOAuth1
    #
    # Creates an OAuth 2.0 access token from the supplied OAuth 1.0 access token.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class FromOAuth1 < Choreography

      ####
      #  Create a new instance of the FromOAuth1 Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/OAuth/FromOAuth1")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return FromOAuth1InputSet
      ####
      def new_input_set()
        return FromOAuth1InputSet.new()
      end

      def make_result_set()
        return FromOAuth1ResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = FromOAuth1ResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the FromOAuth1
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class FromOAuth1InputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) An OAuth 1.0 access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) An OAuth 1.0 access token secret for a specific Dropbox user.
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox after registering your application.
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The App Secret provided by Dropbox after registering your application.
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the FromOAuth1 Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class FromOAuth1ResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "OAuth2AccessToken" output from this Choreo execution
      	#
      	# @return String - (string) The OAuth 2.0 access for a specific Dropbox user.
      	####
      	def get_OAuth2AccessToken()
      	  return @outputs["OAuth2AccessToken"]
      	end
      end

    end # class FromOAuth1



    ##############################################################################
    #
    # InitializeOAuth
    #
    # Generates an authorization URL that an application can use to complete the first step in the OAuth process.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class InitializeOAuth < Choreography

      ####
      #  Create a new instance of the InitializeOAuth Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/OAuth/InitializeOAuth")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return InitializeOAuthInputSet
      ####
      def new_input_set()
        return InitializeOAuthInputSet.new()
      end

      def make_result_set()
        return InitializeOAuthResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = InitializeOAuthResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the InitializeOAuth
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class InitializeOAuthInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccountName input for this Choreo. 
        # 
        # @param String - (optional, string) Deprecated (retained for backward compatibility only).
        ###

        def set_AccountName(value)
          set_input("AccountName", value)
        end
        #### 
        # Set the value of the AppKeyName input for this Choreo. 
        # 
        # @param String - (optional, string) Deprecated (retained for backward compatibility only).
        ###

        def set_AppKeyName(value)
          set_input("AppKeyName", value)
        end
        #### 
        # Set the value of the AppKeyValue input for this Choreo. 
        # 
        # @param String - (optional, string) Deprecated (retained for backward compatibility only).
        ###

        def set_AppKeyValue(value)
          set_input("AppKeyValue", value)
        end
        #### 
        # Set the value of the DropboxAppKey input for this Choreo. 
        # 
        # @param String - (required, string) The App Key provided by Dropbox (AKA the OAuth Consumer Key).
        ###

        def set_DropboxAppKey(value)
          set_input("DropboxAppKey", value)
        end
        #### 
        # Set the value of the DropboxAppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The AppSecret provided by Dropbox (AKA the OAuth Consumer Secret).
        ###

        def set_DropboxAppSecret(value)
          set_input("DropboxAppSecret", value)
        end
        #### 
        # Set the value of the ForwardingURL input for this Choreo. 
        # 
        # @param String - (optional, string) The URL that Temboo will redirect your users to after they grant access to your application. This should include the "https://" or "http://" prefix and be a fully qualified URL.
        ###

        def set_ForwardingURL(value)
          set_input("ForwardingURL", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the InitializeOAuth Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class InitializeOAuthResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "AuthorizationURL" output from this Choreo execution
      	#
      	# @return String - (string) The authorization URL that the application's user needs to go to in order to grant access to your application.
      	####
      	def get_AuthorizationURL()
      	  return @outputs["AuthorizationURL"]
      	end
      	####
      	# Retrieve the value for the "CallbackID" output from this Choreo execution
      	#
      	# @return String - (string) An ID used to retrieve the callback data that Temboo stores once your application's user authorizes.
      	####
      	def get_CallbackID()
      	  return @outputs["CallbackID"]
      	end
      	####
      	# Retrieve the value for the "OAuthTokenSecret" output from this Choreo execution
      	#
      	# @return String - (string) The temporary OAuth Token Secret that can be exchanged for a final token secret using the FinalizeOAuth Choreo.
      	####
      	def get_OAuthTokenSecret()
      	  return @outputs["OAuthTokenSecret"]
      	end
      end

    end # class InitializeOAuth



    ##############################################################################
    #
    # Revoke
    #
    # Disables the access token used to authenticate the call.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Revoke < Choreography

      ####
      #  Create a new instance of the Revoke Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/OAuth/Revoke")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RevokeInputSet
      ####
      def new_input_set()
        return RevokeInputSet.new()
      end

      def make_result_set()
        return RevokeResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RevokeResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Revoke
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RevokeInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Revoke Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RevokeResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Dropbox.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Revoke




  end # module OAuth

  module Sharing



    ##############################################################################
    #
    # CreateSharedLink
    #
    # Creates a shared link.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateSharedLink < Choreography

      ####
      #  Create a new instance of the CreateSharedLink Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Sharing/CreateSharedLink")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateSharedLinkInputSet
      ####
      def new_input_set()
        return CreateSharedLinkInputSet.new()
      end

      def make_result_set()
        return CreateSharedLinkResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateSharedLinkResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateSharedLink
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateSharedLinkInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (required, string) The path to share.
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the ShortURL input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Whether to return a shortened URL. The default for this field is false.
        ###

        def set_ShortURL(value)
          set_input("ShortURL", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateSharedLink Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateSharedLinkResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Dropbox.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateSharedLink



    ##############################################################################
    #
    # RevokeSharedLink
    #
    # Revokes a shared link.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RevokeSharedLink < Choreography

      ####
      #  Create a new instance of the RevokeSharedLink Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Sharing/RevokeSharedLink")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RevokeSharedLinkInputSet
      ####
      def new_input_set()
        return RevokeSharedLinkInputSet.new()
      end

      def make_result_set()
        return RevokeSharedLinkResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RevokeSharedLinkResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RevokeSharedLink
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RevokeSharedLinkInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the URL input for this Choreo. 
        # 
        # @param String - (required, string) The URL of the shared link.
        ###

        def set_URL(value)
          set_input("URL", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RevokeSharedLink Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RevokeSharedLinkResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Dropbox.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class RevokeSharedLink




  end # module Sharing

  module Users



    ##############################################################################
    #
    # GetAccount
    #
    # Retrieves information about a user's account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetAccount < Choreography

      ####
      #  Create a new instance of the GetAccount Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Users/GetAccount")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetAccountInputSet
      ####
      def new_input_set()
        return GetAccountInputSet.new()
      end

      def make_result_set()
        return GetAccountResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetAccountResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetAccount
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetAccountInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccountID input for this Choreo. 
        # 
        # @param String - (required, string) A user's account identifier.
        ###

        def set_AccountID(value)
          set_input("AccountID", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetAccount Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetAccountResultSet < Choreography::ResultSet
      end

    end # class GetAccount



    ##############################################################################
    #
    # GetCurrentAccount
    #
    # Retrieves information about the current user's account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetCurrentAccount < Choreography

      ####
      #  Create a new instance of the GetCurrentAccount Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Dropbox/Users/GetCurrentAccount")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetCurrentAccountInputSet
      ####
      def new_input_set()
        return GetCurrentAccountInputSet.new()
      end

      def make_result_set()
        return GetCurrentAccountResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetCurrentAccountResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetCurrentAccount
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetCurrentAccountInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The access token for a specific Dropbox user.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetCurrentAccount Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetCurrentAccountResultSet < Choreography::ResultSet
      end

    end # class GetCurrentAccount




  end # module Users

end # module Dropbox