require "temboo"

module FedEx




  module Availability



    ##############################################################################
    #
    # ServiceAvailability
    #
    # Retrieves available shipping options and delivery dates for a specified origin and destination.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ServiceAvailability < Choreography

      ####
      #  Create a new instance of the ServiceAvailability Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/FedEx/Availability/ServiceAvailability")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ServiceAvailabilityInputSet
      ####
      def new_input_set()
        return ServiceAvailabilityInputSet.new()
      end

      def make_result_set()
        return ServiceAvailabilityResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ServiceAvailabilityResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ServiceAvailability
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ServiceAvailabilityInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccountNumber input for this Choreo. 
        # 
        # @param String - (required, string) Your FedEx Account Number or Test Account Number.
        ###

        def set_AccountNumber(value)
          set_input("AccountNumber", value)
        end
        #### 
        # Set the value of the AuthenticationKey input for this Choreo. 
        # 
        # @param String - (required, string) The Production Authentication Key or Development Test Key provided by FedEx Web Services.
        ###

        def set_AuthenticationKey(value)
          set_input("AuthenticationKey", value)
        end
        #### 
        # Set the value of the DestinationCountryCode input for this Choreo. 
        # 
        # @param String - (required, string) The destination country code to use for the service availability request (e.g., US).
        ###

        def set_DestinationCountryCode(value)
          set_input("DestinationCountryCode", value)
        end
        #### 
        # Set the value of the DestinationPostalCode input for this Choreo. 
        # 
        # @param String - (required, string) The destination postal code to use for  the service availability request.
        ###

        def set_DestinationPostalCode(value)
          set_input("DestinationPostalCode", value)
        end
        #### 
        # Set the value of the Endpoint input for this Choreo. 
        # 
        # @param String - (conditional, string) Set to "test" to direct requests to the FedEx test environment. Defaults to "production" indicating that requests are sent to the production URL.
        ###

        def set_Endpoint(value)
          set_input("Endpoint", value)
        end
        #### 
        # Set the value of the MeterNumber input for this Choreo. 
        # 
        # @param String - (required, string) The Production or Test Meter Number provided by FedEx Web Services.
        ###

        def set_MeterNumber(value)
          set_input("MeterNumber", value)
        end
        #### 
        # Set the value of the OriginCountryCode input for this Choreo. 
        # 
        # @param String - (required, string) The origin country code to use for the service availability request (e.g., US).
        ###

        def set_OriginCountryCode(value)
          set_input("OriginCountryCode", value)
        end
        #### 
        # Set the value of the OriginPostalCode input for this Choreo. 
        # 
        # @param String - (required, string) The origin postal code to use for the service availability request.
        ###

        def set_OriginPostalCode(value)
          set_input("OriginPostalCode", value)
        end
        #### 
        # Set the value of the Password input for this Choreo. 
        # 
        # @param String - (required, password) The Production or Test Password provided by FedEx Web Services.
        ###

        def set_Password(value)
          set_input("Password", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the ShipDate input for this Choreo. 
        # 
        # @param String - (optional, date) The date to use for the service availability request. Dates should be formatted as YYYY-MM-DD. Defautls to today's date.
        ###

        def set_ShipDate(value)
          set_input("ShipDate", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ServiceAvailability Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ServiceAvailabilityResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from FedEx.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ServiceAvailability




  end # module Availability

  module CountryService



    ##############################################################################
    #
    # PostalCodeInquiry
    #
    # Retrieves location information from FedEx Web Services for a specified postal code.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PostalCodeInquiry < Choreography

      ####
      #  Create a new instance of the PostalCodeInquiry Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/FedEx/CountryService/PostalCodeInquiry")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PostalCodeInquiryInputSet
      ####
      def new_input_set()
        return PostalCodeInquiryInputSet.new()
      end

      def make_result_set()
        return PostalCodeInquiryResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PostalCodeInquiryResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PostalCodeInquiry
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PostalCodeInquiryInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccountNumber input for this Choreo. 
        # 
        # @param String - (required, string) Your FedEx Account Number or Test Account Number.
        ###

        def set_AccountNumber(value)
          set_input("AccountNumber", value)
        end
        #### 
        # Set the value of the AuthenticationKey input for this Choreo. 
        # 
        # @param String - (required, string) The Production Authentication Key or Development Test Key provided by FedEx Web Services.
        ###

        def set_AuthenticationKey(value)
          set_input("AuthenticationKey", value)
        end
        #### 
        # Set the value of the CountryCode input for this Choreo. 
        # 
        # @param String - (required, string) The country code to use in the inquiry request (e.g., US).
        ###

        def set_CountryCode(value)
          set_input("CountryCode", value)
        end
        #### 
        # Set the value of the Endpoint input for this Choreo. 
        # 
        # @param String - (conditional, string) Set to "test" to direct requests to the FedEx test environment. Defaults to "production" indicating that requests are sent to the production URL.
        ###

        def set_Endpoint(value)
          set_input("Endpoint", value)
        end
        #### 
        # Set the value of the MeterNumber input for this Choreo. 
        # 
        # @param String - (required, string) The Production or Test Meter Number provided by FedEx Web Services.
        ###

        def set_MeterNumber(value)
          set_input("MeterNumber", value)
        end
        #### 
        # Set the value of the Password input for this Choreo. 
        # 
        # @param String - (required, password) The Production or Test Password provided by FedEx Web Services.
        ###

        def set_Password(value)
          set_input("Password", value)
        end
        #### 
        # Set the value of the PostalCode input for this Choreo. 
        # 
        # @param String - (required, string) The postal code to use in the inquiry request.
        ###

        def set_PostalCode(value)
          set_input("PostalCode", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the ShipDate input for this Choreo. 
        # 
        # @param String - (optional, string) The ship date to use for the inquiry. Dates should be formatted as YYYY-MM-DD. Defautls to today's date.
        ###

        def set_ShipDate(value)
          set_input("ShipDate", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PostalCodeInquiry Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PostalCodeInquiryResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from FedEx.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PostalCodeInquiry




  end # module CountryService

  module Locations



    ##############################################################################
    #
    # SearchLocationsByAddress
    #
    # Searches for FedEx locations near a given address.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class SearchLocationsByAddress < Choreography

      ####
      #  Create a new instance of the SearchLocationsByAddress Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/FedEx/Locations/SearchLocationsByAddress")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return SearchLocationsByAddressInputSet
      ####
      def new_input_set()
        return SearchLocationsByAddressInputSet.new()
      end

      def make_result_set()
        return SearchLocationsByAddressResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = SearchLocationsByAddressResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the SearchLocationsByAddress
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class SearchLocationsByAddressInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccountNumber input for this Choreo. 
        # 
        # @param String - (required, string) Your FedEx Account Number or Test Account Number.
        ###

        def set_AccountNumber(value)
          set_input("AccountNumber", value)
        end
        #### 
        # Set the value of the AuthenticationKey input for this Choreo. 
        # 
        # @param String - (required, string) The Production Authentication Key or Development Test Key provided by FedEx Web Services.
        ###

        def set_AuthenticationKey(value)
          set_input("AuthenticationKey", value)
        end
        #### 
        # Set the value of the City input for this Choreo. 
        # 
        # @param String - (required, string) The city associated with the location being searched.
        ###

        def set_City(value)
          set_input("City", value)
        end
        #### 
        # Set the value of the CountryCode input for this Choreo. 
        # 
        # @param String - (required, string) The country code associated with the location being searched (e.g., US).
        ###

        def set_CountryCode(value)
          set_input("CountryCode", value)
        end
        #### 
        # Set the value of the Endpoint input for this Choreo. 
        # 
        # @param String - (conditional, string) Set to "test" to direct requests to the FedEx test environment. Defaults to "production" indicating that requests are sent to the production URL.
        ###

        def set_Endpoint(value)
          set_input("Endpoint", value)
        end
        #### 
        # Set the value of the MeterNumber input for this Choreo. 
        # 
        # @param String - (required, string) The Production or Test Meter Number provided by FedEx Web Services.
        ###

        def set_MeterNumber(value)
          set_input("MeterNumber", value)
        end
        #### 
        # Set the value of the Password input for this Choreo. 
        # 
        # @param String - (required, password) The Production or Test Password provided by FedEx Web Services.
        ###

        def set_Password(value)
          set_input("Password", value)
        end
        #### 
        # Set the value of the PostalCode input for this Choreo. 
        # 
        # @param String - (required, string) The postal code associated with the location being searched.
        ###

        def set_PostalCode(value)
          set_input("PostalCode", value)
        end
        #### 
        # Set the value of the RadiusDistance input for this Choreo. 
        # 
        # @param BigDecimal - (optional, decimal) Specifies value of the radius around the address to search for FedEx locations. Note that RadiusUnits applies to this value. Defaults to 10 miles.
        ###

        def set_RadiusDistance(value)
          set_input("RadiusDistance", value)
        end
        #### 
        # Set the value of the RadiusUnits input for this Choreo. 
        # 
        # @param String - (optional, string) Specifies the unit of measure for the RadiusDistance value. Valid values are mi (the default) and km.
        ###

        def set_RadiusUnits(value)
          set_input("RadiusUnits", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SortBy input for this Choreo. 
        # 
        # @param String - (optional, string) Specifies the criterion to be used to sort the location details. Valid values are: distance (the default), latest_express_dropoff_time, latest_ground_dropoff_time, location_type.
        ###

        def set_SortBy(value)
          set_input("SortBy", value)
        end
        #### 
        # Set the value of the SortOrder input for this Choreo. 
        # 
        # @param String - (optional, string) Specifies sort order of the location details. Valid values are: lowest_to_highest (the default) and highest_to_lowest.
        ###

        def set_SortOrder(value)
          set_input("SortOrder", value)
        end
        #### 
        # Set the value of the State input for this Choreo. 
        # 
        # @param String - (required, string) Identifying abbreviation for US state, Canada province (e.g., NY).
        ###

        def set_State(value)
          set_input("State", value)
        end
        #### 
        # Set the value of the Street input for this Choreo. 
        # 
        # @param String - (required, string) The street number and street name (e.g., 350 5th Ave).
        ###

        def set_Street(value)
          set_input("Street", value)
        end
        #### 
        # Set the value of the SupportedServices input for this Choreo. 
        # 
        # @param String - (optional, string) Specifies the types of services supported by a FedEx location for redirect to hold. Valid values are: fedex_express, fedex_ground, fedex_ground_home_delivery.
        ###

        def set_SupportedServices(value)
          set_input("SupportedServices", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the SearchLocationsByAddress Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class SearchLocationsByAddressResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from FedEx.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class SearchLocationsByAddress




  end # module Locations

  module TrackingAndVisibility



    ##############################################################################
    #
    # TrackByNumber
    #
    # Retrieves shipment information for a specified tracking number.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class TrackByNumber < Choreography

      ####
      #  Create a new instance of the TrackByNumber Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/FedEx/TrackingAndVisibility/TrackByNumber")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return TrackByNumberInputSet
      ####
      def new_input_set()
        return TrackByNumberInputSet.new()
      end

      def make_result_set()
        return TrackByNumberResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = TrackByNumberResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the TrackByNumber
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class TrackByNumberInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccountNumber input for this Choreo. 
        # 
        # @param String - (required, string) Your FedEx Account Number or Test Account Number.
        ###

        def set_AccountNumber(value)
          set_input("AccountNumber", value)
        end
        #### 
        # Set the value of the AuthenticationKey input for this Choreo. 
        # 
        # @param String - (required, string) The Production Authentication Key or Development Test Key provided by FedEx Web Services.
        ###

        def set_AuthenticationKey(value)
          set_input("AuthenticationKey", value)
        end
        #### 
        # Set the value of the Endpoint input for this Choreo. 
        # 
        # @param String - (conditional, string) Set to "test" to direct requests to the FedEx test environment. Defaults to "production" indicating that requests are sent to the production URL.
        ###

        def set_Endpoint(value)
          set_input("Endpoint", value)
        end
        #### 
        # Set the value of the MeterNumber input for this Choreo. 
        # 
        # @param String - (required, string) The Production or Test Meter Number provided by FedEx Web Services.
        ###

        def set_MeterNumber(value)
          set_input("MeterNumber", value)
        end
        #### 
        # Set the value of the Password input for this Choreo. 
        # 
        # @param String - (required, password) The Production or Test Password provided by FedEx Web Services.
        ###

        def set_Password(value)
          set_input("Password", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the TrackingNumber input for this Choreo. 
        # 
        # @param String - (required, string) The tracking number for the shipment.
        ###

        def set_TrackingNumber(value)
          set_input("TrackingNumber", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the TrackByNumber Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class TrackByNumberResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from FedEx.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class TrackByNumber



    ##############################################################################
    #
    # TrackByReference
    #
    # Retrieves shipment information for a specified reference number.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class TrackByReference < Choreography

      ####
      #  Create a new instance of the TrackByReference Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/FedEx/TrackingAndVisibility/TrackByReference")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return TrackByReferenceInputSet
      ####
      def new_input_set()
        return TrackByReferenceInputSet.new()
      end

      def make_result_set()
        return TrackByReferenceResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = TrackByReferenceResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the TrackByReference
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class TrackByReferenceInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccountNumber input for this Choreo. 
        # 
        # @param String - (required, string) Your FedEx Account Number or Test Account Number.
        ###

        def set_AccountNumber(value)
          set_input("AccountNumber", value)
        end
        #### 
        # Set the value of the AuthenticationKey input for this Choreo. 
        # 
        # @param String - (required, string) The Production Authentication Key or Development Test Key provided by FedEx Web Services.
        ###

        def set_AuthenticationKey(value)
          set_input("AuthenticationKey", value)
        end
        #### 
        # Set the value of the City input for this Choreo. 
        # 
        # @param String - (optional, string) The destination city.
        ###

        def set_City(value)
          set_input("City", value)
        end
        #### 
        # Set the value of the CountryCode input for this Choreo. 
        # 
        # @param String - (conditional, string) The country code associated with the shipment destination (e.g., US). Required unless specifying the ShipmentAccountNumber.
        ###

        def set_CountryCode(value)
          set_input("CountryCode", value)
        end
        #### 
        # Set the value of the Endpoint input for this Choreo. 
        # 
        # @param String - (conditional, string) Set to "test" to direct requests to the FedEx test environment. Defaults to "production" indicating that requests are sent to the production URL.
        ###

        def set_Endpoint(value)
          set_input("Endpoint", value)
        end
        #### 
        # Set the value of the MeterNumber input for this Choreo. 
        # 
        # @param String - (required, string) The Production or Test Meter Number provided by FedEx Web Services.
        ###

        def set_MeterNumber(value)
          set_input("MeterNumber", value)
        end
        #### 
        # Set the value of the OperatingCompany input for this Choreo. 
        # 
        # @param String - (required, string) Identification for a fedex operating company (e.g.,  fedex_express, fedex_freight, fedex_ground). See Choreo notes for allowed values.
        ###

        def set_OperatingCompany(value)
          set_input("OperatingCompany", value)
        end
        #### 
        # Set the value of the Password input for this Choreo. 
        # 
        # @param String - (required, password) The Production or Test Password provided by FedEx Web Services.
        ###

        def set_Password(value)
          set_input("Password", value)
        end
        #### 
        # Set the value of the PostalCode input for this Choreo. 
        # 
        # @param String - (conditional, string) The postal code associated with the shipment destination. Required unless specifying the ShipmentAccountNumber.
        ###

        def set_PostalCode(value)
          set_input("PostalCode", value)
        end
        #### 
        # Set the value of the Reference input for this Choreo. 
        # 
        # @param String - (required, string) A reference number for tracking the shipment.
        ###

        def set_Reference(value)
          set_input("Reference", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the ShipDateRangeBegin input for this Choreo. 
        # 
        # @param String - (optional, date) Specifies the beginning of a date range used to narrow the search to a period in time. Dates should be formatted as YYYY-MM-DD.
        ###

        def set_ShipDateRangeBegin(value)
          set_input("ShipDateRangeBegin", value)
        end
        #### 
        # Set the value of the ShipDateRangeEnd input for this Choreo. 
        # 
        # @param String - (optional, date) Specifies the beginning of a date range used to narrow the search to a period in time. Dates should be formatted as YYYY-MM-DD.
        ###

        def set_ShipDateRangeEnd(value)
          set_input("ShipDateRangeEnd", value)
        end
        #### 
        # Set the value of the ShipmentAccountNumber input for this Choreo. 
        # 
        # @param String - (conditional, string) The shipment account number. Required unless specifying the PostalCode and CountryCode.
        ###

        def set_ShipmentAccountNumber(value)
          set_input("ShipmentAccountNumber", value)
        end
        #### 
        # Set the value of the State input for this Choreo. 
        # 
        # @param String - (optional, string) Identifying abbreviation for US state, Canada province of the shipment destination (e.g., NY).
        ###

        def set_State(value)
          set_input("State", value)
        end
        #### 
        # Set the value of the Street input for this Choreo. 
        # 
        # @param String - (optional, string) The street number and street name for the shipment destination (e.g., 350 5th Ave).
        ###

        def set_Street(value)
          set_input("Street", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the TrackByReference Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class TrackByReferenceResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from FedEx.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class TrackByReference




  end # module TrackingAndVisibility

  module Validation



    ##############################################################################
    #
    # AddressValidation
    #
    # Validates a given address.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class AddressValidation < Choreography

      ####
      #  Create a new instance of the AddressValidation Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/FedEx/Validation/AddressValidation")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AddressValidationInputSet
      ####
      def new_input_set()
        return AddressValidationInputSet.new()
      end

      def make_result_set()
        return AddressValidationResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AddressValidationResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the AddressValidation
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AddressValidationInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccountNumber input for this Choreo. 
        # 
        # @param String - (required, string) Your FedEx Account Number or Test Account Number.
        ###

        def set_AccountNumber(value)
          set_input("AccountNumber", value)
        end
        #### 
        # Set the value of the AuthenticationKey input for this Choreo. 
        # 
        # @param String - (required, string) The Production Authentication Key or Development Test Key provided by FedEx Web Services.
        ###

        def set_AuthenticationKey(value)
          set_input("AuthenticationKey", value)
        end
        #### 
        # Set the value of the City input for this Choreo. 
        # 
        # @param String - (conditional, string) The name of the city or town.
        ###

        def set_City(value)
          set_input("City", value)
        end
        #### 
        # Set the value of the ClientReferenceID input for this Choreo. 
        # 
        # @param String - (optional, string) A reference id provided by the client.
        ###

        def set_ClientReferenceID(value)
          set_input("ClientReferenceID", value)
        end
        #### 
        # Set the value of the CompanyName input for this Choreo. 
        # 
        # @param String - (optional, string) Identifies the company associated with the location.
        ###

        def set_CompanyName(value)
          set_input("CompanyName", value)
        end
        #### 
        # Set the value of the CountryCode input for this Choreo. 
        # 
        # @param String - (conditional, string) The country code associated with the address being validated (e.g., US).
        ###

        def set_CountryCode(value)
          set_input("CountryCode", value)
        end
        #### 
        # Set the value of the Endpoint input for this Choreo. 
        # 
        # @param String - (conditional, string) Set to "test" to direct requests to the FedEx test environment. Defaults to "production" indicating that requests are sent to the production URL.
        ###

        def set_Endpoint(value)
          set_input("Endpoint", value)
        end
        #### 
        # Set the value of the MeterNumber input for this Choreo. 
        # 
        # @param String - (required, string) The Production or Test Meter Number provided by FedEx Web Services.
        ###

        def set_MeterNumber(value)
          set_input("MeterNumber", value)
        end
        #### 
        # Set the value of the Password input for this Choreo. 
        # 
        # @param String - (required, password) The Production or Test Password provided by FedEx Web Services.
        ###

        def set_Password(value)
          set_input("Password", value)
        end
        #### 
        # Set the value of the PhoneNumber input for this Choreo. 
        # 
        # @param String - (optional, string) Identifies the phone number associated with the contact being validated.
        ###

        def set_PhoneNumber(value)
          set_input("PhoneNumber", value)
        end
        #### 
        # Set the value of the PostalCode input for this Choreo. 
        # 
        # @param String - (conditional, string) The postal code associated with the address being validated.
        ###

        def set_PostalCode(value)
          set_input("PostalCode", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the State input for this Choreo. 
        # 
        # @param String - (conditional, string) Identifying abbreviation for US state, Canada province (e.g., NY).
        ###

        def set_State(value)
          set_input("State", value)
        end
        #### 
        # Set the value of the Street input for this Choreo. 
        # 
        # @param String - (conditional, string) The street number and street name (e.g., 350 5th Ave).
        ###

        def set_Street(value)
          set_input("Street", value)
        end
        #### 
        # Set the value of the UrbanizationCode input for this Choreo. 
        # 
        # @param String - (optional, string) Relevant only to addresses in Puerto Rico.
        ###

        def set_UrbanizationCode(value)
          set_input("UrbanizationCode", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the AddressValidation Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AddressValidationResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from FedEx.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class AddressValidation




  end # module Validation

end # module FedEx