require "temboo"

module Highrise



  ##############################################################################
  #
  # CreatePeople
  #
  # Creates a new contact record in your Highrise CRM.
  #
  # Copyright 2014, Temboo Inc.
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing,
  # software distributed under the License is distributed on an
  # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
  # either express or implied. See the License for the specific
  # language governing permissions and limitations under the License.
  #
  ##############################################################################

  class CreatePeople < Choreography

    ####
    #  Create a new instance of the CreatePeople Choreo. A TembooSession object, containing a valid
    #  set of Temboo credentials, must be supplied.
    ####
    def initialize(session)
      super(session, "/Library/Highrise/CreatePeople")
    end

    #### 
    # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
    #
    # @return CreatePeopleInputSet
    ####
    def new_input_set()
      return CreatePeopleInputSet.new()
    end

    def make_result_set()
      return CreatePeopleResultSet.new()
    end

    ####
    # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
    # and return a ResultSet containing the execution results.
    # @param choreoInputs
    # @return
    # @throws TembooException
    ####
    def execute(input_set = nil)
      resp = super(input_set)
      results = CreatePeopleResultSet.new(resp)
      return results
    end

    ####
    # An InputSet with methods appropriate for specifying the inputs to the CreatePeople
    # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    ####
    class CreatePeopleInputSet < Choreography::InputSet

      #### 
      # Set the value of the AccountName input for this Choreo. 
      # 
      # @param String - (required, string) A valid Highrise account name. This is the first part of the account's URL.
      ###

      def set_AccountName(value)
        set_input("AccountName", value)
      end
      #### 
      # Set the value of the Background input for this Choreo. 
      # 
      # @param String - (optional, string) Corresponds to the background field in Highrise
      ###

      def set_Background(value)
        set_input("Background", value)
      end
      #### 
      # Set the value of the CompanyName input for this Choreo. 
      # 
      # @param String - (optional, string) Corresponds to the company name field in Highrise.
      ###

      def set_CompanyName(value)
        set_input("CompanyName", value)
      end
      #### 
      # Set the value of the EmailAddress input for this Choreo. 
      # 
      # @param String - (optional, string) Corresponds to the email address field in Highrise.
      ###

      def set_EmailAddress(value)
        set_input("EmailAddress", value)
      end
      #### 
      # Set the value of the FirstName input for this Choreo. 
      # 
      # @param String - (required, string) Corresponds to the first name field in Highrise.
      ###

      def set_FirstName(value)
        set_input("FirstName", value)
      end
      #### 
      # Set the value of the HomePhone input for this Choreo. 
      # 
      # @param String - (optional, string) Corresponds to the home phone field in Highrise.
      ###

      def set_HomePhone(value)
        set_input("HomePhone", value)
      end
      #### 
      # Set the value of the LastName input for this Choreo. 
      # 
      # @param String - (optional, string) Corresponds to the last name field in Highrise.
      ###

      def set_LastName(value)
        set_input("LastName", value)
      end
      #### 
      # Set the value of the Password input for this Choreo. 
      # 
      # @param String - (required, password) The Highrise account password. Use the value 'X' when specifying an API Key for the Username input.
      ###

      def set_Password(value)
        set_input("Password", value)
      end
      #### 
      # Set the value of the Title input for this Choreo. 
      # 
      # @param String - (optional, string) Corresponds to the title field in Highrise.
      ###

      def set_Title(value)
        set_input("Title", value)
      end
      #### 
      # Set the value of the Username input for this Choreo. 
      # 
      # @param String - (required, string) A Highrise account username or API Key.
      ###

      def set_Username(value)
        set_input("Username", value)
      end
      #### 
      # Set the value of the WorkPhone input for this Choreo. 
      # 
      # @param String - (optional, string) Corresponds to the work phone field in Highrise.
      ###

      def set_WorkPhone(value)
        set_input("WorkPhone", value)
      end

    end

    ####
    # A ResultSet with methods tailored to the values returned by the CreatePeople Choreo.
    # The ResultSet object is used to retrieve the results of a Choreo execution.
    ####
    class CreatePeopleResultSet < Choreography::ResultSet
    	####
    	# Retrieve the value for the "Response" output from this Choreo execution
    	#
    	# @return String - (xml) The response from Highrise.
    	####
    	def get_Response()
    	  return @outputs["Response"]
    	end
    end

  end # class CreatePeople



  ##############################################################################
  #
  # DeletePeople
  #
  # Deletes a specified contact from your Highrise CRM.
  #
  # Copyright 2014, Temboo Inc.
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing,
  # software distributed under the License is distributed on an
  # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
  # either express or implied. See the License for the specific
  # language governing permissions and limitations under the License.
  #
  ##############################################################################

  class DeletePeople < Choreography

    ####
    #  Create a new instance of the DeletePeople Choreo. A TembooSession object, containing a valid
    #  set of Temboo credentials, must be supplied.
    ####
    def initialize(session)
      super(session, "/Library/Highrise/DeletePeople")
    end

    #### 
    # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
    #
    # @return DeletePeopleInputSet
    ####
    def new_input_set()
      return DeletePeopleInputSet.new()
    end

    def make_result_set()
      return DeletePeopleResultSet.new()
    end

    ####
    # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
    # and return a ResultSet containing the execution results.
    # @param choreoInputs
    # @return
    # @throws TembooException
    ####
    def execute(input_set = nil)
      resp = super(input_set)
      results = DeletePeopleResultSet.new(resp)
      return results
    end

    ####
    # An InputSet with methods appropriate for specifying the inputs to the DeletePeople
    # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    ####
    class DeletePeopleInputSet < Choreography::InputSet

      #### 
      # Set the value of the AccountName input for this Choreo. 
      # 
      # @param String - (required, string) A valid Highrise account name. This is the first part of the account's URL.
      ###

      def set_AccountName(value)
        set_input("AccountName", value)
      end
      #### 
      # Set the value of the ContactID input for this Choreo. 
      # 
      # @param String - (required, string) The ID number of the contact you want to delete. This is used to contruct the URL for the request.
      ###

      def set_ContactID(value)
        set_input("ContactID", value)
      end
      #### 
      # Set the value of the Password input for this Choreo. 
      # 
      # @param String - (required, password) The Highrise account password. Use the value 'X' when specifying an API Key for the Username input.
      ###

      def set_Password(value)
        set_input("Password", value)
      end
      #### 
      # Set the value of the Username input for this Choreo. 
      # 
      # @param String - (required, string) A Highrise account username or API Key.
      ###

      def set_Username(value)
        set_input("Username", value)
      end

    end

    ####
    # A ResultSet with methods tailored to the values returned by the DeletePeople Choreo.
    # The ResultSet object is used to retrieve the results of a Choreo execution.
    ####
    class DeletePeopleResultSet < Choreography::ResultSet
    	####
    	# Retrieve the value for the "Response" output from this Choreo execution
    	#
    	# @return String - The response from Highrise. The delete people API method returns no XML, so this variable will contain no data.
    	####
    	def get_Response()
    	  return @outputs["Response"]
    	end
    end

  end # class DeletePeople



  ##############################################################################
  #
  # ListAllPeople
  #
  # Retrieves contacts from your Highrise CRM.
  #
  # Copyright 2014, Temboo Inc.
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing,
  # software distributed under the License is distributed on an
  # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
  # either express or implied. See the License for the specific
  # language governing permissions and limitations under the License.
  #
  ##############################################################################

  class ListAllPeople < Choreography

    ####
    #  Create a new instance of the ListAllPeople Choreo. A TembooSession object, containing a valid
    #  set of Temboo credentials, must be supplied.
    ####
    def initialize(session)
      super(session, "/Library/Highrise/ListAllPeople")
    end

    #### 
    # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
    #
    # @return ListAllPeopleInputSet
    ####
    def new_input_set()
      return ListAllPeopleInputSet.new()
    end

    def make_result_set()
      return ListAllPeopleResultSet.new()
    end

    ####
    # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
    # and return a ResultSet containing the execution results.
    # @param choreoInputs
    # @return
    # @throws TembooException
    ####
    def execute(input_set = nil)
      resp = super(input_set)
      results = ListAllPeopleResultSet.new(resp)
      return results
    end

    ####
    # An InputSet with methods appropriate for specifying the inputs to the ListAllPeople
    # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    ####
    class ListAllPeopleInputSet < Choreography::InputSet

      #### 
      # Set the value of the AccountName input for this Choreo. 
      # 
      # @param String - (required, string) A valid Highrise account name. This is the first part of the account's URL.
      ###

      def set_AccountName(value)
        set_input("AccountName", value)
      end
      #### 
      # Set the value of the Password input for this Choreo. 
      # 
      # @param String - (required, password) The Highrise account password. Use the value 'X' when specifying an API Key for the Username input.
      ###

      def set_Password(value)
        set_input("Password", value)
      end
      #### 
      # Set the value of the Username input for this Choreo. 
      # 
      # @param String - (required, string) A Highrise account username or API Key.
      ###

      def set_Username(value)
        set_input("Username", value)
      end

    end

    ####
    # A ResultSet with methods tailored to the values returned by the ListAllPeople Choreo.
    # The ResultSet object is used to retrieve the results of a Choreo execution.
    ####
    class ListAllPeopleResultSet < Choreography::ResultSet
    	####
    	# Retrieve the value for the "Response" output from this Choreo execution
    	#
    	# @return String - (xml) The response from Highrise.
    	####
    	def get_Response()
    	  return @outputs["Response"]
    	end
    end

  end # class ListAllPeople



  ##############################################################################
  #
  # SearchPeople
  #
  # Lets you search your Highrise CRM by specifying an email search criteria.
  #
  # Copyright 2014, Temboo Inc.
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing,
  # software distributed under the License is distributed on an
  # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
  # either express or implied. See the License for the specific
  # language governing permissions and limitations under the License.
  #
  ##############################################################################

  class SearchPeople < Choreography

    ####
    #  Create a new instance of the SearchPeople Choreo. A TembooSession object, containing a valid
    #  set of Temboo credentials, must be supplied.
    ####
    def initialize(session)
      super(session, "/Library/Highrise/SearchPeople")
    end

    #### 
    # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
    #
    # @return SearchPeopleInputSet
    ####
    def new_input_set()
      return SearchPeopleInputSet.new()
    end

    def make_result_set()
      return SearchPeopleResultSet.new()
    end

    ####
    # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
    # and return a ResultSet containing the execution results.
    # @param choreoInputs
    # @return
    # @throws TembooException
    ####
    def execute(input_set = nil)
      resp = super(input_set)
      results = SearchPeopleResultSet.new(resp)
      return results
    end

    ####
    # An InputSet with methods appropriate for specifying the inputs to the SearchPeople
    # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    ####
    class SearchPeopleInputSet < Choreography::InputSet

      #### 
      # Set the value of the AccountName input for this Choreo. 
      # 
      # @param String - (required, string) A valid Highrise account name. This is the first part of the account's URL.
      ###

      def set_AccountName(value)
        set_input("AccountName", value)
      end
      #### 
      # Set the value of the City input for this Choreo. 
      # 
      # @param String - (optional, string) Allows you to search by the city field in Highrise.
      ###

      def set_City(value)
        set_input("City", value)
      end
      #### 
      # Set the value of the Country input for this Choreo. 
      # 
      # @param String - (optional, string) Allows you to search by the country field in Highrise.
      ###

      def set_Country(value)
        set_input("Country", value)
      end
      #### 
      # Set the value of the EmailAddress input for this Choreo. 
      # 
      # @param String - (optional, string) Allows you to search by the email address field in Highrise.
      ###

      def set_EmailAddress(value)
        set_input("EmailAddress", value)
      end
      #### 
      # Set the value of the Password input for this Choreo. 
      # 
      # @param String - (required, password) The Highrise account password. Use the value 'X' when specifying an API Key for the Username input.
      ###

      def set_Password(value)
        set_input("Password", value)
      end
      #### 
      # Set the value of the Phone input for this Choreo. 
      # 
      # @param String - (optional, string) Allows you to search by the phone field in Highrise.
      ###

      def set_Phone(value)
        set_input("Phone", value)
      end
      #### 
      # Set the value of the State input for this Choreo. 
      # 
      # @param String - (optional, string) Allows you to search by the state field in Highrise.
      ###

      def set_State(value)
        set_input("State", value)
      end
      #### 
      # Set the value of the Username input for this Choreo. 
      # 
      # @param String - (required, string) A Highrise account username or API Key.
      ###

      def set_Username(value)
        set_input("Username", value)
      end
      #### 
      # Set the value of the Zip input for this Choreo. 
      # 
      # @param String - (optional, string) Allows you to search by the ZIP field in Highrise.
      ###

      def set_Zip(value)
        set_input("Zip", value)
      end

    end

    ####
    # A ResultSet with methods tailored to the values returned by the SearchPeople Choreo.
    # The ResultSet object is used to retrieve the results of a Choreo execution.
    ####
    class SearchPeopleResultSet < Choreography::ResultSet
    	####
    	# Retrieve the value for the "Response" output from this Choreo execution
    	#
    	# @return String - (xml) The response from Highrise.
    	####
    	def get_Response()
    	  return @outputs["Response"]
    	end
    end

  end # class SearchPeople



  ##############################################################################
  #
  # ShowPeople
  #
  # Retrieves contacts from your Highrise CRM.
  #
  # Copyright 2014, Temboo Inc.
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing,
  # software distributed under the License is distributed on an
  # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
  # either express or implied. See the License for the specific
  # language governing permissions and limitations under the License.
  #
  ##############################################################################

  class ShowPeople < Choreography

    ####
    #  Create a new instance of the ShowPeople Choreo. A TembooSession object, containing a valid
    #  set of Temboo credentials, must be supplied.
    ####
    def initialize(session)
      super(session, "/Library/Highrise/ShowPeople")
    end

    #### 
    # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
    #
    # @return ShowPeopleInputSet
    ####
    def new_input_set()
      return ShowPeopleInputSet.new()
    end

    def make_result_set()
      return ShowPeopleResultSet.new()
    end

    ####
    # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
    # and return a ResultSet containing the execution results.
    # @param choreoInputs
    # @return
    # @throws TembooException
    ####
    def execute(input_set = nil)
      resp = super(input_set)
      results = ShowPeopleResultSet.new(resp)
      return results
    end

    ####
    # An InputSet with methods appropriate for specifying the inputs to the ShowPeople
    # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    ####
    class ShowPeopleInputSet < Choreography::InputSet

      #### 
      # Set the value of the AccountName input for this Choreo. 
      # 
      # @param String - (required, string) A Highrise account username or API Key.
      ###

      def set_AccountName(value)
        set_input("AccountName", value)
      end
      #### 
      # Set the value of the ConactID input for this Choreo. 
      # 
      # @param Integer - (required, integer) The ID of the contact you want to retrieve. This is used to construct the URL for the request.
      ###

      def set_ConactID(value)
        set_input("ConactID", value)
      end
      #### 
      # Set the value of the Password input for this Choreo. 
      # 
      # @param String - (required, password) The Highrise account password. Use the value 'X' when specifying an API Key for the Username input.
      ###

      def set_Password(value)
        set_input("Password", value)
      end
      #### 
      # Set the value of the Username input for this Choreo. 
      # 
      # @param String - (required, string) A Highrise account username or API Key.
      ###

      def set_Username(value)
        set_input("Username", value)
      end

    end

    ####
    # A ResultSet with methods tailored to the values returned by the ShowPeople Choreo.
    # The ResultSet object is used to retrieve the results of a Choreo execution.
    ####
    class ShowPeopleResultSet < Choreography::ResultSet
    	####
    	# Retrieve the value for the "Response" output from this Choreo execution
    	#
    	# @return String - (xml) The response from Highrise.
    	####
    	def get_Response()
    	  return @outputs["Response"]
    	end
    end

  end # class ShowPeople




end # module Highrise