require "temboo"

module Klout




  module Identity



    ##############################################################################
    #
    # ByGooglePlusID
    #
    # Performs a lookup for a user's identity using a Google+ ID.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ByGooglePlusID < Choreography

      ####
      #  Create a new instance of the ByGooglePlusID Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Klout/Identity/ByGooglePlusID")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ByGooglePlusIDInputSet
      ####
      def new_input_set()
        return ByGooglePlusIDInputSet.new()
      end

      def make_result_set()
        return ByGooglePlusIDResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ByGooglePlusIDResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ByGooglePlusID
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ByGooglePlusIDInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by Klout.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the GooglePlusID input for this Choreo. 
        # 
        # @param Integer - (required, integer) The numeric ID for a Google+ user.
        ###

        def set_GooglePlusID(value)
          set_input("GooglePlusID", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ByGooglePlusID Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ByGooglePlusIDResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Klout.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ByGooglePlusID



    ##############################################################################
    #
    # ByKloutID
    #
    # Performs a lookup for a user's identity using a Klout ID.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ByKloutID < Choreography

      ####
      #  Create a new instance of the ByKloutID Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Klout/Identity/ByKloutID")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ByKloutIDInputSet
      ####
      def new_input_set()
        return ByKloutIDInputSet.new()
      end

      def make_result_set()
        return ByKloutIDResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ByKloutIDResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ByKloutID
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ByKloutIDInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by Klout.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the KloutID input for this Choreo. 
        # 
        # @param Integer - (required, integer) The numeric ID for a Klout user.
        ###

        def set_KloutID(value)
          set_input("KloutID", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ByKloutID Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ByKloutIDResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Klout.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ByKloutID



    ##############################################################################
    #
    # ByTwitterID
    #
    # Performs a lookup for a user's identity using a Twitter ID.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ByTwitterID < Choreography

      ####
      #  Create a new instance of the ByTwitterID Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Klout/Identity/ByTwitterID")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ByTwitterIDInputSet
      ####
      def new_input_set()
        return ByTwitterIDInputSet.new()
      end

      def make_result_set()
        return ByTwitterIDResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ByTwitterIDResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ByTwitterID
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ByTwitterIDInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by Klout.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the TwitterID input for this Choreo. 
        # 
        # @param Integer - (required, integer) The numeric ID for a Twitter user.
        ###

        def set_TwitterID(value)
          set_input("TwitterID", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ByTwitterID Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ByTwitterIDResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Klout.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ByTwitterID



    ##############################################################################
    #
    # ByTwitterScreenName
    #
    # Performs a lookup for a user's identity using a Twitter screen name.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ByTwitterScreenName < Choreography

      ####
      #  Create a new instance of the ByTwitterScreenName Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Klout/Identity/ByTwitterScreenName")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ByTwitterScreenNameInputSet
      ####
      def new_input_set()
        return ByTwitterScreenNameInputSet.new()
      end

      def make_result_set()
        return ByTwitterScreenNameResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ByTwitterScreenNameResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ByTwitterScreenName
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ByTwitterScreenNameInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by Klout.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the ScreenName input for this Choreo. 
        # 
        # @param String - (required, string) The screen name for a Twitter user.
        ###

        def set_ScreenName(value)
          set_input("ScreenName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ByTwitterScreenName Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ByTwitterScreenNameResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Klout.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ByTwitterScreenName




  end # module Identity

  module User



    ##############################################################################
    #
    # Influence
    #
    # Retrieves a user's influencers and influencees.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Influence < Choreography

      ####
      #  Create a new instance of the Influence Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Klout/User/Influence")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return InfluenceInputSet
      ####
      def new_input_set()
        return InfluenceInputSet.new()
      end

      def make_result_set()
        return InfluenceResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = InfluenceResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Influence
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class InfluenceInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by Klout.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the KloutID input for this Choreo. 
        # 
        # @param String - (required, string) The id for a Klout user to retrieve influencers and influencees for.
        ###

        def set_KloutID(value)
          set_input("KloutID", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Influence Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class InfluenceResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Klout.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Influence



    ##############################################################################
    #
    # Score
    #
    # Retrieves a user's Klout Score and deltas.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Score < Choreography

      ####
      #  Create a new instance of the Score Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Klout/User/Score")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ScoreInputSet
      ####
      def new_input_set()
        return ScoreInputSet.new()
      end

      def make_result_set()
        return ScoreResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ScoreResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Score
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ScoreInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by Klout.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the KloutID input for this Choreo. 
        # 
        # @param String - (required, string) The id for a Klout user to retrieve a score for.
        ###

        def set_KloutID(value)
          set_input("KloutID", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Score Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ScoreResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Klout.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Score



    ##############################################################################
    #
    # ShowUser
    #
    # Retrieves information for a specified Klout user.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ShowUser < Choreography

      ####
      #  Create a new instance of the ShowUser Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Klout/User/ShowUser")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ShowUserInputSet
      ####
      def new_input_set()
        return ShowUserInputSet.new()
      end

      def make_result_set()
        return ShowUserResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ShowUserResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ShowUser
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ShowUserInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by Klout.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the KloutID input for this Choreo. 
        # 
        # @param String - (required, string) The id for a Klout user to retrieve.
        ###

        def set_KloutID(value)
          set_input("KloutID", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ShowUser Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ShowUserResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Klout.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ShowUser



    ##############################################################################
    #
    # Topics
    #
    # Retrieves a user's topics. 
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Topics < Choreography

      ####
      #  Create a new instance of the Topics Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Klout/User/Topics")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return TopicsInputSet
      ####
      def new_input_set()
        return TopicsInputSet.new()
      end

      def make_result_set()
        return TopicsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = TopicsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Topics
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class TopicsInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by Klout.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the KloutID input for this Choreo. 
        # 
        # @param String - (required, string) The id for a Klout user to retrieve topics for.
        ###

        def set_KloutID(value)
          set_input("KloutID", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Topics Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class TopicsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Klout.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Topics




  end # module User

end # module Klout