require "temboo"

module Labs




  module GetPlaces



    ##############################################################################
    #
    # ByAddress
    #
    # Retrieves information from multiple APIs about places near a specified street address.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ByAddress < Choreography

      ####
      #  Create a new instance of the ByAddress Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Labs/GetPlaces/ByAddress")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ByAddressInputSet
      ####
      def new_input_set()
        return ByAddressInputSet.new()
      end

      def make_result_set()
        return ByAddressResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ByAddressResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ByAddress
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ByAddressInputSet < Choreography::InputSet

        #### 
        # Set the value of the APICredentials input for this Choreo. 
        # 
        # @param String - (conditional, json) 
        ###

        def set_APICredentials(value)
          set_input("APICredentials", value)
        end
        #### 
        # Set the value of the Address input for this Choreo. 
        # 
        # @param String - (required, string) The street address to use in the search. This can be a single address, or an array of addresses. See documentation for formatting examples.
        ###

        def set_Address(value)
          set_input("Address", value)
        end
        #### 
        # Set the value of the Limit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Limits the number of Foursquare venues results.
        ###

        def set_Limit(value)
          set_input("Limit", value)
        end
        #### 
        # Set the value of the Query input for this Choreo. 
        # 
        # @param String - (optional, string) This keyword input can be used to narrow search results for Google Places and Foursquare.
        ###

        def set_Query(value)
          set_input("Query", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Type input for this Choreo. 
        # 
        # @param String - (optional, string) Filters results by type of place, such as: bar, dentist, etc. This is used to filter results for Google Places and Yelp.
        ###

        def set_Type(value)
          set_input("Type", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ByAddress Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ByAddressResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - Contains the merged results for search.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ByAddress



    ##############################################################################
    #
    # ByCoordinates
    #
    # Retrieves information about places near a set of coordinates from multiple sources in one API call.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ByCoordinates < Choreography

      ####
      #  Create a new instance of the ByCoordinates Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Labs/GetPlaces/ByCoordinates")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ByCoordinatesInputSet
      ####
      def new_input_set()
        return ByCoordinatesInputSet.new()
      end

      def make_result_set()
        return ByCoordinatesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ByCoordinatesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ByCoordinates
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ByCoordinatesInputSet < Choreography::InputSet

        #### 
        # Set the value of the APICredentials input for this Choreo. 
        # 
        # @param String - (required, json) A JSON dictionary of credentials for the APIs you wish to access. See Choreo documentation for formatting examples.
        ###

        def set_APICredentials(value)
          set_input("APICredentials", value)
        end
        #### 
        # Set the value of the Latitude input for this Choreo. 
        # 
        # @param BigDecimal - (required, decimal) The latitude of the user's location.
        ###

        def set_Latitude(value)
          set_input("Latitude", value)
        end
        #### 
        # Set the value of the Limit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Limits the number of Foursquare venue results.
        ###

        def set_Limit(value)
          set_input("Limit", value)
        end
        #### 
        # Set the value of the Longitude input for this Choreo. 
        # 
        # @param BigDecimal - (required, decimal) The longitude of the user's location.
        ###

        def set_Longitude(value)
          set_input("Longitude", value)
        end
        #### 
        # Set the value of the Query input for this Choreo. 
        # 
        # @param String - (optional, string) This keyword input can be used to narrow search results for Google Places and Foursquare.
        ###

        def set_Query(value)
          set_input("Query", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Type input for this Choreo. 
        # 
        # @param String - (optional, string) Filters results by type of place, such as: bar, dentist, etc. This is used to filter results for Google Places and Yelp.
        ###

        def set_Type(value)
          set_input("Type", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ByCoordinates Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ByCoordinatesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - Contains the merged results from the API responses.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ByCoordinates



    ##############################################################################
    #
    # ByFoursquare
    #
    # Retrieves information from multiple APIs about places near a set of coordinates retrieved from Foursquare.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ByFoursquare < Choreography

      ####
      #  Create a new instance of the ByFoursquare Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Labs/GetPlaces/ByFoursquare")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ByFoursquareInputSet
      ####
      def new_input_set()
        return ByFoursquareInputSet.new()
      end

      def make_result_set()
        return ByFoursquareResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ByFoursquareResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ByFoursquare
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ByFoursquareInputSet < Choreography::InputSet

        #### 
        # Set the value of the APICredentials input for this Choreo. 
        # 
        # @param String - (required, json) A JSON dictionary of credentials for the APIs you wish to access. See Choreo documentation for formatting examples.
        ###

        def set_APICredentials(value)
          set_input("APICredentials", value)
        end
        #### 
        # Set the value of the Limit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Limits the number of Foursquare venues returned.
        ###

        def set_Limit(value)
          set_input("Limit", value)
        end
        #### 
        # Set the value of the Query input for this Choreo. 
        # 
        # @param String - (optional, string) This keyword input can be used to narrow search results for Google Places and Foursquare.
        ###

        def set_Query(value)
          set_input("Query", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Shout input for this Choreo. 
        # 
        # @param String - (optional, string) A message about your check-in. The maximum length of this field is 140 characters.
        ###

        def set_Shout(value)
          set_input("Shout", value)
        end
        #### 
        # Set the value of the Type input for this Choreo. 
        # 
        # @param String - (optional, string) Filters results by type of place, such as: bar, dentist, etc. This is used to filter results for Google Places and Yelp.
        ###

        def set_Type(value)
          set_input("Type", value)
        end
        #### 
        # Set the value of the VenueID input for this Choreo. 
        # 
        # @param String - (optional, string) The venue where the user is checking in. Required if creating a Foursquare checkin.
        ###

        def set_VenueID(value)
          set_input("VenueID", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ByFoursquare Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ByFoursquareResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) Contains weather information based on the coordinates returned from the Foursquare checkin.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ByFoursquare




  end # module GetPlaces

  module GetWeather



    ##############################################################################
    #
    # ByAddress
    #
    # Retrieves weather and UV index data for a given Geo point using the Yahoo Weather and EnviroFacts APIs.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ByAddress < Choreography

      ####
      #  Create a new instance of the ByAddress Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Labs/GetWeather/ByAddress")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ByAddressInputSet
      ####
      def new_input_set()
        return ByAddressInputSet.new()
      end

      def make_result_set()
        return ByAddressResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ByAddressResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ByAddress
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ByAddressInputSet < Choreography::InputSet

        #### 
        # Set the value of the APICredentials input for this Choreo. 
        # 
        # @param String - (optional, json) A JSON dictionary containing a Yahoo App ID. See Choreo documentation for formatting examples.
        ###

        def set_APICredentials(value)
          set_input("APICredentials", value)
        end
        #### 
        # Set the value of the Address input for this Choreo. 
        # 
        # @param String - (required, string) The street address of the location to get weather for.
        ###

        def set_Address(value)
          set_input("Address", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ByAddress Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ByAddressResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) Contains combined weather data from Yahoo Weather and EnviroFacts.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ByAddress



    ##############################################################################
    #
    # ByCoordinates
    #
    # Retrieves weather and UV index data for a given Geo point using the Yahoo Weather and EnviroFacts APIs.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ByCoordinates < Choreography

      ####
      #  Create a new instance of the ByCoordinates Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Labs/GetWeather/ByCoordinates")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ByCoordinatesInputSet
      ####
      def new_input_set()
        return ByCoordinatesInputSet.new()
      end

      def make_result_set()
        return ByCoordinatesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ByCoordinatesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ByCoordinates
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ByCoordinatesInputSet < Choreography::InputSet

        #### 
        # Set the value of the APICredentials input for this Choreo. 
        # 
        # @param String - (optional, json) A JSON dictionary containing a Yahoo App ID. See Choreo documentation for formatting examples.
        ###

        def set_APICredentials(value)
          set_input("APICredentials", value)
        end
        #### 
        # Set the value of the Latitude input for this Choreo. 
        # 
        # @param BigDecimal - (required, decimal) The latitude coordinate to use when looking up weather information.
        ###

        def set_Latitude(value)
          set_input("Latitude", value)
        end
        #### 
        # Set the value of the Longitude input for this Choreo. 
        # 
        # @param BigDecimal - (required, decimal) The longitude coordinate to use when looking up weather information.
        ###

        def set_Longitude(value)
          set_input("Longitude", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ByCoordinates Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ByCoordinatesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) Contains combined weather data from Yahoo Weather and EnviroFacts.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ByCoordinates



    ##############################################################################
    #
    # ByFoursquare
    #
    # Retrieves weather and UV index data based on coordinates returned from a Foursquare recent check-in.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ByFoursquare < Choreography

      ####
      #  Create a new instance of the ByFoursquare Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Labs/GetWeather/ByFoursquare")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ByFoursquareInputSet
      ####
      def new_input_set()
        return ByFoursquareInputSet.new()
      end

      def make_result_set()
        return ByFoursquareResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ByFoursquareResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ByFoursquare
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ByFoursquareInputSet < Choreography::InputSet

        #### 
        # Set the value of the APICredentials input for this Choreo. 
        # 
        # @param String - (required, json) A JSON dictionary containing your Foursquare and Yahoo credentials. See Choreo documentation for formatting examples.
        ###

        def set_APICredentials(value)
          set_input("APICredentials", value)
        end
        #### 
        # Set the value of the Shout input for this Choreo. 
        # 
        # @param String - (optional, string) A message about your check-in. The maximum length of this field is 140 characters.
        ###

        def set_Shout(value)
          set_input("Shout", value)
        end
        #### 
        # Set the value of the VenueID input for this Choreo. 
        # 
        # @param String - (optional, string) The venue where the user is checking in. Required if creating a Foursquare checkin.
        ###

        def set_VenueID(value)
          set_input("VenueID", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ByFoursquare Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ByFoursquareResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) Contains weather information based on the coordinates returned from the Foursquare checkin.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ByFoursquare




  end # module GetWeather

  module GoodCitizen



    ##############################################################################
    #
    # Civic
    #
    # Retrieves a host of information about the district and representatives of a specified location.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Civic < Choreography

      ####
      #  Create a new instance of the Civic Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Labs/GoodCitizen/Civic")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CivicInputSet
      ####
      def new_input_set()
        return CivicInputSet.new()
      end

      def make_result_set()
        return CivicResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CivicResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Civic
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CivicInputSet < Choreography::InputSet

        #### 
        # Set the value of the APICredentials input for this Choreo. 
        # 
        # @param String - (conditional, json) A JSON dictionary containing credentials for Sunlight Labs and LittleSis. If this input is set, a Sunset Labs key must be present. See Choreo notes for formatting examples.
        ###

        def set_APICredentials(value)
          set_input("APICredentials", value)
        end
        #### 
        # Set the value of the Latitude input for this Choreo. 
        # 
        # @param BigDecimal - (required, decimal) The latitude coordinate of your location.
        ###

        def set_Latitude(value)
          set_input("Latitude", value)
        end
        #### 
        # Set the value of the Limit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Set the number of records to return for the bills, votes, and relationships of each legislator. Defaults to 5.
        ###

        def set_Limit(value)
          set_input("Limit", value)
        end
        #### 
        # Set the value of the Longitude input for this Choreo. 
        # 
        # @param BigDecimal - (required, decimal) The longitude coordinate of your locaion.
        ###

        def set_Longitude(value)
          set_input("Longitude", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Civic Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CivicResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (string) The response from the Civic Choreo.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Civic



    ##############################################################################
    #
    # EcoByCoordinates
    #
    # Returns a host of eco-conscious environmental information for a specified location based on Lattitude and Longitude inputs.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class EcoByCoordinates < Choreography

      ####
      #  Create a new instance of the EcoByCoordinates Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Labs/GoodCitizen/EcoByCoordinates")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return EcoByCoordinatesInputSet
      ####
      def new_input_set()
        return EcoByCoordinatesInputSet.new()
      end

      def make_result_set()
        return EcoByCoordinatesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = EcoByCoordinatesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the EcoByCoordinates
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class EcoByCoordinatesInputSet < Choreography::InputSet

        #### 
        # Set the value of the APICredentials input for this Choreo. 
        # 
        # @param String - (optional, string) A JSON dictionary containing credentials for Genability. See Choreo documentation for formatting examples.
        ###

        def set_APICredentials(value)
          set_input("APICredentials", value)
        end
        #### 
        # Set the value of the Latitude input for this Choreo. 
        # 
        # @param BigDecimal - (required, decimal) The latitude coordinate for the user's current location.
        ###

        def set_Latitude(value)
          set_input("Latitude", value)
        end
        #### 
        # Set the value of the Limit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The number of facility records to search for in the Envirofacts database.
        ###

        def set_Limit(value)
          set_input("Limit", value)
        end
        #### 
        # Set the value of the Longitude input for this Choreo. 
        # 
        # @param BigDecimal - (required, decimal) The longitude coordinate for the user's current location.
        ###

        def set_Longitude(value)
          set_input("Longitude", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the EcoByCoordinates Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class EcoByCoordinatesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from the Eco Choreo.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class EcoByCoordinates



    ##############################################################################
    #
    # EcoByZip
    #
    # Returns a host of eco-conscious environmental information for a specified location based on zip code.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class EcoByZip < Choreography

      ####
      #  Create a new instance of the EcoByZip Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Labs/GoodCitizen/EcoByZip")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return EcoByZipInputSet
      ####
      def new_input_set()
        return EcoByZipInputSet.new()
      end

      def make_result_set()
        return EcoByZipResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = EcoByZipResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the EcoByZip
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class EcoByZipInputSet < Choreography::InputSet

        #### 
        # Set the value of the APICredentials input for this Choreo. 
        # 
        # @param String - (optional, string) A JSON dictionary containing credentials for Genability. See Choreo documentation for formatting examples.
        ###

        def set_APICredentials(value)
          set_input("APICredentials", value)
        end
        #### 
        # Set the value of the Limit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The number of facility records to search for in the Envirofacts database.
        ###

        def set_Limit(value)
          set_input("Limit", value)
        end
        #### 
        # Set the value of the Zip input for this Choreo. 
        # 
        # @param Integer - (required, integer) The zip code for the user's current location.
        ###

        def set_Zip(value)
          set_input("Zip", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the EcoByZip Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class EcoByZipResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from the Eco Choreo.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class EcoByZip




  end # module GoodCitizen

  module Social



    ##############################################################################
    #
    # GetContacts
    #
    # Retrieves your social contacts from multiple APIs in one API call.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetContacts < Choreography

      ####
      #  Create a new instance of the GetContacts Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Labs/Social/GetContacts")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetContactsInputSet
      ####
      def new_input_set()
        return GetContactsInputSet.new()
      end

      def make_result_set()
        return GetContactsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetContactsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetContacts
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetContactsInputSet < Choreography::InputSet

        #### 
        # Set the value of the APICredentials input for this Choreo. 
        # 
        # @param String - (conditional, json) A list of credentials for the APIs you wish to access. See Choreo documentation for formatting examples.
        ###

        def set_APICredentials(value)
          set_input("APICredentials", value)
        end
        #### 
        # Set the value of the ScreenName input for this Choreo. 
        # 
        # @param String - (conditional, string) The Twitter screen name to retrieve followers for.
        ###

        def set_ScreenName(value)
          set_input("ScreenName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetContacts Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetContactsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) Contains the merged results from the API responses.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetContacts



    ##############################################################################
    #
    # GetNearbyContacts
    #
    # Searches Foursquare recent check-ins and the Facebook social graph with a given set of Geo coordinates
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetNearbyContacts < Choreography

      ####
      #  Create a new instance of the GetNearbyContacts Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Labs/Social/GetNearbyContacts")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetNearbyContactsInputSet
      ####
      def new_input_set()
        return GetNearbyContactsInputSet.new()
      end

      def make_result_set()
        return GetNearbyContactsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetNearbyContactsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetNearbyContacts
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetNearbyContactsInputSet < Choreography::InputSet

        #### 
        # Set the value of the APICredentials input for this Choreo. 
        # 
        # @param String - (required, json) A JSON dictionary containing Facebook and Foursquare credentials.
        ###

        def set_APICredentials(value)
          set_input("APICredentials", value)
        end
        #### 
        # Set the value of the AfterTimestamp input for this Choreo. 
        # 
        # @param String - (optional, date) Seconds after which to look for checkins, e.g. for looking for new checkins since the last fetch.
        ###

        def set_AfterTimestamp(value)
          set_input("AfterTimestamp", value)
        end
        #### 
        # Set the value of the Latitude input for this Choreo. 
        # 
        # @param BigDecimal - (required, decimal) The latitude coordinate of the location to search for.
        ###

        def set_Latitude(value)
          set_input("Latitude", value)
        end
        #### 
        # Set the value of the Limit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Used to page through results. Limits the number of records returned in the API responses.
        ###

        def set_Limit(value)
          set_input("Limit", value)
        end
        #### 
        # Set the value of the Longitude input for this Choreo. 
        # 
        # @param BigDecimal - (conditional, decimal) The longitude coordinate of the location to search for.
        ###

        def set_Longitude(value)
          set_input("Longitude", value)
        end
        #### 
        # Set the value of the Offset input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Used to page through Facebook results. Returns results starting from the specified number.
        ###

        def set_Offset(value)
          set_input("Offset", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetNearbyContacts Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetNearbyContactsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) A merged result of Foursquare and Facebook location based searches.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetNearbyContacts



    ##############################################################################
    #
    # UpdateAllStatuses
    #
    # Shares a post across multiple social networks such as Facebook, Tumblr, and Twitter.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UpdateAllStatuses < Choreography

      ####
      #  Create a new instance of the UpdateAllStatuses Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Labs/Social/UpdateAllStatuses")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UpdateAllStatusesInputSet
      ####
      def new_input_set()
        return UpdateAllStatusesInputSet.new()
      end

      def make_result_set()
        return UpdateAllStatusesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UpdateAllStatusesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UpdateAllStatuses
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UpdateAllStatusesInputSet < Choreography::InputSet

        #### 
        # Set the value of the APICredentials input for this Choreo. 
        # 
        # @param String - (required, json) A list of credentials for the APIs you wish to access. See Choreo documentation for formatting examples.
        ###

        def set_APICredentials(value)
          set_input("APICredentials", value)
        end
        #### 
        # Set the value of the Message input for this Choreo. 
        # 
        # @param String - (required, string) The message to be posted across social networks.
        ###

        def set_Message(value)
          set_input("Message", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UpdateAllStatuses Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UpdateAllStatusesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) A list of results for each API.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UpdateAllStatuses




  end # module Social

end # module Labs