require "temboo"

module LinkedIn




  module Companies



    ##############################################################################
    #
    # CompanyShare
    #
    # Posts shared comment on a company page.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CompanyShare < Choreography

      ####
      #  Create a new instance of the CompanyShare Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/LinkedIn/Companies/CompanyShare")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CompanyShareInputSet
      ####
      def new_input_set()
        return CompanyShareInputSet.new()
      end

      def make_result_set()
        return CompanyShareResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CompanyShareResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CompanyShare
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CompanyShareInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by LinkedIn (AKA the Client ID).
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process (AKA the OAuth User Token).
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process (AKA the OAuth User Secret).
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the Comment input for this Choreo. 
        # 
        # @param String - (conditional, string) A comment by the member to associated with the share. If this is not provided, you must specify the SubmittedURL.
        ###

        def set_Comment(value)
          set_input("Comment", value)
        end
        #### 
        # Set the value of the CompanyID input for this Choreo. 
        # 
        # @param Integer - (required, integer) A LinkedIn assigned ID associated with the company.
        ###

        def set_CompanyID(value)
          set_input("CompanyID", value)
        end
        #### 
        # Set the value of the Description input for this Choreo. 
        # 
        # @param String - (optional, string) The description of the content being shared.
        ###

        def set_Description(value)
          set_input("Description", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SecretKey input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key provided by LinkedIn (AKA the Client Secret).
        ###

        def set_SecretKey(value)
          set_input("SecretKey", value)
        end
        #### 
        # Set the value of the SharedTargetCode input for this Choreo. 
        # 
        # @param String - (optional, string) A shared target code used to ensure that the shared content reaches a specific audience.
        ###

        def set_SharedTargetCode(value)
          set_input("SharedTargetCode", value)
        end
        #### 
        # Set the value of the SharedTargetValue input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the shared target used to ensure that the shared content reaches a specific audience.
        ###

        def set_SharedTargetValue(value)
          set_input("SharedTargetValue", value)
        end
        #### 
        # Set the value of the SubmittedImageURL input for this Choreo. 
        # 
        # @param String - (optional, string) A fully qualified URL to a thumbnail image to accompany the shared content.
        ###

        def set_SubmittedImageURL(value)
          set_input("SubmittedImageURL", value)
        end
        #### 
        # Set the value of the SubmittedURL input for this Choreo. 
        # 
        # @param String - (optional, string) A fully qualified URL for the content being shared.
        ###

        def set_SubmittedURL(value)
          set_input("SubmittedURL", value)
        end
        #### 
        # Set the value of the Title input for this Choreo. 
        # 
        # @param String - (optional, string) The title of the content being shared.
        ###

        def set_Title(value)
          set_input("Title", value)
        end
        #### 
        # Set the value of the Visibility input for this Choreo. 
        # 
        # @param String - (required, string) The visibility setting of the share. Valid values are: anyone, connections-only.
        ###

        def set_Visibility(value)
          set_input("Visibility", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CompanyShare Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CompanyShareResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from LinkedIn.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CompanyShare



    ##############################################################################
    #
    # GetComments
    #
    # Returns all comments for a specific company update.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetComments < Choreography

      ####
      #  Create a new instance of the GetComments Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/LinkedIn/Companies/GetComments")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetCommentsInputSet
      ####
      def new_input_set()
        return GetCommentsInputSet.new()
      end

      def make_result_set()
        return GetCommentsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetCommentsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetComments
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetCommentsInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by LinkedIn (AKA the Client ID).
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process (AKA the OAuth User Token).
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process (AKA the OAuth User Secret).
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the CompanyID input for this Choreo. 
        # 
        # @param Integer - (required, integer) A LinkedIn assigned ID associated with the company.
        ###

        def set_CompanyID(value)
          set_input("CompanyID", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SecretKey input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key provided by LinkedIn (AKA the Client Secret).
        ###

        def set_SecretKey(value)
          set_input("SecretKey", value)
        end
        #### 
        # Set the value of the UpdateKey input for this Choreo. 
        # 
        # @param String - (required, string) The key of the update to retrieve comments for.
        ###

        def set_UpdateKey(value)
          set_input("UpdateKey", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetComments Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetCommentsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from LinkedIn.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetComments



    ##############################################################################
    #
    # GetCompanyProfileByID
    #
    # Returns profile information about a specified company.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetCompanyProfileByID < Choreography

      ####
      #  Create a new instance of the GetCompanyProfileByID Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/LinkedIn/Companies/GetCompanyProfileByID")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetCompanyProfileByIDInputSet
      ####
      def new_input_set()
        return GetCompanyProfileByIDInputSet.new()
      end

      def make_result_set()
        return GetCompanyProfileByIDResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetCompanyProfileByIDResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetCompanyProfileByID
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetCompanyProfileByIDInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by LinkedIn (AKA the Client ID).
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process (AKA the OAuth User Token).
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process (AKA the OAuth User Secret).
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the CompanyID input for this Choreo. 
        # 
        # @param Integer - (required, integer) A LinkedIn assigned ID associated with the company.
        ###

        def set_CompanyID(value)
          set_input("CompanyID", value)
        end
        #### 
        # Set the value of the FieldSelector input for this Choreo. 
        # 
        # @param String - (optional, string) A comma-separated list of additional field names to return (e.g., id,name,description). See Choreo notes for more details.
        ###

        def set_FieldSelector(value)
          set_input("FieldSelector", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SecretKey input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key provided by LinkedIn (AKA the Client Secret).
        ###

        def set_SecretKey(value)
          set_input("SecretKey", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetCompanyProfileByID Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetCompanyProfileByIDResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from LinkedIn.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetCompanyProfileByID



    ##############################################################################
    #
    # GetCompanyUpdate
    #
    # Returns a specific update event from the LinkedIn company page.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetCompanyUpdate < Choreography

      ####
      #  Create a new instance of the GetCompanyUpdate Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/LinkedIn/Companies/GetCompanyUpdate")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetCompanyUpdateInputSet
      ####
      def new_input_set()
        return GetCompanyUpdateInputSet.new()
      end

      def make_result_set()
        return GetCompanyUpdateResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetCompanyUpdateResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetCompanyUpdate
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetCompanyUpdateInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by LinkedIn (AKA the Client ID).
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process (AKA the OAuth User Token).
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process (AKA the OAuth User Secret).
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the CompanyID input for this Choreo. 
        # 
        # @param Integer - (required, integer) A LinkedIn assigned ID associated with the company.
        ###

        def set_CompanyID(value)
          set_input("CompanyID", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SecretKey input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key provided by LinkedIn (AKA the Client Secret).
        ###

        def set_SecretKey(value)
          set_input("SecretKey", value)
        end
        #### 
        # Set the value of the UpdateKey input for this Choreo. 
        # 
        # @param String - (required, string) The key of the update to return.
        ###

        def set_UpdateKey(value)
          set_input("UpdateKey", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetCompanyUpdate Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetCompanyUpdateResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from LinkedIn.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetCompanyUpdate



    ##############################################################################
    #
    # GetCompanyUpdates
    #
    # Returns a list of update events from the LinkedIn company page.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetCompanyUpdates < Choreography

      ####
      #  Create a new instance of the GetCompanyUpdates Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/LinkedIn/Companies/GetCompanyUpdates")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetCompanyUpdatesInputSet
      ####
      def new_input_set()
        return GetCompanyUpdatesInputSet.new()
      end

      def make_result_set()
        return GetCompanyUpdatesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetCompanyUpdatesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetCompanyUpdates
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetCompanyUpdatesInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by LinkedIn (AKA the Client ID).
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process (AKA the OAuth User Token).
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process (AKA the OAuth User Secret).
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the CompanyID input for this Choreo. 
        # 
        # @param Integer - (required, integer) A LinkedIn assigned ID associated with the company.
        ###

        def set_CompanyID(value)
          set_input("CompanyID", value)
        end
        #### 
        # Set the value of the Count input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The number of results to return in the response.
        ###

        def set_Count(value)
          set_input("Count", value)
        end
        #### 
        # Set the value of the EventType input for this Choreo. 
        # 
        # @param String - (required, string) Filter the results to only return updates of the specified event type. Valid values are: job-posting, new-product, status-update.
        ###

        def set_EventType(value)
          set_input("EventType", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SecretKey input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key provided by LinkedIn (AKA the Client Secret).
        ###

        def set_SecretKey(value)
          set_input("SecretKey", value)
        end
        #### 
        # Set the value of the Start input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The page index to return. Used in combination with the Count input to page through results.
        ###

        def set_Start(value)
          set_input("Start", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetCompanyUpdates Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetCompanyUpdatesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from LinkedIn.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetCompanyUpdates



    ##############################################################################
    #
    # GetFollowers
    #
    # Returns a company's followers, by segment.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetFollowers < Choreography

      ####
      #  Create a new instance of the GetFollowers Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/LinkedIn/Companies/GetFollowers")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetFollowersInputSet
      ####
      def new_input_set()
        return GetFollowersInputSet.new()
      end

      def make_result_set()
        return GetFollowersResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetFollowersResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetFollowers
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetFollowersInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by LinkedIn (AKA the Client ID).
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process (AKA the OAuth User Token).
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process (AKA the OAuth User Secret).
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the CompanyID input for this Choreo. 
        # 
        # @param Integer - (required, integer) A LinkedIn assigned ID associated with the company.
        ###

        def set_CompanyID(value)
          set_input("CompanyID", value)
        end
        #### 
        # Set the value of the CompanySizes input for this Choreo. 
        # 
        # @param String - (optional, string) Used to segment by a particular company size targeting code. See Choreo notes for more details.
        ###

        def set_CompanySizes(value)
          set_input("CompanySizes", value)
        end
        #### 
        # Set the value of the GeographicArea input for this Choreo. 
        # 
        # @param String - (optional, string) Used to segment by a particular geographic area. See Choreo notes for more details.
        ###

        def set_GeographicArea(value)
          set_input("GeographicArea", value)
        end
        #### 
        # Set the value of the Industries input for this Choreo. 
        # 
        # @param String - (optional, string) Used to segment by member industry. See Choreo notes for more details.
        ###

        def set_Industries(value)
          set_input("Industries", value)
        end
        #### 
        # Set the value of the JobFunction input for this Choreo. 
        # 
        # @param String - (optional, string) Used to segment by member job function targeting code. See Choreo notes for more details.
        ###

        def set_JobFunction(value)
          set_input("JobFunction", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SecretKey input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key provided by LinkedIn (AKA the Client Secret).
        ###

        def set_SecretKey(value)
          set_input("SecretKey", value)
        end
        #### 
        # Set the value of the SeniorityLevel input for this Choreo. 
        # 
        # @param String - (optional, string) Used to segment by member seniority level targeting code. See Choreo notes for more details.
        ###

        def set_SeniorityLevel(value)
          set_input("SeniorityLevel", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetFollowers Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetFollowersResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from LinkedIn.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetFollowers



    ##############################################################################
    #
    # GetHistoricalFollowers
    #
    # Returns a company's followers, by date range.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetHistoricalFollowers < Choreography

      ####
      #  Create a new instance of the GetHistoricalFollowers Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/LinkedIn/Companies/GetHistoricalFollowers")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetHistoricalFollowersInputSet
      ####
      def new_input_set()
        return GetHistoricalFollowersInputSet.new()
      end

      def make_result_set()
        return GetHistoricalFollowersResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetHistoricalFollowersResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetHistoricalFollowers
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetHistoricalFollowersInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by LinkedIn (AKA the Client ID).
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process (AKA the OAuth User Token).
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process (AKA the OAuth User Secret).
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the CompanyID input for this Choreo. 
        # 
        # @param Integer - (required, integer) A LinkedIn assigned ID associated with the company.
        ###

        def set_CompanyID(value)
          set_input("CompanyID", value)
        end
        #### 
        # Set the value of the EndTimestamp input for this Choreo. 
        # 
        # @param String - (optional, date) The starting timestamp of when the stats search should begin (milliseconds since epoch). The current time will be used if a timestamp is not provided.
        ###

        def set_EndTimestamp(value)
          set_input("EndTimestamp", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SecretKey input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key provided by LinkedIn (AKA the Client Secret).
        ###

        def set_SecretKey(value)
          set_input("SecretKey", value)
        end
        #### 
        # Set the value of the StartTimestamp input for this Choreo. 
        # 
        # @param String - (required, date) The starting timestamp of when the stats search should begin (milliseconds since epoch). The current time will be used if a timestamp is not provided.
        ###

        def set_StartTimestamp(value)
          set_input("StartTimestamp", value)
        end
        #### 
        # Set the value of the TimeGranularity input for this Choreo. 
        # 
        # @param String - (required, string) Granularity of statistics. Valid values are: day, month.
        ###

        def set_TimeGranularity(value)
          set_input("TimeGranularity", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetHistoricalFollowers Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetHistoricalFollowersResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from LinkedIn.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetHistoricalFollowers



    ##############################################################################
    #
    # GetHistoricalUpdates
    #
    # Returns impression and engagement data on company shares for a given company page.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetHistoricalUpdates < Choreography

      ####
      #  Create a new instance of the GetHistoricalUpdates Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/LinkedIn/Companies/GetHistoricalUpdates")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetHistoricalUpdatesInputSet
      ####
      def new_input_set()
        return GetHistoricalUpdatesInputSet.new()
      end

      def make_result_set()
        return GetHistoricalUpdatesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetHistoricalUpdatesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetHistoricalUpdates
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetHistoricalUpdatesInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by LinkedIn (AKA the Client ID).
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process (AKA the OAuth User Token).
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process (AKA the OAuth User Secret).
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the CompanyID input for this Choreo. 
        # 
        # @param Integer - (required, integer) A LinkedIn assigned ID associated with the company.
        ###

        def set_CompanyID(value)
          set_input("CompanyID", value)
        end
        #### 
        # Set the value of the EndTimestamp input for this Choreo. 
        # 
        # @param String - (optional, date) The starting timestamp of when the stats search should begin (milliseconds since epoch). The current time will be used if a timestamp is not provided.
        ###

        def set_EndTimestamp(value)
          set_input("EndTimestamp", value)
        end
        #### 
        # Set the value of the FieldSelector input for this Choreo. 
        # 
        # @param String - (optional, string) A comma separated list of additional fields to return.
        ###

        def set_FieldSelector(value)
          set_input("FieldSelector", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SecretKey input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key provided by LinkedIn (AKA the Client Secret).
        ###

        def set_SecretKey(value)
          set_input("SecretKey", value)
        end
        #### 
        # Set the value of the StartTimestamp input for this Choreo. 
        # 
        # @param String - (required, date) The starting timestamp of when the stats search should begin (milliseconds since epoch). The current time will be used if a timestamp is not provided.
        ###

        def set_StartTimestamp(value)
          set_input("StartTimestamp", value)
        end
        #### 
        # Set the value of the TimeGranularity input for this Choreo. 
        # 
        # @param String - (required, string) Granularity of statistics. Valid values are: day, month.
        ###

        def set_TimeGranularity(value)
          set_input("TimeGranularity", value)
        end
        #### 
        # Set the value of the UpdateKey input for this Choreo. 
        # 
        # @param String - (optional, string) Optionally provide an update key value to return statistics for a specific company update.
        ###

        def set_UpdateKey(value)
          set_input("UpdateKey", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetHistoricalUpdates Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetHistoricalUpdatesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from LinkedIn.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetHistoricalUpdates



    ##############################################################################
    #
    # GetLikes
    #
    # Returns all likes for a specific company update.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetLikes < Choreography

      ####
      #  Create a new instance of the GetLikes Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/LinkedIn/Companies/GetLikes")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetLikesInputSet
      ####
      def new_input_set()
        return GetLikesInputSet.new()
      end

      def make_result_set()
        return GetLikesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetLikesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetLikes
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetLikesInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by LinkedIn (AKA the Client ID).
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process (AKA the OAuth User Token).
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process (AKA the OAuth User Secret).
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the CompanyID input for this Choreo. 
        # 
        # @param Integer - (required, integer) A LinkedIn assigned ID associated with the company.
        ###

        def set_CompanyID(value)
          set_input("CompanyID", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SecretKey input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key provided by LinkedIn (AKA the Client Secret).
        ###

        def set_SecretKey(value)
          set_input("SecretKey", value)
        end
        #### 
        # Set the value of the UpdateKey input for this Choreo. 
        # 
        # @param String - (required, string) The key of the update to return likes for.
        ###

        def set_UpdateKey(value)
          set_input("UpdateKey", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetLikes Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetLikesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from LinkedIn.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetLikes



    ##############################################################################
    #
    # GetStatistics
    #
    # Returns general statistics for a company.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetStatistics < Choreography

      ####
      #  Create a new instance of the GetStatistics Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/LinkedIn/Companies/GetStatistics")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetStatisticsInputSet
      ####
      def new_input_set()
        return GetStatisticsInputSet.new()
      end

      def make_result_set()
        return GetStatisticsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetStatisticsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetStatistics
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetStatisticsInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by LinkedIn (AKA the Client ID).
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process (AKA the OAuth User Token).
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process (AKA the OAuth User Secret).
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the CompanyID input for this Choreo. 
        # 
        # @param Integer - (required, integer) A LinkedIn assigned ID associated with the company.
        ###

        def set_CompanyID(value)
          set_input("CompanyID", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SecretKey input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key provided by LinkedIn (AKA the Client Secret).
        ###

        def set_SecretKey(value)
          set_input("SecretKey", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetStatistics Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetStatisticsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from LinkedIn.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetStatistics



    ##############################################################################
    #
    # IsAdmin
    #
    # Returns a simple boolean value that indicates whether the currently authenticated user is configured to be an administrator of the specified company.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class IsAdmin < Choreography

      ####
      #  Create a new instance of the IsAdmin Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/LinkedIn/Companies/IsAdmin")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return IsAdminInputSet
      ####
      def new_input_set()
        return IsAdminInputSet.new()
      end

      def make_result_set()
        return IsAdminResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = IsAdminResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the IsAdmin
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class IsAdminInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by LinkedIn (AKA the Client ID).
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process (AKA the OAuth User Token).
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process (AKA the OAuth User Secret).
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the CompanyID input for this Choreo. 
        # 
        # @param Integer - (required, integer) A LinkedIn assigned ID associated with the company.
        ###

        def set_CompanyID(value)
          set_input("CompanyID", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SecretKey input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key provided by LinkedIn (AKA the Client Secret).
        ###

        def set_SecretKey(value)
          set_input("SecretKey", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the IsAdmin Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class IsAdminResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from LinkedIn.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class IsAdmin



    ##############################################################################
    #
    # IsSharingEnabled
    #
    # Returns a simple boolean value that indicates whether the specified company has sharing enabled or disabled.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class IsSharingEnabled < Choreography

      ####
      #  Create a new instance of the IsSharingEnabled Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/LinkedIn/Companies/IsSharingEnabled")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return IsSharingEnabledInputSet
      ####
      def new_input_set()
        return IsSharingEnabledInputSet.new()
      end

      def make_result_set()
        return IsSharingEnabledResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = IsSharingEnabledResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the IsSharingEnabled
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class IsSharingEnabledInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by LinkedIn (AKA the Client ID).
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process (AKA the OAuth User Token).
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process (AKA the OAuth User Secret).
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the CompanyID input for this Choreo. 
        # 
        # @param Integer - (required, integer) A LinkedIn assigned ID associated with the company.
        ###

        def set_CompanyID(value)
          set_input("CompanyID", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SecretKey input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key provided by LinkedIn (AKA the Client Secret).
        ###

        def set_SecretKey(value)
          set_input("SecretKey", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the IsSharingEnabled Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class IsSharingEnabledResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from LinkedIn.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class IsSharingEnabled



    ##############################################################################
    #
    # ListCompanies
    #
    # Returns a list of all of the companies that the authenticated user is currently configured to be an administrator of.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListCompanies < Choreography

      ####
      #  Create a new instance of the ListCompanies Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/LinkedIn/Companies/ListCompanies")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListCompaniesInputSet
      ####
      def new_input_set()
        return ListCompaniesInputSet.new()
      end

      def make_result_set()
        return ListCompaniesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListCompaniesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListCompanies
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListCompaniesInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by LinkedIn (AKA the Client ID).
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process (AKA the OAuth User Token).
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process (AKA the OAuth User Secret).
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the Count input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The number of results to return in the response.
        ###

        def set_Count(value)
          set_input("Count", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SecretKey input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key provided by LinkedIn (AKA the Client Secret).
        ###

        def set_SecretKey(value)
          set_input("SecretKey", value)
        end
        #### 
        # Set the value of the Start input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The page index to return. Used in combination with the Count input to page through results.
        ###

        def set_Start(value)
          set_input("Start", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListCompanies Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListCompaniesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from LinkedIn.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListCompanies




  end # module Companies

  module OAuth



    ##############################################################################
    #
    # FinalizeOAuth
    #
    # Completes the OAuth process by retrieving a LinkedIn access token and access token secret for a user, after they have visited the authorization URL returned by the InitializeOAuth choreo and clicked "allow."
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class FinalizeOAuth < Choreography

      ####
      #  Create a new instance of the FinalizeOAuth Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/LinkedIn/OAuth/FinalizeOAuth")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return FinalizeOAuthInputSet
      ####
      def new_input_set()
        return FinalizeOAuthInputSet.new()
      end

      def make_result_set()
        return FinalizeOAuthResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = FinalizeOAuthResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the FinalizeOAuth
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class FinalizeOAuthInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by LinkedIn (AKA the Client ID).
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the CallbackID input for this Choreo. 
        # 
        # @param String - (required, string) The callback token returned by the InitializeOAuth Choreo. Used to retrieve the callback data after the user authorizes.
        ###

        def set_CallbackID(value)
          set_input("CallbackID", value)
        end
        #### 
        # Set the value of the OAuthTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The OAuthTokenSecret returned by the InitializeOAuth Choreo.
        ###

        def set_OAuthTokenSecret(value)
          set_input("OAuthTokenSecret", value)
        end
        #### 
        # Set the value of the SecretKey input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key provided by LinkedIn (AKA the Client Secret).
        ###

        def set_SecretKey(value)
          set_input("SecretKey", value)
        end
        #### 
        # Set the value of the SuppressErrors input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to true, errors received during the OAuth redirect process will be suppressed and returned in the ErrorMessage output.
        ###

        def set_SuppressErrors(value)
          set_input("SuppressErrors", value)
        end
        #### 
        # Set the value of the Timeout input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The amount of time (in seconds) to poll your Temboo callback URL to see if your app's user has allowed or denied the request for access. Defaults to 20. Max is 60.
        ###

        def set_Timeout(value)
          set_input("Timeout", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the FinalizeOAuth Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class FinalizeOAuthResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "AccessToken" output from this Choreo execution
      	#
      	# @return String - (string) The Access Token retrieved during the OAuth process.
      	####
      	def get_AccessToken()
      	  return @outputs["AccessToken"]
      	end
      	####
      	# Retrieve the value for the "AccessTokenSecret" output from this Choreo execution
      	#
      	# @return String - (string) The Access Token Secret retrieved during the OAuth process.
      	####
      	def get_AccessTokenSecret()
      	  return @outputs["AccessTokenSecret"]
      	end
      	####
      	# Retrieve the value for the "ErrorMessage" output from this Choreo execution
      	#
      	# @return String - (string) Contains an error message if an error occurs during the OAuth redirect process and if SuppressErrors is set to true.
      	####
      	def get_ErrorMessage()
      	  return @outputs["ErrorMessage"]
      	end
      	####
      	# Retrieve the value for the "Expires" output from this Choreo execution
      	#
      	# @return String - (integer) The expiration time in seconds of the access token retrieved.
      	####
      	def get_Expires()
      	  return @outputs["Expires"]
      	end
      end

    end # class FinalizeOAuth



    ##############################################################################
    #
    # InitializeOAuth
    #
    # Generates an authorization URL that an application can use to complete the first step in the OAuth process.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class InitializeOAuth < Choreography

      ####
      #  Create a new instance of the InitializeOAuth Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/LinkedIn/OAuth/InitializeOAuth")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return InitializeOAuthInputSet
      ####
      def new_input_set()
        return InitializeOAuthInputSet.new()
      end

      def make_result_set()
        return InitializeOAuthResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = InitializeOAuthResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the InitializeOAuth
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class InitializeOAuthInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by LinkedIn (AKA the Client ID).
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the ForwardingURL input for this Choreo. 
        # 
        # @param String - (optional, string) The URL that Temboo will redirect your users to after they grant access to your application. This should include the "https://" or "http://" prefix and be a fully qualified URL.
        ###

        def set_ForwardingURL(value)
          set_input("ForwardingURL", value)
        end
        #### 
        # Set the value of the Scope input for this Choreo. 
        # 
        # @param String - (optional, string) A space delimited list of member permissions that your application requires (e.g.,  "r_basicprofile r_emailaddress w_share").
        ###

        def set_Scope(value)
          set_input("Scope", value)
        end
        #### 
        # Set the value of the SecretKey input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key provided by LinkedIn (AKA the Client Secret).
        ###

        def set_SecretKey(value)
          set_input("SecretKey", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the InitializeOAuth Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class InitializeOAuthResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "AuthorizationURL" output from this Choreo execution
      	#
      	# @return String - (string) The authorization URL that the application's user needs to go to in order to grant access to your application.
      	####
      	def get_AuthorizationURL()
      	  return @outputs["AuthorizationURL"]
      	end
      	####
      	# Retrieve the value for the "CallbackID" output from this Choreo execution
      	#
      	# @return String - (string) An ID used to retrieve the callback data that Temboo stores once your application's user authorizes.
      	####
      	def get_CallbackID()
      	  return @outputs["CallbackID"]
      	end
      	####
      	# Retrieve the value for the "OAuthTokenSecret" output from this Choreo execution
      	#
      	# @return String - (string) The temporary OAuth Token Secret that can be exchanged for a final token secret using the FinalizeOAuth Choreo.
      	####
      	def get_OAuthTokenSecret()
      	  return @outputs["OAuthTokenSecret"]
      	end
      end

    end # class InitializeOAuth




  end # module OAuth

  module PeopleAndConnections



    ##############################################################################
    #
    # GetMemberProfile
    #
    # Returns the standard default profile of the current user.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetMemberProfile < Choreography

      ####
      #  Create a new instance of the GetMemberProfile Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/LinkedIn/PeopleAndConnections/GetMemberProfile")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetMemberProfileInputSet
      ####
      def new_input_set()
        return GetMemberProfileInputSet.new()
      end

      def make_result_set()
        return GetMemberProfileResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetMemberProfileResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetMemberProfile
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetMemberProfileInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by LinkedIn (AKA the Client ID).
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process (AKA the OAuth User Token).
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process (AKA the OAuth User Secret).
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the FieldSelector input for this Choreo. 
        # 
        # @param String - (optional, string) A comma separated list of profile properties to return.
        ###

        def set_FieldSelector(value)
          set_input("FieldSelector", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SecretKey input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key provided by LinkedIn (AKA the Client Secret).
        ###

        def set_SecretKey(value)
          set_input("SecretKey", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetMemberProfile Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetMemberProfileResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from LinkedIn.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetMemberProfile




  end # module PeopleAndConnections

  module ShareAndSocialStream



    ##############################################################################
    #
    # CreateShare
    #
    # Allows you to share content on behalf of a LinkedIn member.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateShare < Choreography

      ####
      #  Create a new instance of the CreateShare Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/LinkedIn/ShareAndSocialStream/CreateShare")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateShareInputSet
      ####
      def new_input_set()
        return CreateShareInputSet.new()
      end

      def make_result_set()
        return CreateShareResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateShareResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateShare
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateShareInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by LinkedIn (AKA the Client ID).
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token retrieved during the OAuth process (AKA the OAuth User Token).
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the AccessTokenSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Access Token Secret retrieved during the OAuth process (AKA the OAuth User Secret).
        ###

        def set_AccessTokenSecret(value)
          set_input("AccessTokenSecret", value)
        end
        #### 
        # Set the value of the Comment input for this Choreo. 
        # 
        # @param String - (conditional, string) The text of the member's comment. Required unless providing Title and URL for a shared post.
        ###

        def set_Comment(value)
          set_input("Comment", value)
        end
        #### 
        # Set the value of the Description input for this Choreo. 
        # 
        # @param String - (optional, string) A description of the shared content.
        ###

        def set_Description(value)
          set_input("Description", value)
        end
        #### 
        # Set the value of the ImageURL input for this Choreo. 
        # 
        # @param String - (optional, string) The URL for the image of the shared content.
        ###

        def set_ImageURL(value)
          set_input("ImageURL", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SecretKey input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key provided by LinkedIn (AKA the Client Secret).
        ###

        def set_SecretKey(value)
          set_input("SecretKey", value)
        end
        #### 
        # Set the value of the Title input for this Choreo. 
        # 
        # @param String - (conditional, string) The title of the shared content. Required unless providing a Comment.
        ###

        def set_Title(value)
          set_input("Title", value)
        end
        #### 
        # Set the value of the URL input for this Choreo. 
        # 
        # @param String - (conditional, string) The URL for the shared content. Required unless providing a Comment.
        ###

        def set_URL(value)
          set_input("URL", value)
        end
        #### 
        # Set the value of the Visibility input for this Choreo. 
        # 
        # @param String - (optional, string) Determines if the post will be visible to everyone, or only those who are connected to you. Valid values are: "anyone" or "connections-only" (the default).
        ###

        def set_Visibility(value)
          set_input("Visibility", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateShare Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateShareResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from LinkedIn.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateShare




  end # module ShareAndSocialStream

end # module LinkedIn