require "temboo"

module Microsoft




  module Excel




    module Range



      ##############################################################################
      #
      # DeleteRange
      #
      # Deletes the cells associated with the range.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class DeleteRange < Choreography

        ####
        #  Create a new instance of the DeleteRange Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Microsoft/Excel/Range/DeleteRange")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return DeleteRangeInputSet
        ####
        def new_input_set()
          return DeleteRangeInputSet.new()
        end

        def make_result_set()
          return DeleteRangeResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = DeleteRangeResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the DeleteRange
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class DeleteRangeInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid Access Token retrieved during the OAuth process. This can be passed if your application is authenticating multiple Office 365 users.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the ItemPath input for this Choreo. 
          # 
          # @param String - (required, string) The location of the spreadsheet in OneDrive (e.g. MyFolder/Book.xlsx).
          ###

          def set_ItemPath(value)
            set_input("ItemPath", value)
          end
          #### 
          # Set the value of the Password input for this Choreo. 
          # 
          # @param String - (conditional, password) Your Microsoft password. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Password(value)
            set_input("Password", value)
          end
          #### 
          # Set the value of the Range input for this Choreo. 
          # 
          # @param String - (conditional, string) A cell ange to delete (e.g. A1:B2).
          ###

          def set_Range(value)
            set_input("Range", value)
          end
          #### 
          # Set the value of the Shift input for this Choreo. 
          # 
          # @param String - (required, string) Specifies which way to shift the cells.  Possible values are: Up, Left.
          ###

          def set_Shift(value)
            set_input("Shift", value)
          end
          #### 
          # Set the value of the Username input for this Choreo. 
          # 
          # @param String - (conditional, string) Your Microsoft username. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Username(value)
            set_input("Username", value)
          end
          #### 
          # Set the value of the Worksheet input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the worksheet.
          ###

          def set_Worksheet(value)
            set_input("Worksheet", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the DeleteRange Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class DeleteRangeResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "ResponseCode" output from this Choreo execution
        	#
        	# @return String - (integer) The response status code. A 204 is returned for a successful deletion.
        	####
        	def get_ResponseCode()
        	  return @outputs["ResponseCode"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Microsoft.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class DeleteRange



      ##############################################################################
      #
      # GetLastCell
      #
      # Retrieves the last cell within a specified range.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetLastCell < Choreography

        ####
        #  Create a new instance of the GetLastCell Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Microsoft/Excel/Range/GetLastCell")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetLastCellInputSet
        ####
        def new_input_set()
          return GetLastCellInputSet.new()
        end

        def make_result_set()
          return GetLastCellResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetLastCellResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetLastCell
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetLastCellInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid Access Token retrieved during the OAuth process. This can be passed if your application is authenticating multiple Office 365 users.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the ItemPath input for this Choreo. 
          # 
          # @param String - (required, string) The location of the spreadsheet in OneDrive (e.g. MyFolder/Book.xlsx).
          ###

          def set_ItemPath(value)
            set_input("ItemPath", value)
          end
          #### 
          # Set the value of the Password input for this Choreo. 
          # 
          # @param String - (conditional, password) Your Microsoft password. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Password(value)
            set_input("Password", value)
          end
          #### 
          # Set the value of the Range input for this Choreo. 
          # 
          # @param String - (conditional, string) The cell range to consider (e.g. A1:C100).
          ###

          def set_Range(value)
            set_input("Range", value)
          end
          #### 
          # Set the value of the Select input for this Choreo. 
          # 
          # @param String - (optional, string) Comma-separated list of properties to include in the response.
          ###

          def set_Select(value)
            set_input("Select", value)
          end
          #### 
          # Set the value of the Username input for this Choreo. 
          # 
          # @param String - (conditional, string) Your Microsoft username. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Username(value)
            set_input("Username", value)
          end
          #### 
          # Set the value of the Worksheet input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the worksheet.
          ###

          def set_Worksheet(value)
            set_input("Worksheet", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetLastCell Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetLastCellResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Microsoft.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetLastCell



      ##############################################################################
      #
      # GetLastColumn
      #
      # Retrieves the last column within a specified range.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetLastColumn < Choreography

        ####
        #  Create a new instance of the GetLastColumn Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Microsoft/Excel/Range/GetLastColumn")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetLastColumnInputSet
        ####
        def new_input_set()
          return GetLastColumnInputSet.new()
        end

        def make_result_set()
          return GetLastColumnResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetLastColumnResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetLastColumn
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetLastColumnInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid Access Token retrieved during the OAuth process. This can be passed if your application is authenticating multiple Office 365 users.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the ItemPath input for this Choreo. 
          # 
          # @param String - (required, string) The location of the spreadsheet in OneDrive (e.g. MyFolder/Book.xlsx).
          ###

          def set_ItemPath(value)
            set_input("ItemPath", value)
          end
          #### 
          # Set the value of the Password input for this Choreo. 
          # 
          # @param String - (conditional, password) Your Microsoft password. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Password(value)
            set_input("Password", value)
          end
          #### 
          # Set the value of the Range input for this Choreo. 
          # 
          # @param String - (conditional, string) The cell range to consider (e.g. A1:C100).
          ###

          def set_Range(value)
            set_input("Range", value)
          end
          #### 
          # Set the value of the Select input for this Choreo. 
          # 
          # @param String - (optional, string) Comma-separated list of properties to include in the response.
          ###

          def set_Select(value)
            set_input("Select", value)
          end
          #### 
          # Set the value of the Username input for this Choreo. 
          # 
          # @param String - (conditional, string) Your Microsoft username. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Username(value)
            set_input("Username", value)
          end
          #### 
          # Set the value of the Worksheet input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the worksheet.
          ###

          def set_Worksheet(value)
            set_input("Worksheet", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetLastColumn Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetLastColumnResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Microsoft.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetLastColumn



      ##############################################################################
      #
      # GetLastRow
      #
      # Retrieves the last row within a specified range.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetLastRow < Choreography

        ####
        #  Create a new instance of the GetLastRow Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Microsoft/Excel/Range/GetLastRow")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetLastRowInputSet
        ####
        def new_input_set()
          return GetLastRowInputSet.new()
        end

        def make_result_set()
          return GetLastRowResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetLastRowResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetLastRow
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetLastRowInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid Access Token retrieved during the OAuth process. This can be passed if your application is authenticating multiple Office 365 users.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the ItemPath input for this Choreo. 
          # 
          # @param String - (required, string) The location of the spreadsheet in OneDrive (e.g. MyFolder/Book.xlsx).
          ###

          def set_ItemPath(value)
            set_input("ItemPath", value)
          end
          #### 
          # Set the value of the Password input for this Choreo. 
          # 
          # @param String - (conditional, password) Your Microsoft password. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Password(value)
            set_input("Password", value)
          end
          #### 
          # Set the value of the Range input for this Choreo. 
          # 
          # @param String - (conditional, string) The cell range to consider (e.g. A1:C100).
          ###

          def set_Range(value)
            set_input("Range", value)
          end
          #### 
          # Set the value of the Select input for this Choreo. 
          # 
          # @param String - (optional, string) Comma-separated list of properties to include in the response.
          ###

          def set_Select(value)
            set_input("Select", value)
          end
          #### 
          # Set the value of the Username input for this Choreo. 
          # 
          # @param String - (conditional, string) Your Microsoft username. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Username(value)
            set_input("Username", value)
          end
          #### 
          # Set the value of the Worksheet input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the worksheet.
          ###

          def set_Worksheet(value)
            set_input("Worksheet", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetLastRow Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetLastRowResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Microsoft.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetLastRow



      ##############################################################################
      #
      # GetRange
      #
      # Retrieves the properties and relationships of range object.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetRange < Choreography

        ####
        #  Create a new instance of the GetRange Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Microsoft/Excel/Range/GetRange")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetRangeInputSet
        ####
        def new_input_set()
          return GetRangeInputSet.new()
        end

        def make_result_set()
          return GetRangeResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetRangeResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetRange
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetRangeInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid Access Token retrieved during the OAuth process. This can be passed if your application is authenticating multiple Office 365 users.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the ItemPath input for this Choreo. 
          # 
          # @param String - (required, string) The location of the spreadsheet in OneDrive (e.g. MyFolder/Book.xlsx).
          ###

          def set_ItemPath(value)
            set_input("ItemPath", value)
          end
          #### 
          # Set the value of the Password input for this Choreo. 
          # 
          # @param String - (conditional, password) Your Microsoft password. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Password(value)
            set_input("Password", value)
          end
          #### 
          # Set the value of the Range input for this Choreo. 
          # 
          # @param String - (conditional, string) A range to return (e.g. A1:B2).
          ###

          def set_Range(value)
            set_input("Range", value)
          end
          #### 
          # Set the value of the Select input for this Choreo. 
          # 
          # @param String - (optional, string) Comma-separated list of properties to include in the response.
          ###

          def set_Select(value)
            set_input("Select", value)
          end
          #### 
          # Set the value of the Username input for this Choreo. 
          # 
          # @param String - (conditional, string) Your Microsoft username. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Username(value)
            set_input("Username", value)
          end
          #### 
          # Set the value of the Worksheet input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the worksheet.
          ###

          def set_Worksheet(value)
            set_input("Worksheet", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetRange Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetRangeResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Microsoft.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetRange




    end # module Range

    module Table



      ##############################################################################
      #
      # CreateTableRow
      #
      # Creates new rows in a table.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class CreateTableRow < Choreography

        ####
        #  Create a new instance of the CreateTableRow Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Microsoft/Excel/Table/CreateTableRow")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return CreateTableRowInputSet
        ####
        def new_input_set()
          return CreateTableRowInputSet.new()
        end

        def make_result_set()
          return CreateTableRowResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = CreateTableRowResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the CreateTableRow
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class CreateTableRowInputSet < Choreography::InputSet

          #### 
          # Set the value of the Values input for this Choreo. 
          # 
          # @param String - (required, json) This is an array of arrays. The outer array can represent one or more rows while the inner array can represent one or more cell values. See Choreo notes below for more details.
          ###

          def set_Values(value)
            set_input("Values", value)
          end
          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid Access Token retrieved during the OAuth process. This can be passed if your application is authenticating multiple Office 365 users.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the Index input for this Choreo. 
          # 
          # @param Integer - (optional, integer) Indicates that the row should be created at this index.
          ###

          def set_Index(value)
            set_input("Index", value)
          end
          #### 
          # Set the value of the ItemPath input for this Choreo. 
          # 
          # @param String - (required, string) The location of the spreadsheet in OneDrive (e.g. MyFolder/Book.xlsx).
          ###

          def set_ItemPath(value)
            set_input("ItemPath", value)
          end
          #### 
          # Set the value of the Password input for this Choreo. 
          # 
          # @param String - (conditional, password) Your Microsoft password. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Password(value)
            set_input("Password", value)
          end
          #### 
          # Set the value of the Table input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the table to write to (e.g. Table1).
          ###

          def set_Table(value)
            set_input("Table", value)
          end
          #### 
          # Set the value of the Username input for this Choreo. 
          # 
          # @param String - (conditional, string) Your Microsoft username. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Username(value)
            set_input("Username", value)
          end
          #### 
          # Set the value of the Worksheet input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the worksheet to write to (e.g. Sheet1).
          ###

          def set_Worksheet(value)
            set_input("Worksheet", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the CreateTableRow Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class CreateTableRowResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Microsoft.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class CreateTableRow



      ##############################################################################
      #
      # DataBodyRange
      #
      # Gets the range object associated with the data body of the table.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class DataBodyRange < Choreography

        ####
        #  Create a new instance of the DataBodyRange Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Microsoft/Excel/Table/DataBodyRange")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return DataBodyRangeInputSet
        ####
        def new_input_set()
          return DataBodyRangeInputSet.new()
        end

        def make_result_set()
          return DataBodyRangeResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = DataBodyRangeResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the DataBodyRange
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class DataBodyRangeInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid Access Token retrieved during the OAuth process. This can be passed if your application is authenticating multiple Office 365 users.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the ItemPath input for this Choreo. 
          # 
          # @param String - (required, string) The location of the spreadsheet in OneDrive (e.g. MyFolder/Book.xlsx).
          ###

          def set_ItemPath(value)
            set_input("ItemPath", value)
          end
          #### 
          # Set the value of the Password input for this Choreo. 
          # 
          # @param String - (conditional, password) Your Microsoft password. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Password(value)
            set_input("Password", value)
          end
          #### 
          # Set the value of the Select input for this Choreo. 
          # 
          # @param String - (optional, string) Comma-separated list of properties to include in the response.
          ###

          def set_Select(value)
            set_input("Select", value)
          end
          #### 
          # Set the value of the Table input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the table.
          ###

          def set_Table(value)
            set_input("Table", value)
          end
          #### 
          # Set the value of the Username input for this Choreo. 
          # 
          # @param String - (conditional, string) Your Microsoft username. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Username(value)
            set_input("Username", value)
          end
          #### 
          # Set the value of the Worksheet input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the worksheet.
          ###

          def set_Worksheet(value)
            set_input("Worksheet", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the DataBodyRange Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class DataBodyRangeResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Microsoft.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class DataBodyRange



      ##############################################################################
      #
      # DeleteRow
      #
      # Deletes the row from the table.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class DeleteRow < Choreography

        ####
        #  Create a new instance of the DeleteRow Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Microsoft/Excel/Table/DeleteRow")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return DeleteRowInputSet
        ####
        def new_input_set()
          return DeleteRowInputSet.new()
        end

        def make_result_set()
          return DeleteRowResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = DeleteRowResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the DeleteRow
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class DeleteRowInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid Access Token retrieved during the OAuth process. This can be passed if your application is authenticating multiple Office 365 users.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the Index input for this Choreo. 
          # 
          # @param Integer - (required, integer) The index of the row that should be deleted.
          ###

          def set_Index(value)
            set_input("Index", value)
          end
          #### 
          # Set the value of the ItemPath input for this Choreo. 
          # 
          # @param String - (required, string) The location of the spreadsheet in OneDrive (e.g. MyFolder/Book.xlsx).
          ###

          def set_ItemPath(value)
            set_input("ItemPath", value)
          end
          #### 
          # Set the value of the Password input for this Choreo. 
          # 
          # @param String - (conditional, password) Your Microsoft password. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Password(value)
            set_input("Password", value)
          end
          #### 
          # Set the value of the Table input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the table.
          ###

          def set_Table(value)
            set_input("Table", value)
          end
          #### 
          # Set the value of the Username input for this Choreo. 
          # 
          # @param String - (conditional, string) Your Microsoft username. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Username(value)
            set_input("Username", value)
          end
          #### 
          # Set the value of the Worksheet input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the worksheet.
          ###

          def set_Worksheet(value)
            set_input("Worksheet", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the DeleteRow Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class DeleteRowResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "ResponseCode" output from this Choreo execution
        	#
        	# @return String - (integer) The response status code. A 204 is returned for a successful deletion.
        	####
        	def get_ResponseCode()
        	  return @outputs["ResponseCode"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Microsoft.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class DeleteRow



      ##############################################################################
      #
      # GetRow
      #
      # Retrieve the properties and relationships of tablerow object.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetRow < Choreography

        ####
        #  Create a new instance of the GetRow Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Microsoft/Excel/Table/GetRow")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetRowInputSet
        ####
        def new_input_set()
          return GetRowInputSet.new()
        end

        def make_result_set()
          return GetRowResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetRowResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetRow
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetRowInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid Access Token retrieved during the OAuth process. This can be passed if your application is authenticating multiple Office 365 users.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the Index input for this Choreo. 
          # 
          # @param Integer - (required, integer) The index of the row that should be returned. If left empty, the last row in the table will be returned.
          ###

          def set_Index(value)
            set_input("Index", value)
          end
          #### 
          # Set the value of the ItemPath input for this Choreo. 
          # 
          # @param String - (required, string) The location of the spreadsheet in OneDrive (e.g. MyFolder/Book.xlsx).
          ###

          def set_ItemPath(value)
            set_input("ItemPath", value)
          end
          #### 
          # Set the value of the Password input for this Choreo. 
          # 
          # @param String - (conditional, password) Your Microsoft password. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Password(value)
            set_input("Password", value)
          end
          #### 
          # Set the value of the Select input for this Choreo. 
          # 
          # @param String - (optional, string) Comma-separated list of properties to include in the response.
          ###

          def set_Select(value)
            set_input("Select", value)
          end
          #### 
          # Set the value of the Table input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the table.
          ###

          def set_Table(value)
            set_input("Table", value)
          end
          #### 
          # Set the value of the Username input for this Choreo. 
          # 
          # @param String - (conditional, string) Your Microsoft username. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Username(value)
            set_input("Username", value)
          end
          #### 
          # Set the value of the Worksheet input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the worksheet.
          ###

          def set_Worksheet(value)
            set_input("Worksheet", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetRow Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetRowResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Microsoft.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetRow



      ##############################################################################
      #
      # ListColumns
      #
      # Retrieve a list of tablecolumn objects.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class ListColumns < Choreography

        ####
        #  Create a new instance of the ListColumns Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Microsoft/Excel/Table/ListColumns")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return ListColumnsInputSet
        ####
        def new_input_set()
          return ListColumnsInputSet.new()
        end

        def make_result_set()
          return ListColumnsResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = ListColumnsResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the ListColumns
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class ListColumnsInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid Access Token retrieved during the OAuth process. This can be passed if your application is authenticating multiple Office 365 users.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the ItemPath input for this Choreo. 
          # 
          # @param String - (required, string) The location of the spreadsheet in OneDrive (e.g. MyFolder/Book.xlsx).
          ###

          def set_ItemPath(value)
            set_input("ItemPath", value)
          end
          #### 
          # Set the value of the Password input for this Choreo. 
          # 
          # @param String - (conditional, password) Your Microsoft password. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Password(value)
            set_input("Password", value)
          end
          #### 
          # Set the value of the Select input for this Choreo. 
          # 
          # @param String - (optional, string) Comma-separated list of properties to include in the response.
          ###

          def set_Select(value)
            set_input("Select", value)
          end
          #### 
          # Set the value of the Skip input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The number of items to skip in a result set.
          ###

          def set_Skip(value)
            set_input("Skip", value)
          end
          #### 
          # Set the value of the Table input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the table.
          ###

          def set_Table(value)
            set_input("Table", value)
          end
          #### 
          # Set the value of the Top input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The number of items to return in a result set.
          ###

          def set_Top(value)
            set_input("Top", value)
          end
          #### 
          # Set the value of the Username input for this Choreo. 
          # 
          # @param String - (conditional, string) Your Microsoft username. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Username(value)
            set_input("Username", value)
          end
          #### 
          # Set the value of the Worksheet input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the worksheet.
          ###

          def set_Worksheet(value)
            set_input("Worksheet", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the ListColumns Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class ListColumnsResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Microsoft.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class ListColumns



      ##############################################################################
      #
      # ListRows
      #
      # Retrieve a list of tablerow objects.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class ListRows < Choreography

        ####
        #  Create a new instance of the ListRows Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Microsoft/Excel/Table/ListRows")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return ListRowsInputSet
        ####
        def new_input_set()
          return ListRowsInputSet.new()
        end

        def make_result_set()
          return ListRowsResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = ListRowsResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the ListRows
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class ListRowsInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid Access Token retrieved during the OAuth process. This can be passed if your application is authenticating multiple Office 365 users.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the ItemPath input for this Choreo. 
          # 
          # @param String - (required, string) The location of the spreadsheet in OneDrive (e.g. MyFolder/Book.xlsx).
          ###

          def set_ItemPath(value)
            set_input("ItemPath", value)
          end
          #### 
          # Set the value of the Password input for this Choreo. 
          # 
          # @param String - (conditional, password) Your Microsoft password. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Password(value)
            set_input("Password", value)
          end
          #### 
          # Set the value of the Select input for this Choreo. 
          # 
          # @param String - (optional, string) Comma-separated list of properties to include in the response.
          ###

          def set_Select(value)
            set_input("Select", value)
          end
          #### 
          # Set the value of the Skip input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The number of items to skip in a result set.
          ###

          def set_Skip(value)
            set_input("Skip", value)
          end
          #### 
          # Set the value of the Table input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the table.
          ###

          def set_Table(value)
            set_input("Table", value)
          end
          #### 
          # Set the value of the Top input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The number of items to return in a result set.
          ###

          def set_Top(value)
            set_input("Top", value)
          end
          #### 
          # Set the value of the Username input for this Choreo. 
          # 
          # @param String - (conditional, string) Your Microsoft username. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Username(value)
            set_input("Username", value)
          end
          #### 
          # Set the value of the Worksheet input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the worksheet.
          ###

          def set_Worksheet(value)
            set_input("Worksheet", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the ListRows Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class ListRowsResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Microsoft.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class ListRows



      ##############################################################################
      #
      # ListTables
      #
      # Retrieves a list of tables.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class ListTables < Choreography

        ####
        #  Create a new instance of the ListTables Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Microsoft/Excel/Table/ListTables")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return ListTablesInputSet
        ####
        def new_input_set()
          return ListTablesInputSet.new()
        end

        def make_result_set()
          return ListTablesResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = ListTablesResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the ListTables
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class ListTablesInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid Access Token retrieved during the OAuth process. This can be passed if your application is authenticating multiple Office 365 users.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the ItemPath input for this Choreo. 
          # 
          # @param String - (required, string) The location of the spreadsheet in OneDrive (e.g. MyFolder/Book.xlsx).
          ###

          def set_ItemPath(value)
            set_input("ItemPath", value)
          end
          #### 
          # Set the value of the Password input for this Choreo. 
          # 
          # @param String - (conditional, password) Your Microsoft password. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Password(value)
            set_input("Password", value)
          end
          #### 
          # Set the value of the Select input for this Choreo. 
          # 
          # @param String - (optional, string) Comma-separated list of properties to include in the response.
          ###

          def set_Select(value)
            set_input("Select", value)
          end
          #### 
          # Set the value of the Skip input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The number of items to skip in a result set.
          ###

          def set_Skip(value)
            set_input("Skip", value)
          end
          #### 
          # Set the value of the Top input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The number of items to return in a result set.
          ###

          def set_Top(value)
            set_input("Top", value)
          end
          #### 
          # Set the value of the Username input for this Choreo. 
          # 
          # @param String - (conditional, string) Your Microsoft username. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Username(value)
            set_input("Username", value)
          end
          #### 
          # Set the value of the Worksheet input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the worksheet.
          ###

          def set_Worksheet(value)
            set_input("Worksheet", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the ListTables Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class ListTablesResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Microsoft.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class ListTables




    end # module Table

    module Workbook



      ##############################################################################
      #
      # InvokeFunction
      #
      # Invokes a workbook function.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class InvokeFunction < Choreography

        ####
        #  Create a new instance of the InvokeFunction Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Microsoft/Excel/Workbook/InvokeFunction")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return InvokeFunctionInputSet
        ####
        def new_input_set()
          return InvokeFunctionInputSet.new()
        end

        def make_result_set()
          return InvokeFunctionResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = InvokeFunctionResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the InvokeFunction
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class InvokeFunctionInputSet < Choreography::InputSet

          #### 
          # Set the value of the Arguments input for this Choreo. 
          # 
          # @param String - (required, json) A JSON object containing the function arguments. See Choreo notes for more details.
          ###

          def set_Arguments(value)
            set_input("Arguments", value)
          end
          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid Access Token retrieved during the OAuth process. This can be passed if your application is authenticating multiple Office 365 users.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the Function input for this Choreo. 
          # 
          # @param String - (required, string) The name of the function (e.g. vlookup).
          ###

          def set_Function(value)
            set_input("Function", value)
          end
          #### 
          # Set the value of the ItemPath input for this Choreo. 
          # 
          # @param String - (required, string) The location of the spreadsheet in OneDrive (e.g. MyFolder/Book.xlsx).
          ###

          def set_ItemPath(value)
            set_input("ItemPath", value)
          end
          #### 
          # Set the value of the Password input for this Choreo. 
          # 
          # @param String - (conditional, password) Your Microsoft password. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Password(value)
            set_input("Password", value)
          end
          #### 
          # Set the value of the Username input for this Choreo. 
          # 
          # @param String - (conditional, string) Your Microsoft username. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Username(value)
            set_input("Username", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the InvokeFunction Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class InvokeFunctionResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Microsoft.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class InvokeFunction




    end # module Workbook

    module Worksheet



      ##############################################################################
      #
      # AddWorksheet
      #
      # Adds a new worksheet to the workbook.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class AddWorksheet < Choreography

        ####
        #  Create a new instance of the AddWorksheet Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Microsoft/Excel/Worksheet/AddWorksheet")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return AddWorksheetInputSet
        ####
        def new_input_set()
          return AddWorksheetInputSet.new()
        end

        def make_result_set()
          return AddWorksheetResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = AddWorksheetResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the AddWorksheet
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class AddWorksheetInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid Access Token retrieved during the OAuth process. This can be passed if your application is authenticating multiple Office 365 users.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the ItemPath input for this Choreo. 
          # 
          # @param String - (required, string) The location of the spreadsheet in OneDrive (e.g. MyFolder/Book.xlsx).
          ###

          def set_ItemPath(value)
            set_input("ItemPath", value)
          end
          #### 
          # Set the value of the Password input for this Choreo. 
          # 
          # @param String - (conditional, password) Your Microsoft password. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Password(value)
            set_input("Password", value)
          end
          #### 
          # Set the value of the Username input for this Choreo. 
          # 
          # @param String - (conditional, string) Your Microsoft username. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Username(value)
            set_input("Username", value)
          end
          #### 
          # Set the value of the Worksheet input for this Choreo. 
          # 
          # @param String - (required, string) The name of the new worksheet.
          ###

          def set_Worksheet(value)
            set_input("Worksheet", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the AddWorksheet Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class AddWorksheetResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Microsoft.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class AddWorksheet



      ##############################################################################
      #
      # GetWorksheet
      #
      # Retrieve the properties and relationships of worksheet object.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetWorksheet < Choreography

        ####
        #  Create a new instance of the GetWorksheet Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Microsoft/Excel/Worksheet/GetWorksheet")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetWorksheetInputSet
        ####
        def new_input_set()
          return GetWorksheetInputSet.new()
        end

        def make_result_set()
          return GetWorksheetResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetWorksheetResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetWorksheet
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetWorksheetInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid Access Token retrieved during the OAuth process. This can be passed if your application is authenticating multiple Office 365 users.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Microsoft This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the ItemPath input for this Choreo. 
          # 
          # @param String - (required, string) The location of the spreadsheet in OneDrive (e.g. MyFolder/Book.xlsx).
          ###

          def set_ItemPath(value)
            set_input("ItemPath", value)
          end
          #### 
          # Set the value of the Password input for this Choreo. 
          # 
          # @param String - (conditional, password) Your Microsoft password. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Password(value)
            set_input("Password", value)
          end
          #### 
          # Set the value of the Username input for this Choreo. 
          # 
          # @param String - (conditional, string) Your Microsoft username. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Username(value)
            set_input("Username", value)
          end
          #### 
          # Set the value of the Worksheet input for this Choreo. 
          # 
          # @param String - (required, string) The name or id of the worksheet.
          ###

          def set_Worksheet(value)
            set_input("Worksheet", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetWorksheet Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetWorksheetResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Microsoft.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetWorksheet



      ##############################################################################
      #
      # ListWorksheets
      #
      # Retrieve a list of worksheet objects.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class ListWorksheets < Choreography

        ####
        #  Create a new instance of the ListWorksheets Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Microsoft/Excel/Worksheet/ListWorksheets")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return ListWorksheetsInputSet
        ####
        def new_input_set()
          return ListWorksheetsInputSet.new()
        end

        def make_result_set()
          return ListWorksheetsResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = ListWorksheetsResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the ListWorksheets
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class ListWorksheetsInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid Access Token retrieved during the OAuth process. This can be passed if your application is authenticating multiple Office 365 users.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Microsoft. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the ItemPath input for this Choreo. 
          # 
          # @param String - (required, string) The location of the spreadsheet in OneDrive (e.g. MyFolder/Book.xlsx).
          ###

          def set_ItemPath(value)
            set_input("ItemPath", value)
          end
          #### 
          # Set the value of the Password input for this Choreo. 
          # 
          # @param String - (conditional, password) Your Microsoft password. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Password(value)
            set_input("Password", value)
          end
          #### 
          # Set the value of the Select input for this Choreo. 
          # 
          # @param String - (optional, string) Comma-separated list of properties to include in the response.
          ###

          def set_Select(value)
            set_input("Select", value)
          end
          #### 
          # Set the value of the Skip input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The number of items to skip in a result set.
          ###

          def set_Skip(value)
            set_input("Skip", value)
          end
          #### 
          # Set the value of the Top input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The number of items to return in a result set.
          ###

          def set_Top(value)
            set_input("Top", value)
          end
          #### 
          # Set the value of the Username input for this Choreo. 
          # 
          # @param String - (conditional, string) Your Microsoft username. This is requried unless providing a valid AccessToken (see optional inputs).
          ###

          def set_Username(value)
            set_input("Username", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the ListWorksheets Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class ListWorksheetsResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Microsoft.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class ListWorksheets




    end # module Worksheet

  end # module Excel

  module OAuth



    ##############################################################################
    #
    # FinalizeOAuth
    #
    # Completes the OAuth process by retrieving Microsoft OAuth tokens for a user, after they have visited the authorization URL returned by the InitializeOAuth Choreo and clicked "allow."
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class FinalizeOAuth < Choreography

      ####
      #  Create a new instance of the FinalizeOAuth Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/OAuth/FinalizeOAuth")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return FinalizeOAuthInputSet
      ####
      def new_input_set()
        return FinalizeOAuthInputSet.new()
      end

      def make_result_set()
        return FinalizeOAuthResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = FinalizeOAuthResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the FinalizeOAuth
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class FinalizeOAuthInputSet < Choreography::InputSet

        #### 
        # Set the value of the CallbackID input for this Choreo. 
        # 
        # @param String - (required, string) The callback token returned by the InitializeOAuth Choreo. Used to retrieve the authorization code after the user authorizes.
        ###

        def set_CallbackID(value)
          set_input("CallbackID", value)
        end
        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (required, string) The Client ID provided by Microsoft after registering your application.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Client Secret provided by Microsoft after registering your application.
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end
        #### 
        # Set the value of the Resource input for this Choreo. 
        # 
        # @param String - (conditional, string) The App ID URI of the web API (secured resource). See Choreo notes for details.
        ###

        def set_Resource(value)
          set_input("Resource", value)
        end
        #### 
        # Set the value of the SuppressErrors input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to true, errors received during the OAuth redirect process will be suppressed and returned in the ErrorMessage output.
        ###

        def set_SuppressErrors(value)
          set_input("SuppressErrors", value)
        end
        #### 
        # Set the value of the Timeout input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The amount of time (in seconds) to poll your Temboo callback URL to see if your app's user has allowed or denied the request for access. Defaults to 20. Max is 60.
        ###

        def set_Timeout(value)
          set_input("Timeout", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the FinalizeOAuth Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class FinalizeOAuthResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ErrorMessage" output from this Choreo execution
      	#
      	# @return String - (string) Contains an error message if an error occurs during the OAuth redirect process and if SuppressErrors is set to true.
      	####
      	def get_ErrorMessage()
      	  return @outputs["ErrorMessage"]
      	end
      	####
      	# Retrieve the value for the "Expires" output from this Choreo execution
      	#
      	# @return String - (integer) The remaining lifetime of the short-lived access token.
      	####
      	def get_Expires()
      	  return @outputs["Expires"]
      	end
      	####
      	# Retrieve the value for the "RefreshToken" output from this Choreo execution
      	#
      	# @return String - (string) A token that may be used to obtain a new access token when the short-lived access token expires.
      	####
      	def get_RefreshToken()
      	  return @outputs["RefreshToken"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Microsoft.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class FinalizeOAuth



    ##############################################################################
    #
    # InitializeOAuth
    #
    # Generates an authorization URL that an application can use to complete the first step in the OAuth process.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class InitializeOAuth < Choreography

      ####
      #  Create a new instance of the InitializeOAuth Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/OAuth/InitializeOAuth")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return InitializeOAuthInputSet
      ####
      def new_input_set()
        return InitializeOAuthInputSet.new()
      end

      def make_result_set()
        return InitializeOAuthResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = InitializeOAuthResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the InitializeOAuth
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class InitializeOAuthInputSet < Choreography::InputSet

        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (required, string) The Client ID provided by Microsoft after registering your application.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the CustomCallbackID input for this Choreo. 
        # 
        # @param String - (optional, string) A unique identifier that you can pass to eliminate the need to wait for a Temboo generated CallbackID. Callback identifiers may only contain numbers, letters, periods, and hyphens.
        ###

        def set_CustomCallbackID(value)
          set_input("CustomCallbackID", value)
        end
        #### 
        # Set the value of the DomainHint input for this Choreo. 
        # 
        # @param String - (optional, string) Provides a hint about the tenant or domain that the user should use to sign in.
        ###

        def set_DomainHint(value)
          set_input("DomainHint", value)
        end
        #### 
        # Set the value of the ForwardingURL input for this Choreo. 
        # 
        # @param String - (optional, string) The URL that Temboo will redirect your users to after they grant access to your application. This should include the "https://" or "http://" prefix and be a fully qualified URL.
        ###

        def set_ForwardingURL(value)
          set_input("ForwardingURL", value)
        end
        #### 
        # Set the value of the LoginHint input for this Choreo. 
        # 
        # @param String - (optional, string) Provides a hint to the user on the sign-in page.
        ###

        def set_LoginHint(value)
          set_input("LoginHint", value)
        end
        #### 
        # Set the value of the Prompt input for this Choreo. 
        # 
        # @param String - (optional, string) Indicate the type of user interaction that is required. Valid values are: login, consent, admin_consent.
        ###

        def set_Prompt(value)
          set_input("Prompt", value)
        end
        #### 
        # Set the value of the Resource input for this Choreo. 
        # 
        # @param String - (conditional, string) The App ID URI of the web API (secured resource). See Choreo notes for details.
        ###

        def set_Resource(value)
          set_input("Resource", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the InitializeOAuth Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class InitializeOAuthResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "AuthorizationURL" output from this Choreo execution
      	#
      	# @return String - (string) The authorization URL that the application's user needs to go to in order to grant access to your application.
      	####
      	def get_AuthorizationURL()
      	  return @outputs["AuthorizationURL"]
      	end
      	####
      	# Retrieve the value for the "CallbackID" output from this Choreo execution
      	#
      	# @return String - (string) An ID used to retrieve the callback data that Temboo stores once your application's user authorizes.
      	####
      	def get_CallbackID()
      	  return @outputs["CallbackID"]
      	end
      end

    end # class InitializeOAuth



    ##############################################################################
    #
    # RefreshToken
    #
    # Retrieves a new refresh token and access token by exchanging the refresh token that is associated with the expired access token.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RefreshToken < Choreography

      ####
      #  Create a new instance of the RefreshToken Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/OAuth/RefreshToken")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RefreshTokenInputSet
      ####
      def new_input_set()
        return RefreshTokenInputSet.new()
      end

      def make_result_set()
        return RefreshTokenResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RefreshTokenResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RefreshToken
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RefreshTokenInputSet < Choreography::InputSet

        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (required, string) The Client ID provided by Microsoft after registering your application.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Client Secret provided by Microsoft after registering your application.
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end
        #### 
        # Set the value of the RefreshToken input for this Choreo. 
        # 
        # @param String - (required, string) An OAuth Refresh Token used to generate a new access token when the original token is expired.
        ###

        def set_RefreshToken(value)
          set_input("RefreshToken", value)
        end
        #### 
        # Set the value of the Resource input for this Choreo. 
        # 
        # @param String - (conditional, string) The App ID URI of the web API (secured resource). See Choreo notes for details.
        ###

        def set_Resource(value)
          set_input("Resource", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RefreshToken Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RefreshTokenResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Expires" output from this Choreo execution
      	#
      	# @return String - (integer) The remaining lifetime of the short-lived access token.
      	####
      	def get_Expires()
      	  return @outputs["Expires"]
      	end
      	####
      	# Retrieve the value for the "NewRefreshToken" output from this Choreo execution
      	#
      	# @return String - (string) The new Refresh Token which can be used the next time your app needs to get a new Access Token.
      	####
      	def get_NewRefreshToken()
      	  return @outputs["NewRefreshToken"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Microsoft.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class RefreshToken




  end # module OAuth

  module PowerBI



    ##############################################################################
    #
    # AddRow
    #
    # Adds rows to a table in a dataset
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class AddRow < Choreography

      ####
      #  Create a new instance of the AddRow Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/PowerBI/AddRow")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AddRowInputSet
      ####
      def new_input_set()
        return AddRowInputSet.new()
      end

      def make_result_set()
        return AddRowResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AddRowResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the AddRow
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AddRowInputSet < Choreography::InputSet

        #### 
        # Set the value of the Rows input for this Choreo. 
        # 
        # @param String - (required, json) A JSON object contain one or more rows to insert into a Power BI table. See Choreo notes for formatting details.
        ###

        def set_Rows(value)
          set_input("Rows", value)
        end
        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (optional, string) A valid Access Token retrieved during the OAuth process. This can be passed if your application is authenticating multiple Power BI users.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client ID provided by Power BI. This is requried unless providing a valid AccessToken (see optional inputs).
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client Secret provided by Power BI. This is requried unless providing a valid AccessToken (see optional inputs).
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end
        #### 
        # Set the value of the DatasetID input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the dataset that your table belongs to.
        ###

        def set_DatasetID(value)
          set_input("DatasetID", value)
        end
        #### 
        # Set the value of the Password input for this Choreo. 
        # 
        # @param String - (conditional, password) Your Power BI password. This is requried unless providing a valid AccessToken (see optional inputs).
        ###

        def set_Password(value)
          set_input("Password", value)
        end
        #### 
        # Set the value of the TableName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the Power BI table to insert a row into.
        ###

        def set_TableName(value)
          set_input("TableName", value)
        end
        #### 
        # Set the value of the Username input for this Choreo. 
        # 
        # @param String - (conditional, string) Your Power BI username. This is requried unless providing a valid AccessToken (see optional inputs).
        ###

        def set_Username(value)
          set_input("Username", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the AddRow Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AddRowResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ResponseCode" output from this Choreo execution
      	#
      	# @return String - (integer) The response status code returned from Power BI.
      	####
      	def get_ResponseCode()
      	  return @outputs["ResponseCode"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Power BI.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class AddRow



    ##############################################################################
    #
    # CreateDataset
    #
    # Creates a new Dataset from a JSON schema definition and returns the Dataset ID and the properties of the dataset created.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateDataset < Choreography

      ####
      #  Create a new instance of the CreateDataset Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/PowerBI/CreateDataset")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateDatasetInputSet
      ####
      def new_input_set()
        return CreateDatasetInputSet.new()
      end

      def make_result_set()
        return CreateDatasetResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateDatasetResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateDataset
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateDatasetInputSet < Choreography::InputSet

        #### 
        # Set the value of the SchemaDefinition input for this Choreo. 
        # 
        # @param String - (required, json) A JSON object containing information about the dataset table and columns. See Choreo notes for formatting details.
        ###

        def set_SchemaDefinition(value)
          set_input("SchemaDefinition", value)
        end
        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (optional, string) A valid Access Token retrieved during the OAuth process. This can be passed if your application is authenticating multiple Power BI users.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client ID provided by Power BI. This is requried unless providing a valid AccessToken (see optional inputs).
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client Secret provided by Power BI. This is requried unless providing a valid AccessToken (see optional inputs).
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end
        #### 
        # Set the value of the DefaultRetentionPolicy input for this Choreo. 
        # 
        # @param String - (optional, string) Enables a default retention policy to automatically clean up old data while keeping a constant flow of new data going into your dashboard. Valid values are: None (the default) or basicFIFO.
        ###

        def set_DefaultRetentionPolicy(value)
          set_input("DefaultRetentionPolicy", value)
        end
        #### 
        # Set the value of the Password input for this Choreo. 
        # 
        # @param String - (conditional, password) Your Power BI password. This is requried unless providing a valid AccessToken (see optional inputs).
        ###

        def set_Password(value)
          set_input("Password", value)
        end
        #### 
        # Set the value of the Username input for this Choreo. 
        # 
        # @param String - (conditional, string) Your Power BI username. This is requried unless providing a valid AccessToken (see optional inputs).
        ###

        def set_Username(value)
          set_input("Username", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateDataset Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateDatasetResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ResponseCode" output from this Choreo execution
      	#
      	# @return String - (integer) The response status code returned from Power BI.
      	####
      	def get_ResponseCode()
      	  return @outputs["ResponseCode"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Power BI.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateDataset




  end # module PowerBI

  module Translator



    ##############################################################################
    #
    # AddTranslation
    #
    # Retrieves an array of all translations for a given text.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class AddTranslation < Choreography

      ####
      #  Create a new instance of the AddTranslation Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/Translator/AddTranslation")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AddTranslationInputSet
      ####
      def new_input_set()
        return AddTranslationInputSet.new()
      end

      def make_result_set()
        return AddTranslationResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AddTranslationResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the AddTranslation
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AddTranslationInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (optional, string) A valid access token. This can be retrieved by running the GetToken Choreo. Required unless providing the ClientID and ClientSecret.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the Category input for this Choreo. 
        # 
        # @param String - (optional, string) A string containing the category (domain) of the translation. Defaults to "general".
        ###

        def set_Category(value)
          set_input("Category", value)
        end
        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client ID obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client Secret obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end
        #### 
        # Set the value of the ContentType input for this Choreo. 
        # 
        # @param String - (optional, string) The format of the text being translated. The supported formats are "text/plain" and "text/html".
        ###

        def set_ContentType(value)
          set_input("ContentType", value)
        end
        #### 
        # Set the value of the From input for this Choreo. 
        # 
        # @param String - (required, string) A string containing the ISO 639-1 language code of the source language. Must be one of the languages returned by the method GetLanguagesForTranslate.(e.g., en).
        ###

        def set_From(value)
          set_input("From", value)
        end
        #### 
        # Set the value of the OriginalText input for this Choreo. 
        # 
        # @param String - (required, string) A string containing the text to translate from. The string has a maximum length of 1000 characters.
        ###

        def set_OriginalText(value)
          set_input("OriginalText", value)
        end
        #### 
        # Set the value of the Rating input for this Choreo. 
        # 
        # @param Integer - (optional, integer) An integer representing the quality rating for this string. Value between -10 and 10. Defaults to 1.
        ###

        def set_Rating(value)
          set_input("Rating", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the To input for this Choreo. 
        # 
        # @param String - (required, string) A string containing the lISO 639-1 language code of the target language. Must be one of the languages returned by the method GetLanguagesForTranslate (e.g., es).
        ###

        def set_To(value)
          set_input("To", value)
        end
        #### 
        # Set the value of the TranslatedText input for this Choreo. 
        # 
        # @param String - (required, string) A string containing translated text in the target language. The string has a maximum length of 2000 characters.
        ###

        def set_TranslatedText(value)
          set_input("TranslatedText", value)
        end
        #### 
        # Set the value of the URI input for this Choreo. 
        # 
        # @param String - (optional, string) A string containing the content location of this translation.
        ###

        def set_URI(value)
          set_input("URI", value)
        end
        #### 
        # Set the value of the User input for this Choreo. 
        # 
        # @param String - (required, string) A string used to track the originator of the submission.
        ###

        def set_User(value)
          set_input("User", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the AddTranslation Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AddTranslationResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ExpiresIn" output from this Choreo execution
      	#
      	# @return String - (integer) Contains the number of seconds for which the access token is valid when ClientID and ClientSecret are provided.
      	####
      	def get_ExpiresIn()
      	  return @outputs["ExpiresIn"]
      	end
      	####
      	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
      	#
      	# @return String - (string) Contains a new AccessToken when the ClientID and ClientSecret are provided.
      	####
      	def get_NewAccessToken()
      	  return @outputs["NewAccessToken"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Microsoft.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class AddTranslation



    ##############################################################################
    #
    # AddTranslationArray
    #
    # Adds an array of translations to add translation memory.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class AddTranslationArray < Choreography

      ####
      #  Create a new instance of the AddTranslationArray Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/Translator/AddTranslationArray")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AddTranslationArrayInputSet
      ####
      def new_input_set()
        return AddTranslationArrayInputSet.new()
      end

      def make_result_set()
        return AddTranslationArrayResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AddTranslationArrayResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the AddTranslationArray
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AddTranslationArrayInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (optional, string) A valid access token. This can be retrieved by running the GetToken Choreo. Required unless providing the ClientID and ClientSecret.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the Category input for this Choreo. 
        # 
        # @param String - (optional, string) A string containing the category (domain) of the translation. Defaults to "general".
        ###

        def set_Category(value)
          set_input("Category", value)
        end
        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client ID obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client Secret obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end
        #### 
        # Set the value of the ContentType input for this Choreo. 
        # 
        # @param String - (optional, string) The format of the text being translated. The supported formats are "text/plain" and "text/html".
        ###

        def set_ContentType(value)
          set_input("ContentType", value)
        end
        #### 
        # Set the value of the From input for this Choreo. 
        # 
        # @param String - (required, string) A string containing the ISO 639-1 language code of the source language (e.g., en). Must be one of the languages returned by the method GetLanguagesForTranslate.
        ###

        def set_From(value)
          set_input("From", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the To input for this Choreo. 
        # 
        # @param String - (required, string) A string containing the ISO 639-1 language code of the target language (e.g., es). Must be one of the languages returned by the method GetLanguagesForTranslate.
        ###

        def set_To(value)
          set_input("To", value)
        end
        #### 
        # Set the value of the Translations input for this Choreo. 
        # 
        # @param String - (required, json) An array containing translations to add to translation memory. Each translation must contain: OriginalText, TranslatedText, and Rating. See Choreo description for formatting examples.
        ###

        def set_Translations(value)
          set_input("Translations", value)
        end
        #### 
        # Set the value of the URI input for this Choreo. 
        # 
        # @param String - (optional, string) A string containing the content location of this translation.
        ###

        def set_URI(value)
          set_input("URI", value)
        end
        #### 
        # Set the value of the User input for this Choreo. 
        # 
        # @param String - (required, string) A string used to track the originator of the submission.
        ###

        def set_User(value)
          set_input("User", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the AddTranslationArray Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AddTranslationArrayResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ExpiresIn" output from this Choreo execution
      	#
      	# @return String - (integer) Contains the number of seconds for which the access token is valid when ClientID and ClientSecret are provided.
      	####
      	def get_ExpiresIn()
      	  return @outputs["ExpiresIn"]
      	end
      	####
      	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
      	#
      	# @return String - (string) Contains a new AccessToken when the ClientID and ClientSecret are provided.
      	####
      	def get_NewAccessToken()
      	  return @outputs["NewAccessToken"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Microsoft.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class AddTranslationArray



    ##############################################################################
    #
    # BreakSentences
    #
    # Breaks a piece of text into sentences and returns an array containing the lengths in each sentence.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class BreakSentences < Choreography

      ####
      #  Create a new instance of the BreakSentences Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/Translator/BreakSentences")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return BreakSentencesInputSet
      ####
      def new_input_set()
        return BreakSentencesInputSet.new()
      end

      def make_result_set()
        return BreakSentencesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = BreakSentencesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the BreakSentences
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class BreakSentencesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (optional, string) A valid access token. This can be retrieved by running the GetToken Choreo. Required unless providing the ClientID and ClientSecret.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client ID obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client Secret obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end
        #### 
        # Set the value of the Language input for this Choreo. 
        # 
        # @param String - (required, string) A string representing the ISO 639-1 language code of input text.
        ###

        def set_Language(value)
          set_input("Language", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Text input for this Choreo. 
        # 
        # @param String - (required, string) A string representing the text to split into sentences. The size of the text must not exceed 10000 characters.
        ###

        def set_Text(value)
          set_input("Text", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the BreakSentences Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class BreakSentencesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ExpiresIn" output from this Choreo execution
      	#
      	# @return String - (integer) Contains the number of seconds for which the access token is valid when ClientID and ClientSecret are provided.
      	####
      	def get_ExpiresIn()
      	  return @outputs["ExpiresIn"]
      	end
      	####
      	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
      	#
      	# @return String - (string) Contains a new AccessToken when the ClientID and ClientSecret are provided.
      	####
      	def get_NewAccessToken()
      	  return @outputs["NewAccessToken"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Microsoft.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class BreakSentences



    ##############################################################################
    #
    # Detect
    #
    # Identifies the language of a selected piece of text.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Detect < Choreography

      ####
      #  Create a new instance of the Detect Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/Translator/Detect")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DetectInputSet
      ####
      def new_input_set()
        return DetectInputSet.new()
      end

      def make_result_set()
        return DetectResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DetectResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Detect
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DetectInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (optional, string) A valid access token. This can be retrieved by running the GetToken Choreo. Required unless providing the ClientID and ClientSecret.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client ID obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client Secret obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Text input for this Choreo. 
        # 
        # @param String - (required, string) A string containing some text whose language is to be identified. The size of the text must not exceed 10000 characters.
        ###

        def set_Text(value)
          set_input("Text", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Detect Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DetectResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ExpiresIn" output from this Choreo execution
      	#
      	# @return String - (integer) Contains the number of seconds for which the access token is valid when ClientID and ClientSecret are provided.
      	####
      	def get_ExpiresIn()
      	  return @outputs["ExpiresIn"]
      	end
      	####
      	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
      	#
      	# @return String - (string) Contains a new AccessToken when the ClientID and ClientSecret are provided.
      	####
      	def get_NewAccessToken()
      	  return @outputs["NewAccessToken"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Microsoft.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Detect



    ##############################################################################
    #
    # DetectArray
    #
    # Identifies the language of an array of text strings.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DetectArray < Choreography

      ####
      #  Create a new instance of the DetectArray Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/Translator/DetectArray")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DetectArrayInputSet
      ####
      def new_input_set()
        return DetectArrayInputSet.new()
      end

      def make_result_set()
        return DetectArrayResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DetectArrayResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DetectArray
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DetectArrayInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (optional, string) A valid access token. This can be retrieved by running the GetToken Choreo. Required unless providing the ClientID and ClientSecret.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client ID obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client Secret obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Texts input for this Choreo. 
        # 
        # @param String - (required, json) A JSON array representing the text from an unknown language. The size of the text must not exceed 10000 characters.
        ###

        def set_Texts(value)
          set_input("Texts", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DetectArray Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DetectArrayResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ExpiresIn" output from this Choreo execution
      	#
      	# @return String - (integer) Contains the number of seconds for which the access token is valid when ClientID and ClientSecret are provided.
      	####
      	def get_ExpiresIn()
      	  return @outputs["ExpiresIn"]
      	end
      	####
      	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
      	#
      	# @return String - (string) Contains a new AccessToken when the ClientID and ClientSecret are provided.
      	####
      	def get_NewAccessToken()
      	  return @outputs["NewAccessToken"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Microsoft.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DetectArray



    ##############################################################################
    #
    # GetLanguageNames
    #
    # Retrieves friendly names for languages and localized using the specified locale language.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetLanguageNames < Choreography

      ####
      #  Create a new instance of the GetLanguageNames Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/Translator/GetLanguageNames")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetLanguageNamesInputSet
      ####
      def new_input_set()
        return GetLanguageNamesInputSet.new()
      end

      def make_result_set()
        return GetLanguageNamesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetLanguageNamesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetLanguageNames
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetLanguageNamesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (optional, string) A valid access token. This can be retrieved by running the GetToken Choreo. Required unless providing the ClientID and ClientSecret.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client ID obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client Secret obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end
        #### 
        # Set the value of the LanguageCodes input for this Choreo. 
        # 
        # @param String - (required, json) An array of ISO 639-1 language codes to retrieve friendly names for.
        ###

        def set_LanguageCodes(value)
          set_input("LanguageCodes", value)
        end
        #### 
        # Set the value of the Locale input for this Choreo. 
        # 
        # @param String - (required, string) The ISO 639-1 language code associated with the language you wish to return results in.
        ###

        def set_Locale(value)
          set_input("Locale", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetLanguageNames Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetLanguageNamesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ExpiresIn" output from this Choreo execution
      	#
      	# @return String - (integer) Contains the number of seconds for which the access token is valid when ClientID and ClientSecret are provided.
      	####
      	def get_ExpiresIn()
      	  return @outputs["ExpiresIn"]
      	end
      	####
      	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
      	#
      	# @return String - (string) Contains a new AccessToken when the ClientID and ClientSecret are provided.
      	####
      	def get_NewAccessToken()
      	  return @outputs["NewAccessToken"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Microsoft.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetLanguageNames



    ##############################################################################
    #
    # GetLanguagesForSpeak
    #
    # Retrieves the languages available for speech synthesis.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetLanguagesForSpeak < Choreography

      ####
      #  Create a new instance of the GetLanguagesForSpeak Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/Translator/GetLanguagesForSpeak")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetLanguagesForSpeakInputSet
      ####
      def new_input_set()
        return GetLanguagesForSpeakInputSet.new()
      end

      def make_result_set()
        return GetLanguagesForSpeakResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetLanguagesForSpeakResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetLanguagesForSpeak
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetLanguagesForSpeakInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (optional, string) A valid access token. This can be retrieved by running the GetToken Choreo. Required unless providing the ClientID and ClientSecret.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client ID obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client Secret obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetLanguagesForSpeak Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetLanguagesForSpeakResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ExpiresIn" output from this Choreo execution
      	#
      	# @return String - (integer) Contains the number of seconds for which the access token is valid when ClientID and ClientSecret are provided.
      	####
      	def get_ExpiresIn()
      	  return @outputs["ExpiresIn"]
      	end
      	####
      	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
      	#
      	# @return String - (string) Contains a new AccessToken when the ClientID and ClientSecret are provided.
      	####
      	def get_NewAccessToken()
      	  return @outputs["NewAccessToken"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Microsoft.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetLanguagesForSpeak



    ##############################################################################
    #
    # GetLanguagesForTranslate
    #
    # Retrieves a list of language codes representing languages that are supported by the Translation Service.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetLanguagesForTranslate < Choreography

      ####
      #  Create a new instance of the GetLanguagesForTranslate Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/Translator/GetLanguagesForTranslate")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetLanguagesForTranslateInputSet
      ####
      def new_input_set()
        return GetLanguagesForTranslateInputSet.new()
      end

      def make_result_set()
        return GetLanguagesForTranslateResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetLanguagesForTranslateResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetLanguagesForTranslate
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetLanguagesForTranslateInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (optional, string) A valid access token. This can be retrieved by running the GetToken Choreo. Required unless providing the ClientID and ClientSecret.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client ID obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client Secret obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetLanguagesForTranslate Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetLanguagesForTranslateResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ExpiresIn" output from this Choreo execution
      	#
      	# @return String - (integer) Contains the number of seconds for which the access token is valid when ClientID and ClientSecret are provided.
      	####
      	def get_ExpiresIn()
      	  return @outputs["ExpiresIn"]
      	end
      	####
      	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
      	#
      	# @return String - (string) Contains a new AccessToken when the ClientID and ClientSecret are provided.
      	####
      	def get_NewAccessToken()
      	  return @outputs["NewAccessToken"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Microsoft.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetLanguagesForTranslate



    ##############################################################################
    #
    # GetToken
    #
    # Retrieves an access token that can be used to authenticate with the Microsoft Translator API.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetToken < Choreography

      ####
      #  Create a new instance of the GetToken Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/Translator/GetToken")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetTokenInputSet
      ####
      def new_input_set()
        return GetTokenInputSet.new()
      end

      def make_result_set()
        return GetTokenResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetTokenResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetToken
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetTokenInputSet < Choreography::InputSet

        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (required, string) The Client ID obtained when signing up for Microsoft Translator on Azure Marketplace.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Client Secret obtained when signing up for Microsoft Translator on Azure Marketplace.
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetToken Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetTokenResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "AccessToken" output from this Choreo execution
      	#
      	# @return String - (string) The access token returned from Microsoft.
      	####
      	def get_AccessToken()
      	  return @outputs["AccessToken"]
      	end
      	####
      	# Retrieve the value for the "ExpiresIn" output from this Choreo execution
      	#
      	# @return String - (integer) The number of seconds for which the access token is valid.
      	####
      	def get_ExpiresIn()
      	  return @outputs["ExpiresIn"]
      	end
      end

    end # class GetToken



    ##############################################################################
    #
    # GetTranslations
    #
    # Retrieves an array of all translations for a given text.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetTranslations < Choreography

      ####
      #  Create a new instance of the GetTranslations Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/Translator/GetTranslations")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetTranslationsInputSet
      ####
      def new_input_set()
        return GetTranslationsInputSet.new()
      end

      def make_result_set()
        return GetTranslationsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetTranslationsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetTranslations
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetTranslationsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (optional, string) A valid access token. This can be retrieved by running the GetToken Choreo. Required unless providing the ClientID and ClientSecret.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the Category input for this Choreo. 
        # 
        # @param String - (optional, string) A string containing the category (domain) of the translation. Defaults to "general".
        ###

        def set_Category(value)
          set_input("Category", value)
        end
        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client ID obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client Secret obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end
        #### 
        # Set the value of the ContentType input for this Choreo. 
        # 
        # @param String - (optional, string) The format of the text being translated. The only supported, and the default, option is "text/plain".
        ###

        def set_ContentType(value)
          set_input("ContentType", value)
        end
        #### 
        # Set the value of the From input for this Choreo. 
        # 
        # @param String - (required, string) A string representing the ISO 639-1 language code of the translation text (e.g., en).
        ###

        def set_From(value)
          set_input("From", value)
        end
        #### 
        # Set the value of the MaxTranslations input for this Choreo. 
        # 
        # @param Integer - (required, integer) An integer representing the maximum number of translations to return.
        ###

        def set_MaxTranslations(value)
          set_input("MaxTranslations", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the State input for this Choreo. 
        # 
        # @param String - (optional, string) User state to help correlate request and response. The same contents will be returned in the response.
        ###

        def set_State(value)
          set_input("State", value)
        end
        #### 
        # Set the value of the Text input for this Choreo. 
        # 
        # @param String - (required, string) A string representing the text to translate. The size of the text must not exceed 10000 characters.
        ###

        def set_Text(value)
          set_input("Text", value)
        end
        #### 
        # Set the value of the To input for this Choreo. 
        # 
        # @param String - (required, string) A string representing the ISO 639-1 language code to translate the text into (e.g., es).
        ###

        def set_To(value)
          set_input("To", value)
        end
        #### 
        # Set the value of the URI input for this Choreo. 
        # 
        # @param String - (optional, string) Filter results by this URI. Default: all
        ###

        def set_URI(value)
          set_input("URI", value)
        end
        #### 
        # Set the value of the User input for this Choreo. 
        # 
        # @param String - (optional, string) Filter results by this user. Default: all
        ###

        def set_User(value)
          set_input("User", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetTranslations Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetTranslationsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ExpiresIn" output from this Choreo execution
      	#
      	# @return String - (integer) Contains the number of seconds for which the access token is valid when ClientID and ClientSecret are provided.
      	####
      	def get_ExpiresIn()
      	  return @outputs["ExpiresIn"]
      	end
      	####
      	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
      	#
      	# @return String - (string) Contains a new AccessToken when the ClientID and ClientSecret are provided.
      	####
      	def get_NewAccessToken()
      	  return @outputs["NewAccessToken"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Microsoft.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetTranslations



    ##############################################################################
    #
    # GetTranslationsArray
    #
    # Retrieves multiple translation candidates for multiple source texts.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetTranslationsArray < Choreography

      ####
      #  Create a new instance of the GetTranslationsArray Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/Translator/GetTranslationsArray")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetTranslationsArrayInputSet
      ####
      def new_input_set()
        return GetTranslationsArrayInputSet.new()
      end

      def make_result_set()
        return GetTranslationsArrayResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetTranslationsArrayResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetTranslationsArray
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetTranslationsArrayInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (optional, string) A valid access token. This can be retrieved by running the GetToken Choreo. Required unless providing the ClientID and ClientSecret.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the Category input for this Choreo. 
        # 
        # @param String - (optional, string) A string containing the category (domain) of the translation. Defaults to "general".
        ###

        def set_Category(value)
          set_input("Category", value)
        end
        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client ID obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client Secret obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end
        #### 
        # Set the value of the ContentType input for this Choreo. 
        # 
        # @param String - (optional, string) The format of the text being translated. The only supported, and the default, option is "text/plain".
        ###

        def set_ContentType(value)
          set_input("ContentType", value)
        end
        #### 
        # Set the value of the From input for this Choreo. 
        # 
        # @param String - (required, string) A string representing the ISO 639-1 language code of the translation text (e.g., en).
        ###

        def set_From(value)
          set_input("From", value)
        end
        #### 
        # Set the value of the MaxTranslations input for this Choreo. 
        # 
        # @param Integer - (required, integer) An integer representing the maximum number of translations to return.
        ###

        def set_MaxTranslations(value)
          set_input("MaxTranslations", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the State input for this Choreo. 
        # 
        # @param String - (optional, string) User state to help correlate request and response. The same contents will be returned in the response.
        ###

        def set_State(value)
          set_input("State", value)
        end
        #### 
        # Set the value of the Texts input for this Choreo. 
        # 
        # @param String - (required, json) An array containing the texts for translation. All strings must be of the same language. The total of all texts must not exceed 10000 characters. The max number of array items is 2000.
        ###

        def set_Texts(value)
          set_input("Texts", value)
        end
        #### 
        # Set the value of the To input for this Choreo. 
        # 
        # @param String - (required, string) A string representing the ISO 639-1 language code to translate the text into (e.g., es).
        ###

        def set_To(value)
          set_input("To", value)
        end
        #### 
        # Set the value of the URI input for this Choreo. 
        # 
        # @param String - (optional, string) Filter results by this URI. Default: all
        ###

        def set_URI(value)
          set_input("URI", value)
        end
        #### 
        # Set the value of the User input for this Choreo. 
        # 
        # @param String - (optional, string) Filter results by this user. Default: all
        ###

        def set_User(value)
          set_input("User", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetTranslationsArray Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetTranslationsArrayResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ExpiresIn" output from this Choreo execution
      	#
      	# @return String - (integer) Contains the number of seconds for which the access token is valid when ClientID and ClientSecret are provided.
      	####
      	def get_ExpiresIn()
      	  return @outputs["ExpiresIn"]
      	end
      	####
      	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
      	#
      	# @return String - (string) Contains a new AccessToken when the ClientID and ClientSecret are provided.
      	####
      	def get_NewAccessToken()
      	  return @outputs["NewAccessToken"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Microsoft.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetTranslationsArray



    ##############################################################################
    #
    # Speak
    #
    # Returns a Base64 encoded wave or mp3 file of the passed-in text being spoken in the desired language.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Speak < Choreography

      ####
      #  Create a new instance of the Speak Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/Translator/Speak")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return SpeakInputSet
      ####
      def new_input_set()
        return SpeakInputSet.new()
      end

      def make_result_set()
        return SpeakResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = SpeakResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Speak
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class SpeakInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (optional, string) A valid access token. This can be retrieved by running the GetToken Choreo. Required unless providing the ClientID and ClientSecret.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client ID obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client Secret obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end
        #### 
        # Set the value of the Format input for this Choreo. 
        # 
        # @param String - (optional, string) A string specifying the content-type. Currently, "audio/wav" and "audio/mp3" are available. The default value is "audio/wav".
        ###

        def set_Format(value)
          set_input("Format", value)
        end
        #### 
        # Set the value of the Language input for this Choreo. 
        # 
        # @param String - (required, string) A string representing the supported ISO 639-1 language code to speak the text in (e.g., es). The code must be present in the list of codes returned from the method GetLanguagesForSpeak.
        ###

        def set_Language(value)
          set_input("Language", value)
        end
        #### 
        # Set the value of the Options input for this Choreo. 
        # 
        # @param String - (optional, string) A string specifying the quality of the audio signals. Valid values are: MaxQuality or MinQuality (the default).
        ###

        def set_Options(value)
          set_input("Options", value)
        end
        #### 
        # Set the value of the Text input for this Choreo. 
        # 
        # @param String - (required, string) A string representing the text to translate. The size of the text must not exceed 10000 characters.
        ###

        def set_Text(value)
          set_input("Text", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Speak Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class SpeakResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "AudioFile" output from this Choreo execution
      	#
      	# @return String - (string) The Base64 encoded audio file in mp3 or wav format.
      	####
      	def get_AudioFile()
      	  return @outputs["AudioFile"]
      	end
      	####
      	# Retrieve the value for the "ExpiresIn" output from this Choreo execution
      	#
      	# @return String - (integer) Contains the number of seconds for which the access token is valid when ClientID and ClientSecret are provided.
      	####
      	def get_ExpiresIn()
      	  return @outputs["ExpiresIn"]
      	end
      	####
      	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
      	#
      	# @return String - (string) Contains a new AccessToken when the ClientID and ClientSecret are provided.
      	####
      	def get_NewAccessToken()
      	  return @outputs["NewAccessToken"]
      	end
      end

    end # class Speak



    ##############################################################################
    #
    # Translate
    #
    # Translates a text string from one language to another.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Translate < Choreography

      ####
      #  Create a new instance of the Translate Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/Translator/Translate")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return TranslateInputSet
      ####
      def new_input_set()
        return TranslateInputSet.new()
      end

      def make_result_set()
        return TranslateResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = TranslateResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Translate
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class TranslateInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (optional, string) A valid access token. This can be retrieved by running the GetToken Choreo. Required unless providing the ClientID and ClientSecret.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the Category input for this Choreo. 
        # 
        # @param String - (optional, string) A string containing the category (domain) of the translation. Defaults to "general".
        ###

        def set_Category(value)
          set_input("Category", value)
        end
        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client ID obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client Secret obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end
        #### 
        # Set the value of the ContentType input for this Choreo. 
        # 
        # @param String - (optional, string) The format of the text being translated. The supported formats are "text/plain" (the default) and "text/html".
        ###

        def set_ContentType(value)
          set_input("ContentType", value)
        end
        #### 
        # Set the value of the From input for this Choreo. 
        # 
        # @param String - (required, string) A string representing the ISO 639-1 language code of the translation text (e.g., en).
        ###

        def set_From(value)
          set_input("From", value)
        end
        #### 
        # Set the value of the Text input for this Choreo. 
        # 
        # @param String - (required, string) A string representing the text to translate. The size of the text must not exceed 10000 characters.
        ###

        def set_Text(value)
          set_input("Text", value)
        end
        #### 
        # Set the value of the To input for this Choreo. 
        # 
        # @param String - (required, string) A string representing the ISO 639-1 language codee to translate the text into (e.g., es).
        ###

        def set_To(value)
          set_input("To", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Translate Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class TranslateResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ExpiresIn" output from this Choreo execution
      	#
      	# @return String - (integer) Contains the number of seconds for which the access token is valid when ClientID and ClientSecret are provided.
      	####
      	def get_ExpiresIn()
      	  return @outputs["ExpiresIn"]
      	end
      	####
      	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
      	#
      	# @return String - (string) Contains a new AccessToken when the ClientID and ClientSecret are provided.
      	####
      	def get_NewAccessToken()
      	  return @outputs["NewAccessToken"]
      	end
      	####
      	# Retrieve the value for the "TranslatedText" output from this Choreo execution
      	#
      	# @return String - (string) The translated text parsed from the Microsoft response.
      	####
      	def get_TranslatedText()
      	  return @outputs["TranslatedText"]
      	end
      end

    end # class Translate



    ##############################################################################
    #
    # TranslateArray
    #
    # Translates multiple source texts.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class TranslateArray < Choreography

      ####
      #  Create a new instance of the TranslateArray Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Microsoft/Translator/TranslateArray")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return TranslateArrayInputSet
      ####
      def new_input_set()
        return TranslateArrayInputSet.new()
      end

      def make_result_set()
        return TranslateArrayResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = TranslateArrayResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the TranslateArray
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class TranslateArrayInputSet < Choreography::InputSet

        #### 
        # Set the value of the AccessToken input for this Choreo. 
        # 
        # @param String - (optional, string) A valid access token. This can be retrieved by running the GetToken Choreo. Required unless providing the ClientID and ClientSecret.
        ###

        def set_AccessToken(value)
          set_input("AccessToken", value)
        end
        #### 
        # Set the value of the Category input for this Choreo. 
        # 
        # @param String - (optional, string) A string containing the category (domain) of the translation. Defaults to "general".
        ###

        def set_Category(value)
          set_input("Category", value)
        end
        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client ID obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (conditional, string) The Client Secret obtained when signing up for Microsoft Translator on Azure Marketplace. This is required unless providing an AccessToken.
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end
        #### 
        # Set the value of the ContentType input for this Choreo. 
        # 
        # @param String - (optional, string) The format of the text being translated. The supported formats are "text/plain" (the default) and "text/html".
        ###

        def set_ContentType(value)
          set_input("ContentType", value)
        end
        #### 
        # Set the value of the From input for this Choreo. 
        # 
        # @param String - (optional, string) A string representing the language code of the translation text (e.g., en). If not provided auto-detection is used.
        ###

        def set_From(value)
          set_input("From", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Texts input for this Choreo. 
        # 
        # @param String - (required, json) An array containing the texts for translation. All strings must be of the same language. The total of all texts must not exceed 10000 characters. The max number of array items is 2000.
        ###

        def set_Texts(value)
          set_input("Texts", value)
        end
        #### 
        # Set the value of the To input for this Choreo. 
        # 
        # @param String - (required, string) A string representing the ISO 639-1 language code to translate the text into (e.g., es).
        ###

        def set_To(value)
          set_input("To", value)
        end
        #### 
        # Set the value of the URI input for this Choreo. 
        # 
        # @param String - (optional, string) Filter results by this URI. Default: all
        ###

        def set_URI(value)
          set_input("URI", value)
        end
        #### 
        # Set the value of the User input for this Choreo. 
        # 
        # @param String - (optional, multiline) Filter results by this user. Default: all
        ###

        def set_User(value)
          set_input("User", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the TranslateArray Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class TranslateArrayResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ExpiresIn" output from this Choreo execution
      	#
      	# @return String - (integer) Contains the number of seconds for which the access token is valid when ClientID and ClientSecret are provided.
      	####
      	def get_ExpiresIn()
      	  return @outputs["ExpiresIn"]
      	end
      	####
      	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
      	#
      	# @return String - (string) Contains a new AccessToken when the ClientID and ClientSecret are provided.
      	####
      	def get_NewAccessToken()
      	  return @outputs["NewAccessToken"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Microsoft.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class TranslateArray




  end # module Translator

end # module Microsoft