require "temboo"

module PagerDuty




  module Alerts



    ##############################################################################
    #
    # ListAlerts
    #
    # List alerts for a given time range and allows you to filter by type.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListAlerts < Choreography

      ####
      #  Create a new instance of the ListAlerts Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/PagerDuty/Alerts/ListAlerts")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListAlertsInputSet
      ####
      def new_input_set()
        return ListAlertsInputSet.new()
      end

      def make_result_set()
        return ListAlertsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListAlertsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListAlerts
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListAlertsInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by PagerDuty.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the Filter input for this Choreo. 
        # 
        # @param String - (optional, string) Returns only alerts of this type. Valid types are: SMS, Email, Phone, or Push.
        ###

        def set_Filter(value)
          set_input("Filter", value)
        end
        #### 
        # Set the value of the Since input for this Choreo. 
        # 
        # @param String - (required, date) The start of the date range to search (e.g., 2013-03-06T15:28-05). Note that including the time is optional.
        ###

        def set_Since(value)
          set_input("Since", value)
        end
        #### 
        # Set the value of the SubDomain input for this Choreo. 
        # 
        # @param String - (required, string) The subdomain of your PagerDuty site address.
        ###

        def set_SubDomain(value)
          set_input("SubDomain", value)
        end
        #### 
        # Set the value of the TimeZone input for this Choreo. 
        # 
        # @param String - (optional, string) The time zone in which dates in the result will be rendered. Defaults to account time zone.
        ###

        def set_TimeZone(value)
          set_input("TimeZone", value)
        end
        #### 
        # Set the value of the Until input for this Choreo. 
        # 
        # @param String - (required, date) The end of the date range to search (e.g., 2013-03-06T15:28-05). Note that including the time is optional.
        ###

        def set_Until(value)
          set_input("Until", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListAlerts Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListAlertsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from PagerDuty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListAlerts




  end # module Alerts

  module Events



    ##############################################################################
    #
    # AcknowledgeEvent
    #
    # Updates the state of an incident to "acknowleged", and allows you to log data to an incident log.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class AcknowledgeEvent < Choreography

      ####
      #  Create a new instance of the AcknowledgeEvent Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/PagerDuty/Events/AcknowledgeEvent")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AcknowledgeEventInputSet
      ####
      def new_input_set()
        return AcknowledgeEventInputSet.new()
      end

      def make_result_set()
        return AcknowledgeEventResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AcknowledgeEventResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the AcknowledgeEvent
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AcknowledgeEventInputSet < Choreography::InputSet

        #### 
        # Set the value of the Description input for this Choreo. 
        # 
        # @param String - (optional, string) A short description that will appear in the incident's log associated with this event.
        ###

        def set_Description(value)
          set_input("Description", value)
        end
        #### 
        # Set the value of the Details input for this Choreo. 
        # 
        # @param String - (optional, json) A JSON object containing any data you'd like included in the incident log.
        ###

        def set_Details(value)
          set_input("Details", value)
        end
        #### 
        # Set the value of the IncidentKey input for this Choreo. 
        # 
        # @param String - (required, string) Identifies the incident to acknowledge.
        ###

        def set_IncidentKey(value)
          set_input("IncidentKey", value)
        end
        #### 
        # Set the value of the ServiceKey input for this Choreo. 
        # 
        # @param String - (required, string) The service key of one of your "Generic API" services. This is listed on a Generic API's service detail page.
        ###

        def set_ServiceKey(value)
          set_input("ServiceKey", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the AcknowledgeEvent Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AcknowledgeEventResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from PagerDuty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class AcknowledgeEvent



    ##############################################################################
    #
    # ResolveEvent
    #
    # Updates the state of an incident to "resolved", and allows you to log data to an incident log.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ResolveEvent < Choreography

      ####
      #  Create a new instance of the ResolveEvent Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/PagerDuty/Events/ResolveEvent")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ResolveEventInputSet
      ####
      def new_input_set()
        return ResolveEventInputSet.new()
      end

      def make_result_set()
        return ResolveEventResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ResolveEventResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ResolveEvent
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ResolveEventInputSet < Choreography::InputSet

        #### 
        # Set the value of the Description input for this Choreo. 
        # 
        # @param String - (optional, string) A short description that will appear in the incident's log associated with this event.
        ###

        def set_Description(value)
          set_input("Description", value)
        end
        #### 
        # Set the value of the Details input for this Choreo. 
        # 
        # @param String - (optional, json) A JSON object containing any data you'd like included in the incident log.
        ###

        def set_Details(value)
          set_input("Details", value)
        end
        #### 
        # Set the value of the IncidentKey input for this Choreo. 
        # 
        # @param String - (required, string) Identifies the incident to resolve.
        ###

        def set_IncidentKey(value)
          set_input("IncidentKey", value)
        end
        #### 
        # Set the value of the ServiceKey input for this Choreo. 
        # 
        # @param String - (required, string) The service key of one of your "Generic API" services. This is listed on a Generic API's service detail page.
        ###

        def set_ServiceKey(value)
          set_input("ServiceKey", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ResolveEvent Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ResolveEventResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from PagerDuty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ResolveEvent



    ##############################################################################
    #
    # TriggerEvent
    #
    # Triggers an event that will open a new incident or log an entry to an existing incident.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class TriggerEvent < Choreography

      ####
      #  Create a new instance of the TriggerEvent Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/PagerDuty/Events/TriggerEvent")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return TriggerEventInputSet
      ####
      def new_input_set()
        return TriggerEventInputSet.new()
      end

      def make_result_set()
        return TriggerEventResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = TriggerEventResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the TriggerEvent
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class TriggerEventInputSet < Choreography::InputSet

        #### 
        # Set the value of the Description input for this Choreo. 
        # 
        # @param String - (required, string) A short description of the problem that led to this trigger. The maximum length is 1024 characters.
        ###

        def set_Description(value)
          set_input("Description", value)
        end
        #### 
        # Set the value of the Details input for this Choreo. 
        # 
        # @param String - (required, json) A JSON object containing the data you'd like included in the incident log.
        ###

        def set_Details(value)
          set_input("Details", value)
        end
        #### 
        # Set the value of the IncidentKey input for this Choreo. 
        # 
        # @param String - (optional, string) Identifies the incident to which this trigger event should be applied. If there's no open incident with this key, a new one will be created.
        ###

        def set_IncidentKey(value)
          set_input("IncidentKey", value)
        end
        #### 
        # Set the value of the ServiceKey input for this Choreo. 
        # 
        # @param String - (required, string) The service key of one of your "Generic API" services. This is listed on a Generic API's service detail page.
        ###

        def set_ServiceKey(value)
          set_input("ServiceKey", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the TriggerEvent Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class TriggerEventResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from PagerDuty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class TriggerEvent




  end # module Events

  module Incidents



    ##############################################################################
    #
    # AcknowledgeIncident
    #
    # Acknowledges an incident.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class AcknowledgeIncident < Choreography

      ####
      #  Create a new instance of the AcknowledgeIncident Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/PagerDuty/Incidents/AcknowledgeIncident")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AcknowledgeIncidentInputSet
      ####
      def new_input_set()
        return AcknowledgeIncidentInputSet.new()
      end

      def make_result_set()
        return AcknowledgeIncidentResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AcknowledgeIncidentResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the AcknowledgeIncident
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AcknowledgeIncidentInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by PagerDuty.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the IncidentID input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the incident to acknowledge.
        ###

        def set_IncidentID(value)
          set_input("IncidentID", value)
        end
        #### 
        # Set the value of the RequesterID input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the user making the request. This will be added to the incident log entry.
        ###

        def set_RequesterID(value)
          set_input("RequesterID", value)
        end
        #### 
        # Set the value of the SubDomain input for this Choreo. 
        # 
        # @param String - (required, string) The subdomain of your PagerDuty site address.
        ###

        def set_SubDomain(value)
          set_input("SubDomain", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the AcknowledgeIncident Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AcknowledgeIncidentResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from PagerDuty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class AcknowledgeIncident



    ##############################################################################
    #
    # CountIncidents
    #
    # Returns a count of incidents that match a specified criteria.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CountIncidents < Choreography

      ####
      #  Create a new instance of the CountIncidents Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/PagerDuty/Incidents/CountIncidents")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CountIncidentsInputSet
      ####
      def new_input_set()
        return CountIncidentsInputSet.new()
      end

      def make_result_set()
        return CountIncidentsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CountIncidentsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CountIncidents
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CountIncidentsInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by PagerDuty.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the AssignedToUser input for this Choreo. 
        # 
        # @param String - (optional, string) Returns the count of incidents assigned to the specified user.
        ###

        def set_AssignedToUser(value)
          set_input("AssignedToUser", value)
        end
        #### 
        # Set the value of the DateRange input for this Choreo. 
        # 
        # @param String - (optional, string) When set to "all", this allows you to retrieve the count of all incidents since the account was created.
        ###

        def set_DateRange(value)
          set_input("DateRange", value)
        end
        #### 
        # Set the value of the IncidentKey input for this Choreo. 
        # 
        # @param String - (optional, string) Returns the count of incidents with the specified key.
        ###

        def set_IncidentKey(value)
          set_input("IncidentKey", value)
        end
        #### 
        # Set the value of the Service input for this Choreo. 
        # 
        # @param String - (optional, string) Returns the count of incidents associated with the specified service.
        ###

        def set_Service(value)
          set_input("Service", value)
        end
        #### 
        # Set the value of the Since input for this Choreo. 
        # 
        # @param String - (optional, date) The start of the date range to search (e.g., 2013-03-06T15:28-05). Note that including the time is optional.
        ###

        def set_Since(value)
          set_input("Since", value)
        end
        #### 
        # Set the value of the Status input for this Choreo. 
        # 
        # @param String - (optional, string) Returns the count of incidents with this specified status. Valid values are: triggered, acknowledged, and resolved.
        ###

        def set_Status(value)
          set_input("Status", value)
        end
        #### 
        # Set the value of the SubDomain input for this Choreo. 
        # 
        # @param String - (required, string) The subdomain of your PagerDuty site address.
        ###

        def set_SubDomain(value)
          set_input("SubDomain", value)
        end
        #### 
        # Set the value of the Until input for this Choreo. 
        # 
        # @param String - (optional, date) The end of the date range to search (e.g., 2013-03-06T15:28-05). Note that including the time is optional.
        ###

        def set_Until(value)
          set_input("Until", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CountIncidents Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CountIncidentsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from PagerDuty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CountIncidents



    ##############################################################################
    #
    # GetIncident
    #
    # Returns detailed information about a specified incident.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetIncident < Choreography

      ####
      #  Create a new instance of the GetIncident Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/PagerDuty/Incidents/GetIncident")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetIncidentInputSet
      ####
      def new_input_set()
        return GetIncidentInputSet.new()
      end

      def make_result_set()
        return GetIncidentResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetIncidentResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetIncident
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetIncidentInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by PagerDuty.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the IncidentID input for this Choreo. 
        # 
        # @param String - (required, string) An incident ID, or an incident number.
        ###

        def set_IncidentID(value)
          set_input("IncidentID", value)
        end
        #### 
        # Set the value of the SubDomain input for this Choreo. 
        # 
        # @param String - (required, string) The subdomain of your PagerDuty site address.
        ###

        def set_SubDomain(value)
          set_input("SubDomain", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetIncident Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetIncidentResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from PagerDuty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetIncident



    ##############################################################################
    #
    # ListIncidents
    #
    # Allows you to list or search PagerDuty incidents.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListIncidents < Choreography

      ####
      #  Create a new instance of the ListIncidents Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/PagerDuty/Incidents/ListIncidents")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListIncidentsInputSet
      ####
      def new_input_set()
        return ListIncidentsInputSet.new()
      end

      def make_result_set()
        return ListIncidentsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListIncidentsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListIncidents
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListIncidentsInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by PagerDuty.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the AssignedToUser input for this Choreo. 
        # 
        # @param String - (optional, string) Returns only incidents assigned to the specified user.
        ###

        def set_AssignedToUser(value)
          set_input("AssignedToUser", value)
        end
        #### 
        # Set the value of the DateRange input for this Choreo. 
        # 
        # @param String - (optional, string) When set to "all", this allows you to retrieve all incidents since the account was created.
        ###

        def set_DateRange(value)
          set_input("DateRange", value)
        end
        #### 
        # Set the value of the Fields input for this Choreo. 
        # 
        # @param String - (optional, string) Allows you to select specific incident properties to be returned in the response.
        ###

        def set_Fields(value)
          set_input("Fields", value)
        end
        #### 
        # Set the value of the IncidentKey input for this Choreo. 
        # 
        # @param String - (optional, string) Returns only incidents with the specified key.
        ###

        def set_IncidentKey(value)
          set_input("IncidentKey", value)
        end
        #### 
        # Set the value of the Limit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The number of incidents returned. Default (and max limit) is 100.
        ###

        def set_Limit(value)
          set_input("Limit", value)
        end
        #### 
        # Set the value of the Offset input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The offset of the first incident record returned. Default is 0.
        ###

        def set_Offset(value)
          set_input("Offset", value)
        end
        #### 
        # Set the value of the Service input for this Choreo. 
        # 
        # @param String - (optional, string) Returns only incidents associated with the specified service.
        ###

        def set_Service(value)
          set_input("Service", value)
        end
        #### 
        # Set the value of the Since input for this Choreo. 
        # 
        # @param String - (optional, date) The start of the date range to search (e.g., 2013-03-06T15:28-05). Note that including the time is optional.
        ###

        def set_Since(value)
          set_input("Since", value)
        end
        #### 
        # Set the value of the SortBy input for this Choreo. 
        # 
        # @param String - (optional, string) Used to specify both the field you wish to sort the results on (incident_number, created_on, or resolved_on), as well as the direction (asc/desc) of the results (e.g., created_on:desc).
        ###

        def set_SortBy(value)
          set_input("SortBy", value)
        end
        #### 
        # Set the value of the Status input for this Choreo. 
        # 
        # @param String - (optional, string) Returns only the incidents with this specified status. Valid values are: triggered, acknowledged, and resolved.
        ###

        def set_Status(value)
          set_input("Status", value)
        end
        #### 
        # Set the value of the SubDomain input for this Choreo. 
        # 
        # @param String - (required, string) The subdomain of your PagerDuty site address.
        ###

        def set_SubDomain(value)
          set_input("SubDomain", value)
        end
        #### 
        # Set the value of the TimeZone input for this Choreo. 
        # 
        # @param String - (optional, string) The time zone in which dates in the result will be rendered. Defaults to account time zone.
        ###

        def set_TimeZone(value)
          set_input("TimeZone", value)
        end
        #### 
        # Set the value of the Until input for this Choreo. 
        # 
        # @param String - (optional, date) The end of the date range to search (e.g., 2013-03-06T15:28-05). Note that including the time is optional.
        ###

        def set_Until(value)
          set_input("Until", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListIncidents Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListIncidentsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from PagerDuty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListIncidents



    ##############################################################################
    #
    # ReassignIncident
    #
    # Reassigns an incident.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ReassignIncident < Choreography

      ####
      #  Create a new instance of the ReassignIncident Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/PagerDuty/Incidents/ReassignIncident")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ReassignIncidentInputSet
      ####
      def new_input_set()
        return ReassignIncidentInputSet.new()
      end

      def make_result_set()
        return ReassignIncidentResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ReassignIncidentResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ReassignIncident
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ReassignIncidentInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by PagerDuty.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the AssignedToUser input for this Choreo. 
        # 
        # @param String - (required, string) Assigns this incident to the specified user id.
        ###

        def set_AssignedToUser(value)
          set_input("AssignedToUser", value)
        end
        #### 
        # Set the value of the EscalationLevel input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Escalates the incident to this level in the escalation policy.
        ###

        def set_EscalationLevel(value)
          set_input("EscalationLevel", value)
        end
        #### 
        # Set the value of the IncidentID input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the incident to reassign.
        ###

        def set_IncidentID(value)
          set_input("IncidentID", value)
        end
        #### 
        # Set the value of the RequesterID input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the user making the request. This will be added to the incident log entry.
        ###

        def set_RequesterID(value)
          set_input("RequesterID", value)
        end
        #### 
        # Set the value of the SubDomain input for this Choreo. 
        # 
        # @param String - (required, string) The subdomain of your PagerDuty site address.
        ###

        def set_SubDomain(value)
          set_input("SubDomain", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ReassignIncident Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ReassignIncidentResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from PagerDuty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ReassignIncident



    ##############################################################################
    #
    # ResolveIncident
    #
    # Resolves an incident.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ResolveIncident < Choreography

      ####
      #  Create a new instance of the ResolveIncident Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/PagerDuty/Incidents/ResolveIncident")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ResolveIncidentInputSet
      ####
      def new_input_set()
        return ResolveIncidentInputSet.new()
      end

      def make_result_set()
        return ResolveIncidentResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ResolveIncidentResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ResolveIncident
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ResolveIncidentInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by PagerDuty.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the IncidentID input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the incident to resolve.
        ###

        def set_IncidentID(value)
          set_input("IncidentID", value)
        end
        #### 
        # Set the value of the RequesterID input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the user making the request. This will be added to the incident log entry.
        ###

        def set_RequesterID(value)
          set_input("RequesterID", value)
        end
        #### 
        # Set the value of the SubDomain input for this Choreo. 
        # 
        # @param String - (required, string) The subdomain of your PagerDuty site address.
        ###

        def set_SubDomain(value)
          set_input("SubDomain", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ResolveIncident Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ResolveIncidentResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from PagerDuty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ResolveIncident



    ##############################################################################
    #
    # UpdateIncidents
    #
    # Allows you to acknowledge, resolve, escalate or reassign one or more incidents.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UpdateIncidents < Choreography

      ####
      #  Create a new instance of the UpdateIncidents Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/PagerDuty/Incidents/UpdateIncidents")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UpdateIncidentsInputSet
      ####
      def new_input_set()
        return UpdateIncidentsInputSet.new()
      end

      def make_result_set()
        return UpdateIncidentsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UpdateIncidentsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UpdateIncidents
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UpdateIncidentsInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by PagerDuty.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the Incidents input for this Choreo. 
        # 
        # @param String - (required, json) An array of incident objects that each include an incident ID. Other optional incident properties that can be present include: status, escalation_level, assigned_to_user, and escalation_policy.
        ###

        def set_Incidents(value)
          set_input("Incidents", value)
        end
        #### 
        # Set the value of the RequesterID input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the user making the request. This will be added to the incident log entry.
        ###

        def set_RequesterID(value)
          set_input("RequesterID", value)
        end
        #### 
        # Set the value of the SubDomain input for this Choreo. 
        # 
        # @param String - (required, string) The subdomain of your PagerDuty site address.
        ###

        def set_SubDomain(value)
          set_input("SubDomain", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UpdateIncidents Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UpdateIncidentsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from PagerDuty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UpdateIncidents




  end # module Incidents

  module LogEntries



    ##############################################################################
    #
    # GetLogEntry
    #
    # Returns details for a specific incident log entry.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetLogEntry < Choreography

      ####
      #  Create a new instance of the GetLogEntry Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/PagerDuty/LogEntries/GetLogEntry")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetLogEntryInputSet
      ####
      def new_input_set()
        return GetLogEntryInputSet.new()
      end

      def make_result_set()
        return GetLogEntryResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetLogEntryResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetLogEntry
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetLogEntryInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by PagerDuty.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the LogEntryID input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the log entry to return.
        ###

        def set_LogEntryID(value)
          set_input("LogEntryID", value)
        end
        #### 
        # Set the value of the SubDomain input for this Choreo. 
        # 
        # @param String - (required, string) The subdomain of your PagerDuty site address.
        ###

        def set_SubDomain(value)
          set_input("SubDomain", value)
        end
        #### 
        # Set the value of the TimeZone input for this Choreo. 
        # 
        # @param String - (optional, string) The time zone in which dates in the result will be rendered. Defaults to account time zone.
        ###

        def set_TimeZone(value)
          set_input("TimeZone", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetLogEntry Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetLogEntryResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from PagerDuty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetLogEntry



    ##############################################################################
    #
    # ListLogEntries
    #
    # Lists all incident log entries across an entire account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListLogEntries < Choreography

      ####
      #  Create a new instance of the ListLogEntries Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/PagerDuty/LogEntries/ListLogEntries")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListLogEntriesInputSet
      ####
      def new_input_set()
        return ListLogEntriesInputSet.new()
      end

      def make_result_set()
        return ListLogEntriesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListLogEntriesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListLogEntries
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListLogEntriesInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by PagerDuty.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the Include input for this Choreo. 
        # 
        # @param String - (optional, string) A list of additional details to include in the response. Valid values are: channel, incident, and service.
        ###

        def set_Include(value)
          set_input("Include", value)
        end
        #### 
        # Set the value of the IsOverview input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If set to true, only log entries of type trigger, acknowledge, or resolve are returned. Defaults to false.
        ###

        def set_IsOverview(value)
          set_input("IsOverview", value)
        end
        #### 
        # Set the value of the Limit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The number of log entries returned. Default (and max limit) is 100.
        ###

        def set_Limit(value)
          set_input("Limit", value)
        end
        #### 
        # Set the value of the Offset input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The offset of the first log entry record returned. Default is 0.
        ###

        def set_Offset(value)
          set_input("Offset", value)
        end
        #### 
        # Set the value of the Since input for this Choreo. 
        # 
        # @param String - (optional, date) The start of the date range to search (e.g., 2013-03-06T15:28-05). Note that including the time is optional.
        ###

        def set_Since(value)
          set_input("Since", value)
        end
        #### 
        # Set the value of the SubDomain input for this Choreo. 
        # 
        # @param String - (required, string) The subdomain of your PagerDuty site address.
        ###

        def set_SubDomain(value)
          set_input("SubDomain", value)
        end
        #### 
        # Set the value of the TimeZone input for this Choreo. 
        # 
        # @param String - (optional, string) The time zone in which dates in the result will be rendered. Defaults to account time zone.
        ###

        def set_TimeZone(value)
          set_input("TimeZone", value)
        end
        #### 
        # Set the value of the Until input for this Choreo. 
        # 
        # @param String - (optional, date) The end of the date range to search (e.g., 2013-03-06T15:28-05). Note that including the time is optional.
        ###

        def set_Until(value)
          set_input("Until", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListLogEntries Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListLogEntriesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from PagerDuty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListLogEntries



    ##############################################################################
    #
    # ListLogEntriesByIncident
    #
    # Lists all incident log entries associated with a specific incident.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListLogEntriesByIncident < Choreography

      ####
      #  Create a new instance of the ListLogEntriesByIncident Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/PagerDuty/LogEntries/ListLogEntriesByIncident")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListLogEntriesByIncidentInputSet
      ####
      def new_input_set()
        return ListLogEntriesByIncidentInputSet.new()
      end

      def make_result_set()
        return ListLogEntriesByIncidentResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListLogEntriesByIncidentResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListLogEntriesByIncident
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListLogEntriesByIncidentInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by PagerDuty.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the IncidentID input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the incident associated with the log entries to retrieve.
        ###

        def set_IncidentID(value)
          set_input("IncidentID", value)
        end
        #### 
        # Set the value of the Include input for this Choreo. 
        # 
        # @param String - (optional, string) A list of additional details to include in the response. Valid values are: channel, incident, and service.
        ###

        def set_Include(value)
          set_input("Include", value)
        end
        #### 
        # Set the value of the IsOverview input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If set to true, only log entries of type trigger, acknowledge, or resolve are returned. Defaults to false.
        ###

        def set_IsOverview(value)
          set_input("IsOverview", value)
        end
        #### 
        # Set the value of the Limit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The number of log events returned. Default (and max limit) is 100.
        ###

        def set_Limit(value)
          set_input("Limit", value)
        end
        #### 
        # Set the value of the Offset input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The offset of the first log event record returned. Default is 0.
        ###

        def set_Offset(value)
          set_input("Offset", value)
        end
        #### 
        # Set the value of the Since input for this Choreo. 
        # 
        # @param String - (optional, date) The start of the date range to search (e.g., 2013-03-06T15:28-05). Note that including the time is optional.
        ###

        def set_Since(value)
          set_input("Since", value)
        end
        #### 
        # Set the value of the SubDomain input for this Choreo. 
        # 
        # @param String - (required, string) The subdomain of your PagerDuty site address.
        ###

        def set_SubDomain(value)
          set_input("SubDomain", value)
        end
        #### 
        # Set the value of the TimeZone input for this Choreo. 
        # 
        # @param String - (optional, string) The time zone in which dates in the result will be rendered. Defaults to account time zone.
        ###

        def set_TimeZone(value)
          set_input("TimeZone", value)
        end
        #### 
        # Set the value of the Until input for this Choreo. 
        # 
        # @param String - (optional, date) The end of the date range to search (e.g., 2013-03-06T15:28-05). Note that including the time is optional.
        ###

        def set_Until(value)
          set_input("Until", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListLogEntriesByIncident Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListLogEntriesByIncidentResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from PagerDuty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListLogEntriesByIncident



    ##############################################################################
    #
    # ListLogEntriesByUser
    #
    # Lists all incident log entries associated with a specific user.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListLogEntriesByUser < Choreography

      ####
      #  Create a new instance of the ListLogEntriesByUser Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/PagerDuty/LogEntries/ListLogEntriesByUser")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListLogEntriesByUserInputSet
      ####
      def new_input_set()
        return ListLogEntriesByUserInputSet.new()
      end

      def make_result_set()
        return ListLogEntriesByUserResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListLogEntriesByUserResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListLogEntriesByUser
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListLogEntriesByUserInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by PagerDuty.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the Include input for this Choreo. 
        # 
        # @param String - (optional, string) A list of additional details to include in the response. Valid values are: channel, incident, and service.
        ###

        def set_Include(value)
          set_input("Include", value)
        end
        #### 
        # Set the value of the IsOverview input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If set to true, only log entries of type trigger, acknowledge, or resolve are returned. Defaults to false.
        ###

        def set_IsOverview(value)
          set_input("IsOverview", value)
        end
        #### 
        # Set the value of the Limit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The number of log events returned. Default (and max limit) is 100.
        ###

        def set_Limit(value)
          set_input("Limit", value)
        end
        #### 
        # Set the value of the Offset input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The offset of the first log event record returned. Default is 0.
        ###

        def set_Offset(value)
          set_input("Offset", value)
        end
        #### 
        # Set the value of the Since input for this Choreo. 
        # 
        # @param String - (optional, date) The start of the date range to search (e.g., 2013-03-06T15:28-05). Note that including the time is optional.
        ###

        def set_Since(value)
          set_input("Since", value)
        end
        #### 
        # Set the value of the SubDomain input for this Choreo. 
        # 
        # @param String - (required, string) The subdomain of your PagerDuty site address.
        ###

        def set_SubDomain(value)
          set_input("SubDomain", value)
        end
        #### 
        # Set the value of the TimeZone input for this Choreo. 
        # 
        # @param String - (optional, string) The time zone in which dates in the result will be rendered. Defaults to account time zone.
        ###

        def set_TimeZone(value)
          set_input("TimeZone", value)
        end
        #### 
        # Set the value of the Until input for this Choreo. 
        # 
        # @param String - (optional, date) The end of the date range to search (e.g., 2013-03-06T15:28-05). Note that including the time is optional.
        ###

        def set_Until(value)
          set_input("Until", value)
        end
        #### 
        # Set the value of the UserID input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the user associated with the log entries to retrieve.
        ###

        def set_UserID(value)
          set_input("UserID", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListLogEntriesByUser Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListLogEntriesByUserResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from PagerDuty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListLogEntriesByUser




  end # module LogEntries

  module Reports



    ##############################################################################
    #
    # AlertsPerTime
    #
    # Returns high-level statistics about the number of alerts sent for a specified time period.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class AlertsPerTime < Choreography

      ####
      #  Create a new instance of the AlertsPerTime Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/PagerDuty/Reports/AlertsPerTime")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AlertsPerTimeInputSet
      ####
      def new_input_set()
        return AlertsPerTimeInputSet.new()
      end

      def make_result_set()
        return AlertsPerTimeResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AlertsPerTimeResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the AlertsPerTime
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AlertsPerTimeInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by PagerDuty.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the Rollup input for this Choreo. 
        # 
        # @param String - (optional, string) Used to rollup totals by time period. Valid values are: daily, weekly, or monthly.
        ###

        def set_Rollup(value)
          set_input("Rollup", value)
        end
        #### 
        # Set the value of the Since input for this Choreo. 
        # 
        # @param String - (required, date) The start of the date range to search (e.g., 2013-03-06T15:28-05). Note that including the time is optional.
        ###

        def set_Since(value)
          set_input("Since", value)
        end
        #### 
        # Set the value of the SubDomain input for this Choreo. 
        # 
        # @param String - (required, string) The subdomain of your PagerDuty site address.
        ###

        def set_SubDomain(value)
          set_input("SubDomain", value)
        end
        #### 
        # Set the value of the Until input for this Choreo. 
        # 
        # @param String - (required, date) The end of the date range to search (e.g., 2013-03-06T15:28-05). Note that including the time is optional.
        ###

        def set_Until(value)
          set_input("Until", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the AlertsPerTime Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AlertsPerTimeResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from PagerDuty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class AlertsPerTime



    ##############################################################################
    #
    # IncidentsPerTime
    #
    # Returns high-level statistics about the number of incidents created for a specified time period.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class IncidentsPerTime < Choreography

      ####
      #  Create a new instance of the IncidentsPerTime Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/PagerDuty/Reports/IncidentsPerTime")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return IncidentsPerTimeInputSet
      ####
      def new_input_set()
        return IncidentsPerTimeInputSet.new()
      end

      def make_result_set()
        return IncidentsPerTimeResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = IncidentsPerTimeResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the IncidentsPerTime
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class IncidentsPerTimeInputSet < Choreography::InputSet

        #### 
        # Set the value of the APIKey input for this Choreo. 
        # 
        # @param String - (required, string) The API Key provided by PagerDuty.
        ###

        def set_APIKey(value)
          set_input("APIKey", value)
        end
        #### 
        # Set the value of the Rollup input for this Choreo. 
        # 
        # @param String - (optional, string) Used to rollup totals by time period. Valid values are: daily, weekly, or monthly.
        ###

        def set_Rollup(value)
          set_input("Rollup", value)
        end
        #### 
        # Set the value of the Since input for this Choreo. 
        # 
        # @param String - (required, date) The start of the date range to search (e.g., 2013-03-06T15:28-05). Note that including the time is optional.
        ###

        def set_Since(value)
          set_input("Since", value)
        end
        #### 
        # Set the value of the SubDomain input for this Choreo. 
        # 
        # @param String - (required, string) The subdomain of your PagerDuty site address.
        ###

        def set_SubDomain(value)
          set_input("SubDomain", value)
        end
        #### 
        # Set the value of the Until input for this Choreo. 
        # 
        # @param String - (required, date) The end of the date range to search (e.g., 2013-03-06T15:28-05). Note that including the time is optional.
        ###

        def set_Until(value)
          set_input("Until", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the IncidentsPerTime Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class IncidentsPerTimeResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from PagerDuty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class IncidentsPerTime




  end # module Reports

end # module PagerDuty