require "temboo"

module Pusher




  module Channels



    ##############################################################################
    #
    # GetChannel
    #
    # Retrieves information for a specific channel.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetChannel < Choreography

      ####
      #  Create a new instance of the GetChannel Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Pusher/Channels/GetChannel")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetChannelInputSet
      ####
      def new_input_set()
        return GetChannelInputSet.new()
      end

      def make_result_set()
        return GetChannelResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetChannelResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetChannel
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetChannelInputSet < Choreography::InputSet

        #### 
        # Set the value of the AppID input for this Choreo. 
        # 
        # @param String - (required, string) The application ID provided by Pusher.
        ###

        def set_AppID(value)
          set_input("AppID", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The authenticaion key provided by Pusher.
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The authentication secret provided by Pusher.
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the ChannelName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the channel to retrieve.
        ###

        def set_ChannelName(value)
          set_input("ChannelName", value)
        end
        #### 
        # Set the value of the Info input for this Choreo. 
        # 
        # @param String - (optional, string) A comma separated list of attributes which should be returned for the channel (e.g., user_count, subscription_count). Note that the user_count attribute is only applicable for presence channels.
        ###

        def set_Info(value)
          set_input("Info", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetChannel Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetChannelResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Pusher.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetChannel



    ##############################################################################
    #
    # ListChannels
    #
    # Retrieves information for occupied channels.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListChannels < Choreography

      ####
      #  Create a new instance of the ListChannels Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Pusher/Channels/ListChannels")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListChannelsInputSet
      ####
      def new_input_set()
        return ListChannelsInputSet.new()
      end

      def make_result_set()
        return ListChannelsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListChannelsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListChannels
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListChannelsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AppID input for this Choreo. 
        # 
        # @param String - (required, string) The application ID provided by Pusher.
        ###

        def set_AppID(value)
          set_input("AppID", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The authenticaion key provided by Pusher.
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The authentication secret provided by Pusher.
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the FilterByPrefix input for this Choreo. 
        # 
        # @param String - (optional, string) Filter the returned channels by a specific prefix (e.g. "presence-").
        ###

        def set_FilterByPrefix(value)
          set_input("FilterByPrefix", value)
        end
        #### 
        # Set the value of the Info input for this Choreo. 
        # 
        # @param String - (optional, string) A comma separated list of attributes which should be returned for each channel (e.g., user_count). Note that the user_count attribute is only applicable for presence channels.
        ###

        def set_Info(value)
          set_input("Info", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListChannels Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListChannelsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Pusher.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListChannels




  end # module Channels

  module Events



    ##############################################################################
    #
    # PostEvent
    #
    # Triggers an event on one or more channels.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PostEvent < Choreography

      ####
      #  Create a new instance of the PostEvent Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Pusher/Events/PostEvent")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PostEventInputSet
      ####
      def new_input_set()
        return PostEventInputSet.new()
      end

      def make_result_set()
        return PostEventResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PostEventResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PostEvent
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PostEventInputSet < Choreography::InputSet

        #### 
        # Set the value of the AppID input for this Choreo. 
        # 
        # @param String - (required, string) The application ID provided by Pusher.
        ###

        def set_AppID(value)
          set_input("AppID", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The authenticaion key provided by Pusher.
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The authentication secret provided by Pusher.
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the ChannelName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the channel to publish to. This can also be a list of channels formatted as a JSON array.
        ###

        def set_ChannelName(value)
          set_input("ChannelName", value)
        end
        #### 
        # Set the value of the EventData input for this Choreo. 
        # 
        # @param String - (required, json) A JSON object containing the event data.
        ###

        def set_EventData(value)
          set_input("EventData", value)
        end
        #### 
        # Set the value of the EventName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the event being triggered.
        ###

        def set_EventName(value)
          set_input("EventName", value)
        end
        #### 
        # Set the value of the SocketID input for this Choreo. 
        # 
        # @param String - (optional, string) Excludes the event from being sent to a specific connection.
        ###

        def set_SocketID(value)
          set_input("SocketID", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PostEvent Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PostEventResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Pusher. A successful request returns an empty JSON hash.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PostEvent




  end # module Events

  module Users



    ##############################################################################
    #
    # ListUsers
    #
    # Retrieves IDs for users currently subscribed to a presence channel.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListUsers < Choreography

      ####
      #  Create a new instance of the ListUsers Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Pusher/Users/ListUsers")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListUsersInputSet
      ####
      def new_input_set()
        return ListUsersInputSet.new()
      end

      def make_result_set()
        return ListUsersResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListUsersResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListUsers
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListUsersInputSet < Choreography::InputSet

        #### 
        # Set the value of the AppID input for this Choreo. 
        # 
        # @param String - (required, string) The application ID provided by Pusher.
        ###

        def set_AppID(value)
          set_input("AppID", value)
        end
        #### 
        # Set the value of the AppKey input for this Choreo. 
        # 
        # @param String - (required, string) The authenticaion key provided by Pusher.
        ###

        def set_AppKey(value)
          set_input("AppKey", value)
        end
        #### 
        # Set the value of the AppSecret input for this Choreo. 
        # 
        # @param String - (required, string) The authentication secret provided by Pusher.
        ###

        def set_AppSecret(value)
          set_input("AppSecret", value)
        end
        #### 
        # Set the value of the ChannelName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the channel that the users are subscribed to.
        ###

        def set_ChannelName(value)
          set_input("ChannelName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListUsers Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListUsersResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Pusher.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListUsers




  end # module Users

end # module Pusher