require "temboo"

module Wikipedia



  ##############################################################################
  #
  # GetPageSummary
  #
  # Retrieves a summary response including a text extract of the first several sentences, as well as information about a thumbnail that represents the page.
  #
  # Copyright 2014, Temboo Inc.
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing,
  # software distributed under the License is distributed on an
  # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
  # either express or implied. See the License for the specific
  # language governing permissions and limitations under the License.
  #
  ##############################################################################

  class GetPageSummary < Choreography

    ####
    #  Create a new instance of the GetPageSummary Choreo. A TembooSession object, containing a valid
    #  set of Temboo credentials, must be supplied.
    ####
    def initialize(session)
      super(session, "/Library/Wikipedia/GetPageSummary")
    end

    #### 
    # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
    #
    # @return GetPageSummaryInputSet
    ####
    def new_input_set()
      return GetPageSummaryInputSet.new()
    end

    def make_result_set()
      return GetPageSummaryResultSet.new()
    end

    ####
    # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
    # and return a ResultSet containing the execution results.
    # @param choreoInputs
    # @return
    # @throws TembooException
    ####
    def execute(input_set = nil)
      resp = super(input_set)
      results = GetPageSummaryResultSet.new(resp)
      return results
    end

    ####
    # An InputSet with methods appropriate for specifying the inputs to the GetPageSummary
    # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    ####
    class GetPageSummaryInputSet < Choreography::InputSet

      #### 
      # Set the value of the Title input for this Choreo. 
      # 
      # @param String - (required, string) The Wikipedia page title.
      ###

      def set_Title(value)
        set_input("Title", value)
      end

    end

    ####
    # A ResultSet with methods tailored to the values returned by the GetPageSummary Choreo.
    # The ResultSet object is used to retrieve the results of a Choreo execution.
    ####
    class GetPageSummaryResultSet < Choreography::ResultSet
    	####
    	# Retrieve the value for the "Extract" output from this Choreo execution
    	#
    	# @return String - (string) The page summary.
    	####
    	def get_Extract()
    	  return @outputs["Extract"]
    	end
    	####
    	# Retrieve the value for the "ResponseCode" output from this Choreo execution
    	#
    	# @return String - (integer) The response code returned by the API.
    	####
    	def get_ResponseCode()
    	  return @outputs["ResponseCode"]
    	end
    	####
    	# Retrieve the value for the "Response" output from this Choreo execution
    	#
    	# @return String - (json) The response from Wikipedia.
    	####
    	def get_Response()
    	  return @outputs["Response"]
    	end
    end

  end # class GetPageSummary




end # module Wikipedia