require "temboo"

module Amazon




  module CloudDrive




    module Account



      ##############################################################################
      #
      # GetAccountInfo
      #
      # Retrieves account information for the authenticated user.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetAccountInfo < Choreography

        ####
        #  Create a new instance of the GetAccountInfo Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Account/GetAccountInfo")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetAccountInfoInputSet
        ####
        def new_input_set()
          return GetAccountInfoInputSet.new()
        end

        def make_result_set()
          return GetAccountInfoResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetAccountInfoResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetAccountInfo
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetAccountInfoInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetAccountInfo Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetAccountInfoResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetAccountInfo



      ##############################################################################
      #
      # GetEndpoint
      #
      # Retrieves the customer end-point against which requests can be executed.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetEndpoint < Choreography

        ####
        #  Create a new instance of the GetEndpoint Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Account/GetEndpoint")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetEndpointInputSet
        ####
        def new_input_set()
          return GetEndpointInputSet.new()
        end

        def make_result_set()
          return GetEndpointResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetEndpointResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetEndpoint
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetEndpointInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetEndpoint Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetEndpointResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetEndpoint



      ##############################################################################
      #
      # GetQuota
      #
      # Retrieves account quota and storage availability information.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetQuota < Choreography

        ####
        #  Create a new instance of the GetQuota Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Account/GetQuota")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetQuotaInputSet
        ####
        def new_input_set()
          return GetQuotaInputSet.new()
        end

        def make_result_set()
          return GetQuotaResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetQuotaResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetQuota
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetQuotaInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetQuota Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetQuotaResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetQuota



      ##############################################################################
      #
      # GetUsage
      #
      # Retrieves account usage information broken down by content category.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetUsage < Choreography

        ####
        #  Create a new instance of the GetUsage Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Account/GetUsage")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetUsageInputSet
        ####
        def new_input_set()
          return GetUsageInputSet.new()
        end

        def make_result_set()
          return GetUsageResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetUsageResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetUsage
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetUsageInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetUsage Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetUsageResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetUsage



      ##############################################################################
      #
      # SetupAccount
      #
      # Creates an account with a given terms of use parameter.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class SetupAccount < Choreography

        ####
        #  Create a new instance of the SetupAccount Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Account/SetupAccount")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return SetupAccountInputSet
        ####
        def new_input_set()
          return SetupAccountInputSet.new()
        end

        def make_result_set()
          return SetupAccountResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = SetupAccountResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the SetupAccount
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class SetupAccountInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end
          #### 
          # Set the value of the TermsOfUse input for this Choreo. 
          # 
          # @param BigDecimal - (optional, decimal) The terms of use version. Defaults to 1.0.0.
          ###

          def set_TermsOfUse(value)
            set_input("TermsOfUse", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the SetupAccount Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class SetupAccountResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "ResponseStatusCode" output from this Choreo execution
        	#
        	# @return String - (integer) The response status code returned from Amazon.
        	####
        	def get_ResponseStatusCode()
        	  return @outputs["ResponseStatusCode"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class SetupAccount




    end # module Account

    module Children



      ##############################################################################
      #
      # AddChild
      #
      # Moves a specified folder into a parent folder.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class AddChild < Choreography

        ####
        #  Create a new instance of the AddChild Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Children/AddChild")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return AddChildInputSet
        ####
        def new_input_set()
          return AddChildInputSet.new()
        end

        def make_result_set()
          return AddChildResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = AddChildResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the AddChild
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class AddChildInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ChildID input for this Choreo. 
          # 
          # @param String - (required, string) The ID of the folder that is being moved within a parent folder.
          ###

          def set_ChildID(value)
            set_input("ChildID", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the MetaDataURL input for this Choreo. 
          # 
          # @param String - (optional, string) The appropriate metadataUrl for your account. When not provided, the Choreo will lookup the URL using the Account.GetEndpoint Choreo.
          ###

          def set_MetaDataURL(value)
            set_input("MetaDataURL", value)
          end
          #### 
          # Set the value of the ParentID input for this Choreo. 
          # 
          # @param String - (required, string) The ID of the parent folder that will contain the child folder that's being moved.
          ###

          def set_ParentID(value)
            set_input("ParentID", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the AddChild Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class AddChildResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class AddChild



      ##############################################################################
      #
      # ListChildren
      #
      # Returns the children of a specified parent folder.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class ListChildren < Choreography

        ####
        #  Create a new instance of the ListChildren Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Children/ListChildren")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return ListChildrenInputSet
        ####
        def new_input_set()
          return ListChildrenInputSet.new()
        end

        def make_result_set()
          return ListChildrenResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = ListChildrenResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the ListChildren
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class ListChildrenInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the Fields input for this Choreo. 
          # 
          # @param String - (optional, string) A comma-separated list of additional fields to include in the response.
          ###

          def set_Fields(value)
            set_input("Fields", value)
          end
          #### 
          # Set the value of the Filters input for this Choreo. 
          # 
          # @param String - (optional, string) A filter used to narrow the result set (e.g., name:Documents). The default value is "kind:FOLDER". To a make a request using no filters, you can pass "none".
          ###

          def set_Filters(value)
            set_input("Filters", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the Limit input for this Choreo. 
          # 
          # @param String - (optional, string) The maximum number of records to be returned.
          ###

          def set_Limit(value)
            set_input("Limit", value)
          end
          #### 
          # Set the value of the MetaDataURL input for this Choreo. 
          # 
          # @param String - (optional, string) The appropriate metadataUrl for you account. When not provided, the Choreo will lookup the URL using the Account.GetEndpoint Choreo.
          ###

          def set_MetaDataURL(value)
            set_input("MetaDataURL", value)
          end
          #### 
          # Set the value of the ParentID input for this Choreo. 
          # 
          # @param String - (required, string) The ID of the parent that contains the list of children to retrieve.
          ###

          def set_ParentID(value)
            set_input("ParentID", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end
          #### 
          # Set the value of the Sort input for this Choreo. 
          # 
          # @param String - (optional, json) A JSON array containing sort properties (e.g., ["name ASC","contentProperties.size" DESC]).
          ###

          def set_Sort(value)
            set_input("Sort", value)
          end
          #### 
          # Set the value of the StartToken input for this Choreo. 
          # 
          # @param String - (optional, string) The nextToken returned from a previous request. Used to paginate through results.
          ###

          def set_StartToken(value)
            set_input("StartToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the ListChildren Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class ListChildrenResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class ListChildren



      ##############################################################################
      #
      # RemoveChild
      #
      # Removes a specified folder from a parent folder.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class RemoveChild < Choreography

        ####
        #  Create a new instance of the RemoveChild Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Children/RemoveChild")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return RemoveChildInputSet
        ####
        def new_input_set()
          return RemoveChildInputSet.new()
        end

        def make_result_set()
          return RemoveChildResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = RemoveChildResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the RemoveChild
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class RemoveChildInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ChildID input for this Choreo. 
          # 
          # @param String - (required, string) The ID of the folder that is being removed from a parent folder.
          ###

          def set_ChildID(value)
            set_input("ChildID", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the MetaDataURL input for this Choreo. 
          # 
          # @param String - (optional, string) The appropriate metadataUrl for your account. When not provided, the Choreo will lookup the URL using the Account.GetEndpoint Choreo.
          ###

          def set_MetaDataURL(value)
            set_input("MetaDataURL", value)
          end
          #### 
          # Set the value of the ParentID input for this Choreo. 
          # 
          # @param String - (required, string) The ID of the parent folder that contains the child folder that's being removed.
          ###

          def set_ParentID(value)
            set_input("ParentID", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the RemoveChild Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class RemoveChildResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class RemoveChild




    end # module Children

    module Files



      ##############################################################################
      #
      # DownloadFile
      #
      # Queries the Amazon Cloud Drive API to retrieve the content for a specific file.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class DownloadFile < Choreography

        ####
        #  Create a new instance of the DownloadFile Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Files/DownloadFile")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return DownloadFileInputSet
        ####
        def new_input_set()
          return DownloadFileInputSet.new()
        end

        def make_result_set()
          return DownloadFileResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = DownloadFileResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the DownloadFile
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class DownloadFileInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the ContentURL input for this Choreo. 
          # 
          # @param String - (optional, string) The appropriate contentUrl for your account. When not provided, the Choreo will lookup the URL using the Account.GetEndpoint Choreo.
          ###

          def set_ContentURL(value)
            set_input("ContentURL", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the ID input for this Choreo. 
          # 
          # @param String - (required, string) The ID of the file to return content for.
          ###

          def set_ID(value)
            set_input("ID", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the DownloadFile Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class DownloadFileResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (string) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class DownloadFile



      ##############################################################################
      #
      # GetFileMetadata
      #
      # Queries the Amazon Cloud Drive API to retrieve metadata for a specific file.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetFileMetadata < Choreography

        ####
        #  Create a new instance of the GetFileMetadata Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Files/GetFileMetadata")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetFileMetadataInputSet
        ####
        def new_input_set()
          return GetFileMetadataInputSet.new()
        end

        def make_result_set()
          return GetFileMetadataResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetFileMetadataResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetFileMetadata
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetFileMetadataInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the Fields input for this Choreo. 
          # 
          # @param String - (optional, string) A comma-separated list of additional fields to include in the response.
          ###

          def set_Fields(value)
            set_input("Fields", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the ID input for this Choreo. 
          # 
          # @param String - (required, string) The ID of the file to return metadata for.
          ###

          def set_ID(value)
            set_input("ID", value)
          end
          #### 
          # Set the value of the MetaDataURL input for this Choreo. 
          # 
          # @param String - (optional, string) The appropriate metadataUrl for your account. When not provided, the Choreo will lookup the URL using the Account.GetEndpoint Choreo.
          ###

          def set_MetaDataURL(value)
            set_input("MetaDataURL", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end
          #### 
          # Set the value of the TempLink input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Set true to include tempLink in response. Defaults to false.
          ###

          def set_TempLink(value)
            set_input("TempLink", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetFileMetadata Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetFileMetadataResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetFileMetadata



      ##############################################################################
      #
      # ListFiles
      #
      # Queries the Amazon Cloud Drive API to return a list of files.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class ListFiles < Choreography

        ####
        #  Create a new instance of the ListFiles Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Files/ListFiles")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return ListFilesInputSet
        ####
        def new_input_set()
          return ListFilesInputSet.new()
        end

        def make_result_set()
          return ListFilesResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = ListFilesResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the ListFiles
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class ListFilesInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the Fields input for this Choreo. 
          # 
          # @param String - (optional, string) A comma-separated list of additional fields to include in the response.
          ###

          def set_Fields(value)
            set_input("Fields", value)
          end
          #### 
          # Set the value of the Filters input for this Choreo. 
          # 
          # @param String - (optional, string) A filter used to narrow the result set (e.g., name:MyFile.txt). The default value is "kind:FILE". To a make a request using no filters, you can pass "none".
          ###

          def set_Filters(value)
            set_input("Filters", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the Limit input for this Choreo. 
          # 
          # @param String - (optional, string) The maximum number of records to be returned.
          ###

          def set_Limit(value)
            set_input("Limit", value)
          end
          #### 
          # Set the value of the MetaDataURL input for this Choreo. 
          # 
          # @param String - (optional, string) The appropriate metadataUrl for your account. When not provided, the Choreo will lookup the URL using the Account.GetEndpoint Choreo.
          ###

          def set_MetaDataURL(value)
            set_input("MetaDataURL", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end
          #### 
          # Set the value of the Sort input for this Choreo. 
          # 
          # @param String - (optional, json) A JSON array containing sort properties (e.g., ["name ASC","contentProperties.size" DESC]).
          ###

          def set_Sort(value)
            set_input("Sort", value)
          end
          #### 
          # Set the value of the StartToken input for this Choreo. 
          # 
          # @param String - (optional, string) The nextToken returned from a previous request. Used to paginate through results.
          ###

          def set_StartToken(value)
            set_input("StartToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the ListFiles Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class ListFilesResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class ListFiles



      ##############################################################################
      #
      # OverwriteFile
      #
      # Queries the Amazon Cloud Drive API to overwrite the content of an existing file.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class OverwriteFile < Choreography

        ####
        #  Create a new instance of the OverwriteFile Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Files/OverwriteFile")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return OverwriteFileInputSet
        ####
        def new_input_set()
          return OverwriteFileInputSet.new()
        end

        def make_result_set()
          return OverwriteFileResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = OverwriteFileResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the OverwriteFile
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class OverwriteFileInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the ContentURL input for this Choreo. 
          # 
          # @param String - (optional, string) The appropriate contentUrl for your account. When not provided, the Choreo will lookup the URL using the Account.GetEndpoint Choreo.
          ###

          def set_ContentURL(value)
            set_input("ContentURL", value)
          end
          #### 
          # Set the value of the FileContent input for this Choreo. 
          # 
          # @param String - (conditional, string) The Base64 encoded contents of the file to upload.
          ###

          def set_FileContent(value)
            set_input("FileContent", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the ID input for this Choreo. 
          # 
          # @param String - (required, string) The ID of the file to update.
          ###

          def set_ID(value)
            set_input("ID", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end
          #### 
          # Set the value of the VaultFile input for this Choreo. 
          # 
          # @param TembooPath - 
          ###

          def set_VaultFile(value)
            set_alias("VaultFile", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the OverwriteFile Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class OverwriteFileResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class OverwriteFile



      ##############################################################################
      #
      # UploadFile
      #
      # Calls the Amazon Cloud Drive API to upload a file to Amazon Cloud Drive.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class UploadFile < Choreography

        ####
        #  Create a new instance of the UploadFile Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Files/UploadFile")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return UploadFileInputSet
        ####
        def new_input_set()
          return UploadFileInputSet.new()
        end

        def make_result_set()
          return UploadFileResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = UploadFileResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the UploadFile
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class UploadFileInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the ContentType input for this Choreo. 
          # 
          # @param String - (required, string) The Content-Type of the file that is being uploaded (e.g., image/jpeg, text/plain, etc.) Defaults to application/octet-stream.
          ###

          def set_ContentType(value)
            set_input("ContentType", value)
          end
          #### 
          # Set the value of the ContentURL input for this Choreo. 
          # 
          # @param String - (optional, string) The appropriate contentUrl for your account. When not provided, the Choreo will lookup the URL using the Account.GetEndpoint Choreo.
          ###

          def set_ContentURL(value)
            set_input("ContentURL", value)
          end
          #### 
          # Set the value of the FileContent input for this Choreo. 
          # 
          # @param String - (conditional, string) The Base64 encoded contents of the file to upload.
          ###

          def set_FileContent(value)
            set_input("FileContent", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the Labels input for this Choreo. 
          # 
          # @param String - (optional, json) A JSON array containing labels to apply to the file.
          ###

          def set_Labels(value)
            set_input("Labels", value)
          end
          #### 
          # Set the value of the LocalID input for this Choreo. 
          # 
          # @param String - (optional, string) A unique ID within the application. Multiple POSTs with the same localId from the same application will result in the same node-id. If not provided the server will generate a node-id.
          ###

          def set_LocalID(value)
            set_input("LocalID", value)
          end
          #### 
          # Set the value of the Name input for this Choreo. 
          # 
          # @param String - (required, string) The name of the file being uploaded.
          ###

          def set_Name(value)
            set_input("Name", value)
          end
          #### 
          # Set the value of the Parents input for this Choreo. 
          # 
          # @param String - (optional, json) A JSON array containing parent IDs associated with the new folder.
          ###

          def set_Parents(value)
            set_input("Parents", value)
          end
          #### 
          # Set the value of the Properties input for this Choreo. 
          # 
          # @param String - (optional, json) A JSON object containing properties to be applied to the file.
          ###

          def set_Properties(value)
            set_input("Properties", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end
          #### 
          # Set the value of the Supress input for this Choreo. 
          # 
          # @param String - (optional, string) Valid values are: "deduplication" (disables checking for duplicates when uploading) and "process" (disables any processing Amazon may do on the file).
          ###

          def set_Supress(value)
            set_input("Supress", value)
          end
          #### 
          # Set the value of the VaultFile input for this Choreo. 
          # 
          # @param TembooPath - 
          ###

          def set_VaultFile(value)
            set_alias("VaultFile", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the UploadFile Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class UploadFileResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class UploadFile




    end # module Files

    module Folders



      ##############################################################################
      #
      # CreateFolder
      #
      # Creates a new folder using the Amazon Cloud Drive API.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class CreateFolder < Choreography

        ####
        #  Create a new instance of the CreateFolder Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Folders/CreateFolder")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return CreateFolderInputSet
        ####
        def new_input_set()
          return CreateFolderInputSet.new()
        end

        def make_result_set()
          return CreateFolderResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = CreateFolderResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the CreateFolder
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class CreateFolderInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the Labels input for this Choreo. 
          # 
          # @param String - (optional, json) A JSON array containing labels to apply to the folder.
          ###

          def set_Labels(value)
            set_input("Labels", value)
          end
          #### 
          # Set the value of the LocalID input for this Choreo. 
          # 
          # @param String - (optional, string) Globally unique client local Id for the customer.
          ###

          def set_LocalID(value)
            set_input("LocalID", value)
          end
          #### 
          # Set the value of the MetaDataURL input for this Choreo. 
          # 
          # @param String - (optional, string) The appropriate metadataUrl for your account. When not provided, the Choreo will lookup the URL using the Account.GetEndpoint Choreo.
          ###

          def set_MetaDataURL(value)
            set_input("MetaDataURL", value)
          end
          #### 
          # Set the value of the Name input for this Choreo. 
          # 
          # @param String - (required, string) The name of the new folder.
          ###

          def set_Name(value)
            set_input("Name", value)
          end
          #### 
          # Set the value of the Parents input for this Choreo. 
          # 
          # @param String - (optional, json) A JSON array containing parent names associated with the new folder.
          ###

          def set_Parents(value)
            set_input("Parents", value)
          end
          #### 
          # Set the value of the Properties input for this Choreo. 
          # 
          # @param String - (optional, json) A JSON object containing properties to be applied to the folder.
          ###

          def set_Properties(value)
            set_input("Properties", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the CreateFolder Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class CreateFolderResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class CreateFolder



      ##############################################################################
      #
      # GetFolderMetadata
      #
      # Retrieves metadata for a specific folder using the Amazon Cloud Drive API.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetFolderMetadata < Choreography

        ####
        #  Create a new instance of the GetFolderMetadata Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Folders/GetFolderMetadata")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetFolderMetadataInputSet
        ####
        def new_input_set()
          return GetFolderMetadataInputSet.new()
        end

        def make_result_set()
          return GetFolderMetadataResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetFolderMetadataResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetFolderMetadata
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetFolderMetadataInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the Fields input for this Choreo. 
          # 
          # @param String - (optional, string) A comma-separated list of additional fields to include in the response.
          ###

          def set_Fields(value)
            set_input("Fields", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the ID input for this Choreo. 
          # 
          # @param String - (required, string) The ID of the folder to return metadata for.
          ###

          def set_ID(value)
            set_input("ID", value)
          end
          #### 
          # Set the value of the MetaDataURL input for this Choreo. 
          # 
          # @param String - (optional, string) The appropriate metadataUrl for your account. When not provided, the Choreo will lookup the URL using the Account.GetEndpoint Choreo.
          ###

          def set_MetaDataURL(value)
            set_input("MetaDataURL", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetFolderMetadata Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetFolderMetadataResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetFolderMetadata



      ##############################################################################
      #
      # ListFolders
      #
      # Queries the Amazon Cloud Drive API to return a list of folders.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class ListFolders < Choreography

        ####
        #  Create a new instance of the ListFolders Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Folders/ListFolders")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return ListFoldersInputSet
        ####
        def new_input_set()
          return ListFoldersInputSet.new()
        end

        def make_result_set()
          return ListFoldersResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = ListFoldersResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the ListFolders
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class ListFoldersInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the Fields input for this Choreo. 
          # 
          # @param String - (optional, string) A comma-separated list of additional fields to include in the response.
          ###

          def set_Fields(value)
            set_input("Fields", value)
          end
          #### 
          # Set the value of the Filters input for this Choreo. 
          # 
          # @param String - (optional, string) A filter used to narrow the result set (e.g., name:Documents). The default value is "kind:FOLDER". To a make a request using no filters, you can pass "none".
          ###

          def set_Filters(value)
            set_input("Filters", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the Limit input for this Choreo. 
          # 
          # @param String - (optional, string) The maximum number of records to be returned.
          ###

          def set_Limit(value)
            set_input("Limit", value)
          end
          #### 
          # Set the value of the MetaDataURL input for this Choreo. 
          # 
          # @param String - (optional, string) The appropriate metadataUrl for you account. When not provided, the Choreo will lookup the URL using the Account.GetEndpoint Choreo.
          ###

          def set_MetaDataURL(value)
            set_input("MetaDataURL", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end
          #### 
          # Set the value of the Sort input for this Choreo. 
          # 
          # @param String - (optional, json) A JSON array containing sort properties (e.g., ["name ASC","contentProperties.size" DESC]).
          ###

          def set_Sort(value)
            set_input("Sort", value)
          end
          #### 
          # Set the value of the StartToken input for this Choreo. 
          # 
          # @param String - (optional, string) The nextToken returned from a previous request. Used to paginate through results.
          ###

          def set_StartToken(value)
            set_input("StartToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the ListFolders Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class ListFoldersResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class ListFolders




    end # module Folders

    module Properties



      ##############################################################################
      #
      # AddProperty
      #
      # Adds a property to a file or folder using the Amazon Cloud Drive API.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class AddProperty < Choreography

        ####
        #  Create a new instance of the AddProperty Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Properties/AddProperty")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return AddPropertyInputSet
        ####
        def new_input_set()
          return AddPropertyInputSet.new()
        end

        def make_result_set()
          return AddPropertyResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = AddPropertyResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the AddProperty
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class AddPropertyInputSet < Choreography::InputSet

          #### 
          # Set the value of the Value input for this Choreo. 
          # 
          # @param String - (required, string) The value of the property. Max length 500 characters.
          ###

          def set_Value(value)
            set_input("Value", value)
          end
          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the ID input for this Choreo. 
          # 
          # @param String - (required, string) The ID of the file or folder to which the properties needs to be added.
          ###

          def set_ID(value)
            set_input("ID", value)
          end
          #### 
          # Set the value of the Key input for this Choreo. 
          # 
          # @param String - (required, string) The key of the properties which needs to be added. The key should just contain alphanumeric and "_". Max length is 50 characters.
          ###

          def set_Key(value)
            set_input("Key", value)
          end
          #### 
          # Set the value of the MetaDataURL input for this Choreo. 
          # 
          # @param String - (optional, string) The appropriate metadataUrl for your account. When not provided, the Choreo will lookup the URL using the Account.GetEndpoint Choreo.
          ###

          def set_MetaDataURL(value)
            set_input("MetaDataURL", value)
          end
          #### 
          # Set the value of the Owner input for this Choreo. 
          # 
          # @param String - (required, string) The "owner" of property.
          ###

          def set_Owner(value)
            set_input("Owner", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the AddProperty Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class AddPropertyResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class AddProperty



      ##############################################################################
      #
      # DeleteProperty
      #
      # Uses the Amazon Cloud Drive API to delete a specific property by key.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class DeleteProperty < Choreography

        ####
        #  Create a new instance of the DeleteProperty Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Properties/DeleteProperty")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return DeletePropertyInputSet
        ####
        def new_input_set()
          return DeletePropertyInputSet.new()
        end

        def make_result_set()
          return DeletePropertyResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = DeletePropertyResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the DeleteProperty
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class DeletePropertyInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the ID input for this Choreo. 
          # 
          # @param String - (required, string) The ID of the file or folder associated with the property being deleted.
          ###

          def set_ID(value)
            set_input("ID", value)
          end
          #### 
          # Set the value of the Key input for this Choreo. 
          # 
          # @param String - (required, string) The key of the properties which needs to be deleted.
          ###

          def set_Key(value)
            set_input("Key", value)
          end
          #### 
          # Set the value of the MetaDataURL input for this Choreo. 
          # 
          # @param String - (optional, string) The appropriate metadataUrl for your account. When not provided, the Choreo will lookup the URL using the Account.GetEndpoint Choreo.
          ###

          def set_MetaDataURL(value)
            set_input("MetaDataURL", value)
          end
          #### 
          # Set the value of the Owner input for this Choreo. 
          # 
          # @param String - (required, string) The "owner" of property.
          ###

          def set_Owner(value)
            set_input("Owner", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the DeleteProperty Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class DeletePropertyResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "ResponseStatusCode" output from this Choreo execution
        	#
        	# @return String - (integer) The response status code returned from Amazon. A 204 is returned for a successful delete operation.
        	####
        	def get_ResponseStatusCode()
        	  return @outputs["ResponseStatusCode"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon. An empty result object is returned for a successful delete operation.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class DeleteProperty



      ##############################################################################
      #
      # GetProperty
      #
      # Queries the Amazon Cloud Drive API to retrieve a specific property by key.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetProperty < Choreography

        ####
        #  Create a new instance of the GetProperty Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Properties/GetProperty")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetPropertyInputSet
        ####
        def new_input_set()
          return GetPropertyInputSet.new()
        end

        def make_result_set()
          return GetPropertyResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetPropertyResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetProperty
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetPropertyInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the ID input for this Choreo. 
          # 
          # @param String - (required, string) The ID of the file or folder associated with the property being retrieved.
          ###

          def set_ID(value)
            set_input("ID", value)
          end
          #### 
          # Set the value of the Key input for this Choreo. 
          # 
          # @param String - (required, string) The key of the properties which needs to be retrieved.
          ###

          def set_Key(value)
            set_input("Key", value)
          end
          #### 
          # Set the value of the MetaDataURL input for this Choreo. 
          # 
          # @param String - (optional, string) The appropriate metadataUrl for your account. When not provided, the Choreo will lookup the URL using the Account.GetEndpoint Choreo.
          ###

          def set_MetaDataURL(value)
            set_input("MetaDataURL", value)
          end
          #### 
          # Set the value of the Owner input for this Choreo. 
          # 
          # @param String - (required, string) The "owner" of property.
          ###

          def set_Owner(value)
            set_input("Owner", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetProperty Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetPropertyResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetProperty



      ##############################################################################
      #
      # ListProperties
      #
      # Queries the Amazon Cloud Drive API to return a list of properties for a specified file or folder.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class ListProperties < Choreography

        ####
        #  Create a new instance of the ListProperties Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Properties/ListProperties")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return ListPropertiesInputSet
        ####
        def new_input_set()
          return ListPropertiesInputSet.new()
        end

        def make_result_set()
          return ListPropertiesResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = ListPropertiesResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the ListProperties
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class ListPropertiesInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Integer - (optional, integer) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the ID input for this Choreo. 
          # 
          # @param String - (required, string) The ID of the file or folder to list properties for.
          ###

          def set_ID(value)
            set_input("ID", value)
          end
          #### 
          # Set the value of the MetaDataURL input for this Choreo. 
          # 
          # @param String - (optional, string) The appropriate metadataUrl for you account. When not provided, the Choreo will lookup the URL using the Account.GetEndpoint Choreo.
          ###

          def set_MetaDataURL(value)
            set_input("MetaDataURL", value)
          end
          #### 
          # Set the value of the Owner input for this Choreo. 
          # 
          # @param String - (required, string) The "owner" of properties to list.
          ###

          def set_Owner(value)
            set_input("Owner", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the ListProperties Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class ListPropertiesResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class ListProperties




    end # module Properties

    module Trash



      ##############################################################################
      #
      # AddToTrash
      #
      # Uses the Amazon Cloud Drive API to move a specific file or folder to the trash.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class AddToTrash < Choreography

        ####
        #  Create a new instance of the AddToTrash Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Trash/AddToTrash")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return AddToTrashInputSet
        ####
        def new_input_set()
          return AddToTrashInputSet.new()
        end

        def make_result_set()
          return AddToTrashResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = AddToTrashResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the AddToTrash
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class AddToTrashInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the ID input for this Choreo. 
          # 
          # @param String - (required, string) The ID of the folder to put in the trash.
          ###

          def set_ID(value)
            set_input("ID", value)
          end
          #### 
          # Set the value of the MetaDataURL input for this Choreo. 
          # 
          # @param String - (optional, string) The appropriate metadataUrl for your account. When not provided, the Choreo will lookup the URL using the Account.GetEndpoint Choreo.
          ###

          def set_MetaDataURL(value)
            set_input("MetaDataURL", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the AddToTrash Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class AddToTrashResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class AddToTrash



      ##############################################################################
      #
      # ListTrash
      #
      # Queries the Amazon Cloud Drive API to return metadata for items in the trash.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class ListTrash < Choreography

        ####
        #  Create a new instance of the ListTrash Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Trash/ListTrash")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return ListTrashInputSet
        ####
        def new_input_set()
          return ListTrashInputSet.new()
        end

        def make_result_set()
          return ListTrashResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = ListTrashResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the ListTrash
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class ListTrashInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the Fields input for this Choreo. 
          # 
          # @param String - (optional, string) A comma-separated list of additional fields to include in the response.
          ###

          def set_Fields(value)
            set_input("Fields", value)
          end
          #### 
          # Set the value of the Filters input for this Choreo. 
          # 
          # @param String - (optional, string) A filter used to narrow the result set (e.g., name:Documents). The default value is "kind:FOLDER". To a make a request using no filters, you can pass "none".
          ###

          def set_Filters(value)
            set_input("Filters", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the Limit input for this Choreo. 
          # 
          # @param String - (optional, string) The maximum number of records to be returned.
          ###

          def set_Limit(value)
            set_input("Limit", value)
          end
          #### 
          # Set the value of the MetaDataURL input for this Choreo. 
          # 
          # @param String - (optional, string) The appropriate metadataUrl for you account. When not provided, the Choreo will lookup the URL using the Account.GetEndpoint Choreo.
          ###

          def set_MetaDataURL(value)
            set_input("MetaDataURL", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end
          #### 
          # Set the value of the Sort input for this Choreo. 
          # 
          # @param String - (optional, json) A JSON array containing sort properties (e.g., ["name ASC","contentProperties.size" DESC]).
          ###

          def set_Sort(value)
            set_input("Sort", value)
          end
          #### 
          # Set the value of the StartToken input for this Choreo. 
          # 
          # @param String - (optional, string) The nextToken returned from a previous request. Used to paginate through results.
          ###

          def set_StartToken(value)
            set_input("StartToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the ListTrash Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class ListTrashResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class ListTrash



      ##############################################################################
      #
      # Restore
      #
      # Calls the Amazon Cloud Drive API to restore a folder or file that has been moved to the trash.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class Restore < Choreography

        ####
        #  Create a new instance of the Restore Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/CloudDrive/Trash/Restore")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return RestoreInputSet
        ####
        def new_input_set()
          return RestoreInputSet.new()
        end

        def make_result_set()
          return RestoreResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = RestoreResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the Restore
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class RestoreInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessToken input for this Choreo. 
          # 
          # @param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
          ###

          def set_AccessToken(value)
            set_input("AccessToken", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client ID provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (conditional, string) The Client Secret provided by Amazon. Required unless providing a valid AccessToken.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the HandleRequestThrottling input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Whether or not to perform a retry sequence if a throttling error occurs. Set to true to enable this feature. The request will be retried up-to five times when enabled.
          ###

          def set_HandleRequestThrottling(value)
            set_input("HandleRequestThrottling", value)
          end
          #### 
          # Set the value of the ID input for this Choreo. 
          # 
          # @param String - (required, string) The ID of the file or folder to restore.
          ###

          def set_ID(value)
            set_input("ID", value)
          end
          #### 
          # Set the value of the MetaDataURL input for this Choreo. 
          # 
          # @param String - (optional, string) The appropriate metadataUrl for your account. When not provided, the Choreo will lookup the URL using the Account.GetEndpoint Choreo.
          ###

          def set_MetaDataURL(value)
            set_input("MetaDataURL", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the Restore Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class RestoreResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NewAccessToken" output from this Choreo execution
        	#
        	# @return String - (string) Contains a new AccessToken when the RefreshToken is provided.
        	####
        	def get_NewAccessToken()
        	  return @outputs["NewAccessToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class Restore




    end # module Trash

  end # module CloudDrive

  module DynamoDB



    ##############################################################################
    #
    # BatchGetItem
    #
    # Returns the attributes of one or more items from one or more tables
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class BatchGetItem < Choreography

      ####
      #  Create a new instance of the BatchGetItem Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/DynamoDB/BatchGetItem")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return BatchGetItemInputSet
      ####
      def new_input_set()
        return BatchGetItemInputSet.new()
      end

      def make_result_set()
        return BatchGetItemResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = BatchGetItemResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the BatchGetItem
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class BatchGetItemInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the RequestItems input for this Choreo. 
        # 
        # @param String - (required, json) A map of one or more table names and, for each table, a map that describes one or more items to retrieve from that table. See choreo notes for more details.
        ###

        def set_RequestItems(value)
          set_input("RequestItems", value)
        end
        #### 
        # Set the value of the ReturnConsumedCapacity input for this Choreo. 
        # 
        # @param String - (optional, string) Determines the level of detail about provisioned throughput consumption that is returned in the response. Valid values are: INDEXES, TOTAL, NONE.
        ###

        def set_ReturnConsumedCapacity(value)
          set_input("ReturnConsumedCapacity", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the BatchGetItem Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class BatchGetItemResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class BatchGetItem



    ##############################################################################
    #
    # BatchWriteItem
    #
    # Puts or deletes multiple items in one or more tables.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class BatchWriteItem < Choreography

      ####
      #  Create a new instance of the BatchWriteItem Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/DynamoDB/BatchWriteItem")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return BatchWriteItemInputSet
      ####
      def new_input_set()
        return BatchWriteItemInputSet.new()
      end

      def make_result_set()
        return BatchWriteItemResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = BatchWriteItemResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the BatchWriteItem
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class BatchWriteItemInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the RequestItems input for this Choreo. 
        # 
        # @param String - (required, json) A map of one or more table names and, for each table, a list of operations to be performed (DeleteRequest or PutRequest). See choreo notes for more details.
        ###

        def set_RequestItems(value)
          set_input("RequestItems", value)
        end
        #### 
        # Set the value of the ReturnConsumedCapacity input for this Choreo. 
        # 
        # @param String - (optional, string) Determines the level of detail about provisioned throughput consumption that is returned in the response. Valid values are: INDEXES, TOTAL, NONE.
        ###

        def set_ReturnConsumedCapacity(value)
          set_input("ReturnConsumedCapacity", value)
        end
        #### 
        # Set the value of the ReturnItemCollectionMetrics input for this Choreo. 
        # 
        # @param String - (optional, string) Determines whether item collection metrics are returned. Valid values are: SIZE and NONE.
        ###

        def set_ReturnItemCollectionMetrics(value)
          set_input("ReturnItemCollectionMetrics", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the BatchWriteItem Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class BatchWriteItemResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class BatchWriteItem



    ##############################################################################
    #
    # CreateTable
    #
    # Adds a new table to your account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateTable < Choreography

      ####
      #  Create a new instance of the CreateTable Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/DynamoDB/CreateTable")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateTableInputSet
      ####
      def new_input_set()
        return CreateTableInputSet.new()
      end

      def make_result_set()
        return CreateTableResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateTableResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateTable
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateTableInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AttributeDefinitions input for this Choreo. 
        # 
        # @param String - (required, json) An array of attributes that describe the key schema for the table and indexes.
        ###

        def set_AttributeDefinitions(value)
          set_input("AttributeDefinitions", value)
        end
        #### 
        # Set the value of the GlobalSecondaryIndexes input for this Choreo. 
        # 
        # @param String - (optional, json) One or more global secondary indexes (the maximum is five) to be created on the table.
        ###

        def set_GlobalSecondaryIndexes(value)
          set_input("GlobalSecondaryIndexes", value)
        end
        #### 
        # Set the value of the KeySchema input for this Choreo. 
        # 
        # @param String - (required, json) Specifies the attributes that make up the primary key for a table or an index. This is a JSON array of objects containing properties for AttributeName and KeyType. 
        ###

        def set_KeySchema(value)
          set_input("KeySchema", value)
        end
        #### 
        # Set the value of the LocalSecondaryIndexes input for this Choreo. 
        # 
        # @param String - (optional, json) One or more local secondary indexes (the maximum is five) to be created on the table.
        ###

        def set_LocalSecondaryIndexes(value)
          set_input("LocalSecondaryIndexes", value)
        end
        #### 
        # Set the value of the ProvisionedThroughput input for this Choreo. 
        # 
        # @param String - (required, json) Represents the provisioned throughput settings for a specified table or index.
        ###

        def set_ProvisionedThroughput(value)
          set_input("ProvisionedThroughput", value)
        end
        #### 
        # Set the value of the StreamSpecification input for this Choreo. 
        # 
        # @param String - (optional, json) The settings for DynamoDB Streams on the table.
        ###

        def set_StreamSpecification(value)
          set_input("StreamSpecification", value)
        end
        #### 
        # Set the value of the TableName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the table to create.
        ###

        def set_TableName(value)
          set_input("TableName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateTable Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateTableResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateTable



    ##############################################################################
    #
    # DeleteItem
    #
    # Deletes a single item in a table by primary key.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteItem < Choreography

      ####
      #  Create a new instance of the DeleteItem Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/DynamoDB/DeleteItem")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteItemInputSet
      ####
      def new_input_set()
        return DeleteItemInputSet.new()
      end

      def make_result_set()
        return DeleteItemResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteItemResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteItem
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteItemInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ConditionExpression input for this Choreo. 
        # 
        # @param String - (optional, string) A condition that must be satisfied in order for a conditional DeleteItem to succeed.
        ###

        def set_ConditionExpression(value)
          set_input("ConditionExpression", value)
        end
        #### 
        # Set the value of the ExpressionAttributeNames input for this Choreo. 
        # 
        # @param String - (optional, json) One or more substitution tokens for attribute names in an expression.
        ###

        def set_ExpressionAttributeNames(value)
          set_input("ExpressionAttributeNames", value)
        end
        #### 
        # Set the value of the ExpressionAttributeValues input for this Choreo. 
        # 
        # @param String - (optional, json) One or more values that can be substituted in an expression.
        ###

        def set_ExpressionAttributeValues(value)
          set_input("ExpressionAttributeValues", value)
        end
        #### 
        # Set the value of the Key input for this Choreo. 
        # 
        # @param String - (required, json) A map of attribute names to AttributeValue objects, representing the primary key of the item to delete.
        ###

        def set_Key(value)
          set_input("Key", value)
        end
        #### 
        # Set the value of the ReturnConsumedCapacity input for this Choreo. 
        # 
        # @param String - (optional, string) Determines the level of detail about provisioned throughput consumption that is returned in the response. Valid values are: INDEXES, TOTAL, NONE.
        ###

        def set_ReturnConsumedCapacity(value)
          set_input("ReturnConsumedCapacity", value)
        end
        #### 
        # Set the value of the ReturnItemCollectionMetrics input for this Choreo. 
        # 
        # @param String - (optional, string) Determines whether item collection metrics are returned. Valid values are: SIZE and NONE.
        ###

        def set_ReturnItemCollectionMetrics(value)
          set_input("ReturnItemCollectionMetrics", value)
        end
        #### 
        # Set the value of the ReturnValues input for this Choreo. 
        # 
        # @param String - (optional, string) Use ReturnValues if you want to get the item attributes as they appeared before they were deleted. Valid values are NONE and ALL_OLD.
        ###

        def set_ReturnValues(value)
          set_input("ReturnValues", value)
        end
        #### 
        # Set the value of the TableName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the table from which to delete the item.
        ###

        def set_TableName(value)
          set_input("TableName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteItem Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteItemResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteItem



    ##############################################################################
    #
    # DeleteTable
    #
    # Deletes a table and all of its items.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteTable < Choreography

      ####
      #  Create a new instance of the DeleteTable Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/DynamoDB/DeleteTable")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteTableInputSet
      ####
      def new_input_set()
        return DeleteTableInputSet.new()
      end

      def make_result_set()
        return DeleteTableResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteTableResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteTable
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteTableInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the TableName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the table to delete.
        ###

        def set_TableName(value)
          set_input("TableName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteTable Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteTableResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteTable



    ##############################################################################
    #
    # DescribeLimits
    #
    # Returns the current provisioned-capacity limits for your AWS account in a region, both for the region as a whole and for any one DynamoDB table that you create there.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeLimits < Choreography

      ####
      #  Create a new instance of the DescribeLimits Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/DynamoDB/DescribeLimits")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeLimitsInputSet
      ####
      def new_input_set()
        return DescribeLimitsInputSet.new()
      end

      def make_result_set()
        return DescribeLimitsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeLimitsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeLimits
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeLimitsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeLimits Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeLimitsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeLimits



    ##############################################################################
    #
    # DescribeTable
    #
    # Returns information about the table.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeTable < Choreography

      ####
      #  Create a new instance of the DescribeTable Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/DynamoDB/DescribeTable")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeTableInputSet
      ####
      def new_input_set()
        return DescribeTableInputSet.new()
      end

      def make_result_set()
        return DescribeTableResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeTableResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeTable
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeTableInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the TableName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the table to describe.
        ###

        def set_TableName(value)
          set_input("TableName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeTable Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeTableResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeTable



    ##############################################################################
    #
    # GetItem
    #
    # Returns a set of attributes for the item with the given primary key.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetItem < Choreography

      ####
      #  Create a new instance of the GetItem Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/DynamoDB/GetItem")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetItemInputSet
      ####
      def new_input_set()
        return GetItemInputSet.new()
      end

      def make_result_set()
        return GetItemResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetItemResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetItem
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetItemInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ConsistentRead input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Determines the read consistency model: If set to true, then the operation uses strongly consistent reads; otherwise, the operation uses eventually consistent reads.
        ###

        def set_ConsistentRead(value)
          set_input("ConsistentRead", value)
        end
        #### 
        # Set the value of the ExpressionAttributeNames input for this Choreo. 
        # 
        # @param String - (optional, json) One or more substitution tokens for attribute names in an expression.
        ###

        def set_ExpressionAttributeNames(value)
          set_input("ExpressionAttributeNames", value)
        end
        #### 
        # Set the value of the Key input for this Choreo. 
        # 
        # @param String - (required, json) A map of attribute names to AttributeValue objects, representing the primary key of the item to retrieve.
        ###

        def set_Key(value)
          set_input("Key", value)
        end
        #### 
        # Set the value of the ProjectionExpression input for this Choreo. 
        # 
        # @param String - (optional, string) A string that identifies one or more attributes to retrieve from the table.
        ###

        def set_ProjectionExpression(value)
          set_input("ProjectionExpression", value)
        end
        #### 
        # Set the value of the ReturnConsumedCapacity input for this Choreo. 
        # 
        # @param String - (optional, string) Determines the level of detail about provisioned throughput consumption that is returned in the response. Valid values are: INDEXES, TOTAL, NONE.
        ###

        def set_ReturnConsumedCapacity(value)
          set_input("ReturnConsumedCapacity", value)
        end
        #### 
        # Set the value of the TableName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the table containing the requested items.
        ###

        def set_TableName(value)
          set_input("TableName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetItem Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetItemResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetItem



    ##############################################################################
    #
    # ListTables
    #
    # Returns an array of table names associated with the current account and endpoint.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListTables < Choreography

      ####
      #  Create a new instance of the ListTables Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/DynamoDB/ListTables")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListTablesInputSet
      ####
      def new_input_set()
        return ListTablesInputSet.new()
      end

      def make_result_set()
        return ListTablesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListTablesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListTables
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListTablesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ExclusiveStartTableName input for this Choreo. 
        # 
        # @param String - (optional, string) The first table name that this operation will evaluate. Use the value that was returned for LastEvaluatedTableName in a previous request to retrieve the next page of results.
        ###

        def set_ExclusiveStartTableName(value)
          set_input("ExclusiveStartTableName", value)
        end
        #### 
        # Set the value of the Limit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) A maximum number of table names to return. Defaults to 100.
        ###

        def set_Limit(value)
          set_input("Limit", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListTables Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListTablesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListTables



    ##############################################################################
    #
    # PutItem
    #
    # Creates a new item, or replaces an old item with a new item.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PutItem < Choreography

      ####
      #  Create a new instance of the PutItem Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/DynamoDB/PutItem")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutItemInputSet
      ####
      def new_input_set()
        return PutItemInputSet.new()
      end

      def make_result_set()
        return PutItemResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutItemResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PutItem
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutItemInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ConditionExpression input for this Choreo. 
        # 
        # @param String - (optional, string) A condition that must be satisfied in order for a conditional PutItem operation to succeed.
        ###

        def set_ConditionExpression(value)
          set_input("ConditionExpression", value)
        end
        #### 
        # Set the value of the ExpressionAttributeNames input for this Choreo. 
        # 
        # @param String - (optional, json) One or more substitution tokens for attribute names in an expression.
        ###

        def set_ExpressionAttributeNames(value)
          set_input("ExpressionAttributeNames", value)
        end
        #### 
        # Set the value of the ExpressionAttributeValues input for this Choreo. 
        # 
        # @param String - (optional, json) One or more values that can be substituted in an expression.
        ###

        def set_ExpressionAttributeValues(value)
          set_input("ExpressionAttributeValues", value)
        end
        #### 
        # Set the value of the Item input for this Choreo. 
        # 
        # @param String - (required, json) A map of attribute name/value pairs, one for each attribute. Only the primary key attributes are required.
        ###

        def set_Item(value)
          set_input("Item", value)
        end
        #### 
        # Set the value of the ReturnConsumedCapacity input for this Choreo. 
        # 
        # @param String - (optional, string) Determines the level of detail about provisioned throughput consumption that is returned in the response. Valid values are: INDEXES, TOTAL, NONE.
        ###

        def set_ReturnConsumedCapacity(value)
          set_input("ReturnConsumedCapacity", value)
        end
        #### 
        # Set the value of the ReturnItemCollectionMetrics input for this Choreo. 
        # 
        # @param String - (optional, string) Determines whether item collection metrics are returned. Valid values are: SIZE and NONE.
        ###

        def set_ReturnItemCollectionMetrics(value)
          set_input("ReturnItemCollectionMetrics", value)
        end
        #### 
        # Set the value of the ReturnValues input for this Choreo. 
        # 
        # @param String - (optional, string) Use ReturnValues if you want to get the item attributes as they appeared before they were updated with the PutItem request. Valid values are NONE and ALL_OLD.
        ###

        def set_ReturnValues(value)
          set_input("ReturnValues", value)
        end
        #### 
        # Set the value of the TableName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the table to contain the item.
        ###

        def set_TableName(value)
          set_input("TableName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PutItem Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutItemResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PutItem



    ##############################################################################
    #
    # Query
    #
    # Queries a table using the primary key or a secondary index.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Query < Choreography

      ####
      #  Create a new instance of the Query Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/DynamoDB/Query")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return QueryInputSet
      ####
      def new_input_set()
        return QueryInputSet.new()
      end

      def make_result_set()
        return QueryResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = QueryResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Query
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class QueryInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ConsistentRead input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Determines the read consistency model: If set to true, then the operation uses strongly consistent reads; otherwise, the operation uses eventually consistent reads.
        ###

        def set_ConsistentRead(value)
          set_input("ConsistentRead", value)
        end
        #### 
        # Set the value of the ExclusiveStartKey input for this Choreo. 
        # 
        # @param String - (optional, json) The primary key of the first item that this operation will evaluate. Use the value that was returned for LastEvaluatedKey in the previous operation.
        ###

        def set_ExclusiveStartKey(value)
          set_input("ExclusiveStartKey", value)
        end
        #### 
        # Set the value of the ExpressionAttributeNames input for this Choreo. 
        # 
        # @param String - (optional, json) One or more substitution tokens for attribute names in an expression.
        ###

        def set_ExpressionAttributeNames(value)
          set_input("ExpressionAttributeNames", value)
        end
        #### 
        # Set the value of the ExpressionAttributeValues input for this Choreo. 
        # 
        # @param String - (conditional, json) One or more values that can be substituted in an expression.
        ###

        def set_ExpressionAttributeValues(value)
          set_input("ExpressionAttributeValues", value)
        end
        #### 
        # Set the value of the FilterExpression input for this Choreo. 
        # 
        # @param String - (optional, string) A string that contains conditions that DynamoDB applies after the Query operation, but before the data is returned to you.
        ###

        def set_FilterExpression(value)
          set_input("FilterExpression", value)
        end
        #### 
        # Set the value of the IndexName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of an index to query. This index can be any local secondary index or global secondary index on the table.
        ###

        def set_IndexName(value)
          set_input("IndexName", value)
        end
        #### 
        # Set the value of the KeyConditionExpression input for this Choreo. 
        # 
        # @param String - (conditional, string) The condition that specifies the key value(s) for items to be retrieved by the Query action.
        ###

        def set_KeyConditionExpression(value)
          set_input("KeyConditionExpression", value)
        end
        #### 
        # Set the value of the Limit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The maximum number of items to evaluate (not necessarily the number of matching items).
        ###

        def set_Limit(value)
          set_input("Limit", value)
        end
        #### 
        # Set the value of the ProjectionExpression input for this Choreo. 
        # 
        # @param String - (optional, string) A string that identifies one or more attributes to retrieve from the table.
        ###

        def set_ProjectionExpression(value)
          set_input("ProjectionExpression", value)
        end
        #### 
        # Set the value of the ReturnConsumedCapacity input for this Choreo. 
        # 
        # @param String - (optional, string) Determines the level of detail about provisioned throughput consumption that is returned in the response. Valid values are: INDEXES, TOTAL, NONE.
        ###

        def set_ReturnConsumedCapacity(value)
          set_input("ReturnConsumedCapacity", value)
        end
        #### 
        # Set the value of the ScanIndexForward input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Specifies the order for index traversal: If true (default), the traversal is performed in ascending order; if false, the traversal is performed in descending order.
        ###

        def set_ScanIndexForward(value)
          set_input("ScanIndexForward", value)
        end
        #### 
        # Set the value of the Select input for this Choreo. 
        # 
        # @param String - (optional, string) The attributes to be returned in the result. Valid values are: ALL_ATTRIBUTES, ALL_PROJECTED_ATTRIBUTES, SPECIFIC_ATTRIBUTES, and COUNT.
        ###

        def set_Select(value)
          set_input("Select", value)
        end
        #### 
        # Set the value of the TableName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the table containing the requested items.
        ###

        def set_TableName(value)
          set_input("TableName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Query Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class QueryResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Query



    ##############################################################################
    #
    # Scan
    #
    # Returns one or more items and item attributes by accessing every item in a table or a secondary index.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Scan < Choreography

      ####
      #  Create a new instance of the Scan Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/DynamoDB/Scan")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ScanInputSet
      ####
      def new_input_set()
        return ScanInputSet.new()
      end

      def make_result_set()
        return ScanResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ScanResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Scan
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ScanInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ConsistentRead input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) A Boolean value that determines the read consistency model during the scan.
        ###

        def set_ConsistentRead(value)
          set_input("ConsistentRead", value)
        end
        #### 
        # Set the value of the ExclusiveStartKey input for this Choreo. 
        # 
        # @param String - (optional, json) The primary key of the first item that this operation will evaluate. Use the value that was returned for LastEvaluatedKey in the previous operation.
        ###

        def set_ExclusiveStartKey(value)
          set_input("ExclusiveStartKey", value)
        end
        #### 
        # Set the value of the ExpressionAttributeNames input for this Choreo. 
        # 
        # @param String - (optional, json) One or more substitution tokens for attribute names in an expression.
        ###

        def set_ExpressionAttributeNames(value)
          set_input("ExpressionAttributeNames", value)
        end
        #### 
        # Set the value of the ExpressionAttributeValues input for this Choreo. 
        # 
        # @param String - (optional, json) One or more values that can be substituted in an expression.
        ###

        def set_ExpressionAttributeValues(value)
          set_input("ExpressionAttributeValues", value)
        end
        #### 
        # Set the value of the FilterExpression input for this Choreo. 
        # 
        # @param String - (optional, string) A string that contains conditions that DynamoDB applies after the Scan operation, but before the data is returned to you.
        ###

        def set_FilterExpression(value)
          set_input("FilterExpression", value)
        end
        #### 
        # Set the value of the IndexName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of an index to scan. This index can be any local secondary index or global secondary index on the table.
        ###

        def set_IndexName(value)
          set_input("IndexName", value)
        end
        #### 
        # Set the value of the Limit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The maximum number of items to evaluate (not necessarily the number of matching items).
        ###

        def set_Limit(value)
          set_input("Limit", value)
        end
        #### 
        # Set the value of the ProjectionExpression input for this Choreo. 
        # 
        # @param String - (optional, string) A string that identifies one or more attributes to retrieve from the table.
        ###

        def set_ProjectionExpression(value)
          set_input("ProjectionExpression", value)
        end
        #### 
        # Set the value of the ReturnConsumedCapacity input for this Choreo. 
        # 
        # @param String - (optional, string) Determines the level of detail about provisioned throughput consumption that is returned in the response. Valid values are: INDEXES, TOTAL, NONE.
        ###

        def set_ReturnConsumedCapacity(value)
          set_input("ReturnConsumedCapacity", value)
        end
        #### 
        # Set the value of the Segment input for this Choreo. 
        # 
        # @param Integer - (optional, integer) For a parallel Scan request, Segment identifies an individual segment to be scanned by an application worker.
        ###

        def set_Segment(value)
          set_input("Segment", value)
        end
        #### 
        # Set the value of the Select input for this Choreo. 
        # 
        # @param String - (optional, string) The attributes to be returned in the result. Valid values are: ALL_ATTRIBUTES, ALL_PROJECTED_ATTRIBUTES, SPECIFIC_ATTRIBUTES, and COUNT.
        ###

        def set_Select(value)
          set_input("Select", value)
        end
        #### 
        # Set the value of the TableName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the table containing the requested items.
        ###

        def set_TableName(value)
          set_input("TableName", value)
        end
        #### 
        # Set the value of the TotalSegments input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Specifies the order for index traversal: If true (default), the traversal is performed in ascending order; if false, the traversal is performed in descending order.
        ###

        def set_TotalSegments(value)
          set_input("TotalSegments", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Scan Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ScanResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Scan



    ##############################################################################
    #
    # UpdateItem
    #
    # Edits an existing item's attributes, or adds a new item to the table if it does not already exist.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UpdateItem < Choreography

      ####
      #  Create a new instance of the UpdateItem Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/DynamoDB/UpdateItem")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UpdateItemInputSet
      ####
      def new_input_set()
        return UpdateItemInputSet.new()
      end

      def make_result_set()
        return UpdateItemResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UpdateItemResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UpdateItem
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UpdateItemInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ConditionExpression input for this Choreo. 
        # 
        # @param String - (optional, string) A condition that must be satisfied in order for a conditional update to succeed.
        ###

        def set_ConditionExpression(value)
          set_input("ConditionExpression", value)
        end
        #### 
        # Set the value of the ExpressionAttributeNames input for this Choreo. 
        # 
        # @param String - (optional, json) One or more substitution tokens for attribute names in an expression.
        ###

        def set_ExpressionAttributeNames(value)
          set_input("ExpressionAttributeNames", value)
        end
        #### 
        # Set the value of the ExpressionAttributeValues input for this Choreo. 
        # 
        # @param String - (optional, json) One or more values that can be substituted in an expression.
        ###

        def set_ExpressionAttributeValues(value)
          set_input("ExpressionAttributeValues", value)
        end
        #### 
        # Set the value of the Key input for this Choreo. 
        # 
        # @param String - (required, json) The primary key of the item to be updated. Each element consists of an attribute name and a value for that attribute.
        ###

        def set_Key(value)
          set_input("Key", value)
        end
        #### 
        # Set the value of the ReturnConsumedCapacity input for this Choreo. 
        # 
        # @param String - (optional, string) Determines the level of detail about provisioned throughput consumption that is returned in the response. Valid values are: INDEXES, TOTAL, NONE.
        ###

        def set_ReturnConsumedCapacity(value)
          set_input("ReturnConsumedCapacity", value)
        end
        #### 
        # Set the value of the ReturnItemCollectionMetrics input for this Choreo. 
        # 
        # @param String - (optional, string) Determines whether item collection metrics are returned. Valid values are: SIZE and NONE.
        ###

        def set_ReturnItemCollectionMetrics(value)
          set_input("ReturnItemCollectionMetrics", value)
        end
        #### 
        # Set the value of the ReturnValues input for this Choreo. 
        # 
        # @param String - (optional, string) Use ReturnValues if you want to get the item attributes as they appeared either before or after they were updated. Valid values are NONE and ALL_OLD.
        ###

        def set_ReturnValues(value)
          set_input("ReturnValues", value)
        end
        #### 
        # Set the value of the TableName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the table to contain the item.
        ###

        def set_TableName(value)
          set_input("TableName", value)
        end
        #### 
        # Set the value of the UpdateExpression input for this Choreo. 
        # 
        # @param String - (optional, string) An expression that defines one or more attributes to be updated, the action to be performed on them, and new value(s) for them.
        ###

        def set_UpdateExpression(value)
          set_input("UpdateExpression", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UpdateItem Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UpdateItemResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UpdateItem



    ##############################################################################
    #
    # UpdateTable
    #
    # Modifies the provisioned throughput settings, global secondary indexes, or DynamoDB Streams settings for a given table.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UpdateTable < Choreography

      ####
      #  Create a new instance of the UpdateTable Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/DynamoDB/UpdateTable")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UpdateTableInputSet
      ####
      def new_input_set()
        return UpdateTableInputSet.new()
      end

      def make_result_set()
        return UpdateTableResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UpdateTableResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UpdateTable
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UpdateTableInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AttributeDefinitions input for this Choreo. 
        # 
        # @param String - (optional, json) An array of attributes that describe the key schema for the table and indexes.
        ###

        def set_AttributeDefinitions(value)
          set_input("AttributeDefinitions", value)
        end
        #### 
        # Set the value of the GlobalSecondaryIndexUpdates input for this Choreo. 
        # 
        # @param String - (conditional, json) One or more global secondary indexes (the maximum is five) to be created on the table.
        ###

        def set_GlobalSecondaryIndexUpdates(value)
          set_input("GlobalSecondaryIndexUpdates", value)
        end
        #### 
        # Set the value of the ProvisionedThroughput input for this Choreo. 
        # 
        # @param String - (conditional, json) Represents the provisioned throughput settings for a specified table or index.
        ###

        def set_ProvisionedThroughput(value)
          set_input("ProvisionedThroughput", value)
        end
        #### 
        # Set the value of the StreamSpecification input for this Choreo. 
        # 
        # @param String - (conditional, json) The settings for DynamoDB Streams on the table.
        ###

        def set_StreamSpecification(value)
          set_input("StreamSpecification", value)
        end
        #### 
        # Set the value of the TableName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the table to create.
        ###

        def set_TableName(value)
          set_input("TableName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UpdateTable Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UpdateTableResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UpdateTable




  end # module DynamoDB

  module EC2



    ##############################################################################
    #
    # AllocateAddress
    #
    # Calls the Amazon EC2 API to acquire an Elastic IP address for use with your AWS account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class AllocateAddress < Choreography

      ####
      #  Create a new instance of the AllocateAddress Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/AllocateAddress")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AllocateAddressInputSet
      ####
      def new_input_set()
        return AllocateAddressInputSet.new()
      end

      def make_result_set()
        return AllocateAddressResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AllocateAddressResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the AllocateAddress
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AllocateAddressInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Domain input for this Choreo. 
        # 
        # @param String - (conditional, string) Set to "vpc" to allocate the address for use with instances in a VPC.
        ###

        def set_Domain(value)
          set_input("Domain", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the AllocateAddress Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AllocateAddressResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class AllocateAddress



    ##############################################################################
    #
    # AssociateAddress
    #
    # Associates an Elastic IP address with an instance or a network interface using the Amazon EC2 API.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class AssociateAddress < Choreography

      ####
      #  Create a new instance of the AssociateAddress Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/AssociateAddress")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AssociateAddressInputSet
      ####
      def new_input_set()
        return AssociateAddressInputSet.new()
      end

      def make_result_set()
        return AssociateAddressResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AssociateAddressResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the AssociateAddress
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AssociateAddressInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AllocationId input for this Choreo. 
        # 
        # @param String - (optional, string) [EC2-VPC] The allocation ID.  Required for a VPC.
        ###

        def set_AllocationId(value)
          set_input("AllocationId", value)
        end
        #### 
        # Set the value of the AllowReassociation input for this Choreo. 
        # 
        # @param String - (optional, string) [EC2-VPC] Allows an Elastic IP address that is already associated with an instance or network interface to be re-associated with the specified instance or network interface. False if not specified.
        ###

        def set_AllowReassociation(value)
          set_input("AllowReassociation", value)
        end
        #### 
        # Set the value of the InstanceId input for this Choreo. 
        # 
        # @param String - (conditional, string) The ID of the instance.  Required for EC2-Classic. For a VPC, you can specify either an instance ID or a network interface ID, but not both.
        ###

        def set_InstanceId(value)
          set_input("InstanceId", value)
        end
        #### 
        # Set the value of the NetworkInterfaceId input for this Choreo. 
        # 
        # @param String - (optional, string) [EC2-VPC] The ID of the network interface. Association fails when specifying an instance ID unless exactly one interface is attached.
        ###

        def set_NetworkInterfaceId(value)
          set_input("NetworkInterfaceId", value)
        end
        #### 
        # Set the value of the PrivateIpAddress input for this Choreo. 
        # 
        # @param String - (optional, string) [EC2-VPC] The primary or secondary private IP address to associate with the Elastic IP address. If nothing is specified, the Elastic IP address is associated with the primary private IP address.
        ###

        def set_PrivateIpAddress(value)
          set_input("PrivateIpAddress", value)
        end
        #### 
        # Set the value of the PublicIp input for this Choreo. 
        # 
        # @param String - (conditional, string) The Elastic IP address.
        ###

        def set_PublicIp(value)
          set_input("PublicIp", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the AssociateAddress Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AssociateAddressResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class AssociateAddress



    ##############################################################################
    #
    # AttachVolume
    #
    # Attaches an Amazon EBS volume to a running instance and exposes it as the specified device using the Amazon EC2 API.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class AttachVolume < Choreography

      ####
      #  Create a new instance of the AttachVolume Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/AttachVolume")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AttachVolumeInputSet
      ####
      def new_input_set()
        return AttachVolumeInputSet.new()
      end

      def make_result_set()
        return AttachVolumeResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AttachVolumeResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the AttachVolume
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AttachVolumeInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Device input for this Choreo. 
        # 
        # @param String - (required, string) How the device is exposed to the instance (i.e. " /dev/sdh" or "xvdh").
        ###

        def set_Device(value)
          set_input("Device", value)
        end
        #### 
        # Set the value of the InstanceId input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the instance to which the volume attaches. The volume and instance must be within the same Availability Zone and the instance must be running.
        ###

        def set_InstanceId(value)
          set_input("InstanceId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the VolumeId input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the Amazon EBS volume. The volume and instance must be within the same Availability Zone and the instance must be running.
        ###

        def set_VolumeId(value)
          set_input("VolumeId", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the AttachVolume Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AttachVolumeResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class AttachVolume



    ##############################################################################
    #
    # AuthorizeSecurityGroupIngress
    #
    # Adds an ingress rule to a security group using the Amazon EC2 API.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class AuthorizeSecurityGroupIngress < Choreography

      ####
      #  Create a new instance of the AuthorizeSecurityGroupIngress Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/AuthorizeSecurityGroupIngress")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AuthorizeSecurityGroupIngressInputSet
      ####
      def new_input_set()
        return AuthorizeSecurityGroupIngressInputSet.new()
      end

      def make_result_set()
        return AuthorizeSecurityGroupIngressResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AuthorizeSecurityGroupIngressResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the AuthorizeSecurityGroupIngress
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AuthorizeSecurityGroupIngressInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the GroupId input for this Choreo. 
        # 
        # @param String - (conditional, string) The ID of the security group to modify. Can be used instead of GroupName.
        ###

        def set_GroupId(value)
          set_input("GroupId", value)
        end
        #### 
        # Set the value of the GroupName input for this Choreo. 
        # 
        # @param String - (conditional, string) The name of the security group to modify. Can be used instead of GroupId.
        ###

        def set_GroupName(value)
          set_input("GroupName", value)
        end
        #### 
        # Set the value of the IpPermissionsCidrIp input for this Choreo. 
        # 
        # @param String - (optional, string) The CIDR range. Cannot be used when specifying a source security group.
        ###

        def set_IpPermissionsCidrIp(value)
          set_input("IpPermissionsCidrIp", value)
        end
        #### 
        # Set the value of the IpPermissionsFromPort input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The start of port range for the TCP and UDP protocols, or an ICMP type number. For the ICMP type number, you can use -1 to specify all ICMP types.
        ###

        def set_IpPermissionsFromPort(value)
          set_input("IpPermissionsFromPort", value)
        end
        #### 
        # Set the value of the IpPermissionsGroupId input for this Choreo. 
        # 
        # @param String - (optional, string) The ID of the source security group. Cannot be used when specifying a CIDR IP address.
        ###

        def set_IpPermissionsGroupId(value)
          set_input("IpPermissionsGroupId", value)
        end
        #### 
        # Set the value of the IpPermissionsGroupName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the source security group. Cannot be used when specifying a CIDR IP address.
        ###

        def set_IpPermissionsGroupName(value)
          set_input("IpPermissionsGroupName", value)
        end
        #### 
        # Set the value of the IpPermissionsIpProtocol input for this Choreo. 
        # 
        # @param String - (required, string) The IP protocol name or number. Valid values for EC2-Classic: tcp, udp, icmp (or 6, 17, 1). Valid values for EC2-VPC: tcp, udp, icmp, any valid protocol number (0-254), or -1 (to specify all).
        ###

        def set_IpPermissionsIpProtocol(value)
          set_input("IpPermissionsIpProtocol", value)
        end
        #### 
        # Set the value of the IpPermissionsToPort input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The end of port range for the TCP and UDP protocols, or an ICMP code number. For the ICMP code number, you can use -1 to specify all ICMP codes for the given ICMP type.
        ###

        def set_IpPermissionsToPort(value)
          set_input("IpPermissionsToPort", value)
        end
        #### 
        # Set the value of the IpPermissionsUserId input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS account ID that owns the source security group. Cannot be used when specifying a CIDR IP address.
        ###

        def set_IpPermissionsUserId(value)
          set_input("IpPermissionsUserId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the AuthorizeSecurityGroupIngress Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AuthorizeSecurityGroupIngressResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class AuthorizeSecurityGroupIngress



    ##############################################################################
    #
    # CreateImage
    #
    # Creates an Amazon Machine Image from an Amazon EBS-backed instance using the Amazon EC2 API. The image can be used later to launch other identical servers.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateImage < Choreography

      ####
      #  Create a new instance of the CreateImage Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/CreateImage")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateImageInputSet
      ####
      def new_input_set()
        return CreateImageInputSet.new()
      end

      def make_result_set()
        return CreateImageResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateImageResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateImage
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateImageInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the DeleteOnTermination input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Whether the volume is deleted on instance termination. Defaults to "true".
        ###

        def set_DeleteOnTermination(value)
          set_input("DeleteOnTermination", value)
        end
        #### 
        # Set the value of the Description input for this Choreo. 
        # 
        # @param String - (optional, string) A description for the image you want to create.
        ###

        def set_Description(value)
          set_input("Description", value)
        end
        #### 
        # Set the value of the DeviceName input for this Choreo. 
        # 
        # @param String - (conditional, string) The device name exposed to the instance (i.e. /dev/sdh or xvdh). When registering an AMI from a snapshot, DiviceName is required as well as SnapshotId.
        ###

        def set_DeviceName(value)
          set_input("DeviceName", value)
        end
        #### 
        # Set the value of the InstanceId input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the instance to create the image on.
        ###

        def set_InstanceId(value)
          set_input("InstanceId", value)
        end
        #### 
        # Set the value of the Iops input for this Choreo. 
        # 
        # @param Integer - (conditional, integer) The number of I/O operations per second (IOPS) that the volume supports. Valid range is 100 to 2000.
        ###

        def set_Iops(value)
          set_input("Iops", value)
        end
        #### 
        # Set the value of the Name input for this Choreo. 
        # 
        # @param String - (required, string) The name for the image you are creating.
        ###

        def set_Name(value)
          set_input("Name", value)
        end
        #### 
        # Set the value of the NoDevice input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Suppresses a device mapping. Defaults to "true".
        ###

        def set_NoDevice(value)
          set_input("NoDevice", value)
        end
        #### 
        # Set the value of the NoReboot input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Defaults to "false". Amazon EC2 will attempt to shut down the instance before and after creating the image. Set to "true" for NoReboot.
        ###

        def set_NoReboot(value)
          set_input("NoReboot", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SnapshotId input for this Choreo. 
        # 
        # @param String - (conditional, string) The ID of the snapshot. Required when registering from a snapshot. You must also specify DeviceName with the root device name.
        ###

        def set_SnapshotId(value)
          set_input("SnapshotId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the VirtualName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the virtual device.
        ###

        def set_VirtualName(value)
          set_input("VirtualName", value)
        end
        #### 
        # Set the value of the VolumeSize input for this Choreo. 
        # 
        # @param String - (conditional, string) The size of the volume, in GiBs. Required unless you're creating the volume from a snapshot which indicates that the size will be the size of the snapshot.
        ###

        def set_VolumeSize(value)
          set_input("VolumeSize", value)
        end
        #### 
        # Set the value of the VolumeType input for this Choreo. 
        # 
        # @param String - (optional, string) The volume type. Valid values are: standard (the default) and io1.
        ###

        def set_VolumeType(value)
          set_input("VolumeType", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateImage Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateImageResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateImage



    ##############################################################################
    #
    # CreateKeyPair
    #
    # Creates a new 2048-bit RSA key pair with the specified name using the Amazon EC2 API.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateKeyPair < Choreography

      ####
      #  Create a new instance of the CreateKeyPair Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/CreateKeyPair")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateKeyPairInputSet
      ####
      def new_input_set()
        return CreateKeyPairInputSet.new()
      end

      def make_result_set()
        return CreateKeyPairResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateKeyPairResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateKeyPair
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateKeyPairInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the KeyName input for this Choreo. 
        # 
        # @param String - (required, string) A unique name for the key pair.
        ###

        def set_KeyName(value)
          set_input("KeyName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateKeyPair Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateKeyPairResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateKeyPair



    ##############################################################################
    #
    # CreateSecurityGroup
    #
    # Creates a new EC2 security group using the Amazon EC2 API.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateSecurityGroup < Choreography

      ####
      #  Create a new instance of the CreateSecurityGroup Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/CreateSecurityGroup")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateSecurityGroupInputSet
      ####
      def new_input_set()
        return CreateSecurityGroupInputSet.new()
      end

      def make_result_set()
        return CreateSecurityGroupResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateSecurityGroupResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateSecurityGroup
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateSecurityGroupInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the GroupDescription input for this Choreo. 
        # 
        # @param String - (required, string) A description for the security group that that you want to create.
        ###

        def set_GroupDescription(value)
          set_input("GroupDescription", value)
        end
        #### 
        # Set the value of the GroupName input for this Choreo. 
        # 
        # @param String - (required, string) A name for the security group to create.
        ###

        def set_GroupName(value)
          set_input("GroupName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the VpcId input for this Choreo. 
        # 
        # @param String - (optional, string) The ID of the VPC. Required for EC2-VPC.
        ###

        def set_VpcId(value)
          set_input("VpcId", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateSecurityGroup Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateSecurityGroupResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateSecurityGroup



    ##############################################################################
    #
    # CreateSnapshot
    #
    # Create a snapshot from a specified EBS volume using the Amazon EC2 API.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateSnapshot < Choreography

      ####
      #  Create a new instance of the CreateSnapshot Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/CreateSnapshot")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateSnapshotInputSet
      ####
      def new_input_set()
        return CreateSnapshotInputSet.new()
      end

      def make_result_set()
        return CreateSnapshotResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateSnapshotResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateSnapshot
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateSnapshotInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Description input for this Choreo. 
        # 
        # @param String - (optional, string) A description for the volume that you want to create.
        ###

        def set_Description(value)
          set_input("Description", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the VolumeId input for this Choreo. 
        # 
        # @param String - (required, string) The id of the EBS volume to snapshot.
        ###

        def set_VolumeId(value)
          set_input("VolumeId", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateSnapshot Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateSnapshotResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateSnapshot



    ##############################################################################
    #
    # CreateTags
    #
    # Adds or overwrites one or more tags for the specified EC2 resource or resources using the Amazon EC2 API.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateTags < Choreography

      ####
      #  Create a new instance of the CreateTags Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/CreateTags")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateTagsInputSet
      ####
      def new_input_set()
        return CreateTagsInputSet.new()
      end

      def make_result_set()
        return CreateTagsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateTagsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateTags
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateTagsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResourceId input for this Choreo. 
        # 
        # @param String - (required, string) The ID of a resource to tag. This can be a comma-separated list of up to 10  Resource IDs.
        ###

        def set_ResourceId(value)
          set_input("ResourceId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the TagKey input for this Choreo. 
        # 
        # @param String - (required, string) The key for a tag.
        ###

        def set_TagKey(value)
          set_input("TagKey", value)
        end
        #### 
        # Set the value of the TagValue input for this Choreo. 
        # 
        # @param String - (conditional, string) The value for a tag. If empty, the value will be set to be an empty string.
        ###

        def set_TagValue(value)
          set_input("TagValue", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateTags Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateTagsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateTags



    ##############################################################################
    #
    # CreateVolume
    #
    # Calls the Amazon EC2 API to create a new EBS volume that your EC2 instance can attach to.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateVolume < Choreography

      ####
      #  Create a new instance of the CreateVolume Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/CreateVolume")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateVolumeInputSet
      ####
      def new_input_set()
        return CreateVolumeInputSet.new()
      end

      def make_result_set()
        return CreateVolumeResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateVolumeResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateVolume
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateVolumeInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AvailabilityZone input for this Choreo. 
        # 
        # @param String - (required, string) The Availability Zone to use when creating thew new volume (i.e us-east-1a).
        ###

        def set_AvailabilityZone(value)
          set_input("AvailabilityZone", value)
        end
        #### 
        # Set the value of the Iops input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The number of I/O operations per second (IOPS) that the volume supports. Valid range is 100 to 2000. Required when the volume type is io1.
        ###

        def set_Iops(value)
          set_input("Iops", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Size input for this Choreo. 
        # 
        # @param Integer - (conditional, integer) The size for the volume (in gigabytes) that you are creating. Valid Values are 1-1024. Required if you're not creating a volume from a snapshot. If the volume type is io1, the min size is 10 GiB.
        ###

        def set_Size(value)
          set_input("Size", value)
        end
        #### 
        # Set the value of the SnapshotId input for this Choreo. 
        # 
        # @param String - (conditional, string) The snapshot from which to create the new volume. Required if you are creating a volume from a snapshot.
        ###

        def set_SnapshotId(value)
          set_input("SnapshotId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the VolumeType input for this Choreo. 
        # 
        # @param String - (optional, string) The volume type.Valid values are: "standard" (the default) and "io1".
        ###

        def set_VolumeType(value)
          set_input("VolumeType", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateVolume Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateVolumeResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateVolume



    ##############################################################################
    #
    # DeleteKeyPair
    #
    # Deletes the specified key pair by removing the public key from Amazon EC2 using the Amazon EC2 API. You must own the key pair.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteKeyPair < Choreography

      ####
      #  Create a new instance of the DeleteKeyPair Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DeleteKeyPair")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteKeyPairInputSet
      ####
      def new_input_set()
        return DeleteKeyPairInputSet.new()
      end

      def make_result_set()
        return DeleteKeyPairResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteKeyPairResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteKeyPair
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteKeyPairInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the KeyName input for this Choreo. 
        # 
        # @param String - (required, string) A unique name for the key pair.
        ###

        def set_KeyName(value)
          set_input("KeyName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteKeyPair Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteKeyPairResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteKeyPair



    ##############################################################################
    #
    # DeleteSecurityGroup
    #
    # Calls the Amazon EC2 API to delete a security group using the group name you specify.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteSecurityGroup < Choreography

      ####
      #  Create a new instance of the DeleteSecurityGroup Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DeleteSecurityGroup")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteSecurityGroupInputSet
      ####
      def new_input_set()
        return DeleteSecurityGroupInputSet.new()
      end

      def make_result_set()
        return DeleteSecurityGroupResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteSecurityGroupResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteSecurityGroup
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteSecurityGroupInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the GroupId input for this Choreo. 
        # 
        # @param String - (conditional, string) The id of the security group to delete. Required unless providing the GroupName.
        ###

        def set_GroupId(value)
          set_input("GroupId", value)
        end
        #### 
        # Set the value of the GroupName input for this Choreo. 
        # 
        # @param String - (conditional, string) The name of the security group to delete.Required unless providing the GroupId.
        ###

        def set_GroupName(value)
          set_input("GroupName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, any) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteSecurityGroup Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteSecurityGroupResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteSecurityGroup



    ##############################################################################
    #
    # DeleteSnapshot
    #
    # Calls the Amazon EC2 API to delete a snapshot using a snapshot id that you specify.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteSnapshot < Choreography

      ####
      #  Create a new instance of the DeleteSnapshot Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DeleteSnapshot")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteSnapshotInputSet
      ####
      def new_input_set()
        return DeleteSnapshotInputSet.new()
      end

      def make_result_set()
        return DeleteSnapshotResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteSnapshotResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteSnapshot
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteSnapshotInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SnapshotId input for this Choreo. 
        # 
        # @param String - (required, string) The id of the snapshot to delete.
        ###

        def set_SnapshotId(value)
          set_input("SnapshotId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteSnapshot Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteSnapshotResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteSnapshot



    ##############################################################################
    #
    # DeleteTags
    #
    # Deletes a specific set of tags from a specific set of resources using the Amazon EC2 API.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteTags < Choreography

      ####
      #  Create a new instance of the DeleteTags Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DeleteTags")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteTagsInputSet
      ####
      def new_input_set()
        return DeleteTagsInputSet.new()
      end

      def make_result_set()
        return DeleteTagsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteTagsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteTags
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteTagsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResourceId input for this Choreo. 
        # 
        # @param String - (required, string) The ID of a resource to tag. This can be a comma-separated list of up to 10  Resource IDs.
        ###

        def set_ResourceId(value)
          set_input("ResourceId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the TagKey input for this Choreo. 
        # 
        # @param String - (required, string) The key for a tag.
        ###

        def set_TagKey(value)
          set_input("TagKey", value)
        end
        #### 
        # Set the value of the TagValue input for this Choreo. 
        # 
        # @param String - (optional, string) Indicates a tag should be deleted only if the value matches.To delete a tag regardless of its value, leave this blank. To delete a tag with an empty string value (""), pass the string value "null".
        ###

        def set_TagValue(value)
          set_input("TagValue", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteTags Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteTagsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteTags



    ##############################################################################
    #
    # DeleteVolume
    #
    # Calls the Amazon EC2 API to delete a volume using a volume id that you specify.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteVolume < Choreography

      ####
      #  Create a new instance of the DeleteVolume Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DeleteVolume")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteVolumeInputSet
      ####
      def new_input_set()
        return DeleteVolumeInputSet.new()
      end

      def make_result_set()
        return DeleteVolumeResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteVolumeResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteVolume
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteVolumeInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the VolumeId input for this Choreo. 
        # 
        # @param String - (required, string) The id of the volume to delete.
        ###

        def set_VolumeId(value)
          set_input("VolumeId", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteVolume Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteVolumeResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteVolume



    ##############################################################################
    #
    # DeregisterImage
    #
    # Calls the Amazon EC2 API to deregister the specified AMI.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeregisterImage < Choreography

      ####
      #  Create a new instance of the DeregisterImage Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DeregisterImage")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeregisterImageInputSet
      ####
      def new_input_set()
        return DeregisterImageInputSet.new()
      end

      def make_result_set()
        return DeregisterImageResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeregisterImageResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeregisterImage
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeregisterImageInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ImageId input for this Choreo. 
        # 
        # @param String - (required, string) The AMI ID.
        ###

        def set_ImageId(value)
          set_input("ImageId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeregisterImage Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeregisterImageResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeregisterImage



    ##############################################################################
    #
    # DescribeAddresses
    #
    # Queries the Amazon EC2 API to describe one or more of your Elastic IP addresses.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeAddresses < Choreography

      ####
      #  Create a new instance of the DescribeAddresses Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DescribeAddresses")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeAddressesInputSet
      ####
      def new_input_set()
        return DescribeAddressesInputSet.new()
      end

      def make_result_set()
        return DescribeAddressesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeAddressesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeAddresses
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeAddressesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AllocationId input for this Choreo. 
        # 
        # @param String - (optional, string) One or more allocation IDs corresponding to the address or addresses to describe (VPC addresses only). This can be a comma-separated list of up to 10 Allocation Ids.
        ###

        def set_AllocationId(value)
          set_input("AllocationId", value)
        end
        #### 
        # Set the value of the FilterName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of a supported filter to narrow the results with.
        ###

        def set_FilterName(value)
          set_input("FilterName", value)
        end
        #### 
        # Set the value of the FilterValue input for this Choreo. 
        # 
        # @param String - (optional, string) A value for the specified filter.
        ###

        def set_FilterValue(value)
          set_input("FilterValue", value)
        end
        #### 
        # Set the value of the PublicIp input for this Choreo. 
        # 
        # @param String - (optional, string) One or more EC2 Elastic IP addresses.  This can be a comma-separated list of up to 10 IP addresses.
        ###

        def set_PublicIp(value)
          set_input("PublicIp", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeAddresses Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeAddressesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeAddresses



    ##############################################################################
    #
    # DescribeAvailabilityZones
    #
    # Queries the Amazon EC2 API to return Availability Zones that are available for your EC2 account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeAvailabilityZones < Choreography

      ####
      #  Create a new instance of the DescribeAvailabilityZones Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DescribeAvailabilityZones")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeAvailabilityZonesInputSet
      ####
      def new_input_set()
        return DescribeAvailabilityZonesInputSet.new()
      end

      def make_result_set()
        return DescribeAvailabilityZonesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeAvailabilityZonesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeAvailabilityZones
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeAvailabilityZonesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the FilterName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of a supported filter to narrow results with.
        ###

        def set_FilterName(value)
          set_input("FilterName", value)
        end
        #### 
        # Set the value of the FilterValue input for this Choreo. 
        # 
        # @param String - (optional, string) A value for the specified filter.
        ###

        def set_FilterValue(value)
          set_input("FilterValue", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the ZoneName input for this Choreo. 
        # 
        # @param String - (optional, string) One or more Availability Zones.  This can be a comma-separated list of up to 10 instance Zones.
        ###

        def set_ZoneName(value)
          set_input("ZoneName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeAvailabilityZones Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeAvailabilityZonesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeAvailabilityZones



    ##############################################################################
    #
    # DescribeImageAttribute
    #
    # Queries the Amazon EC2 API to retrieve information about an attribute of an AMI.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeImageAttribute < Choreography

      ####
      #  Create a new instance of the DescribeImageAttribute Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DescribeImageAttribute")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeImageAttributeInputSet
      ####
      def new_input_set()
        return DescribeImageAttributeInputSet.new()
      end

      def make_result_set()
        return DescribeImageAttributeResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeImageAttributeResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeImageAttribute
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeImageAttributeInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Attribute input for this Choreo. 
        # 
        # @param String - (required, string) The AMI attribute to get. Valid Values are: description | kernel | ramdisk | launchPermission | productCodes | blockDeviceMapping.
        ###

        def set_Attribute(value)
          set_input("Attribute", value)
        end
        #### 
        # Set the value of the ImageId input for this Choreo. 
        # 
        # @param String - (required, string) The AMI ID.
        ###

        def set_ImageId(value)
          set_input("ImageId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeImageAttribute Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeImageAttributeResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeImageAttribute



    ##############################################################################
    #
    # DescribeImages
    #
    # Queries the Amazon EC2 API to return information about Amazon Machine Image(s) that are available to you.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeImages < Choreography

      ####
      #  Create a new instance of the DescribeImages Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DescribeImages")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeImagesInputSet
      ####
      def new_input_set()
        return DescribeImagesInputSet.new()
      end

      def make_result_set()
        return DescribeImagesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeImagesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeImages
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeImagesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ExecutableBy input for this Choreo. 
        # 
        # @param String - (optional, string) The user ID that has explicit launch permissions. The user ID can be an AWS account ID, "self", or "all" to return AMIs with public launch permissions.
        ###

        def set_ExecutableBy(value)
          set_input("ExecutableBy", value)
        end
        #### 
        # Set the value of the FilterName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of a supported filter to narrow results with.
        ###

        def set_FilterName(value)
          set_input("FilterName", value)
        end
        #### 
        # Set the value of the FilterValue input for this Choreo. 
        # 
        # @param String - (optional, string) A value for the specified filter.
        ###

        def set_FilterValue(value)
          set_input("FilterValue", value)
        end
        #### 
        # Set the value of the ImageId input for this Choreo. 
        # 
        # @param String - (conditional, string) The ID of the AMI that you want to return. Returns all AMIs when this parameter is not specified.
        ###

        def set_ImageId(value)
          set_input("ImageId", value)
        end
        #### 
        # Set the value of the Owner input for this Choreo. 
        # 
        # @param String - (conditional, string) The IDs "amazon", "aws-marketplace", and "self" can be used to include AMIs owned by Amazon, AWS Marketplace, or AMIs owned by you, respectively.
        ###

        def set_Owner(value)
          set_input("Owner", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeImages Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeImagesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeImages



    ##############################################################################
    #
    # DescribeInstances
    #
    # Queries the Amazon EC2 API to return information on EC2 instances associated with your AWS account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeInstances < Choreography

      ####
      #  Create a new instance of the DescribeInstances Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DescribeInstances")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeInstancesInputSet
      ####
      def new_input_set()
        return DescribeInstancesInputSet.new()
      end

      def make_result_set()
        return DescribeInstancesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeInstancesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeInstances
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeInstancesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the FilterName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of a supported filter to narrow results with.
        ###

        def set_FilterName(value)
          set_input("FilterName", value)
        end
        #### 
        # Set the value of the FilterValue input for this Choreo. 
        # 
        # @param String - (optional, string) A value for the specified filter.
        ###

        def set_FilterValue(value)
          set_input("FilterValue", value)
        end
        #### 
        # Set the value of the InstanceId input for this Choreo. 
        # 
        # @param String - (optional, string) The ID(s) of the instance(s) you want to monitor. This can be a comma-separated list of up to 10 instance IDs.  Returns all instances if this parameter is not specified.
        ###

        def set_InstanceId(value)
          set_input("InstanceId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeInstances Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeInstancesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeInstances



    ##############################################################################
    #
    # DescribeKeyPairs
    #
    # Queries the Amazon EC2 API to describe one or more of your key pairs.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeKeyPairs < Choreography

      ####
      #  Create a new instance of the DescribeKeyPairs Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DescribeKeyPairs")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeKeyPairsInputSet
      ####
      def new_input_set()
        return DescribeKeyPairsInputSet.new()
      end

      def make_result_set()
        return DescribeKeyPairsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeKeyPairsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeKeyPairs
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeKeyPairsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the FilterName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of a supported filter to narrow the results with.
        ###

        def set_FilterName(value)
          set_input("FilterName", value)
        end
        #### 
        # Set the value of the FilterValue input for this Choreo. 
        # 
        # @param String - (optional, string) A value for the specified filter.
        ###

        def set_FilterValue(value)
          set_input("FilterValue", value)
        end
        #### 
        # Set the value of the KeyName input for this Choreo. 
        # 
        # @param String - (optional, string) One or more key pair names to return. This can be a comma-separated list of up to 10 key pair namess.
        ###

        def set_KeyName(value)
          set_input("KeyName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeKeyPairs Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeKeyPairsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeKeyPairs



    ##############################################################################
    #
    # DescribeRegions
    #
    # Queries the Amazon EC2 API to describe one or more regions that are currently available to you.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeRegions < Choreography

      ####
      #  Create a new instance of the DescribeRegions Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DescribeRegions")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeRegionsInputSet
      ####
      def new_input_set()
        return DescribeRegionsInputSet.new()
      end

      def make_result_set()
        return DescribeRegionsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeRegionsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeRegions
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeRegionsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the FilterName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of a supported filter to narrow results with.
        ###

        def set_FilterName(value)
          set_input("FilterName", value)
        end
        #### 
        # Set the value of the FilterValue input for this Choreo. 
        # 
        # @param String - (optional, string) A value for the specified filter.
        ###

        def set_FilterValue(value)
          set_input("FilterValue", value)
        end
        #### 
        # Set the value of the RegionName input for this Choreo. 
        # 
        # @param String - (optional, string) One or more region names. This can be a comma-separated list of up to 10 region names.
        ###

        def set_RegionName(value)
          set_input("RegionName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeRegions Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeRegionsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeRegions



    ##############################################################################
    #
    # DescribeSecurityGroups
    #
    # Queries the Amazon EC2 API to return security group information associated with your AWS Account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeSecurityGroups < Choreography

      ####
      #  Create a new instance of the DescribeSecurityGroups Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DescribeSecurityGroups")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeSecurityGroupsInputSet
      ####
      def new_input_set()
        return DescribeSecurityGroupsInputSet.new()
      end

      def make_result_set()
        return DescribeSecurityGroupsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeSecurityGroupsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeSecurityGroups
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeSecurityGroupsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the FilterName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of a supported filter to narrow results with.
        ###

        def set_FilterName(value)
          set_input("FilterName", value)
        end
        #### 
        # Set the value of the FilterValue input for this Choreo. 
        # 
        # @param String - (optional, string) A value for the specified filter.
        ###

        def set_FilterValue(value)
          set_input("FilterValue", value)
        end
        #### 
        # Set the value of the GroupId input for this Choreo. 
        # 
        # @param String - (optional, string) One or more security group IDs.  This can be a comma-separated list of up to 10 GroupIDs.  If no group names nor group IDs supplied, returns all groups.
        ###

        def set_GroupId(value)
          set_input("GroupId", value)
        end
        #### 
        # Set the value of the GroupName input for this Choreo. 
        # 
        # @param String - (optional, string) One or more security group names. This can be a comma-separated list of up to 10 group names.  If no group names nor group IDs supplied, returns all groups.
        ###

        def set_GroupName(value)
          set_input("GroupName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeSecurityGroups Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeSecurityGroupsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeSecurityGroups



    ##############################################################################
    #
    # DescribeSnapshots
    #
    # Queries the Amazon EC2 API to return information on available Amazon EBS snapshots.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeSnapshots < Choreography

      ####
      #  Create a new instance of the DescribeSnapshots Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DescribeSnapshots")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeSnapshotsInputSet
      ####
      def new_input_set()
        return DescribeSnapshotsInputSet.new()
      end

      def make_result_set()
        return DescribeSnapshotsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeSnapshotsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeSnapshots
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeSnapshotsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the FilterName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of a supported filter to narrow results with.
        ###

        def set_FilterName(value)
          set_input("FilterName", value)
        end
        #### 
        # Set the value of the FilterValue input for this Choreo. 
        # 
        # @param String - (optional, string) A value for the specified filter.
        ###

        def set_FilterValue(value)
          set_input("FilterValue", value)
        end
        #### 
        # Set the value of the Owner input for this Choreo. 
        # 
        # @param String - (conditional, string) Returns the snapshots owned by the specified owner. Valid values are: "self" (the default), "amazon", or an AWS Account ID.
        ###

        def set_Owner(value)
          set_input("Owner", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the RestorableBy input for this Choreo. 
        # 
        # @param String - (optional, string) AWS accounts ID that can create volumes from the snapshot.
        ###

        def set_RestorableBy(value)
          set_input("RestorableBy", value)
        end
        #### 
        # Set the value of the SnapshotId input for this Choreo. 
        # 
        # @param String - (optional, string) The ID of the snapshot you want to retrieve. Returns all snapshots if not specified.
        ###

        def set_SnapshotId(value)
          set_input("SnapshotId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeSnapshots Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeSnapshotsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeSnapshots



    ##############################################################################
    #
    # DescribeTags
    #
    # Queries the Amazon EC2 API to describe one or more of the tags for your EC2 resources. 
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeTags < Choreography

      ####
      #  Create a new instance of the DescribeTags Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DescribeTags")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeTagsInputSet
      ####
      def new_input_set()
        return DescribeTagsInputSet.new()
      end

      def make_result_set()
        return DescribeTagsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeTagsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeTags
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeTagsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the FilterName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of a supported filter to narrow results with.
        ###

        def set_FilterName(value)
          set_input("FilterName", value)
        end
        #### 
        # Set the value of the FilterValue input for this Choreo. 
        # 
        # @param String - (optional, string) A value for the specified filter.
        ###

        def set_FilterValue(value)
          set_input("FilterValue", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeTags Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeTagsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeTags



    ##############################################################################
    #
    # DescribeVolumes
    #
    # Queries the Amazon EC2 API to return information for one or more of your Amazon EBS volumes.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeVolumes < Choreography

      ####
      #  Create a new instance of the DescribeVolumes Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DescribeVolumes")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeVolumesInputSet
      ####
      def new_input_set()
        return DescribeVolumesInputSet.new()
      end

      def make_result_set()
        return DescribeVolumesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeVolumesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeVolumes
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeVolumesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the FilterName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of a supported filter to narrow results with.
        ###

        def set_FilterName(value)
          set_input("FilterName", value)
        end
        #### 
        # Set the value of the FilterValue input for this Choreo. 
        # 
        # @param String - (optional, string) A value for the specified filter.
        ###

        def set_FilterValue(value)
          set_input("FilterValue", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the VolumeId input for this Choreo. 
        # 
        # @param String - (conditional, string) The ID of the volume to return. This can be a comma-separated list of up to 10 volume IDs.
        ###

        def set_VolumeId(value)
          set_input("VolumeId", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeVolumes Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeVolumesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeVolumes



    ##############################################################################
    #
    # DetachVolume
    #
    # Detaches an Amazon EBS volume from an instance using the Amazon EC2 API.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DetachVolume < Choreography

      ####
      #  Create a new instance of the DetachVolume Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DetachVolume")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DetachVolumeInputSet
      ####
      def new_input_set()
        return DetachVolumeInputSet.new()
      end

      def make_result_set()
        return DetachVolumeResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DetachVolumeResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DetachVolume
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DetachVolumeInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Device input for this Choreo. 
        # 
        # @param String - (optional, string) The device name.
        ###

        def set_Device(value)
          set_input("Device", value)
        end
        #### 
        # Set the value of the Force input for this Choreo. 
        # 
        # @param Boolean - (required, boolean) Forces detachment if the previous detachment attempt did not occur cleanly. Use this option only as a last resort to detach a volume from a failed instance. Defaults to false.
        ###

        def set_Force(value)
          set_input("Force", value)
        end
        #### 
        # Set the value of the InstanceId input for this Choreo. 
        # 
        # @param String - (optional, string) The ID of the instance.
        ###

        def set_InstanceId(value)
          set_input("InstanceId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the VolumeId input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the volume.
        ###

        def set_VolumeId(value)
          set_input("VolumeId", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DetachVolume Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DetachVolumeResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DetachVolume



    ##############################################################################
    #
    # DisassociateAddress
    #
    # Disassociates an Elastic IP address from the instance or network interface it's associated with using the Amazon EC2 API.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DisassociateAddress < Choreography

      ####
      #  Create a new instance of the DisassociateAddress Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/DisassociateAddress")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DisassociateAddressInputSet
      ####
      def new_input_set()
        return DisassociateAddressInputSet.new()
      end

      def make_result_set()
        return DisassociateAddressResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DisassociateAddressResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DisassociateAddress
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DisassociateAddressInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AssociationId input for this Choreo. 
        # 
        # @param String - (conditional, string) [EC2-VPC] The association ID corresponding to the Elastic IP address.
        ###

        def set_AssociationId(value)
          set_input("AssociationId", value)
        end
        #### 
        # Set the value of the PublicIp input for this Choreo. 
        # 
        # @param String - (conditional, string) [EC2-Classic] The Elastic IP address.
        ###

        def set_PublicIp(value)
          set_input("PublicIp", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DisassociateAddress Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DisassociateAddressResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DisassociateAddress



    ##############################################################################
    #
    # ImportKeyPair
    #
    # Calls the Amazon EC2 API to import the public key from an RSA key pair that you created with a third-party tool.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ImportKeyPair < Choreography

      ####
      #  Create a new instance of the ImportKeyPair Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/ImportKeyPair")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ImportKeyPairInputSet
      ####
      def new_input_set()
        return ImportKeyPairInputSet.new()
      end

      def make_result_set()
        return ImportKeyPairResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ImportKeyPairResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ImportKeyPair
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ImportKeyPairInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the KeyName input for this Choreo. 
        # 
        # @param String - (required, string) A unique name for the key pair.
        ###

        def set_KeyName(value)
          set_input("KeyName", value)
        end
        #### 
        # Set the value of the PublicKeyMaterial input for this Choreo. 
        # 
        # @param String - (required, string) The public key. You must Base64-encode the public key material before sending it to AWS.
        ###

        def set_PublicKeyMaterial(value)
          set_input("PublicKeyMaterial", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ImportKeyPair Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ImportKeyPairResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ImportKeyPair



    ##############################################################################
    #
    # ModifyImageAttribute
    #
    # Modifies an attribute of an AMI using the Amazon EC2 API.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ModifyImageAttribute < Choreography

      ####
      #  Create a new instance of the ModifyImageAttribute Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/ModifyImageAttribute")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ModifyImageAttributeInputSet
      ####
      def new_input_set()
        return ModifyImageAttributeInputSet.new()
      end

      def make_result_set()
        return ModifyImageAttributeResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ModifyImageAttributeResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ModifyImageAttribute
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ModifyImageAttributeInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AddGroup input for this Choreo. 
        # 
        # @param String - (optional, string) Adds the specified group to the image's list of launch permissions. The only valid value is "all".
        ###

        def set_AddGroup(value)
          set_input("AddGroup", value)
        end
        #### 
        # Set the value of the AddUserId input for this Choreo. 
        # 
        # @param String - (optional, string) Adds the specified AWS account ID to the AMI's list of launch permissions.
        ###

        def set_AddUserId(value)
          set_input("AddUserId", value)
        end
        #### 
        # Set the value of the Description input for this Choreo. 
        # 
        # @param String - (optional, string) Changes the AMI's description to the specified value.
        ###

        def set_Description(value)
          set_input("Description", value)
        end
        #### 
        # Set the value of the ImageId input for this Choreo. 
        # 
        # @param String - (required, string) The AMI ID.
        ###

        def set_ImageId(value)
          set_input("ImageId", value)
        end
        #### 
        # Set the value of the ProductCode input for this Choreo. 
        # 
        # @param String - (optional, string) Adds the specified product code to the specified Amazon S3-backed AMI. Once you add a product code to an AMI, it can't be removed.
        ###

        def set_ProductCode(value)
          set_input("ProductCode", value)
        end
        #### 
        # Set the value of the RemoveGroup input for this Choreo. 
        # 
        # @param String - (optional, string) Removes the specified group from the image's list of launch permissions. The only valid value is "all".
        ###

        def set_RemoveGroup(value)
          set_input("RemoveGroup", value)
        end
        #### 
        # Set the value of the RemoveUserId input for this Choreo. 
        # 
        # @param String - (optional, string) Removes the specified AWS account ID from the AMI's list of launch permissions.
        ###

        def set_RemoveUserId(value)
          set_input("RemoveUserId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ModifyImageAttribute Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ModifyImageAttributeResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ModifyImageAttribute



    ##############################################################################
    #
    # MonitorInstances
    #
    # Enables monitoring for a specified instance using the Amazon EC2 API.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class MonitorInstances < Choreography

      ####
      #  Create a new instance of the MonitorInstances Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/MonitorInstances")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return MonitorInstancesInputSet
      ####
      def new_input_set()
        return MonitorInstancesInputSet.new()
      end

      def make_result_set()
        return MonitorInstancesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = MonitorInstancesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the MonitorInstances
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class MonitorInstancesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the InstanceId input for this Choreo. 
        # 
        # @param String - (required, string) The ID(s) of the instance(s) you want to monitor. This can be a comma-separated list of up to 10 instance IDs.
        ###

        def set_InstanceId(value)
          set_input("InstanceId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the MonitorInstances Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class MonitorInstancesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class MonitorInstances



    ##############################################################################
    #
    # RebootInstances
    #
    # Calls the Amazon EC2 API to reboot an instance by specifying the instance ID.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RebootInstances < Choreography

      ####
      #  Create a new instance of the RebootInstances Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/RebootInstances")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RebootInstancesInputSet
      ####
      def new_input_set()
        return RebootInstancesInputSet.new()
      end

      def make_result_set()
        return RebootInstancesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RebootInstancesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RebootInstances
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RebootInstancesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the InstanceId input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the instance to reboot. This can be a comma-separated list of up to 10 instance IDs.
        ###

        def set_InstanceId(value)
          set_input("InstanceId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RebootInstances Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RebootInstancesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class RebootInstances



    ##############################################################################
    #
    # RegisterImage
    #
    # Registers a new AMI with Amazon EC2 using the Amazon EC2 API.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RegisterImage < Choreography

      ####
      #  Create a new instance of the RegisterImage Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/RegisterImage")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RegisterImageInputSet
      ####
      def new_input_set()
        return RegisterImageInputSet.new()
      end

      def make_result_set()
        return RegisterImageResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RegisterImageResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RegisterImage
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RegisterImageInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Architecture input for this Choreo. 
        # 
        # @param String - (optional, string) The architecture of the image. Valid values are: i386 or x86_64. Defaults to i386.
        ###

        def set_Architecture(value)
          set_input("Architecture", value)
        end
        #### 
        # Set the value of the DeleteOnTermination input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Whether the Amazon EBS volume is deleted on instance termination. Defaults to true.
        ###

        def set_DeleteOnTermination(value)
          set_input("DeleteOnTermination", value)
        end
        #### 
        # Set the value of the Description input for this Choreo. 
        # 
        # @param String - (optional, string) The description of the AMI.
        ###

        def set_Description(value)
          set_input("Description", value)
        end
        #### 
        # Set the value of the DeviceName input for this Choreo. 
        # 
        # @param String - (conditional, string) If registering an Amazon EBS-backed AMI from a snapshot, specify this input with the root device name (e.g., /dev/sda1, or xvda), and SnapshotId.
        ###

        def set_DeviceName(value)
          set_input("DeviceName", value)
        end
        #### 
        # Set the value of the ImageLocation input for this Choreo. 
        # 
        # @param String - (conditional, string) Full path to your AMI manifest in Amazon S3 storage. Required if registering an Amazon-S3 backed AMI.
        ###

        def set_ImageLocation(value)
          set_input("ImageLocation", value)
        end
        #### 
        # Set the value of the Iops input for this Choreo. 
        # 
        # @param Integer - (conditional, integer) The number of I/O operations per second (IOPS) that the volume supports. A valid range is: 100 to 2000.
        ###

        def set_Iops(value)
          set_input("Iops", value)
        end
        #### 
        # Set the value of the KernelId input for this Choreo. 
        # 
        # @param String - (optional, string) The ID of the kernel to select.
        ###

        def set_KernelId(value)
          set_input("KernelId", value)
        end
        #### 
        # Set the value of the Name input for this Choreo. 
        # 
        # @param String - (required, string) A name for your AMI.
        ###

        def set_Name(value)
          set_input("Name", value)
        end
        #### 
        # Set the value of the NoDevice input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Specifies that no device should be mapped. Defaults to 1 (true).
        ###

        def set_NoDevice(value)
          set_input("NoDevice", value)
        end
        #### 
        # Set the value of the RamdiskId input for this Choreo. 
        # 
        # @param String - (optional, string) The ID of the RAM disk to select.
        ###

        def set_RamdiskId(value)
          set_input("RamdiskId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the RootDeviceName input for this Choreo. 
        # 
        # @param String - (conditional, string) The root device name (e.g., /dev/sda1, or xvda). Required if registering an Amazon EBS-backed AMI.
        ###

        def set_RootDeviceName(value)
          set_input("RootDeviceName", value)
        end
        #### 
        # Set the value of the SnapshotId input for this Choreo. 
        # 
        # @param String - (conditional, string) If registering an Amazon EBS-backed AMI from a snapshot, you must at least specify this input with the snapshot ID, and DeviceName with the root device name.
        ###

        def set_SnapshotId(value)
          set_input("SnapshotId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the VirtualName input for this Choreo. 
        # 
        # @param String - (optional, string) The virtual device name.
        ###

        def set_VirtualName(value)
          set_input("VirtualName", value)
        end
        #### 
        # Set the value of the VolumeSize input for this Choreo. 
        # 
        # @param Integer - (conditional, integer) The size of the volume, in GiBs. Required if you are not creating a volume from a snapshot.
        ###

        def set_VolumeSize(value)
          set_input("VolumeSize", value)
        end
        #### 
        # Set the value of the VolumeType input for this Choreo. 
        # 
        # @param String - (optional, string) The volume type. Valid values are: standard and io.
        ###

        def set_VolumeType(value)
          set_input("VolumeType", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RegisterImage Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RegisterImageResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class RegisterImage



    ##############################################################################
    #
    # ReleaseAddress
    #
    # Calls the Amazon EC2 API to release an Elastic IP address allocated to your account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ReleaseAddress < Choreography

      ####
      #  Create a new instance of the ReleaseAddress Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/ReleaseAddress")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ReleaseAddressInputSet
      ####
      def new_input_set()
        return ReleaseAddressInputSet.new()
      end

      def make_result_set()
        return ReleaseAddressResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ReleaseAddressResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ReleaseAddress
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ReleaseAddressInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AllocationId input for this Choreo. 
        # 
        # @param String - (conditional, string) [EC2-VPC] The allocation ID that AWS provided when you allocated the address for use with a VPC.
        ###

        def set_AllocationId(value)
          set_input("AllocationId", value)
        end
        #### 
        # Set the value of the PublicIp input for this Choreo. 
        # 
        # @param String - (conditional, string) [EC2-Classic] The Elastic IP address.
        ###

        def set_PublicIp(value)
          set_input("PublicIp", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ReleaseAddress Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ReleaseAddressResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ReleaseAddress



    ##############################################################################
    #
    # RevokeSecurityGroupIngress
    #
    # Removes one or more ingress rules from a security group using the Amazon EC2 API.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RevokeSecurityGroupIngress < Choreography

      ####
      #  Create a new instance of the RevokeSecurityGroupIngress Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/RevokeSecurityGroupIngress")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RevokeSecurityGroupIngressInputSet
      ####
      def new_input_set()
        return RevokeSecurityGroupIngressInputSet.new()
      end

      def make_result_set()
        return RevokeSecurityGroupIngressResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RevokeSecurityGroupIngressResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RevokeSecurityGroupIngress
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RevokeSecurityGroupIngressInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the GroupId input for this Choreo. 
        # 
        # @param String - (conditional, string) The ID of the security group to modify. Can be used instead of GroupName.
        ###

        def set_GroupId(value)
          set_input("GroupId", value)
        end
        #### 
        # Set the value of the GroupName input for this Choreo. 
        # 
        # @param String - (conditional, string) The name of the security group to modify. Can be used instead of GroupId.
        ###

        def set_GroupName(value)
          set_input("GroupName", value)
        end
        #### 
        # Set the value of the IpPermissionsCidrIp input for this Choreo. 
        # 
        # @param String - (optional, string) The CIDR range. Cannot be used when specifying a source security group.
        ###

        def set_IpPermissionsCidrIp(value)
          set_input("IpPermissionsCidrIp", value)
        end
        #### 
        # Set the value of the IpPermissionsFromPort input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The start of port range for the TCP and UDP protocols, or an ICMP type number. For the ICMP type number, you can use -1 to specify all ICMP types.
        ###

        def set_IpPermissionsFromPort(value)
          set_input("IpPermissionsFromPort", value)
        end
        #### 
        # Set the value of the IpPermissionsGroupId input for this Choreo. 
        # 
        # @param String - (optional, string) The ID of the source security group. Cannot be used when specifying a CIDR IP address.
        ###

        def set_IpPermissionsGroupId(value)
          set_input("IpPermissionsGroupId", value)
        end
        #### 
        # Set the value of the IpPermissionsGroupName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the source security group. Cannot be used when specifying a CIDR IP address.
        ###

        def set_IpPermissionsGroupName(value)
          set_input("IpPermissionsGroupName", value)
        end
        #### 
        # Set the value of the IpPermissionsIpProtocol input for this Choreo. 
        # 
        # @param String - (required, string) The IP protocol name or number. Valid values for EC2-Classic: tcp, udp, icmp (or 6, 17, 1). Valid values for EC2-VPC: tcp, udp, icmp, any valid protocol number (0-254), or -1 (to specify all).
        ###

        def set_IpPermissionsIpProtocol(value)
          set_input("IpPermissionsIpProtocol", value)
        end
        #### 
        # Set the value of the IpPermissionsToPort input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The end of port range for the TCP and UDP protocols, or an ICMP code number. For the ICMP code number, you can use -1 to specify all ICMP codes for the given ICMP type.
        ###

        def set_IpPermissionsToPort(value)
          set_input("IpPermissionsToPort", value)
        end
        #### 
        # Set the value of the IpPermissionsUserId input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS account ID that owns the source security group. Cannot be used when specifying a CIDR IP address.
        ###

        def set_IpPermissionsUserId(value)
          set_input("IpPermissionsUserId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RevokeSecurityGroupIngress Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RevokeSecurityGroupIngressResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class RevokeSecurityGroupIngress



    ##############################################################################
    #
    # RunInstances
    #
    # Calls the Amazon EC2 API to launch the specified number of instances of an AMI for which you have permissions.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RunInstances < Choreography

      ####
      #  Create a new instance of the RunInstances Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/RunInstances")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RunInstancesInputSet
      ####
      def new_input_set()
        return RunInstancesInputSet.new()
      end

      def make_result_set()
        return RunInstancesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RunInstancesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RunInstances
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RunInstancesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the DeleteOnTermination input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Sets whether the volume is deleted on instance termination. Defaults to "true". This is a Block Device Mapping parameter.
        ###

        def set_DeleteOnTermination(value)
          set_input("DeleteOnTermination", value)
        end
        #### 
        # Set the value of the DeviceName input for this Choreo. 
        # 
        # @param String - (optional, string) The device name exposed to the instance (i.e. /dev/sdh or xvdh). This is a Block Device Mapping parameter.
        ###

        def set_DeviceName(value)
          set_input("DeviceName", value)
        end
        #### 
        # Set the value of the ImageId input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the AMI.
        ###

        def set_ImageId(value)
          set_input("ImageId", value)
        end
        #### 
        # Set the value of the InstanceType input for this Choreo. 
        # 
        # @param String - (optional, string) The instance type (i.e. t1.micro, m1.small, m1.medium, m1.large, m1.xlarge). Default is m1.small.
        ###

        def set_InstanceType(value)
          set_input("InstanceType", value)
        end
        #### 
        # Set the value of the Iops input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The number of I/O operations per second (IOPS) that the volume supports. Valid range is 100 to 2000. This is a Block Device Mapping parameter.
        ###

        def set_Iops(value)
          set_input("Iops", value)
        end
        #### 
        # Set the value of the KernelId input for this Choreo. 
        # 
        # @param String - (optional, string) The ID of the kernel with which to launch the instance.
        ###

        def set_KernelId(value)
          set_input("KernelId", value)
        end
        #### 
        # Set the value of the KeyName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the key pair to use.
        ###

        def set_KeyName(value)
          set_input("KeyName", value)
        end
        #### 
        # Set the value of the MaxCount input for this Choreo. 
        # 
        # @param Integer - (required, integer) The maximum number of instances to launch. If the value is more than Amazon EC2 can launch, the largest possible number above MinCount will be launched instead.
        ###

        def set_MaxCount(value)
          set_input("MaxCount", value)
        end
        #### 
        # Set the value of the MinCount input for this Choreo. 
        # 
        # @param Integer - (required, integer) The minimum number of instances to launch. If the value is more than Amazon EC2 can launch, no instances are launched at all.
        ###

        def set_MinCount(value)
          set_input("MinCount", value)
        end
        #### 
        # Set the value of the MonitoringEnabled input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Enables monitoring for the instance. Defaults to false.
        ###

        def set_MonitoringEnabled(value)
          set_input("MonitoringEnabled", value)
        end
        #### 
        # Set the value of the NoDevice input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Suppresses a device mapping. This is a Block Device Mapping parameter.
        ###

        def set_NoDevice(value)
          set_input("NoDevice", value)
        end
        #### 
        # Set the value of the PlacementAvailabilityZone input for this Choreo. 
        # 
        # @param String - (optional, string) The Availability Zone to launch the instance into.
        ###

        def set_PlacementAvailabilityZone(value)
          set_input("PlacementAvailabilityZone", value)
        end
        #### 
        # Set the value of the PlacementGroupName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of an existing placement group you want to launch the instance into (for cluster instances).
        ###

        def set_PlacementGroupName(value)
          set_input("PlacementGroupName", value)
        end
        #### 
        # Set the value of the PlacementTenancy input for this Choreo. 
        # 
        # @param String - (optional, string) The tenancy of the instance. When set to "dedicated", the instance will run on single-tenant hardware and can only be launched into a VPC.
        ###

        def set_PlacementTenancy(value)
          set_input("PlacementTenancy", value)
        end
        #### 
        # Set the value of the RamdiskId input for this Choreo. 
        # 
        # @param String - (optional, string) The ID of the RAM disk.
        ###

        def set_RamdiskId(value)
          set_input("RamdiskId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SecurityGroup input for this Choreo. 
        # 
        # @param String - (optional, string) One or more security group names. This can be a comma-separated list of up to 10 security group names.
        ###

        def set_SecurityGroup(value)
          set_input("SecurityGroup", value)
        end
        #### 
        # Set the value of the SecurityGroupId input for this Choreo. 
        # 
        # @param String - (optional, string) One or more security group IDs. This can be a comma-separated list of up to 10 security group ids.
        ###

        def set_SecurityGroupId(value)
          set_input("SecurityGroupId", value)
        end
        #### 
        # Set the value of the ShutdownBehavior input for this Choreo. 
        # 
        # @param String - (optional, string) Whether the instance stops or terminates on instance-initiated shutdown. Valid values are: stop and terminate.
        ###

        def set_ShutdownBehavior(value)
          set_input("ShutdownBehavior", value)
        end
        #### 
        # Set the value of the SnapshotId input for this Choreo. 
        # 
        # @param String - (optional, string) The ID of the snapshot. This is a Block Device Mapping parameter.
        ###

        def set_SnapshotId(value)
          set_input("SnapshotId", value)
        end
        #### 
        # Set the value of the SubnetId input for this Choreo. 
        # 
        # @param String - (optional, string) The ID of the subnet to launch the instance into (i.e. subnet-dea63cb7).
        ###

        def set_SubnetId(value)
          set_input("SubnetId", value)
        end
        #### 
        # Set the value of the UserData input for this Choreo. 
        # 
        # @param String - (optional, string) The Base64-encoded MIME user data to be made available to the instance(s).
        ###

        def set_UserData(value)
          set_input("UserData", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the VirtualName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the virtual device. This is a Block Device Mapping parameter.
        ###

        def set_VirtualName(value)
          set_input("VirtualName", value)
        end
        #### 
        # Set the value of the VolumeSize input for this Choreo. 
        # 
        # @param String - (optional, string) The size of the volume, in GiBs. Required unless you're creating the volume from a snapshot which indicates that the size will be the size of the snapshot. This is a Block Device Mapping parameter.
        ###

        def set_VolumeSize(value)
          set_input("VolumeSize", value)
        end
        #### 
        # Set the value of the VolumeType input for this Choreo. 
        # 
        # @param String - (optional, string) The volume type. Valid values are: standard (the default) and io1. This is a Block Device Mapping parameter.
        ###

        def set_VolumeType(value)
          set_input("VolumeType", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RunInstances Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RunInstancesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class RunInstances



    ##############################################################################
    #
    # StartInstances
    #
    # Allows you to start an Amazon Machine Image by specifying its instance ID using the Amazon EC2 API.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class StartInstances < Choreography

      ####
      #  Create a new instance of the StartInstances Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/StartInstances")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return StartInstancesInputSet
      ####
      def new_input_set()
        return StartInstancesInputSet.new()
      end

      def make_result_set()
        return StartInstancesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = StartInstancesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the StartInstances
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class StartInstancesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the InstanceId input for this Choreo. 
        # 
        # @param String - (required, string) The instance ID to start. This can be a comma-separated list of up to 10 instance IDs.
        ###

        def set_InstanceId(value)
          set_input("InstanceId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the StartInstances Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class StartInstancesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class StartInstances



    ##############################################################################
    #
    # StopInstances
    #
    # Calls the Amazon EC2 API to stop an Amazon EBS-backed instance.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class StopInstances < Choreography

      ####
      #  Create a new instance of the StopInstances Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/StopInstances")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return StopInstancesInputSet
      ####
      def new_input_set()
        return StopInstancesInputSet.new()
      end

      def make_result_set()
        return StopInstancesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = StopInstancesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the StopInstances
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class StopInstancesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the InstanceId input for this Choreo. 
        # 
        # @param String - (required, string) The instance ID to stop. This can be a comma-separated list of up to 10 instance IDs.
        ###

        def set_InstanceId(value)
          set_input("InstanceId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the StopInstances Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class StopInstancesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class StopInstances



    ##############################################################################
    #
    # TerminateInstances
    #
    # Shuts down one or more instances using the Amazon EC2 API.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class TerminateInstances < Choreography

      ####
      #  Create a new instance of the TerminateInstances Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/TerminateInstances")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return TerminateInstancesInputSet
      ####
      def new_input_set()
        return TerminateInstancesInputSet.new()
      end

      def make_result_set()
        return TerminateInstancesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = TerminateInstancesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the TerminateInstances
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class TerminateInstancesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the InstanceId input for this Choreo. 
        # 
        # @param String - (required, string) The instance ID to terminate. This can be a comma-separated list of up to 10 instance IDs.
        ###

        def set_InstanceId(value)
          set_input("InstanceId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the TerminateInstances Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class TerminateInstancesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class TerminateInstances



    ##############################################################################
    #
    # UnmonitorInstances
    #
    # Calls the Amazon EC2 API to disable monitoring for a specified instance.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UnmonitorInstances < Choreography

      ####
      #  Create a new instance of the UnmonitorInstances Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/EC2/UnmonitorInstances")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UnmonitorInstancesInputSet
      ####
      def new_input_set()
        return UnmonitorInstancesInputSet.new()
      end

      def make_result_set()
        return UnmonitorInstancesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UnmonitorInstancesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UnmonitorInstances
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UnmonitorInstancesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the InstanceId input for this Choreo. 
        # 
        # @param String - (required, string) The ID(s) of the instance(s) you want to stop monitoring. This can be a comma-separated list of up to 10 instance IDs.
        ###

        def set_InstanceId(value)
          set_input("InstanceId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the EC2 endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UnmonitorInstances Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UnmonitorInstancesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UnmonitorInstances




  end # module EC2

  module IAM



    ##############################################################################
    #
    # AddRoleToInstanceProfile
    #
    # Adds the specified role to the specified instance profile.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class AddRoleToInstanceProfile < Choreography

      ####
      #  Create a new instance of the AddRoleToInstanceProfile Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/AddRoleToInstanceProfile")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AddRoleToInstanceProfileInputSet
      ####
      def new_input_set()
        return AddRoleToInstanceProfileInputSet.new()
      end

      def make_result_set()
        return AddRoleToInstanceProfileResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AddRoleToInstanceProfileResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the AddRoleToInstanceProfile
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AddRoleToInstanceProfileInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the InstanceProfileName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the instance profile to update.
        ###

        def set_InstanceProfileName(value)
          set_input("InstanceProfileName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the RoleName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the role to add.
        ###

        def set_RoleName(value)
          set_input("RoleName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the AddRoleToInstanceProfile Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AddRoleToInstanceProfileResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class AddRoleToInstanceProfile



    ##############################################################################
    #
    # AddUserToGroup
    #
    # Adds a specified user to a specified group.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class AddUserToGroup < Choreography

      ####
      #  Create a new instance of the AddUserToGroup Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/AddUserToGroup")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AddUserToGroupInputSet
      ####
      def new_input_set()
        return AddUserToGroupInputSet.new()
      end

      def make_result_set()
        return AddUserToGroupResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AddUserToGroupResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the AddUserToGroup
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AddUserToGroupInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the GroupName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the group that the user will be added to.
        ###

        def set_GroupName(value)
          set_input("GroupName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the user to add.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the AddUserToGroup Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AddUserToGroupResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class AddUserToGroup



    ##############################################################################
    #
    # ChangePassword
    #
    # Allows the authenticating user to change their password.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ChangePassword < Choreography

      ####
      #  Create a new instance of the ChangePassword Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/ChangePassword")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ChangePasswordInputSet
      ####
      def new_input_set()
        return ChangePasswordInputSet.new()
      end

      def make_result_set()
        return ChangePasswordResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ChangePasswordResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ChangePassword
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ChangePasswordInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The user's Access Key ID.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The user's Secret Key ID.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the NewPassword input for this Choreo. 
        # 
        # @param String - (required, string) The new password.
        ###

        def set_NewPassword(value)
          set_input("NewPassword", value)
        end
        #### 
        # Set the value of the OldPassword input for this Choreo. 
        # 
        # @param String - (required, string) The old password.
        ###

        def set_OldPassword(value)
          set_input("OldPassword", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ChangePassword Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ChangePasswordResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ChangePassword



    ##############################################################################
    #
    # CreateAccessKey
    #
    # Creates a new AWS Secret Access Key and corresponding AWS Access Key ID for a specified user.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateAccessKey < Choreography

      ####
      #  Create a new instance of the CreateAccessKey Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/CreateAccessKey")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateAccessKeyInputSet
      ####
      def new_input_set()
        return CreateAccessKeyInputSet.new()
      end

      def make_result_set()
        return CreateAccessKeyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateAccessKeyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateAccessKey
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateAccessKeyInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (conditional, string) The user name that the new key will belong to.  If you do not specify a user name, IAM determines the user name implicitly based on the AWS Access Key ID signing the request. 
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateAccessKey Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateAccessKeyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateAccessKey



    ##############################################################################
    #
    # CreateAccountAlias
    #
    # Creates an alias for your AWS account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateAccountAlias < Choreography

      ####
      #  Create a new instance of the CreateAccountAlias Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/CreateAccountAlias")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateAccountAliasInputSet
      ####
      def new_input_set()
        return CreateAccountAliasInputSet.new()
      end

      def make_result_set()
        return CreateAccountAliasResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateAccountAliasResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateAccountAlias
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateAccountAliasInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AccountAlias input for this Choreo. 
        # 
        # @param String - (required, string) Name of the account alias to create. Must contain only digits, lowercase letters, and hyphens (-), but cannot begin or end with a hyphen. Ex.: alias-account-name.
        ###

        def set_AccountAlias(value)
          set_input("AccountAlias", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateAccountAlias Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateAccountAliasResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateAccountAlias



    ##############################################################################
    #
    # CreateGroup
    #
    # Creates a new group in your AWS account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateGroup < Choreography

      ####
      #  Create a new instance of the CreateGroup Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/CreateGroup")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateGroupInputSet
      ####
      def new_input_set()
        return CreateGroupInputSet.new()
      end

      def make_result_set()
        return CreateGroupResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateGroupResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateGroup
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateGroupInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the GroupName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the group to create.
        ###

        def set_GroupName(value)
          set_input("GroupName", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (optional, string) The path to the group. If it is not included, it defaults to a slash (/).
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateGroup Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateGroupResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateGroup



    ##############################################################################
    #
    # CreateInstanceProfile
    #
    # Creates a new instance profile.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateInstanceProfile < Choreography

      ####
      #  Create a new instance of the CreateInstanceProfile Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/CreateInstanceProfile")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateInstanceProfileInputSet
      ####
      def new_input_set()
        return CreateInstanceProfileInputSet.new()
      end

      def make_result_set()
        return CreateInstanceProfileResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateInstanceProfileResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateInstanceProfile
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateInstanceProfileInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the InstanceProfileName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the instance profile to create.
        ###

        def set_InstanceProfileName(value)
          set_input("InstanceProfileName", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (optional, string) The path for the user name. If it is not included, it defaults to a slash (/).
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateInstanceProfile Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateInstanceProfileResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateInstanceProfile



    ##############################################################################
    #
    # CreateLoginProfile
    #
    # Creates a password for the specified user, which gives the user the ability to access AWS services through the AWS Management Console.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateLoginProfile < Choreography

      ####
      #  Create a new instance of the CreateLoginProfile Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/CreateLoginProfile")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateLoginProfileInputSet
      ####
      def new_input_set()
        return CreateLoginProfileInputSet.new()
      end

      def make_result_set()
        return CreateLoginProfileResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateLoginProfileResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateLoginProfile
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateLoginProfileInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the MustChangePassword input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Whether or not the user is required to change their password immediately.  Valid values are true/false or 1/0.
        ###

        def set_MustChangePassword(value)
          set_input("MustChangePassword", value)
        end
        #### 
        # Set the value of the Password input for this Choreo. 
        # 
        # @param String - (required, string) The new password for the user.
        ###

        def set_Password(value)
          set_input("Password", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the user to create a password for.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateLoginProfile Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateLoginProfileResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateLoginProfile



    ##############################################################################
    #
    # CreateUser
    #
    # Creates a new user for your AWS account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateUser < Choreography

      ####
      #  Create a new instance of the CreateUser Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/CreateUser")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateUserInputSet
      ####
      def new_input_set()
        return CreateUserInputSet.new()
      end

      def make_result_set()
        return CreateUserResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateUserResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateUser
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateUserInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (optional, string) The path for the user name. If it is not included, it defaults to a slash (/).
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the user to create.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateUser Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateUserResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateUser



    ##############################################################################
    #
    # CreateVirtualMFADevice
    #
    # Creates a new virtual MFA device for the AWS account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateVirtualMFADevice < Choreography

      ####
      #  Create a new instance of the CreateVirtualMFADevice Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/CreateVirtualMFADevice")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateVirtualMFADeviceInputSet
      ####
      def new_input_set()
        return CreateVirtualMFADeviceInputSet.new()
      end

      def make_result_set()
        return CreateVirtualMFADeviceResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateVirtualMFADeviceResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateVirtualMFADevice
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateVirtualMFADeviceInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (optional, string) The path for the virtual MFA device. If it is not included, it defaults to a slash (/).
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the VirtualMFADeviceName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the virtual MFA device. Use with path to uniquely identify a virtual MFA device.
        ###

        def set_VirtualMFADeviceName(value)
          set_input("VirtualMFADeviceName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateVirtualMFADevice Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateVirtualMFADeviceResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateVirtualMFADevice



    ##############################################################################
    #
    # DeactivateMFADevice
    #
    # Deactivates the specified MFA device and removes it from association with the user name for which it was originally enabled.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeactivateMFADevice < Choreography

      ####
      #  Create a new instance of the DeactivateMFADevice Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/DeactivateMFADevice")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeactivateMFADeviceInputSet
      ####
      def new_input_set()
        return DeactivateMFADeviceInputSet.new()
      end

      def make_result_set()
        return DeactivateMFADeviceResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeactivateMFADeviceResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeactivateMFADevice
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeactivateMFADeviceInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SerialNumber input for this Choreo. 
        # 
        # @param String - (required, string) The serial number that uniquely identifies the MFA device. For virtual MFA devices, the serial number is the device ARN.
        ###

        def set_SerialNumber(value)
          set_input("SerialNumber", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the user whose MFA device you want to deactivate.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeactivateMFADevice Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeactivateMFADeviceResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeactivateMFADevice



    ##############################################################################
    #
    # DeleteAccessKey
    #
    # Deletes the access key associated with the specified user.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteAccessKey < Choreography

      ####
      #  Create a new instance of the DeleteAccessKey Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/DeleteAccessKey")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteAccessKeyInputSet
      ####
      def new_input_set()
        return DeleteAccessKeyInputSet.new()
      end

      def make_result_set()
        return DeleteAccessKeyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteAccessKeyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteAccessKey
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteAccessKeyInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) An AWS Access Key ID with sufficient permissions to delete the specified AccessKeyId.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID associated with the AWS AccessKey ID with sufficient permissions to delete the AccessKeyId.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AccessKeyId input for this Choreo. 
        # 
        # @param String - (conditional, string) The Access Key ID for the Access Key ID and Secret Access Key you want to delete.
        ###

        def set_AccessKeyId(value)
          set_input("AccessKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (conditional, string) Name of the user whose key you want to delete.  If you do not specify a user name, IAM determines the user name implicitly based on the AWS Access Key ID signing the request.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteAccessKey Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteAccessKeyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteAccessKey



    ##############################################################################
    #
    # DeleteAccountAlias
    #
    # Deletes the specified AWS account alias.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteAccountAlias < Choreography

      ####
      #  Create a new instance of the DeleteAccountAlias Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/DeleteAccountAlias")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteAccountAliasInputSet
      ####
      def new_input_set()
        return DeleteAccountAliasInputSet.new()
      end

      def make_result_set()
        return DeleteAccountAliasResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteAccountAliasResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteAccountAlias
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteAccountAliasInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AccountAlias input for this Choreo. 
        # 
        # @param String - (required, string) Name of the account alias to delete.
        ###

        def set_AccountAlias(value)
          set_input("AccountAlias", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteAccountAlias Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteAccountAliasResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteAccountAlias



    ##############################################################################
    #
    # DeleteAccountPasswordPolicy
    #
    # Deletes the password policy for the AWS account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteAccountPasswordPolicy < Choreography

      ####
      #  Create a new instance of the DeleteAccountPasswordPolicy Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/DeleteAccountPasswordPolicy")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteAccountPasswordPolicyInputSet
      ####
      def new_input_set()
        return DeleteAccountPasswordPolicyInputSet.new()
      end

      def make_result_set()
        return DeleteAccountPasswordPolicyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteAccountPasswordPolicyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteAccountPasswordPolicy
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteAccountPasswordPolicyInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteAccountPasswordPolicy Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteAccountPasswordPolicyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteAccountPasswordPolicy



    ##############################################################################
    #
    # DeleteGroup
    #
    # Deletes a specified group.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteGroup < Choreography

      ####
      #  Create a new instance of the DeleteGroup Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/DeleteGroup")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteGroupInputSet
      ####
      def new_input_set()
        return DeleteGroupInputSet.new()
      end

      def make_result_set()
        return DeleteGroupResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteGroupResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteGroup
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteGroupInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the GroupName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the group to delete.
        ###

        def set_GroupName(value)
          set_input("GroupName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteGroup Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteGroupResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteGroup



    ##############################################################################
    #
    # DeleteGroupPolicy
    #
    # Deletes the specified policy that is associated with the specified group.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteGroupPolicy < Choreography

      ####
      #  Create a new instance of the DeleteGroupPolicy Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/DeleteGroupPolicy")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteGroupPolicyInputSet
      ####
      def new_input_set()
        return DeleteGroupPolicyInputSet.new()
      end

      def make_result_set()
        return DeleteGroupPolicyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteGroupPolicyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteGroupPolicy
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteGroupPolicyInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the GroupName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the group the policy is associated with.
        ###

        def set_GroupName(value)
          set_input("GroupName", value)
        end
        #### 
        # Set the value of the PolicyName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the policy document.
        ###

        def set_PolicyName(value)
          set_input("PolicyName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteGroupPolicy Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteGroupPolicyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteGroupPolicy



    ##############################################################################
    #
    # DeleteInstanceProfile
    #
    # Deletes the specified instance profile. 
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteInstanceProfile < Choreography

      ####
      #  Create a new instance of the DeleteInstanceProfile Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/DeleteInstanceProfile")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteInstanceProfileInputSet
      ####
      def new_input_set()
        return DeleteInstanceProfileInputSet.new()
      end

      def make_result_set()
        return DeleteInstanceProfileResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteInstanceProfileResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteInstanceProfile
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteInstanceProfileInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the InstanceProfileName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the instance profile to delete.
        ###

        def set_InstanceProfileName(value)
          set_input("InstanceProfileName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteInstanceProfile Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteInstanceProfileResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteInstanceProfile



    ##############################################################################
    #
    # DeleteLoginProfile
    #
    # Deletes the password for the specified user, which terminates the user's ability to access AWS services through the AWS Management Console.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteLoginProfile < Choreography

      ####
      #  Create a new instance of the DeleteLoginProfile Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/DeleteLoginProfile")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteLoginProfileInputSet
      ####
      def new_input_set()
        return DeleteLoginProfileInputSet.new()
      end

      def make_result_set()
        return DeleteLoginProfileResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteLoginProfileResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteLoginProfile
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteLoginProfileInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the user whose login profile you want to delete.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteLoginProfile Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteLoginProfileResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteLoginProfile



    ##############################################################################
    #
    # DeleteRole
    #
    # Deletes the specified role.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteRole < Choreography

      ####
      #  Create a new instance of the DeleteRole Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/DeleteRole")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteRoleInputSet
      ####
      def new_input_set()
        return DeleteRoleInputSet.new()
      end

      def make_result_set()
        return DeleteRoleResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteRoleResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteRole
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteRoleInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the RoleName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the role to delete.
        ###

        def set_RoleName(value)
          set_input("RoleName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteRole Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteRoleResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteRole



    ##############################################################################
    #
    # DeleteRolePolicy
    #
    # Deletes the specified policy associated with the specified role.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteRolePolicy < Choreography

      ####
      #  Create a new instance of the DeleteRolePolicy Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/DeleteRolePolicy")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteRolePolicyInputSet
      ####
      def new_input_set()
        return DeleteRolePolicyInputSet.new()
      end

      def make_result_set()
        return DeleteRolePolicyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteRolePolicyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteRolePolicy
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteRolePolicyInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the PolicyName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the policy document.
        ###

        def set_PolicyName(value)
          set_input("PolicyName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the RoleName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the role the associated with the policy.
        ###

        def set_RoleName(value)
          set_input("RoleName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteRolePolicy Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteRolePolicyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteRolePolicy



    ##############################################################################
    #
    # DeleteServerCertificate
    #
    # Deletes the specified server certificate.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteServerCertificate < Choreography

      ####
      #  Create a new instance of the DeleteServerCertificate Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/DeleteServerCertificate")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteServerCertificateInputSet
      ####
      def new_input_set()
        return DeleteServerCertificateInputSet.new()
      end

      def make_result_set()
        return DeleteServerCertificateResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteServerCertificateResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteServerCertificate
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteServerCertificateInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the ServerCertificateName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the server certificate you want to delete.
        ###

        def set_ServerCertificateName(value)
          set_input("ServerCertificateName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteServerCertificate Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteServerCertificateResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteServerCertificate



    ##############################################################################
    #
    # DeleteSigningCertificate
    #
    # Deletes the specified signing certificate associated with the specified user.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteSigningCertificate < Choreography

      ####
      #  Create a new instance of the DeleteSigningCertificate Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/DeleteSigningCertificate")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteSigningCertificateInputSet
      ####
      def new_input_set()
        return DeleteSigningCertificateInputSet.new()
      end

      def make_result_set()
        return DeleteSigningCertificateResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteSigningCertificateResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteSigningCertificate
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteSigningCertificateInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the CertificateId input for this Choreo. 
        # 
        # @param String - (required, string) ID of the signing certificate to delete.
        ###

        def set_CertificateId(value)
          set_input("CertificateId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (optional, string) Name of the user the signing certificate belongs to.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteSigningCertificate Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteSigningCertificateResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteSigningCertificate



    ##############################################################################
    #
    # DeleteUser
    #
    # Deletes a specified user. The user must not belong to any groups, have any keys or signing certificates, or have any attached policies.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteUser < Choreography

      ####
      #  Create a new instance of the DeleteUser Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/DeleteUser")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteUserInputSet
      ####
      def new_input_set()
        return DeleteUserInputSet.new()
      end

      def make_result_set()
        return DeleteUserResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteUserResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteUser
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteUserInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the user to delete.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteUser Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteUserResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteUser



    ##############################################################################
    #
    # DeleteUserPolicy
    #
    # Deletes the specified policy associated with the specified user.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteUserPolicy < Choreography

      ####
      #  Create a new instance of the DeleteUserPolicy Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/DeleteUserPolicy")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteUserPolicyInputSet
      ####
      def new_input_set()
        return DeleteUserPolicyInputSet.new()
      end

      def make_result_set()
        return DeleteUserPolicyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteUserPolicyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteUserPolicy
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteUserPolicyInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the PolicyName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the user policy document you would like to delete.
        ###

        def set_PolicyName(value)
          set_input("PolicyName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the user to delete the specified policy for.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteUserPolicy Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteUserPolicyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteUserPolicy



    ##############################################################################
    #
    # DeleteVirtualMFADevice
    #
    # Deletes a virtual MFA device.  You must deactivate a user's virtual MFA device before you can delete it.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteVirtualMFADevice < Choreography

      ####
      #  Create a new instance of the DeleteVirtualMFADevice Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/DeleteVirtualMFADevice")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteVirtualMFADeviceInputSet
      ####
      def new_input_set()
        return DeleteVirtualMFADeviceInputSet.new()
      end

      def make_result_set()
        return DeleteVirtualMFADeviceResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteVirtualMFADeviceResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteVirtualMFADevice
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteVirtualMFADeviceInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SerialNumber input for this Choreo. 
        # 
        # @param String - (required, string) The serial number that uniquely identifies the MFA device. For virtual MFA devices, the serial number is the same as the ARN.
        ###

        def set_SerialNumber(value)
          set_input("SerialNumber", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteVirtualMFADevice Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteVirtualMFADeviceResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteVirtualMFADevice



    ##############################################################################
    #
    # EnableMFADevice
    #
    # Enables the specified MFA device and associates it with the specified user name. When enabled, the MFA device is required for every subsequent login by the user name associated with the device.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class EnableMFADevice < Choreography

      ####
      #  Create a new instance of the EnableMFADevice Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/EnableMFADevice")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return EnableMFADeviceInputSet
      ####
      def new_input_set()
        return EnableMFADeviceInputSet.new()
      end

      def make_result_set()
        return EnableMFADeviceResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = EnableMFADeviceResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the EnableMFADevice
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class EnableMFADeviceInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AuthenticationCode1 input for this Choreo. 
        # 
        # @param String - (required, string) An authentication code emitted by the device.
        ###

        def set_AuthenticationCode1(value)
          set_input("AuthenticationCode1", value)
        end
        #### 
        # Set the value of the AuthenticationCode2 input for this Choreo. 
        # 
        # @param String - (required, string) A subsequent authentication code emitted by the device.
        ###

        def set_AuthenticationCode2(value)
          set_input("AuthenticationCode2", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SerialNumber input for this Choreo. 
        # 
        # @param String - (required, string) The serial number that uniquely identifies the MFA device. For virtual MFA devices, the serial number is the same as the ARN.
        ###

        def set_SerialNumber(value)
          set_input("SerialNumber", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the user for whom you want to enable the MFA device.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the EnableMFADevice Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class EnableMFADeviceResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class EnableMFADevice



    ##############################################################################
    #
    # GetAccountPasswordPolicy
    #
    # Retrieves the password policy for the AWS account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetAccountPasswordPolicy < Choreography

      ####
      #  Create a new instance of the GetAccountPasswordPolicy Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/GetAccountPasswordPolicy")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetAccountPasswordPolicyInputSet
      ####
      def new_input_set()
        return GetAccountPasswordPolicyInputSet.new()
      end

      def make_result_set()
        return GetAccountPasswordPolicyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetAccountPasswordPolicyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetAccountPasswordPolicy
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetAccountPasswordPolicyInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetAccountPasswordPolicy Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetAccountPasswordPolicyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetAccountPasswordPolicy



    ##############################################################################
    #
    # GetAccountSummary
    #
    # Retrieves account level information about account entity usage and IAM quotas.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetAccountSummary < Choreography

      ####
      #  Create a new instance of the GetAccountSummary Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/GetAccountSummary")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetAccountSummaryInputSet
      ####
      def new_input_set()
        return GetAccountSummaryInputSet.new()
      end

      def make_result_set()
        return GetAccountSummaryResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetAccountSummaryResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetAccountSummary
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetAccountSummaryInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetAccountSummary Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetAccountSummaryResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetAccountSummary



    ##############################################################################
    #
    # GetGroup
    #
    # Returns a list of users that are in the specified group.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetGroup < Choreography

      ####
      #  Create a new instance of the GetGroup Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/GetGroup")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetGroupInputSet
      ####
      def new_input_set()
        return GetGroupInputSet.new()
      end

      def make_result_set()
        return GetGroupResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetGroupResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetGroup
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetGroupInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the GroupName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the group to return.
        ###

        def set_GroupName(value)
          set_input("GroupName", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param String - (optional, string) Used for pagination to indicate the starting point of the results to return.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxItems input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
        ###

        def set_MaxItems(value)
          set_input("MaxItems", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetGroup Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetGroupResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetGroup



    ##############################################################################
    #
    # GetGroupPolicy
    #
    # Retrieves the specified policy document for the specified group.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetGroupPolicy < Choreography

      ####
      #  Create a new instance of the GetGroupPolicy Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/GetGroupPolicy")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetGroupPolicyInputSet
      ####
      def new_input_set()
        return GetGroupPolicyInputSet.new()
      end

      def make_result_set()
        return GetGroupPolicyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetGroupPolicyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetGroupPolicy
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetGroupPolicyInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the GroupName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the group to return.
        ###

        def set_GroupName(value)
          set_input("GroupName", value)
        end
        #### 
        # Set the value of the PolicyName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the policy document to get.
        ###

        def set_PolicyName(value)
          set_input("PolicyName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetGroupPolicy Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetGroupPolicyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetGroupPolicy



    ##############################################################################
    #
    # GetInstanceProfile
    #
    # Retrieves information about the specified instance profile, including the instance profile's path, ARN, and RoleId.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetInstanceProfile < Choreography

      ####
      #  Create a new instance of the GetInstanceProfile Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/GetInstanceProfile")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetInstanceProfileInputSet
      ####
      def new_input_set()
        return GetInstanceProfileInputSet.new()
      end

      def make_result_set()
        return GetInstanceProfileResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetInstanceProfileResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetInstanceProfile
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetInstanceProfileInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the InstanceProfileName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the instance profile to get information about.
        ###

        def set_InstanceProfileName(value)
          set_input("InstanceProfileName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetInstanceProfile Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetInstanceProfileResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetInstanceProfile



    ##############################################################################
    #
    # GetLoginProfile
    #
    # Retrieves the user name and password create date for the specified user.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetLoginProfile < Choreography

      ####
      #  Create a new instance of the GetLoginProfile Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/GetLoginProfile")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetLoginProfileInputSet
      ####
      def new_input_set()
        return GetLoginProfileInputSet.new()
      end

      def make_result_set()
        return GetLoginProfileResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetLoginProfileResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetLoginProfile
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetLoginProfileInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the user whose login profile you want to retrieve.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetLoginProfile Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetLoginProfileResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetLoginProfile



    ##############################################################################
    #
    # GetRole
    #
    # Retrieves information about the specified role, including the role's path, ARN, RoleId, and the policy granting permission to EC2 to assume the role.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetRole < Choreography

      ####
      #  Create a new instance of the GetRole Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/GetRole")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetRoleInputSet
      ####
      def new_input_set()
        return GetRoleInputSet.new()
      end

      def make_result_set()
        return GetRoleResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetRoleResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetRole
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetRoleInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the RoleName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the role to get information about.
        ###

        def set_RoleName(value)
          set_input("RoleName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetRole Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetRoleResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetRole



    ##############################################################################
    #
    # GetRolePolicy
    #
    # Retrieves the specified policy document for the specified role.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetRolePolicy < Choreography

      ####
      #  Create a new instance of the GetRolePolicy Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/GetRolePolicy")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetRolePolicyInputSet
      ####
      def new_input_set()
        return GetRolePolicyInputSet.new()
      end

      def make_result_set()
        return GetRolePolicyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetRolePolicyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetRolePolicy
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetRolePolicyInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the PolicyName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the policy document to get.
        ###

        def set_PolicyName(value)
          set_input("PolicyName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the RoleName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the role associated with the policy.
        ###

        def set_RoleName(value)
          set_input("RoleName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetRolePolicy Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetRolePolicyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetRolePolicy



    ##############################################################################
    #
    # GetServerCertificate
    #
    # Retrieves information about the specified server certificate.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetServerCertificate < Choreography

      ####
      #  Create a new instance of the GetServerCertificate Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/GetServerCertificate")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetServerCertificateInputSet
      ####
      def new_input_set()
        return GetServerCertificateInputSet.new()
      end

      def make_result_set()
        return GetServerCertificateResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetServerCertificateResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetServerCertificate
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetServerCertificateInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the ServerCertificateName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the server certificate you want to retrieve information about.
        ###

        def set_ServerCertificateName(value)
          set_input("ServerCertificateName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetServerCertificate Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetServerCertificateResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetServerCertificate



    ##############################################################################
    #
    # GetUser
    #
    # Retrieves details about a specified user, including the user's path, GUID, and ARN.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetUser < Choreography

      ####
      #  Create a new instance of the GetUser Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/GetUser")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetUserInputSet
      ####
      def new_input_set()
        return GetUserInputSet.new()
      end

      def make_result_set()
        return GetUserResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetUserResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetUser
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetUserInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (conditional, string) The name of the user to retrieve. If you do not specify a user name, IAM determines the user name implicitly based on the AWS Access Key ID signing the request.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetUser Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetUserResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetUser



    ##############################################################################
    #
    # GetUserPolicy
    #
    # Retrieves the specified policy document for the specified user.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetUserPolicy < Choreography

      ####
      #  Create a new instance of the GetUserPolicy Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/GetUserPolicy")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetUserPolicyInputSet
      ####
      def new_input_set()
        return GetUserPolicyInputSet.new()
      end

      def make_result_set()
        return GetUserPolicyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetUserPolicyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetUserPolicy
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetUserPolicyInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the PolicyName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the policy document to get.
        ###

        def set_PolicyName(value)
          set_input("PolicyName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the user to retrieve.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetUserPolicy Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetUserPolicyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetUserPolicy



    ##############################################################################
    #
    # ListAccessKeys
    #
    # Returns information about the Access Key IDs associated with the specified user.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListAccessKeys < Choreography

      ####
      #  Create a new instance of the ListAccessKeys Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/ListAccessKeys")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListAccessKeysInputSet
      ####
      def new_input_set()
        return ListAccessKeysInputSet.new()
      end

      def make_result_set()
        return ListAccessKeysResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListAccessKeysResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListAccessKeys
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListAccessKeysInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param String - (optional, string) Used for pagination to indicate the starting point of the results to return.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxItems input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
        ###

        def set_MaxItems(value)
          set_input("MaxItems", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (conditional, string) Name of the user.  If the UserName field is not specified, the UserName is determined implicitly based on the AWS Access Key ID used to sign the request.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListAccessKeys Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListAccessKeysResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListAccessKeys



    ##############################################################################
    #
    # ListAccountAliases
    #
    # Lists the account aliases associated with the account. 
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListAccountAliases < Choreography

      ####
      #  Create a new instance of the ListAccountAliases Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/ListAccountAliases")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListAccountAliasesInputSet
      ####
      def new_input_set()
        return ListAccountAliasesInputSet.new()
      end

      def make_result_set()
        return ListAccountAliasesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListAccountAliasesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListAccountAliases
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListAccountAliasesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param String - (optional, string) Used for pagination to indicate the starting point of the results to return.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxItems input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
        ###

        def set_MaxItems(value)
          set_input("MaxItems", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListAccountAliases Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListAccountAliasesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListAccountAliases



    ##############################################################################
    #
    # ListGroupPolicies
    #
    # Lists the names of the policies associated with the specified group.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListGroupPolicies < Choreography

      ####
      #  Create a new instance of the ListGroupPolicies Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/ListGroupPolicies")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListGroupPoliciesInputSet
      ####
      def new_input_set()
        return ListGroupPoliciesInputSet.new()
      end

      def make_result_set()
        return ListGroupPoliciesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListGroupPoliciesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListGroupPolicies
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListGroupPoliciesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the GroupName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the group to list policies for.
        ###

        def set_GroupName(value)
          set_input("GroupName", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param String - (optional, string) Used for pagination to indicate the starting point of the results to return.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxItems input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
        ###

        def set_MaxItems(value)
          set_input("MaxItems", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListGroupPolicies Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListGroupPoliciesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListGroupPolicies



    ##############################################################################
    #
    # ListGroups
    #
    # Returns a list of groups and allows you to filter the results with a specific path prefix.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListGroups < Choreography

      ####
      #  Create a new instance of the ListGroups Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/ListGroups")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListGroupsInputSet
      ####
      def new_input_set()
        return ListGroupsInputSet.new()
      end

      def make_result_set()
        return ListGroupsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListGroupsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListGroups
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListGroupsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param String - (optional, string) Used for pagination to indicate the starting point of the results to return.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxItems input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
        ###

        def set_MaxItems(value)
          set_input("MaxItems", value)
        end
        #### 
        # Set the value of the PathPrefix input for this Choreo. 
        # 
        # @param String - (optional, string) The path prefix for filtering the results. For example, "/division_abc/subdivision_xyz/" retrieves all groups whose path starts with that string. If it is not included, it defaults to a slash (/).
        ###

        def set_PathPrefix(value)
          set_input("PathPrefix", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListGroups Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListGroupsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListGroups



    ##############################################################################
    #
    # ListGroupsForUser
    #
    # Lists the groups the specified user belongs to.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListGroupsForUser < Choreography

      ####
      #  Create a new instance of the ListGroupsForUser Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/ListGroupsForUser")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListGroupsForUserInputSet
      ####
      def new_input_set()
        return ListGroupsForUserInputSet.new()
      end

      def make_result_set()
        return ListGroupsForUserResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListGroupsForUserResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListGroupsForUser
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListGroupsForUserInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param String - (optional, string) Used for pagination to indicate the starting point of the results to return.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxItems input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
        ###

        def set_MaxItems(value)
          set_input("MaxItems", value)
        end
        #### 
        # Set the value of the PathPrefix input for this Choreo. 
        # 
        # @param String - (optional, string) The path prefix for filtering the results. For example, "/division_abc/subdivision_xyz/" retrieves all groups whose path starts with that string. If it is not included, it defaults to a slash (/).
        ###

        def set_PathPrefix(value)
          set_input("PathPrefix", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (required, string) Lists the groups the specified user belongs to.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListGroupsForUser Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListGroupsForUserResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListGroupsForUser



    ##############################################################################
    #
    # ListInstanceProfiles
    #
    # Lists the instance profiles that have the specified path prefix.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListInstanceProfiles < Choreography

      ####
      #  Create a new instance of the ListInstanceProfiles Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/ListInstanceProfiles")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListInstanceProfilesInputSet
      ####
      def new_input_set()
        return ListInstanceProfilesInputSet.new()
      end

      def make_result_set()
        return ListInstanceProfilesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListInstanceProfilesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListInstanceProfiles
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListInstanceProfilesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param String - (optional, string) Used for pagination to indicate the starting point of the results to return.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxItems input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
        ###

        def set_MaxItems(value)
          set_input("MaxItems", value)
        end
        #### 
        # Set the value of the PathPrefix input for this Choreo. 
        # 
        # @param String - (optional, string) The path prefix for filtering the results. For example, "/division_abc/subdivision_xyz/" retrieves all groups whose path starts with that string. If it is not included, it defaults to a slash (/).
        ###

        def set_PathPrefix(value)
          set_input("PathPrefix", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListInstanceProfiles Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListInstanceProfilesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListInstanceProfiles



    ##############################################################################
    #
    # ListInstanceProfilesForRole
    #
    # Lists the names of the policies associated with the specified role. 
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListInstanceProfilesForRole < Choreography

      ####
      #  Create a new instance of the ListInstanceProfilesForRole Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/ListInstanceProfilesForRole")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListInstanceProfilesForRoleInputSet
      ####
      def new_input_set()
        return ListInstanceProfilesForRoleInputSet.new()
      end

      def make_result_set()
        return ListInstanceProfilesForRoleResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListInstanceProfilesForRoleResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListInstanceProfilesForRole
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListInstanceProfilesForRoleInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param String - (optional, string) Used for pagination to indicate the starting point of the results to return.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxItems input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
        ###

        def set_MaxItems(value)
          set_input("MaxItems", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the RoleName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the role to list instance profiles for.
        ###

        def set_RoleName(value)
          set_input("RoleName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListInstanceProfilesForRole Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListInstanceProfilesForRoleResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListInstanceProfilesForRole



    ##############################################################################
    #
    # ListMFADevices
    #
    # Lists the MFA devices. If the request includes the user name, then this action lists all the MFA devices associated with the specified user name. If you do not specify a user name, IAM determines the user name implicitly based on the AWS Access Key ID signing the request.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListMFADevices < Choreography

      ####
      #  Create a new instance of the ListMFADevices Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/ListMFADevices")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListMFADevicesInputSet
      ####
      def new_input_set()
        return ListMFADevicesInputSet.new()
      end

      def make_result_set()
        return ListMFADevicesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListMFADevicesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListMFADevices
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListMFADevicesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param String - (optional, string) Used for pagination to indicate the starting point of the results to return.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxItems input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
        ###

        def set_MaxItems(value)
          set_input("MaxItems", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (optional, string) Name of the user whose MFA devices you want to list.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListMFADevices Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListMFADevicesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListMFADevices



    ##############################################################################
    #
    # ListRolePolicies
    #
    # Lists the names of the policies associated with the specified role. 
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListRolePolicies < Choreography

      ####
      #  Create a new instance of the ListRolePolicies Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/ListRolePolicies")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListRolePoliciesInputSet
      ####
      def new_input_set()
        return ListRolePoliciesInputSet.new()
      end

      def make_result_set()
        return ListRolePoliciesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListRolePoliciesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListRolePolicies
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListRolePoliciesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param String - (optional, string) Used for pagination to indicate the starting point of the results to return.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxItems input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
        ###

        def set_MaxItems(value)
          set_input("MaxItems", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the RoleName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the Role that you would like to retrieve policies for.
        ###

        def set_RoleName(value)
          set_input("RoleName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListRolePolicies Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListRolePoliciesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListRolePolicies



    ##############################################################################
    #
    # ListRoles
    #
    # Lists the roles that have the specified path prefix. If there are none, the action returns an empty list.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListRoles < Choreography

      ####
      #  Create a new instance of the ListRoles Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/ListRoles")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListRolesInputSet
      ####
      def new_input_set()
        return ListRolesInputSet.new()
      end

      def make_result_set()
        return ListRolesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListRolesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListRoles
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListRolesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param String - (optional, string) Used for pagination to indicate the starting point of the results to return.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxItems input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
        ###

        def set_MaxItems(value)
          set_input("MaxItems", value)
        end
        #### 
        # Set the value of the PathPrefix input for this Choreo. 
        # 
        # @param String - (optional, string) The path prefix for filtering the results. For example, "/division_abc/subdivision_xyz/" retrieves all groups whose path starts with that string. If it is not included, it defaults to a slash (/).
        ###

        def set_PathPrefix(value)
          set_input("PathPrefix", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListRoles Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListRolesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListRoles



    ##############################################################################
    #
    # ListServerCertificates
    #
    # Lists the server certificates that have the specified path prefix. If none exist, the action returns an empty list.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListServerCertificates < Choreography

      ####
      #  Create a new instance of the ListServerCertificates Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/ListServerCertificates")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListServerCertificatesInputSet
      ####
      def new_input_set()
        return ListServerCertificatesInputSet.new()
      end

      def make_result_set()
        return ListServerCertificatesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListServerCertificatesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListServerCertificates
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListServerCertificatesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param String - (optional, string) Used for pagination to indicate the starting point of the results to return.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxItems input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
        ###

        def set_MaxItems(value)
          set_input("MaxItems", value)
        end
        #### 
        # Set the value of the PathPrefix input for this Choreo. 
        # 
        # @param String - (optional, string) The path prefix for filtering the results. For example, "/division_abc/subdivision_xyz/" retrieves all groups whose path starts with that string. If it is not included, it defaults to a slash (/).
        ###

        def set_PathPrefix(value)
          set_input("PathPrefix", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListServerCertificates Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListServerCertificatesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListServerCertificates



    ##############################################################################
    #
    # ListSigningCertificates
    #
    # Returns information about the signing certificates associated with the specified user. If there are none, the action returns an empty list.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListSigningCertificates < Choreography

      ####
      #  Create a new instance of the ListSigningCertificates Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/ListSigningCertificates")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListSigningCertificatesInputSet
      ####
      def new_input_set()
        return ListSigningCertificatesInputSet.new()
      end

      def make_result_set()
        return ListSigningCertificatesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListSigningCertificatesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListSigningCertificates
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListSigningCertificatesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param String - (optional, string) Used for pagination to indicate the starting point of the results to return.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxItems input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
        ###

        def set_MaxItems(value)
          set_input("MaxItems", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the user.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListSigningCertificates Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListSigningCertificatesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListSigningCertificates



    ##############################################################################
    #
    # ListUserPolicies
    #
    # Lists the names of the policies associated with the specified user.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListUserPolicies < Choreography

      ####
      #  Create a new instance of the ListUserPolicies Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/ListUserPolicies")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListUserPoliciesInputSet
      ####
      def new_input_set()
        return ListUserPoliciesInputSet.new()
      end

      def make_result_set()
        return ListUserPoliciesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListUserPoliciesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListUserPolicies
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListUserPoliciesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param String - (optional, string) Used for pagination to indicate the starting point of the results to return.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxItems input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
        ###

        def set_MaxItems(value)
          set_input("MaxItems", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the user to list policies for.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListUserPolicies Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListUserPoliciesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListUserPolicies



    ##############################################################################
    #
    # ListUsers
    #
    # Lists the users that have the specified path prefix. If there are none, the action returns an empty list.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListUsers < Choreography

      ####
      #  Create a new instance of the ListUsers Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/ListUsers")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListUsersInputSet
      ####
      def new_input_set()
        return ListUsersInputSet.new()
      end

      def make_result_set()
        return ListUsersResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListUsersResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListUsers
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListUsersInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param String - (optional, string) Used for pagination to indicate the starting point of the results to return.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxItems input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
        ###

        def set_MaxItems(value)
          set_input("MaxItems", value)
        end
        #### 
        # Set the value of the PathPrefix input for this Choreo. 
        # 
        # @param String - (conditional, string) The path prefix for filtering the results. For example, "/division_abc/subdivision_xyz/" retrieves all users whose path starts with that string. If it is not included, it defaults to a slash (/).
        ###

        def set_PathPrefix(value)
          set_input("PathPrefix", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListUsers Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListUsersResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListUsers



    ##############################################################################
    #
    # ListVirtualMFADevices
    #
    # Lists the virtual MFA devices under the AWS account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListVirtualMFADevices < Choreography

      ####
      #  Create a new instance of the ListVirtualMFADevices Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/ListVirtualMFADevices")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListVirtualMFADevicesInputSet
      ####
      def new_input_set()
        return ListVirtualMFADevicesInputSet.new()
      end

      def make_result_set()
        return ListVirtualMFADevicesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListVirtualMFADevicesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListVirtualMFADevices
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListVirtualMFADevicesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AssignmentStatus input for this Choreo. 
        # 
        # @param String - (optional, string) Filters by the whether the device is assigned or unassigned to a specific user. Valid values: "Unassigned", "Assigned" or "Any" (default - both assigned and unassigned devices).
        ###

        def set_AssignmentStatus(value)
          set_input("AssignmentStatus", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param String - (optional, string) Used for pagination to indicate the starting point of the results to return.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxItems input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Used for pagination to limit the number of results returned. Defaults to 100.
        ###

        def set_MaxItems(value)
          set_input("MaxItems", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListVirtualMFADevices Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListVirtualMFADevicesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListVirtualMFADevices



    ##############################################################################
    #
    # PutGroupPolicy
    #
    # Adds or updates a policy document associated with a specified group.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PutGroupPolicy < Choreography

      ####
      #  Create a new instance of the PutGroupPolicy Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/PutGroupPolicy")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutGroupPolicyInputSet
      ####
      def new_input_set()
        return PutGroupPolicyInputSet.new()
      end

      def make_result_set()
        return PutGroupPolicyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutGroupPolicyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PutGroupPolicy
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutGroupPolicyInputSet < Choreography::InputSet

        #### 
        # Set the value of the PolicyDocument input for this Choreo. 
        # 
        # @param String - (required, json) The policy document. See documentation for formatting examples.
        ###

        def set_PolicyDocument(value)
          set_input("PolicyDocument", value)
        end
        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the GroupName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the group to associate the policy with.
        ###

        def set_GroupName(value)
          set_input("GroupName", value)
        end
        #### 
        # Set the value of the PolicyName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the policy document.
        ###

        def set_PolicyName(value)
          set_input("PolicyName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PutGroupPolicy Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutGroupPolicyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PutGroupPolicy



    ##############################################################################
    #
    # PutRolePolicy
    #
    # Adds or updates a policy document associated with a specified role.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PutRolePolicy < Choreography

      ####
      #  Create a new instance of the PutRolePolicy Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/PutRolePolicy")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutRolePolicyInputSet
      ####
      def new_input_set()
        return PutRolePolicyInputSet.new()
      end

      def make_result_set()
        return PutRolePolicyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutRolePolicyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PutRolePolicy
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutRolePolicyInputSet < Choreography::InputSet

        #### 
        # Set the value of the PolicyDocument input for this Choreo. 
        # 
        # @param String - (required, json) The policy document. See documentation for formatting examples.
        ###

        def set_PolicyDocument(value)
          set_input("PolicyDocument", value)
        end
        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the PolicyName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the policy document.
        ###

        def set_PolicyName(value)
          set_input("PolicyName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the RoleName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the role to associate the policy with.
        ###

        def set_RoleName(value)
          set_input("RoleName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PutRolePolicy Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutRolePolicyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PutRolePolicy



    ##############################################################################
    #
    # PutUserPolicy
    #
    # Adds or updates a policy document associated with a specified user.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PutUserPolicy < Choreography

      ####
      #  Create a new instance of the PutUserPolicy Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/PutUserPolicy")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutUserPolicyInputSet
      ####
      def new_input_set()
        return PutUserPolicyInputSet.new()
      end

      def make_result_set()
        return PutUserPolicyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutUserPolicyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PutUserPolicy
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutUserPolicyInputSet < Choreography::InputSet

        #### 
        # Set the value of the PolicyDocument input for this Choreo. 
        # 
        # @param String - (required, json) The policy document. See documentation for formatting examples.
        ###

        def set_PolicyDocument(value)
          set_input("PolicyDocument", value)
        end
        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the PolicyName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the policy document.
        ###

        def set_PolicyName(value)
          set_input("PolicyName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the user to associate the policy with.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PutUserPolicy Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutUserPolicyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PutUserPolicy



    ##############################################################################
    #
    # RemoveRoleFromInstanceProfile
    #
    # Removes the specified Role from the specified Instance Profile.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RemoveRoleFromInstanceProfile < Choreography

      ####
      #  Create a new instance of the RemoveRoleFromInstanceProfile Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/RemoveRoleFromInstanceProfile")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RemoveRoleFromInstanceProfileInputSet
      ####
      def new_input_set()
        return RemoveRoleFromInstanceProfileInputSet.new()
      end

      def make_result_set()
        return RemoveRoleFromInstanceProfileResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RemoveRoleFromInstanceProfileResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RemoveRoleFromInstanceProfile
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RemoveRoleFromInstanceProfileInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the InstanceProfileName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the instance profile to update.
        ###

        def set_InstanceProfileName(value)
          set_input("InstanceProfileName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the RoleName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the role to remove.
        ###

        def set_RoleName(value)
          set_input("RoleName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RemoveRoleFromInstanceProfile Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RemoveRoleFromInstanceProfileResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class RemoveRoleFromInstanceProfile



    ##############################################################################
    #
    # RemoveUserFromGroup
    #
    # Removes the specified user from the specified group.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RemoveUserFromGroup < Choreography

      ####
      #  Create a new instance of the RemoveUserFromGroup Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/RemoveUserFromGroup")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RemoveUserFromGroupInputSet
      ####
      def new_input_set()
        return RemoveUserFromGroupInputSet.new()
      end

      def make_result_set()
        return RemoveUserFromGroupResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RemoveUserFromGroupResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RemoveUserFromGroup
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RemoveUserFromGroupInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the GroupName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the group to update.
        ###

        def set_GroupName(value)
          set_input("GroupName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the user to remove.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RemoveUserFromGroup Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RemoveUserFromGroupResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class RemoveUserFromGroup



    ##############################################################################
    #
    # ResyncMFADevice
    #
    # Synchronizes the specified MFA device with AWS servers.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ResyncMFADevice < Choreography

      ####
      #  Create a new instance of the ResyncMFADevice Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/ResyncMFADevice")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ResyncMFADeviceInputSet
      ####
      def new_input_set()
        return ResyncMFADeviceInputSet.new()
      end

      def make_result_set()
        return ResyncMFADeviceResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ResyncMFADeviceResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ResyncMFADevice
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ResyncMFADeviceInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AuthenticationCode1 input for this Choreo. 
        # 
        # @param String - (required, string) An authentication code emitted by the device.
        ###

        def set_AuthenticationCode1(value)
          set_input("AuthenticationCode1", value)
        end
        #### 
        # Set the value of the AuthenticationCode2 input for this Choreo. 
        # 
        # @param String - (required, string) A subsequent authentication code emitted by the device.
        ###

        def set_AuthenticationCode2(value)
          set_input("AuthenticationCode2", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SerialNumber input for this Choreo. 
        # 
        # @param String - (required, string) The serial number that uniquely identifies the MFA device. For virtual MFA devices, the serial number is the same as the ARN.
        ###

        def set_SerialNumber(value)
          set_input("SerialNumber", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the user for whom you want to enable the MFA device.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ResyncMFADevice Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ResyncMFADeviceResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ResyncMFADevice



    ##############################################################################
    #
    # UpdateAccessKey
    #
    # Changes the status of the specified access key from Active to Inactive, or vice versa. This action can be used to disable a user's key as part of a key rotation workflow.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UpdateAccessKey < Choreography

      ####
      #  Create a new instance of the UpdateAccessKey Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/UpdateAccessKey")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UpdateAccessKeyInputSet
      ####
      def new_input_set()
        return UpdateAccessKeyInputSet.new()
      end

      def make_result_set()
        return UpdateAccessKeyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UpdateAccessKeyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UpdateAccessKey
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UpdateAccessKeyInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AccessKeyId input for this Choreo. 
        # 
        # @param String - (conditional, string) The Access Key ID for the Access Key ID and Secret Access Key you want to delete.
        ###

        def set_AccessKeyId(value)
          set_input("AccessKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Status input for this Choreo. 
        # 
        # @param String - (required, string) The status you want to assign to the Secret Access Key. Active means the key can be used for API calls to AWS, while Inactive means the key cannot be used.
        ###

        def set_Status(value)
          set_input("Status", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (conditional, string) Name of the user whose key you want to update.  If the UserName field is not specified, the UserName is determined implicitly based on the AWS Access Key ID used to sign the request.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UpdateAccessKey Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UpdateAccessKeyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UpdateAccessKey



    ##############################################################################
    #
    # UpdateAccountPasswordPolicy
    #
    # Updates the password policy settings for the account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UpdateAccountPasswordPolicy < Choreography

      ####
      #  Create a new instance of the UpdateAccountPasswordPolicy Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/UpdateAccountPasswordPolicy")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UpdateAccountPasswordPolicyInputSet
      ####
      def new_input_set()
        return UpdateAccountPasswordPolicyInputSet.new()
      end

      def make_result_set()
        return UpdateAccountPasswordPolicyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UpdateAccountPasswordPolicyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UpdateAccountPasswordPolicy
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UpdateAccountPasswordPolicyInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AllowUsersToChangePassword input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Determines whether users can set/change their own passwords. Valid values: "true" or "false" (the default).
        ###

        def set_AllowUsersToChangePassword(value)
          set_input("AllowUsersToChangePassword", value)
        end
        #### 
        # Set the value of the ExpirePasswords input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Determines whether the passwords expire. Valid values: "true" or "false" (the default).
        ###

        def set_ExpirePasswords(value)
          set_input("ExpirePasswords", value)
        end
        #### 
        # Set the value of the MaxPasswordsAge input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Maximum age of the passwords before they expire.
        ###

        def set_MaxPasswordsAge(value)
          set_input("MaxPasswordsAge", value)
        end
        #### 
        # Set the value of the MinimumPasswordLength input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Mininum length of the password. Defaults to none.
        ###

        def set_MinimumPasswordLength(value)
          set_input("MinimumPasswordLength", value)
        end
        #### 
        # Set the value of the RequireLowercaseCharacters input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Determines whether at least one lower-case character is required in the password. Valid values: "true" or "false" (the default).
        ###

        def set_RequireLowercaseCharacters(value)
          set_input("RequireLowercaseCharacters", value)
        end
        #### 
        # Set the value of the RequireNumbers input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Determines whether numbers are required in the password. Valid values: "true" or "false" (the default).
        ###

        def set_RequireNumbers(value)
          set_input("RequireNumbers", value)
        end
        #### 
        # Set the value of the RequireSymbols input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Determines whether symbols are required in the password. Valid values: "true" or "false" (the default).
        ###

        def set_RequireSymbols(value)
          set_input("RequireSymbols", value)
        end
        #### 
        # Set the value of the RequireUppercaseCharacters input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Determines whether at least one upper-case character is required in the password. Valid values: "true" or "false" (the default).
        ###

        def set_RequireUppercaseCharacters(value)
          set_input("RequireUppercaseCharacters", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UpdateAccountPasswordPolicy Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UpdateAccountPasswordPolicyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UpdateAccountPasswordPolicy



    ##############################################################################
    #
    # UpdateGroup
    #
    # Updates the name and/or the path of a specified group.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UpdateGroup < Choreography

      ####
      #  Create a new instance of the UpdateGroup Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/UpdateGroup")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UpdateGroupInputSet
      ####
      def new_input_set()
        return UpdateGroupInputSet.new()
      end

      def make_result_set()
        return UpdateGroupResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UpdateGroupResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UpdateGroup
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UpdateGroupInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the GroupName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the group to update.
        ###

        def set_GroupName(value)
          set_input("GroupName", value)
        end
        #### 
        # Set the value of the NewGroupName input for this Choreo. 
        # 
        # @param String - (optional, string) The new name of the group. Include a value here only if you are updating the group's name.
        ###

        def set_NewGroupName(value)
          set_input("NewGroupName", value)
        end
        #### 
        # Set the value of the NewPath input for this Choreo. 
        # 
        # @param String - (optional, string) The new path for the group. Include a value here only if you are changing the user's existing path.
        ###

        def set_NewPath(value)
          set_input("NewPath", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UpdateGroup Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UpdateGroupResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UpdateGroup



    ##############################################################################
    #
    # UpdateLoginProfile
    #
    # Changes the password for the specified user.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UpdateLoginProfile < Choreography

      ####
      #  Create a new instance of the UpdateLoginProfile Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/UpdateLoginProfile")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UpdateLoginProfileInputSet
      ####
      def new_input_set()
        return UpdateLoginProfileInputSet.new()
      end

      def make_result_set()
        return UpdateLoginProfileResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UpdateLoginProfileResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UpdateLoginProfile
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UpdateLoginProfileInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the MustChangePassword input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Specifies whether or not the user should be required to change their password immediately.  Valid values are true/false or 1/0.
        ###

        def set_MustChangePassword(value)
          set_input("MustChangePassword", value)
        end
        #### 
        # Set the value of the Password input for this Choreo. 
        # 
        # @param String - (required, string) The new password for the user name.
        ###

        def set_Password(value)
          set_input("Password", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the user to update.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UpdateLoginProfile Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UpdateLoginProfileResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UpdateLoginProfile



    ##############################################################################
    #
    # UpdateServerCertificate
    #
    # Updates the name and/or the path of the specified server certificate.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UpdateServerCertificate < Choreography

      ####
      #  Create a new instance of the UpdateServerCertificate Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/UpdateServerCertificate")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UpdateServerCertificateInputSet
      ####
      def new_input_set()
        return UpdateServerCertificateInputSet.new()
      end

      def make_result_set()
        return UpdateServerCertificateResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UpdateServerCertificateResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UpdateServerCertificate
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UpdateServerCertificateInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the NewPath input for this Choreo. 
        # 
        # @param String - (conditional, string) The new path for the server certificate. Include this only if you are updating the server certificate's path.
        ###

        def set_NewPath(value)
          set_input("NewPath", value)
        end
        #### 
        # Set the value of the NewServerCertificateName input for this Choreo. 
        # 
        # @param String - (conditional, string) The new name for the server certificate. Include this only if you are updating the server certificate's name.
        ###

        def set_NewServerCertificateName(value)
          set_input("NewServerCertificateName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the ServerCertificateName input for this Choreo. 
        # 
        # @param String - (required, string) The name for the server certificate. Do not include the path in this value.
        ###

        def set_ServerCertificateName(value)
          set_input("ServerCertificateName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UpdateServerCertificate Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UpdateServerCertificateResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UpdateServerCertificate



    ##############################################################################
    #
    # UpdateSigningCertificate
    #
    # Changes the status of the specified signing certificate from active to disabled, or vice versa. This action can be used to disable a user's signing certificate as part of a certificate rotation workflow.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UpdateSigningCertificate < Choreography

      ####
      #  Create a new instance of the UpdateSigningCertificate Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/UpdateSigningCertificate")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UpdateSigningCertificateInputSet
      ####
      def new_input_set()
        return UpdateSigningCertificateInputSet.new()
      end

      def make_result_set()
        return UpdateSigningCertificateResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UpdateSigningCertificateResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UpdateSigningCertificate
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UpdateSigningCertificateInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the CertificateId input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the signing certificate you want to update.
        ###

        def set_CertificateId(value)
          set_input("CertificateId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Status input for this Choreo. 
        # 
        # @param String - (required, string) The status you want to assign to the certificate. Active means the certificate can be used for API calls to AWS, while Inactive means the certificate cannot be used.
        ###

        def set_Status(value)
          set_input("Status", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (optional, string) Name of the user the signing certificate belongs to.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UpdateSigningCertificate Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UpdateSigningCertificateResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UpdateSigningCertificate



    ##############################################################################
    #
    # UpdateUser
    #
    # Updates the name and/or the path of a specified user.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UpdateUser < Choreography

      ####
      #  Create a new instance of the UpdateUser Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/UpdateUser")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UpdateUserInputSet
      ####
      def new_input_set()
        return UpdateUserInputSet.new()
      end

      def make_result_set()
        return UpdateUserResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UpdateUserResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UpdateUser
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UpdateUserInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the NewPath input for this Choreo. 
        # 
        # @param String - (optional, string) The new path for the user. Include a value here only if you are changing the user's existing path. The path needs to start with and end with a slash(/).  For example, "/Division/HR/".
        ###

        def set_NewPath(value)
          set_input("NewPath", value)
        end
        #### 
        # Set the value of the NewUserName input for this Choreo. 
        # 
        # @param String - (optional, string) The new name of the user. Include a value here only if you are updating the user's name.
        ###

        def set_NewUserName(value)
          set_input("NewUserName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the user to update.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UpdateUser Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UpdateUserResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UpdateUser



    ##############################################################################
    #
    # UploadServerCertificate
    #
    # Uploads a server certificate entity for the AWS account. The server certificate entity includes a public key certificate, a private key, and an optional certificate chain, which should all be PEM-encoded.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UploadServerCertificate < Choreography

      ####
      #  Create a new instance of the UploadServerCertificate Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/UploadServerCertificate")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UploadServerCertificateInputSet
      ####
      def new_input_set()
        return UploadServerCertificateInputSet.new()
      end

      def make_result_set()
        return UploadServerCertificateResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UploadServerCertificateResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UploadServerCertificate
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UploadServerCertificateInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the CertificateBody input for this Choreo. 
        # 
        # @param String - (required, multiline) The contents of the signing certificate.
        ###

        def set_CertificateBody(value)
          set_input("CertificateBody", value)
        end
        #### 
        # Set the value of the CertificateChain input for this Choreo. 
        # 
        # @param String - (optional, multiline) The contents of the certificate chain. This is typically a concatenation of the PEM-encoded public key certificates of the chain.
        ###

        def set_CertificateChain(value)
          set_input("CertificateChain", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (optional, string) The path for the server certificate.
        ###

        def set_Path(value)
          set_input("Path", value)
        end
        #### 
        # Set the value of the PrivateKey input for this Choreo. 
        # 
        # @param String - (required, multiline) The contents of the private key in PEM-encoded format.
        ###

        def set_PrivateKey(value)
          set_input("PrivateKey", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the ServerCertificateName input for this Choreo. 
        # 
        # @param String - (required, string) The name for the server certificate. Do not include the path in this value.
        ###

        def set_ServerCertificateName(value)
          set_input("ServerCertificateName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UploadServerCertificate Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UploadServerCertificateResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UploadServerCertificate



    ##############################################################################
    #
    # UploadSigningCertificate
    #
    # Uploads an X.509 signing certificate and associates it with the specified user.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UploadSigningCertificate < Choreography

      ####
      #  Create a new instance of the UploadSigningCertificate Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/IAM/UploadSigningCertificate")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UploadSigningCertificateInputSet
      ####
      def new_input_set()
        return UploadSigningCertificateInputSet.new()
      end

      def make_result_set()
        return UploadSigningCertificateResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UploadSigningCertificateResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UploadSigningCertificate
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UploadSigningCertificateInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the CertificateBody input for this Choreo. 
        # 
        # @param String - (required, multiline) The contents of the signing certificate.
        ###

        def set_CertificateBody(value)
          set_input("CertificateBody", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the user.
        ###

        def set_UserName(value)
          set_input("UserName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UploadSigningCertificate Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UploadSigningCertificateResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UploadSigningCertificate




  end # module IAM

  module Lex




    module RuntimeService



      ##############################################################################
      #
      # PostText
      #
      # Returns a DataSource that includes metadata and data file information, as well as the current status of the DataSource.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class PostText < Choreography

        ####
        #  Create a new instance of the PostText Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Lex/RuntimeService/PostText")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return PostTextInputSet
        ####
        def new_input_set()
          return PostTextInputSet.new()
        end

        def make_result_set()
          return PostTextResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = PostTextResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the PostText
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class PostTextInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the InputString input for this Choreo. 
          # 
          # @param String - (required, string) 
          ###

          def set_InputString(value)
            set_input("InputString", value)
          end
          #### 
          # Set the value of the UserRegion input for this Choreo. 
          # 
          # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
          ###

          def set_UserRegion(value)
            set_input("UserRegion", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the PostText Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class PostTextResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (json) The response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class PostText




    end # module RuntimeService

  end # module Lex

  module LoginWithAmazon



    ##############################################################################
    #
    # FinalizeOAuth
    #
    # Completes the OAuth process by retrieving an Amazon access token for a user, after they have visited the authorization URL returned by the InitializeOAuth Choreo and clicked "allow."
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class FinalizeOAuth < Choreography

      ####
      #  Create a new instance of the FinalizeOAuth Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/LoginWithAmazon/FinalizeOAuth")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return FinalizeOAuthInputSet
      ####
      def new_input_set()
        return FinalizeOAuthInputSet.new()
      end

      def make_result_set()
        return FinalizeOAuthResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = FinalizeOAuthResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the FinalizeOAuth
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class FinalizeOAuthInputSet < Choreography::InputSet

        #### 
        # Set the value of the CallbackID input for this Choreo. 
        # 
        # @param String - (required, string) The callback token returned by the InitializeOAuth Choreo. Used to retrieve the authorization code after the user authorizes.
        ###

        def set_CallbackID(value)
          set_input("CallbackID", value)
        end
        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (required, string) The Client ID provided by Amazon.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the ClientSecret input for this Choreo. 
        # 
        # @param String - (required, string) The Client Secret provided by Amazon.
        ###

        def set_ClientSecret(value)
          set_input("ClientSecret", value)
        end
        #### 
        # Set the value of the SuppressErrors input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to true, errors received during the OAuth redirect process will be suppressed and returned in the ErrorMessage output.
        ###

        def set_SuppressErrors(value)
          set_input("SuppressErrors", value)
        end
        #### 
        # Set the value of the Timeout input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The amount of time (in seconds) to poll your Temboo callback URL to see if your app's user has allowed or denied the request for access. Defaults to 20. Max is 60.
        ###

        def set_Timeout(value)
          set_input("Timeout", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the FinalizeOAuth Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class FinalizeOAuthResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "AccessToken" output from this Choreo execution
      	#
      	# @return String - (string) The access token for the user that has granted access to your application.
      	####
      	def get_AccessToken()
      	  return @outputs["AccessToken"]
      	end
      	####
      	# Retrieve the value for the "ErrorMessage" output from this Choreo execution
      	#
      	# @return String - (string) Contains an error message if an error occurs during the OAuth redirect process and if SuppressErrors is set to true.
      	####
      	def get_ErrorMessage()
      	  return @outputs["ErrorMessage"]
      	end
      	####
      	# Retrieve the value for the "Expires" output from this Choreo execution
      	#
      	# @return String - (integer) The expiration time of the access_token retrieved.
      	####
      	def get_Expires()
      	  return @outputs["Expires"]
      	end
      	####
      	# Retrieve the value for the "RefreshToken" output from this Choreo execution
      	#
      	# @return String - (string) A token that may be used to obtain a new access token when the short-lived access token expires.
      	####
      	def get_RefreshToken()
      	  return @outputs["RefreshToken"]
      	end
      end

    end # class FinalizeOAuth



    ##############################################################################
    #
    # InitializeOAuth
    #
    # Generates an authorization URL that an application can use to complete the first step in the OAuth process.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class InitializeOAuth < Choreography

      ####
      #  Create a new instance of the InitializeOAuth Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/LoginWithAmazon/InitializeOAuth")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return InitializeOAuthInputSet
      ####
      def new_input_set()
        return InitializeOAuthInputSet.new()
      end

      def make_result_set()
        return InitializeOAuthResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = InitializeOAuthResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the InitializeOAuth
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class InitializeOAuthInputSet < Choreography::InputSet

        #### 
        # Set the value of the ClientID input for this Choreo. 
        # 
        # @param String - (required, string) The Client ID provided by Amazon.
        ###

        def set_ClientID(value)
          set_input("ClientID", value)
        end
        #### 
        # Set the value of the CustomCallbackID input for this Choreo. 
        # 
        # @param String - (optional, string) A unique identifier that you can pass to eliminate the need to wait for a Temboo generated CallbackID. Callback identifiers may only contain numbers, letters, periods, and hyphens.
        ###

        def set_CustomCallbackID(value)
          set_input("CustomCallbackID", value)
        end
        #### 
        # Set the value of the ForwardingURL input for this Choreo. 
        # 
        # @param String - (optional, string) The URL that Temboo will redirect your users to after they grant access to your application. This should include the "https://" or "http://" prefix and be a fully qualified URL.
        ###

        def set_ForwardingURL(value)
          set_input("ForwardingURL", value)
        end
        #### 
        # Set the value of the Scope input for this Choreo. 
        # 
        # @param String - (conditional, string) A space-delimited list of permissions to request access for (e.g., clouddrive:read clouddrive:write).
        ###

        def set_Scope(value)
          set_input("Scope", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the InitializeOAuth Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class InitializeOAuthResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "AuthorizationURL" output from this Choreo execution
      	#
      	# @return String - (string) The authorization URL to send your user to in order for them to grant access to your application.
      	####
      	def get_AuthorizationURL()
      	  return @outputs["AuthorizationURL"]
      	end
      	####
      	# Retrieve the value for the "CallbackID" output from this Choreo execution
      	#
      	# @return String - (string) An ID used to retrieve the callback data that Temboo stores once your application's user authorizes.
      	####
      	def get_CallbackID()
      	  return @outputs["CallbackID"]
      	end
      end

    end # class InitializeOAuth




  end # module LoginWithAmazon

  module MachineLearning



    ##############################################################################
    #
    # AddTags
    #
    # Adds one or more tags to an object, up to a limit of 10. 
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class AddTags < Choreography

      ####
      #  Create a new instance of the AddTags Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/AddTags")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AddTagsInputSet
      ####
      def new_input_set()
        return AddTagsInputSet.new()
      end

      def make_result_set()
        return AddTagsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AddTagsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the AddTags
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AddTagsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResourceId input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the ML object to tag.
        ###

        def set_ResourceId(value)
          set_input("ResourceId", value)
        end
        #### 
        # Set the value of the ResourceType input for this Choreo. 
        # 
        # @param String - (required, string) The type of the ML object to tag. Valid values are: BatchPrediction, DataSource, Evaluation, MLModel.
        ###

        def set_ResourceType(value)
          set_input("ResourceType", value)
        end
        #### 
        # Set the value of the Tags input for this Choreo. 
        # 
        # @param String - (required, json) An array of tag objects in a key-value pair format.
        ###

        def set_Tags(value)
          set_input("Tags", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the AddTags Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AddTagsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class AddTags



    ##############################################################################
    #
    # CreateBatchPrediction
    #
    # Generates predictions for a group of observations.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateBatchPrediction < Choreography

      ####
      #  Create a new instance of the CreateBatchPrediction Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/CreateBatchPrediction")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateBatchPredictionInputSet
      ####
      def new_input_set()
        return CreateBatchPredictionInputSet.new()
      end

      def make_result_set()
        return CreateBatchPredictionResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateBatchPredictionResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateBatchPrediction
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateBatchPredictionInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BatchPredictionDataSourceId input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the DataSource that points to the group of observations to predict.
        ###

        def set_BatchPredictionDataSourceId(value)
          set_input("BatchPredictionDataSourceId", value)
        end
        #### 
        # Set the value of the BatchPredictionId input for this Choreo. 
        # 
        # @param String - (required, string) A user-supplied ID that uniquely identifies the BatchPrediction.
        ###

        def set_BatchPredictionId(value)
          set_input("BatchPredictionId", value)
        end
        #### 
        # Set the value of the BatchPredictionName input for this Choreo. 
        # 
        # @param String - (optional, string) A user-supplied name or description of the BatchPrediction.
        ###

        def set_BatchPredictionName(value)
          set_input("BatchPredictionName", value)
        end
        #### 
        # Set the value of the MLModelId input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the MLModel that will generate predictions for the group of observations.
        ###

        def set_MLModelId(value)
          set_input("MLModelId", value)
        end
        #### 
        # Set the value of the OutputUri input for this Choreo. 
        # 
        # @param String - (required, string) The location of an Amazon S3 bucket or directory to store the batch prediction results.
        ###

        def set_OutputUri(value)
          set_input("OutputUri", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateBatchPrediction Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateBatchPredictionResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateBatchPrediction



    ##############################################################################
    #
    # CreateDataSourceFromS3
    #
    # Creates a DataSource object.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateDataSourceFromS3 < Choreography

      ####
      #  Create a new instance of the CreateDataSourceFromS3 Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/CreateDataSourceFromS3")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateDataSourceFromS3InputSet
      ####
      def new_input_set()
        return CreateDataSourceFromS3InputSet.new()
      end

      def make_result_set()
        return CreateDataSourceFromS3ResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateDataSourceFromS3ResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateDataSourceFromS3
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateDataSourceFromS3InputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ComputeStatistics input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) The compute statistics for a DataSource. This parameter must be set to true if the DataSource needs to be used for MLModel training. Defaults to false.
        ###

        def set_ComputeStatistics(value)
          set_input("ComputeStatistics", value)
        end
        #### 
        # Set the value of the DataLocationS3 input for this Choreo. 
        # 
        # @param String - (required, string) The location of the data file(s) used by a DataSource. The URI specifies a data file or an Amazon Simple Storage Service (Amazon S3) directory or bucket containing data files.
        ###

        def set_DataLocationS3(value)
          set_input("DataLocationS3", value)
        end
        #### 
        # Set the value of the DataRearrangement input for this Choreo. 
        # 
        # @param String - (optional, json) A JSON string that represents the splitting and rearrangement requirements for the Datasource.
        ###

        def set_DataRearrangement(value)
          set_input("DataRearrangement", value)
        end
        #### 
        # Set the value of the DataSchema input for this Choreo. 
        # 
        # @param String - (optional, json) A JSON string representing the schema. This is required unless specifying a valid URI for DataSchemaLocationS3.
        ###

        def set_DataSchema(value)
          set_input("DataSchema", value)
        end
        #### 
        # Set the value of the DataSchemaLocationS3 input for this Choreo. 
        # 
        # @param String - (conditional, string) The Amazon S3 location of the DataSchema. This is required unless specifying a valid JSON schema file for DataSchema (see optional inputs).
        ###

        def set_DataSchemaLocationS3(value)
          set_input("DataSchemaLocationS3", value)
        end
        #### 
        # Set the value of the DataSourceId input for this Choreo. 
        # 
        # @param String - (required, string) A user-supplied identifier that uniquely identifies the DataSource.
        ###

        def set_DataSourceId(value)
          set_input("DataSourceId", value)
        end
        #### 
        # Set the value of the DataSourceName input for this Choreo. 
        # 
        # @param String - (optional, string) A user-supplied name or description of the DataSource.
        ###

        def set_DataSourceName(value)
          set_input("DataSourceName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateDataSourceFromS3 Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateDataSourceFromS3ResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateDataSourceFromS3



    ##############################################################################
    #
    # CreateEvaluation
    #
    # Creates a new Evaluation of an MLModel.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateEvaluation < Choreography

      ####
      #  Create a new instance of the CreateEvaluation Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/CreateEvaluation")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateEvaluationInputSet
      ####
      def new_input_set()
        return CreateEvaluationInputSet.new()
      end

      def make_result_set()
        return CreateEvaluationResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateEvaluationResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateEvaluation
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateEvaluationInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the EvaluationDataSourceId input for this Choreo. 
        # 
        # @param String - (required, string) The DataSource that points to the training data.
        ###

        def set_EvaluationDataSourceId(value)
          set_input("EvaluationDataSourceId", value)
        end
        #### 
        # Set the value of the EvaluationId input for this Choreo. 
        # 
        # @param String - (required, string) A user-supplied identifier that uniquely identifies the MLModel.
        ###

        def set_EvaluationId(value)
          set_input("EvaluationId", value)
        end
        #### 
        # Set the value of the EvaluationName input for this Choreo. 
        # 
        # @param String - (optional, string) A user-supplied name or description of the MLModel.
        ###

        def set_EvaluationName(value)
          set_input("EvaluationName", value)
        end
        #### 
        # Set the value of the MLModelId input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the MLModel to evaluate.
        ###

        def set_MLModelId(value)
          set_input("MLModelId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateEvaluation Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateEvaluationResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateEvaluation



    ##############################################################################
    #
    # CreateMLModel
    #
    # Creates a new MLModel using the DataSource and the recipe as information sources.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateMLModel < Choreography

      ####
      #  Create a new instance of the CreateMLModel Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/CreateMLModel")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateMLModelInputSet
      ####
      def new_input_set()
        return CreateMLModelInputSet.new()
      end

      def make_result_set()
        return CreateMLModelResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateMLModelResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateMLModel
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateMLModelInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the MLModelId input for this Choreo. 
        # 
        # @param String - (required, string) A user-supplied identifier that uniquely identifies the MLModel.
        ###

        def set_MLModelId(value)
          set_input("MLModelId", value)
        end
        #### 
        # Set the value of the MLModelName input for this Choreo. 
        # 
        # @param String - (optional, string) A user-supplied name or description of the MLModel.
        ###

        def set_MLModelName(value)
          set_input("MLModelName", value)
        end
        #### 
        # Set the value of the MLModelType input for this Choreo. 
        # 
        # @param String - (required, string) The category of supervised learning that this MLModel will address. Choose from the following types: REGRESSION, BINARY, MULTICLASS.
        ###

        def set_MLModelType(value)
          set_input("MLModelType", value)
        end
        #### 
        # Set the value of the Parameters input for this Choreo. 
        # 
        # @param String - (optional, json) A list of the training parameters in the MLModel. The list is implemented as a map of key-value pairs.
        ###

        def set_Parameters(value)
          set_input("Parameters", value)
        end
        #### 
        # Set the value of the Recipe input for this Choreo. 
        # 
        # @param String - (optional, string) The data recipe for creating the MLModel. You must specify either the recipe or its URI. If you don't specify a recipe or its URI, Amazon ML creates a default.
        ###

        def set_Recipe(value)
          set_input("Recipe", value)
        end
        #### 
        # Set the value of the RecipeUri input for this Choreo. 
        # 
        # @param String - (optional, string) The Amazon S3 location and file name that contains the MLModel recipe. You must specify either the recipe or its URI. If you don't specify a recipe or its URI, Amazon ML creates a default.
        ###

        def set_RecipeUri(value)
          set_input("RecipeUri", value)
        end
        #### 
        # Set the value of the TrainingDataSourceId input for this Choreo. 
        # 
        # @param String - (required, string) The DataSource that points to the training data.
        ###

        def set_TrainingDataSourceId(value)
          set_input("TrainingDataSourceId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateMLModel Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateMLModelResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateMLModel



    ##############################################################################
    #
    # CreateRealtimeEndpoint
    #
    # This Choreo creates a real-time endpoint for the MLModel. The endpoint contains the URI of the MLModel which is the location to send real-time prediction requests for the specified MLModel.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateRealtimeEndpoint < Choreography

      ####
      #  Create a new instance of the CreateRealtimeEndpoint Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/CreateRealtimeEndpoint")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateRealtimeEndpointInputSet
      ####
      def new_input_set()
        return CreateRealtimeEndpointInputSet.new()
      end

      def make_result_set()
        return CreateRealtimeEndpointResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateRealtimeEndpointResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateRealtimeEndpoint
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateRealtimeEndpointInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the MLModelId input for this Choreo. 
        # 
        # @param String - (required, string) The ID assigned to the MLModelId at creation.
        ###

        def set_MLModelId(value)
          set_input("MLModelId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateRealtimeEndpoint Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateRealtimeEndpointResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateRealtimeEndpoint



    ##############################################################################
    #
    # DeleteBatchPrediction
    #
    # Assigns the DELETED status to a BatchPrediction, rendering it unusable.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteBatchPrediction < Choreography

      ####
      #  Create a new instance of the DeleteBatchPrediction Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/DeleteBatchPrediction")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteBatchPredictionInputSet
      ####
      def new_input_set()
        return DeleteBatchPredictionInputSet.new()
      end

      def make_result_set()
        return DeleteBatchPredictionResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteBatchPredictionResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteBatchPrediction
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteBatchPredictionInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BatchPredictionId input for this Choreo. 
        # 
        # @param String - (required, string) A user-supplied ID that uniquely identifies the BatchPrediction.
        ###

        def set_BatchPredictionId(value)
          set_input("BatchPredictionId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the Verbose input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Specifies whether the GetDataSource operation should return DataSourceSchema. Defaults to true.
        ###

        def set_Verbose(value)
          set_input("Verbose", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteBatchPrediction Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteBatchPredictionResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteBatchPrediction



    ##############################################################################
    #
    # DeleteDataSource
    #
    # Assigns the DELETED status to a DataSource, rendering it unusable.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteDataSource < Choreography

      ####
      #  Create a new instance of the DeleteDataSource Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/DeleteDataSource")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteDataSourceInputSet
      ####
      def new_input_set()
        return DeleteDataSourceInputSet.new()
      end

      def make_result_set()
        return DeleteDataSourceResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteDataSourceResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteDataSource
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteDataSourceInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the DataSourceId input for this Choreo. 
        # 
        # @param String - (required, string) A user-supplied ID that uniquely identifies the DataSource.
        ###

        def set_DataSourceId(value)
          set_input("DataSourceId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the Verbose input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Specifies whether the GetDataSource operation should return DataSourceSchema. Defaults to true.
        ###

        def set_Verbose(value)
          set_input("Verbose", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteDataSource Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteDataSourceResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteDataSource



    ##############################################################################
    #
    # DeleteEvaluation
    #
    # Assigns the DELETED status to an Evaluation, rendering it unusable.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteEvaluation < Choreography

      ####
      #  Create a new instance of the DeleteEvaluation Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/DeleteEvaluation")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteEvaluationInputSet
      ####
      def new_input_set()
        return DeleteEvaluationInputSet.new()
      end

      def make_result_set()
        return DeleteEvaluationResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteEvaluationResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteEvaluation
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteEvaluationInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the EvaluationId input for this Choreo. 
        # 
        # @param String - (required, string) A user-supplied ID that uniquely identifies the Evaluation to delete.
        ###

        def set_EvaluationId(value)
          set_input("EvaluationId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteEvaluation Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteEvaluationResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteEvaluation



    ##############################################################################
    #
    # DeleteMLModel
    #
    # Assigns the DELETED status to an MLModel, rendering it unusable.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteMLModel < Choreography

      ####
      #  Create a new instance of the DeleteMLModel Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/DeleteMLModel")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteMLModelInputSet
      ####
      def new_input_set()
        return DeleteMLModelInputSet.new()
      end

      def make_result_set()
        return DeleteMLModelResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteMLModelResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteMLModel
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteMLModelInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the MLModelId input for this Choreo. 
        # 
        # @param String - (required, string) The ID assigned to the MLModelId at creation.
        ###

        def set_MLModelId(value)
          set_input("MLModelId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteMLModel Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteMLModelResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteMLModel



    ##############################################################################
    #
    # DeleteRealtimeEndpoint
    #
    # Deletes a real time endpoint of an MLModel.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteRealtimeEndpoint < Choreography

      ####
      #  Create a new instance of the DeleteRealtimeEndpoint Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/DeleteRealtimeEndpoint")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteRealtimeEndpointInputSet
      ####
      def new_input_set()
        return DeleteRealtimeEndpointInputSet.new()
      end

      def make_result_set()
        return DeleteRealtimeEndpointResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteRealtimeEndpointResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteRealtimeEndpoint
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteRealtimeEndpointInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the MLModelId input for this Choreo. 
        # 
        # @param String - (required, string) The ID assigned to the MLModelId at creation.
        ###

        def set_MLModelId(value)
          set_input("MLModelId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the Verbose input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Specifies whether the GetMLModel operation should return Recipe. Defaults to false.
        ###

        def set_Verbose(value)
          set_input("Verbose", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteRealtimeEndpoint Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteRealtimeEndpointResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteRealtimeEndpoint



    ##############################################################################
    #
    # DeleteTags
    #
    # Deletes the specified tags associated with an ML object.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteTags < Choreography

      ####
      #  Create a new instance of the DeleteTags Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/DeleteTags")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteTagsInputSet
      ####
      def new_input_set()
        return DeleteTagsInputSet.new()
      end

      def make_result_set()
        return DeleteTagsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteTagsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteTags
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteTagsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResourceId input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the ML object to tag.
        ###

        def set_ResourceId(value)
          set_input("ResourceId", value)
        end
        #### 
        # Set the value of the ResourceType input for this Choreo. 
        # 
        # @param String - (required, string) The type of the ML object to tag. Valid values are: BatchPrediction, DataSource, Evaluation, MLModel.
        ###

        def set_ResourceType(value)
          set_input("ResourceType", value)
        end
        #### 
        # Set the value of the TagKeys input for this Choreo. 
        # 
        # @param String - (required, json) One or more tags to delete.
        ###

        def set_TagKeys(value)
          set_input("TagKeys", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteTags Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteTagsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteTags



    ##############################################################################
    #
    # DescribeDataSources
    #
    # Returns a list of DataSources that match the search criteria in the request.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeDataSources < Choreography

      ####
      #  Create a new instance of the DescribeDataSources Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/DescribeDataSources")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeDataSourcesInputSet
      ####
      def new_input_set()
        return DescribeDataSourcesInputSet.new()
      end

      def make_result_set()
        return DescribeDataSourcesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeDataSourcesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeDataSources
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeDataSourcesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the EQ input for this Choreo. 
        # 
        # @param String - (optional, string) The equal to operator. The DataSource results will have FilterVariable values that exactly match the value specified with EQ.
        ###

        def set_EQ(value)
          set_input("EQ", value)
        end
        #### 
        # Set the value of the FilterVariable input for this Choreo. 
        # 
        # @param String - (optional, string) Use one of the following variables to filter a list of DataSource: CreatedAt, Status, Name, DataUri, IAMUser.
        ###

        def set_FilterVariable(value)
          set_input("FilterVariable", value)
        end
        #### 
        # Set the value of the GE input for this Choreo. 
        # 
        # @param String - (optional, string) The greater than or equal to operator. The DataSource results will have FilterVariable values that are greater than or equal to the value specified with GE.
        ###

        def set_GE(value)
          set_input("GE", value)
        end
        #### 
        # Set the value of the GT input for this Choreo. 
        # 
        # @param String - (optional, string) The greater than operator. The DataSource results will have FilterVariable values that are greater than the value specified with GT.
        ###

        def set_GT(value)
          set_input("GT", value)
        end
        #### 
        # Set the value of the LE input for this Choreo. 
        # 
        # @param String - (optional, string) The less than or equal to operator. The DataSource results will have FilterVariable values that are less than or equal to the value specified with LE.
        ###

        def set_LE(value)
          set_input("LE", value)
        end
        #### 
        # Set the value of the LT input for this Choreo. 
        # 
        # @param String - (optional, string) The less than operator. The DataSource results will have FilterVariable values that are less than the value specified with LT.
        ###

        def set_LT(value)
          set_input("LT", value)
        end
        #### 
        # Set the value of the Limit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The maximum number of DataSource to include in the result.
        ###

        def set_Limit(value)
          set_input("Limit", value)
        end
        #### 
        # Set the value of the NE input for this Choreo. 
        # 
        # @param String - (optional, string) The not equal to operator. The DataSource results will have FilterVariable values not equal to the value specified with NE.
        ###

        def set_NE(value)
          set_input("NE", value)
        end
        #### 
        # Set the value of the NextToken input for this Choreo. 
        # 
        # @param String - (optional, string) The ID of the page in the paginated results.
        ###

        def set_NextToken(value)
          set_input("NextToken", value)
        end
        #### 
        # Set the value of the Prefix input for this Choreo. 
        # 
        # @param String - (optional, string) A string that is found at the beginning of a variable, such as Name or Id.
        ###

        def set_Prefix(value)
          set_input("Prefix", value)
        end
        #### 
        # Set the value of the SortOrder input for this Choreo. 
        # 
        # @param String - (optional, string) Determines the sequence of the resulting list of DataSource. Valid values are: asc, dsc.
        ###

        def set_SortOrder(value)
          set_input("SortOrder", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeDataSources Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeDataSourcesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeDataSources



    ##############################################################################
    #
    # DescribeEvaluations
    #
    # Returns a list of Evaluations that match the search criteria in the request.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeEvaluations < Choreography

      ####
      #  Create a new instance of the DescribeEvaluations Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/DescribeEvaluations")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeEvaluationsInputSet
      ####
      def new_input_set()
        return DescribeEvaluationsInputSet.new()
      end

      def make_result_set()
        return DescribeEvaluationsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeEvaluationsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeEvaluations
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeEvaluationsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the EQ input for this Choreo. 
        # 
        # @param String - (optional, string) The equal to operator. The Evaluation results will have FilterVariable values that exactly match the value specified with EQ.
        ###

        def set_EQ(value)
          set_input("EQ", value)
        end
        #### 
        # Set the value of the FilterVariable input for this Choreo. 
        # 
        # @param String - (optional, string) Use one of the following variables to filter a list of Evaluation: CreatedAt, Status, Name, IAMUser, MLModelId, DataSourceId, DataUri.
        ###

        def set_FilterVariable(value)
          set_input("FilterVariable", value)
        end
        #### 
        # Set the value of the GE input for this Choreo. 
        # 
        # @param String - (optional, string) The greater than or equal to operator. The Evaluation results will have FilterVariable values that are greater than or equal to the value specified with GE.
        ###

        def set_GE(value)
          set_input("GE", value)
        end
        #### 
        # Set the value of the GT input for this Choreo. 
        # 
        # @param String - (optional, string) The greater than operator. The Evaluation results will have FilterVariable values that are greater than the value specified with GT.
        ###

        def set_GT(value)
          set_input("GT", value)
        end
        #### 
        # Set the value of the LE input for this Choreo. 
        # 
        # @param String - (optional, string) The less than or equal to operator. The Evaluation results will have FilterVariable values that are less than or equal to the value specified with LE.
        ###

        def set_LE(value)
          set_input("LE", value)
        end
        #### 
        # Set the value of the LT input for this Choreo. 
        # 
        # @param String - (optional, string) The less than operator. The Evaluation results will have FilterVariable values that are less than the value specified with LT.
        ###

        def set_LT(value)
          set_input("LT", value)
        end
        #### 
        # Set the value of the Limit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The maximum number of Evaluation to include in the result.
        ###

        def set_Limit(value)
          set_input("Limit", value)
        end
        #### 
        # Set the value of the NE input for this Choreo. 
        # 
        # @param String - (optional, string) The not equal to operator. The Evaluation results will have FilterVariable values not equal to the value specified with NE.
        ###

        def set_NE(value)
          set_input("NE", value)
        end
        #### 
        # Set the value of the NextToken input for this Choreo. 
        # 
        # @param String - (optional, string) The ID of the page in the paginated results.
        ###

        def set_NextToken(value)
          set_input("NextToken", value)
        end
        #### 
        # Set the value of the Prefix input for this Choreo. 
        # 
        # @param String - (optional, string) A string that is found at the beginning of a variable, such as Name or Id.
        ###

        def set_Prefix(value)
          set_input("Prefix", value)
        end
        #### 
        # Set the value of the SortOrder input for this Choreo. 
        # 
        # @param String - (optional, string) Determines the sequence of the resulting list of Evaluation. Valid values are: asc, dsc.
        ###

        def set_SortOrder(value)
          set_input("SortOrder", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeEvaluations Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeEvaluationsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeEvaluations



    ##############################################################################
    #
    # DescribeMLModels
    #
    # Returns a list of MLModels that match the search criteria in the request.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeMLModels < Choreography

      ####
      #  Create a new instance of the DescribeMLModels Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/DescribeMLModels")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeMLModelsInputSet
      ####
      def new_input_set()
        return DescribeMLModelsInputSet.new()
      end

      def make_result_set()
        return DescribeMLModelsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeMLModelsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeMLModels
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeMLModelsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the EQ input for this Choreo. 
        # 
        # @param String - (optional, string) The equal to operator. The MLModel results will have FilterVariable values that exactly match the value specified with EQ.
        ###

        def set_EQ(value)
          set_input("EQ", value)
        end
        #### 
        # Set the value of the FilterVariable input for this Choreo. 
        # 
        # @param String - (optional, string) Use one of the following variables to filter a list of MLModel: CreatedAt, Status, Name, IAMUser, TrainingDataSourceId, RealtimeEndpointStatus, MLModelType, Algorithm, TrainingDataURI.
        ###

        def set_FilterVariable(value)
          set_input("FilterVariable", value)
        end
        #### 
        # Set the value of the GE input for this Choreo. 
        # 
        # @param String - (optional, string) The greater than or equal to operator. The MLModel results will have FilterVariable values that are greater than or equal to the value specified with GE.
        ###

        def set_GE(value)
          set_input("GE", value)
        end
        #### 
        # Set the value of the GT input for this Choreo. 
        # 
        # @param String - (optional, string) The greater than operator. The MLModel results will have FilterVariable values that are greater than the value specified with GT.
        ###

        def set_GT(value)
          set_input("GT", value)
        end
        #### 
        # Set the value of the LE input for this Choreo. 
        # 
        # @param String - (optional, string) The less than or equal to operator. The MLModel results will have FilterVariable values that are less than or equal to the value specified with LE.
        ###

        def set_LE(value)
          set_input("LE", value)
        end
        #### 
        # Set the value of the LT input for this Choreo. 
        # 
        # @param String - (optional, string) The less than operator. The MLModel results will have FilterVariable values that are less than the value specified with LT.
        ###

        def set_LT(value)
          set_input("LT", value)
        end
        #### 
        # Set the value of the Limit input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The maximum number of MLModel to include in the result.
        ###

        def set_Limit(value)
          set_input("Limit", value)
        end
        #### 
        # Set the value of the NE input for this Choreo. 
        # 
        # @param String - (optional, string) The not equal to operator. The MLModel results will have FilterVariable values not equal to the value specified with NE.
        ###

        def set_NE(value)
          set_input("NE", value)
        end
        #### 
        # Set the value of the NextToken input for this Choreo. 
        # 
        # @param String - (optional, string) The ID of the page in the paginated results.
        ###

        def set_NextToken(value)
          set_input("NextToken", value)
        end
        #### 
        # Set the value of the Prefix input for this Choreo. 
        # 
        # @param String - (optional, string) A string that is found at the beginning of a variable, such as Name or Id.
        ###

        def set_Prefix(value)
          set_input("Prefix", value)
        end
        #### 
        # Set the value of the SortOrder input for this Choreo. 
        # 
        # @param String - (optional, string) Determines the sequence of the resulting list of MLModel. Valid values are: asc, dsc.
        ###

        def set_SortOrder(value)
          set_input("SortOrder", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeMLModels Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeMLModelsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeMLModels



    ##############################################################################
    #
    # DescribeTags
    #
    # Describes one or more of the tags for your Amazon ML object.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeTags < Choreography

      ####
      #  Create a new instance of the DescribeTags Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/DescribeTags")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeTagsInputSet
      ####
      def new_input_set()
        return DescribeTagsInputSet.new()
      end

      def make_result_set()
        return DescribeTagsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeTagsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeTags
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeTagsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResourceId input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the ML object.
        ###

        def set_ResourceId(value)
          set_input("ResourceId", value)
        end
        #### 
        # Set the value of the ResourceType input for this Choreo. 
        # 
        # @param String - (required, string) The type of the ML object. Valid values are: BatchPrediction, DataSource, Evaluation, MLModel.
        ###

        def set_ResourceType(value)
          set_input("ResourceType", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeTags Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeTagsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeTags



    ##############################################################################
    #
    # GetDataSource
    #
    # Returns a DataSource that includes metadata and data file information, as well as the current status of the DataSource.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetDataSource < Choreography

      ####
      #  Create a new instance of the GetDataSource Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/GetDataSource")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetDataSourceInputSet
      ####
      def new_input_set()
        return GetDataSourceInputSet.new()
      end

      def make_result_set()
        return GetDataSourceResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetDataSourceResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetDataSource
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetDataSourceInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the DataSourceId input for this Choreo. 
        # 
        # @param String - (required, string) The ID assigned to the DataSource at creation.
        ###

        def set_DataSourceId(value)
          set_input("DataSourceId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the Verbose input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Specifies whether the GetDataSource operation should return DataSourceSchema. Defaults to true.
        ###

        def set_Verbose(value)
          set_input("Verbose", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetDataSource Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetDataSourceResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetDataSource



    ##############################################################################
    #
    # GetEvaluation
    #
    # Returns an Evaluation that includes metadata as well as the current status of the Evaluation.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetEvaluation < Choreography

      ####
      #  Create a new instance of the GetEvaluation Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/GetEvaluation")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetEvaluationInputSet
      ####
      def new_input_set()
        return GetEvaluationInputSet.new()
      end

      def make_result_set()
        return GetEvaluationResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetEvaluationResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetEvaluation
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetEvaluationInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the EvaluationId input for this Choreo. 
        # 
        # @param String - (required, string) The ID of the Evaluation to retrieve.
        ###

        def set_EvaluationId(value)
          set_input("EvaluationId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetEvaluation Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetEvaluationResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetEvaluation



    ##############################################################################
    #
    # GetMLModel
    #
    # Returns an MLModel that includes detailed metadata, data source information, and the current status of the MLModel.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetMLModel < Choreography

      ####
      #  Create a new instance of the GetMLModel Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/GetMLModel")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetMLModelInputSet
      ####
      def new_input_set()
        return GetMLModelInputSet.new()
      end

      def make_result_set()
        return GetMLModelResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetMLModelResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetMLModel
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetMLModelInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the MLModelId input for this Choreo. 
        # 
        # @param String - (required, string) The ID assigned to the MLModelId at creation.
        ###

        def set_MLModelId(value)
          set_input("MLModelId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the Verbose input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Specifies whether the GetMLModel operation should return Recipe. Defaults to false.
        ###

        def set_Verbose(value)
          set_input("Verbose", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetMLModel Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetMLModelResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetMLModel



    ##############################################################################
    #
    # Predict
    #
    # Generates a prediction for the observation using the specified ML Model.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Predict < Choreography

      ####
      #  Create a new instance of the Predict Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/Predict")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PredictInputSet
      ####
      def new_input_set()
        return PredictInputSet.new()
      end

      def make_result_set()
        return PredictResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PredictResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Predict
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PredictInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the MLModelId input for this Choreo. 
        # 
        # @param String - (required, string) A unique identifier of the MLModel.
        ###

        def set_MLModelId(value)
          set_input("MLModelId", value)
        end
        #### 
        # Set the value of the PredictEndpoint input for this Choreo. 
        # 
        # @param String - (required, string) The realtime endpoint to use for the prediction.
        ###

        def set_PredictEndpoint(value)
          set_input("PredictEndpoint", value)
        end
        #### 
        # Set the value of the Record input for this Choreo. 
        # 
        # @param String - (required, json) A map of variable name-value pairs that represent an observation.
        ###

        def set_Record(value)
          set_input("Record", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Predict Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PredictResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Predict



    ##############################################################################
    #
    # UpdateBatchPrediction
    #
    # Updates the BatchPredictionName of a BatchPrediction.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UpdateBatchPrediction < Choreography

      ####
      #  Create a new instance of the UpdateBatchPrediction Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/UpdateBatchPrediction")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UpdateBatchPredictionInputSet
      ####
      def new_input_set()
        return UpdateBatchPredictionInputSet.new()
      end

      def make_result_set()
        return UpdateBatchPredictionResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UpdateBatchPredictionResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UpdateBatchPrediction
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UpdateBatchPredictionInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BatchPredictionId input for this Choreo. 
        # 
        # @param String - (required, string) The ID assigned to the BatchPrediction during creation.
        ###

        def set_BatchPredictionId(value)
          set_input("BatchPredictionId", value)
        end
        #### 
        # Set the value of the BatchPredictionName input for this Choreo. 
        # 
        # @param String - (required, string) A new user-supplied name or description of the BatchPrediction.
        ###

        def set_BatchPredictionName(value)
          set_input("BatchPredictionName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UpdateBatchPrediction Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UpdateBatchPredictionResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UpdateBatchPrediction



    ##############################################################################
    #
    # UpdateDataSource
    #
    # Updates the DataSourceName of a DataSource.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UpdateDataSource < Choreography

      ####
      #  Create a new instance of the UpdateDataSource Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/UpdateDataSource")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UpdateDataSourceInputSet
      ####
      def new_input_set()
        return UpdateDataSourceInputSet.new()
      end

      def make_result_set()
        return UpdateDataSourceResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UpdateDataSourceResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UpdateDataSource
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UpdateDataSourceInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the DataSourceId input for this Choreo. 
        # 
        # @param String - (required, string) The ID assigned to the DataSource at creation.
        ###

        def set_DataSourceId(value)
          set_input("DataSourceId", value)
        end
        #### 
        # Set the value of the DataSourceName input for this Choreo. 
        # 
        # @param String - (required, string) A new user-supplied name or description of the DataSource that will replace the current description.
        ###

        def set_DataSourceName(value)
          set_input("DataSourceName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UpdateDataSource Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UpdateDataSourceResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UpdateDataSource



    ##############################################################################
    #
    # UpdateEvaluation
    #
    # Updates the EvaluationName of an Evaluation.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UpdateEvaluation < Choreography

      ####
      #  Create a new instance of the UpdateEvaluation Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/UpdateEvaluation")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UpdateEvaluationInputSet
      ####
      def new_input_set()
        return UpdateEvaluationInputSet.new()
      end

      def make_result_set()
        return UpdateEvaluationResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UpdateEvaluationResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UpdateEvaluation
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UpdateEvaluationInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the EvaluationId input for this Choreo. 
        # 
        # @param String - (required, string) The ID assigned to the Evaluation during creation.
        ###

        def set_EvaluationId(value)
          set_input("EvaluationId", value)
        end
        #### 
        # Set the value of the EvaluationName input for this Choreo. 
        # 
        # @param String - (required, string) A new user-supplied name or description of the Evaluation that will replace the current content.
        ###

        def set_EvaluationName(value)
          set_input("EvaluationName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UpdateEvaluation Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UpdateEvaluationResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UpdateEvaluation



    ##############################################################################
    #
    # UpdateMLModel
    #
    # Updates the MLModelName and the ScoreThreshold of an MLModel.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UpdateMLModel < Choreography

      ####
      #  Create a new instance of the UpdateMLModel Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/MachineLearning/UpdateMLModel")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UpdateMLModelInputSet
      ####
      def new_input_set()
        return UpdateMLModelInputSet.new()
      end

      def make_result_set()
        return UpdateMLModelResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UpdateMLModelResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UpdateMLModel
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UpdateMLModelInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the MLModelId input for this Choreo. 
        # 
        # @param String - (required, string) The ID assigned to the MLModelId at creation.
        ###

        def set_MLModelId(value)
          set_input("MLModelId", value)
        end
        #### 
        # Set the value of the MLModelName input for this Choreo. 
        # 
        # @param String - (required, string) A user-supplied name or description of the MLModel.
        ###

        def set_MLModelName(value)
          set_input("MLModelName", value)
        end
        #### 
        # Set the value of the ScoreThreshold input for this Choreo. 
        # 
        # @param BigDecimal - (optional, decimal) The ScoreThreshold used in binary classification MLModel that marks the boundary between a positive prediction and a negative prediction.
        ###

        def set_ScoreThreshold(value)
          set_input("ScoreThreshold", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UpdateMLModel Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UpdateMLModelResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class UpdateMLModel




  end # module MachineLearning

  module Marketplace




    module Feeds



      ##############################################################################
      #
      # AddOrUpdateInventoryItem
      #
      # Add or update an individual inventory listing.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class AddOrUpdateInventoryItem < Choreography

        ####
        #  Create a new instance of the AddOrUpdateInventoryItem Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Feeds/AddOrUpdateInventoryItem")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return AddOrUpdateInventoryItemInputSet
        ####
        def new_input_set()
          return AddOrUpdateInventoryItemInputSet.new()
        end

        def make_result_set()
          return AddOrUpdateInventoryItemResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = AddOrUpdateInventoryItemResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the AddOrUpdateInventoryItem
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class AddOrUpdateInventoryItemInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the ExpeditedShipping input for this Choreo. 
          # 
          # @param String - (optional, string) The expedited shipping options that you offer for this item. Valid values: 3 = UK Only; N = None, no express delivery offered.
          ###

          def set_ExpeditedShipping(value)
            set_input("ExpeditedShipping", value)
          end
          #### 
          # Set the value of the FulfillmentCenterId input for this Choreo. 
          # 
          # @param String - (conditional, string) For those merchants using Amazon fulfillment services, this designates which fulfillment network will be used. Required when using Amazon fulfillment services. Valid values are: AMAZON_EU, DEFAULT.
          ###

          def set_FulfillmentCenterId(value)
            set_input("FulfillmentCenterId", value)
          end
          #### 
          # Set the value of the ItemCondition input for this Choreo. 
          # 
          # @param Integer - (conditional, integer) A numerical entry that indicates the condition of the item. Required for new listings. Valid values are: 1-11. See documentation for description of item condition numeric values.
          ###

          def set_ItemCondition(value)
            set_input("ItemCondition", value)
          end
          #### 
          # Set the value of the ItemNote input for this Choreo. 
          # 
          # @param String - (optional, string) A description or note for the item you're adding or updating.
          ###

          def set_ItemNote(value)
            set_input("ItemNote", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the Price input for this Choreo. 
          # 
          # @param BigDecimal - (conditional, decimal) The price at which the merchant offers the product for sale. Required if ProductId is provided.
          ###

          def set_Price(value)
            set_input("Price", value)
          end
          #### 
          # Set the value of the ProductId input for this Choreo. 
          # 
          # @param String - (conditional, string) A standard, alphanumeric string that uniquely identifies the product. This could be a UPC, EAN or ISBN.  This is a required field if product-id-type is provided.
          ###

          def set_ProductId(value)
            set_input("ProductId", value)
          end
          #### 
          # Set the value of the ProductIdType input for this Choreo. 
          # 
          # @param Integer - (conditional, integer) The type of standard, unique identifier entered in the product-id field. This is a required field if product-id is provided. Valid values are: 1 (ASIN), 2 (ISBN), 3 (UPC), 4  (EAN).
          ###

          def set_ProductIdType(value)
            set_input("ProductIdType", value)
          end
          #### 
          # Set the value of the Quantity input for this Choreo. 
          # 
          # @param Integer - (conditional, integer) Enter the quantity of the item you are making available for sale. Required for merchant-fulfilled items. Leave blank for amazon-fullfilled items.
          ###

          def set_Quantity(value)
            set_input("Quantity", value)
          end
          #### 
          # Set the value of the SKU input for this Choreo. 
          # 
          # @param String - (required, string) A unique identifier for the product, assigned by the merchant. The SKU must be unique for each product listed.
          ###

          def set_SKU(value)
            set_input("SKU", value)
          end
          #### 
          # Set the value of the TimeToWait input for this Choreo. 
          # 
          # @param Integer - (optional, integer) By default, the Choreo will wait for 10 minutes to see if the report is ready for retrieval. Max is 120 minutes.
          ###

          def set_TimeToWait(value)
            set_input("TimeToWait", value)
          end
          #### 
          # Set the value of the WillShipInternationally input for this Choreo. 
          # 
          # @param Integer - (optional, integer) Specify your international shipping options. Valid values are: 3 = UK Only; 4 = UK and Europe; 5 = UK, Europe, and North America; 6 = Worldwide
          ###

          def set_WillShipInternationally(value)
            set_input("WillShipInternationally", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the AddOrUpdateInventoryItem Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class AddOrUpdateInventoryItemResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "ProcessingStatus" output from this Choreo execution
        	#
        	# @return String - (string) The processing status of the product submission which is parsed from the Amazon response.
        	####
        	def get_ProcessingStatus()
        	  return @outputs["ProcessingStatus"]
        	end
        	####
        	# Retrieve the value for the "SubmissionId" output from this Choreo execution
        	#
        	# @return String - (integer) The submission id parsed from the Amazon response.
        	####
        	def get_SubmissionId()
        	  return @outputs["SubmissionId"]
        	end
        	####
        	# Retrieve the value for the "SubmissionResult" output from this Choreo execution
        	#
        	# @return String - (string) The submission result returned from Amazon.
        	####
        	def get_SubmissionResult()
        	  return @outputs["SubmissionResult"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (xml) The response from Amazon after submitting the feed.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class AddOrUpdateInventoryItem



      ##############################################################################
      #
      # AddOrUpdateInventoryItems
      #
      # Adds or updates one or more inventory listings in your Seller Central account with a given flat flile.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class AddOrUpdateInventoryItems < Choreography

        ####
        #  Create a new instance of the AddOrUpdateInventoryItems Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Feeds/AddOrUpdateInventoryItems")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return AddOrUpdateInventoryItemsInputSet
        ####
        def new_input_set()
          return AddOrUpdateInventoryItemsInputSet.new()
        end

        def make_result_set()
          return AddOrUpdateInventoryItemsResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = AddOrUpdateInventoryItemsResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the AddOrUpdateInventoryItems
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class AddOrUpdateInventoryItemsInputSet < Choreography::InputSet

          #### 
          # Set the value of the FeedData input for this Choreo. 
          # 
          # @param String - (conditional, multiline) The feed data to sumbit to Amazon Marketplace.
          ###

          def set_FeedData(value)
            set_input("FeedData", value)
          end
          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the TimeToWait input for this Choreo. 
          # 
          # @param Integer - (optional, integer) By default, the Choreo will wait for 10 minutes to see if the report is ready for retrieval. Max is 120 minutes.
          ###

          def set_TimeToWait(value)
            set_input("TimeToWait", value)
          end
          #### 
          # Set the value of the VaultFile input for this Choreo. 
          # 
          # @param TembooPath - The path to the vault file you want to submit. Required unless you using the FeedData input.
          ###

          def set_VaultFile(value)
            set_alias("VaultFile", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the AddOrUpdateInventoryItems Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class AddOrUpdateInventoryItemsResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "ProcessingStatus" output from this Choreo execution
        	#
        	# @return String - (string) The processing status of the feed submission which is parsed from the Amazon response.
        	####
        	def get_ProcessingStatus()
        	  return @outputs["ProcessingStatus"]
        	end
        	####
        	# Retrieve the value for the "SubmissionId" output from this Choreo execution
        	#
        	# @return String - (integer) The submission id parsed from the Amazon response.
        	####
        	def get_SubmissionId()
        	  return @outputs["SubmissionId"]
        	end
        	####
        	# Retrieve the value for the "SubmissionResult" output from this Choreo execution
        	#
        	# @return String - (string) The submission result returned from Amazon.
        	####
        	def get_SubmissionResult()
        	  return @outputs["SubmissionResult"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (xml) The response from Amazon after submitting the feed.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class AddOrUpdateInventoryItems



      ##############################################################################
      #
      # AddOrUpdateProductImage
      #
      # Adds or updates a product image with a given image location and SKU.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class AddOrUpdateProductImage < Choreography

        ####
        #  Create a new instance of the AddOrUpdateProductImage Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Feeds/AddOrUpdateProductImage")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return AddOrUpdateProductImageInputSet
        ####
        def new_input_set()
          return AddOrUpdateProductImageInputSet.new()
        end

        def make_result_set()
          return AddOrUpdateProductImageResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = AddOrUpdateProductImageResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the AddOrUpdateProductImage
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class AddOrUpdateProductImageInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the ImageLocation input for this Choreo. 
          # 
          # @param String - (required, string) The URL for the image location.
          ###

          def set_ImageLocation(value)
            set_input("ImageLocation", value)
          end
          #### 
          # Set the value of the ImageType input for this Choreo. 
          # 
          # @param String - (optional, string) The type of image (Main, Alternate, or Swatch). Defaults to "Main".
          ###

          def set_ImageType(value)
            set_input("ImageType", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the SKU input for this Choreo. 
          # 
          # @param String - (required, string) A SKU is a "Stock Keeping Unit" which you can assign to your products to track your inventory. Provide the SKU for the product that is associated with the image you are uploading.
          ###

          def set_SKU(value)
            set_input("SKU", value)
          end
          #### 
          # Set the value of the TimeToWait input for this Choreo. 
          # 
          # @param Integer - (optional, integer) By default, the Choreo will wait for 10 minutes to see if the report is ready for retrieval. Max is 120 minutes.
          ###

          def set_TimeToWait(value)
            set_input("TimeToWait", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the AddOrUpdateProductImage Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class AddOrUpdateProductImageResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "ProcessingStatus" output from this Choreo execution
        	#
        	# @return String - (string) The processing status of the feed submission which is parsed from the Amazon response.
        	####
        	def get_ProcessingStatus()
        	  return @outputs["ProcessingStatus"]
        	end
        	####
        	# Retrieve the value for the "SubmissionId" output from this Choreo execution
        	#
        	# @return String - (integer) The submission id parsed from the Amazon response.
        	####
        	def get_SubmissionId()
        	  return @outputs["SubmissionId"]
        	end
        	####
        	# Retrieve the value for the "SubmissionResult" output from this Choreo execution
        	#
        	# @return String - (string) The submission result returned from Amazon.
        	####
        	def get_SubmissionResult()
        	  return @outputs["SubmissionResult"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (xml) The response from Amazon after submitting the feed.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class AddOrUpdateProductImage



      ##############################################################################
      #
      # DeleteInventoryItem
      #
      # Deletes an individual inventory listings from a Seller Central account with a given SKU.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class DeleteInventoryItem < Choreography

        ####
        #  Create a new instance of the DeleteInventoryItem Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Feeds/DeleteInventoryItem")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return DeleteInventoryItemInputSet
        ####
        def new_input_set()
          return DeleteInventoryItemInputSet.new()
        end

        def make_result_set()
          return DeleteInventoryItemResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = DeleteInventoryItemResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the DeleteInventoryItem
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class DeleteInventoryItemInputSet < Choreography::InputSet

          #### 
          # Set the value of the SKU input for this Choreo. 
          # 
          # @param String - (required, string) A individual SKU associating with the product to delete.
          ###

          def set_SKU(value)
            set_input("SKU", value)
          end
          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the DeleteOptions input for this Choreo. 
          # 
          # @param String - (optional, string) Use 'd' to reduce the listings inventory to 0 and keep details in the system. Use 'x'  to completely delete listings from your current inventory. Defaults to "d".
          ###

          def set_DeleteOptions(value)
            set_input("DeleteOptions", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the TimeToWait input for this Choreo. 
          # 
          # @param Integer - (optional, integer) By default, the Choreo will wait for 10 minutes to see if the report is ready for retrieval. Max is 120 minutes.
          ###

          def set_TimeToWait(value)
            set_input("TimeToWait", value)
          end
          #### 
          # Set the value of the VaultFile input for this Choreo. 
          # 
          # @param TembooPath - The path to the vault file you want to submit.
          ###

          def set_VaultFile(value)
            set_alias("VaultFile", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the DeleteInventoryItem Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class DeleteInventoryItemResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "ProcessingStatus" output from this Choreo execution
        	#
        	# @return String - (string) The processing status of the feed submission which is parsed from the Amazon response.
        	####
        	def get_ProcessingStatus()
        	  return @outputs["ProcessingStatus"]
        	end
        	####
        	# Retrieve the value for the "SubmissionId" output from this Choreo execution
        	#
        	# @return String - (integer) The submission id parsed from the Amazon response.
        	####
        	def get_SubmissionId()
        	  return @outputs["SubmissionId"]
        	end
        	####
        	# Retrieve the value for the "SubmissionResult" output from this Choreo execution
        	#
        	# @return String - (string) The submission result returned from Amazon.
        	####
        	def get_SubmissionResult()
        	  return @outputs["SubmissionResult"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (xml) The response from Amazon after submitting the feed.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class DeleteInventoryItem



      ##############################################################################
      #
      # DeleteInventoryItems
      #
      # Deletes inventory listings from a Seller Central account with a given flat file of SKUs.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class DeleteInventoryItems < Choreography

        ####
        #  Create a new instance of the DeleteInventoryItems Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Feeds/DeleteInventoryItems")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return DeleteInventoryItemsInputSet
        ####
        def new_input_set()
          return DeleteInventoryItemsInputSet.new()
        end

        def make_result_set()
          return DeleteInventoryItemsResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = DeleteInventoryItemsResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the DeleteInventoryItems
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class DeleteInventoryItemsInputSet < Choreography::InputSet

          #### 
          # Set the value of the SKUs input for this Choreo. 
          # 
          # @param String - (conditional, multiline) The list of SKUs associating with the products to delete. SKUs are provided as Tab Delimited values (do not include a sku column name).
          ###

          def set_SKUs(value)
            set_input("SKUs", value)
          end
          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the DeleteOptions input for this Choreo. 
          # 
          # @param String - (optional, string) Use 'd' to reduce the listings inventory to 0 and keep details in the system. Use 'x'  to completely delete listings from your current inventory. Defaults to "d".
          ###

          def set_DeleteOptions(value)
            set_input("DeleteOptions", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the TimeToWait input for this Choreo. 
          # 
          # @param Integer - (optional, integer) By default, the Choreo will wait for 10 minutes to see if the report is ready for retrieval. Max is 120 minutes.
          ###

          def set_TimeToWait(value)
            set_input("TimeToWait", value)
          end
          #### 
          # Set the value of the VaultFile input for this Choreo. 
          # 
          # @param TembooPath - The path to the vault file you want to submit.
          ###

          def set_VaultFile(value)
            set_alias("VaultFile", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the DeleteInventoryItems Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class DeleteInventoryItemsResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "ProcessingStatus" output from this Choreo execution
        	#
        	# @return String - (string) The processing status of the feed submission which is parsed from the Amazon response.
        	####
        	def get_ProcessingStatus()
        	  return @outputs["ProcessingStatus"]
        	end
        	####
        	# Retrieve the value for the "SubmissionId" output from this Choreo execution
        	#
        	# @return String - (integer) The submission id parsed from the Amazon response.
        	####
        	def get_SubmissionId()
        	  return @outputs["SubmissionId"]
        	end
        	####
        	# Retrieve the value for the "SubmissionResult" output from this Choreo execution
        	#
        	# @return String - (string) The submission result returned from Amazon.
        	####
        	def get_SubmissionResult()
        	  return @outputs["SubmissionResult"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (xml) The response from Amazon after submitting the feed.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class DeleteInventoryItems



      ##############################################################################
      #
      # GetFeedSubmissionList
      #
      # Returns a list of all feed submissions submitted in the previous 90 days.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetFeedSubmissionList < Choreography

        ####
        #  Create a new instance of the GetFeedSubmissionList Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Feeds/GetFeedSubmissionList")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetFeedSubmissionListInputSet
        ####
        def new_input_set()
          return GetFeedSubmissionListInputSet.new()
        end

        def make_result_set()
          return GetFeedSubmissionListResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetFeedSubmissionListResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetFeedSubmissionList
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetFeedSubmissionListInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the FeedProcessingStatusList input for this Choreo. 
          # 
          # @param String - (optional, string) A comma separated list of one or more feed processing statuses by which to filter the list of feed submissions.
          ###

          def set_FeedProcessingStatusList(value)
            set_input("FeedProcessingStatusList", value)
          end
          #### 
          # Set the value of the FeedSubmissionIdList input for this Choreo. 
          # 
          # @param String - (optional, string) A comma separated list of FeedSubmmissionId values. If you pass in FeedSubmmissionId values in a request, other query conditions are ignored.
          ###

          def set_FeedSubmissionIdList(value)
            set_input("FeedSubmissionIdList", value)
          end
          #### 
          # Set the value of the FeedTypeList input for this Choreo. 
          # 
          # @param String - (optional, string) A comma separated list of one or more FeedType enumeration values by which to filter the list of feed submissions.
          ###

          def set_FeedTypeList(value)
            set_input("FeedTypeList", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the MaxCount input for this Choreo. 
          # 
          # @param Integer - (optional, integer) A non-negative integer that indicates the maximum number of feed submissions to return in the list. Defaults to 10. Max is 100.
          ###

          def set_MaxCount(value)
            set_input("MaxCount", value)
          end
          #### 
          # Set the value of the SubmittedFromDate input for this Choreo. 
          # 
          # @param String - (optional, date) The earliest submission date that you are looking for, in ISO8601 date format (i.e. 2012-01-01).
          ###

          def set_SubmittedFromDate(value)
            set_input("SubmittedFromDate", value)
          end
          #### 
          # Set the value of the SubmittedToDate input for this Choreo. 
          # 
          # @param String - (optional, date) The latest submission date that you are looking for, in ISO8601 date format (i.e. 2012-01-01).
          ###

          def set_SubmittedToDate(value)
            set_input("SubmittedToDate", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetFeedSubmissionList Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetFeedSubmissionListResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "FeedProcessingStatus" output from this Choreo execution
        	#
        	# @return String - (string) The FeedProcessingStatus parsed from the Amazon response.
        	####
        	def get_FeedProcessingStatus()
        	  return @outputs["FeedProcessingStatus"]
        	end
        	####
        	# Retrieve the value for the "FeedSubmissionId" output from this Choreo execution
        	#
        	# @return String - (integer) The FeedSubmissionId parsed from the Amazon response. If multiple records are returned, this output variable will contain the first id in the list.
        	####
        	def get_FeedSubmissionId()
        	  return @outputs["FeedSubmissionId"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (xml) Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetFeedSubmissionList



      ##############################################################################
      #
      # GetFeedSubmissionResult
      #
      # Returns the feed processing report and the Content-MD5 header.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetFeedSubmissionResult < Choreography

        ####
        #  Create a new instance of the GetFeedSubmissionResult Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Feeds/GetFeedSubmissionResult")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetFeedSubmissionResultInputSet
        ####
        def new_input_set()
          return GetFeedSubmissionResultInputSet.new()
        end

        def make_result_set()
          return GetFeedSubmissionResultResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetFeedSubmissionResultResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetFeedSubmissionResult
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetFeedSubmissionResultInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the FeedSubmissionId input for this Choreo. 
          # 
          # @param String - (required, string) A FeedSubmmissionId value.
          ###

          def set_FeedSubmissionId(value)
            set_input("FeedSubmissionId", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetFeedSubmissionResult Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetFeedSubmissionResultResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "ContentMD5Header" output from this Choreo execution
        	#
        	# @return String - (string) The Content MD5 header returned from Amazon. This can used to check against an MD5 hash that you generate before submitting the feed to verify that the feed was submitted correctly.
        	####
        	def get_ContentMD5Header()
        	  return @outputs["ContentMD5Header"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetFeedSubmissionResult



      ##############################################################################
      #
      # SubmitFeed
      #
      # Submits a feed, of the specified type, to Amazon Marketplace.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class SubmitFeed < Choreography

        ####
        #  Create a new instance of the SubmitFeed Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Feeds/SubmitFeed")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return SubmitFeedInputSet
        ####
        def new_input_set()
          return SubmitFeedInputSet.new()
        end

        def make_result_set()
          return SubmitFeedResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = SubmitFeedResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the SubmitFeed
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class SubmitFeedInputSet < Choreography::InputSet

          #### 
          # Set the value of the FeedData input for this Choreo. 
          # 
          # @param String - (conditional, multiline) The feed data to submit to Amazon Marketplace.
          ###

          def set_FeedData(value)
            set_input("FeedData", value)
          end
          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the FeedType input for this Choreo. 
          # 
          # @param String - (optional, string) The type of feed being submitted.  Default value is set to  _POST_FLAT_FILE_INVLOADER_DATA_).
          ###

          def set_FeedType(value)
            set_input("FeedType", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the TimeToWait input for this Choreo. 
          # 
          # @param Integer - (optional, integer) By default, the Choreo will wait for 10 minutes to see if the report is ready for retrieval. Max is 120 minutes.
          ###

          def set_TimeToWait(value)
            set_input("TimeToWait", value)
          end
          #### 
          # Set the value of the VaultFile input for this Choreo. 
          # 
          # @param TembooPath - The path to the vault file you want to submit. Required unless you using the FeedData input.
          ###

          def set_VaultFile(value)
            set_alias("VaultFile", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the SubmitFeed Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class SubmitFeedResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "ProcessingStatus" output from this Choreo execution
        	#
        	# @return String - (string) The processing status of the feed submission which is parsed from the Amazon response.
        	####
        	def get_ProcessingStatus()
        	  return @outputs["ProcessingStatus"]
        	end
        	####
        	# Retrieve the value for the "SubmissionId" output from this Choreo execution
        	#
        	# @return String - (integer) The submission id parsed from the Amazon response.
        	####
        	def get_SubmissionId()
        	  return @outputs["SubmissionId"]
        	end
        	####
        	# Retrieve the value for the "SubmissionResult" output from this Choreo execution
        	#
        	# @return String - (string) The submission result returned from Amazon.
        	####
        	def get_SubmissionResult()
        	  return @outputs["SubmissionResult"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (xml) The response from Amazon after submitting the feed.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class SubmitFeed



      ##############################################################################
      #
      # UpdatePriceAndQuantity
      #
      # Updates only the price and quantity of a particular product with a given product SKU.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class UpdatePriceAndQuantity < Choreography

        ####
        #  Create a new instance of the UpdatePriceAndQuantity Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Feeds/UpdatePriceAndQuantity")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return UpdatePriceAndQuantityInputSet
        ####
        def new_input_set()
          return UpdatePriceAndQuantityInputSet.new()
        end

        def make_result_set()
          return UpdatePriceAndQuantityResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = UpdatePriceAndQuantityResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the UpdatePriceAndQuantity
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class UpdatePriceAndQuantityInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the Price input for this Choreo. 
          # 
          # @param BigDecimal - (required, decimal) Enter the unit price for this product. The price must be greater than 0.00. Do NOT include the currency symbol (e.g. $).
          ###

          def set_Price(value)
            set_input("Price", value)
          end
          #### 
          # Set the value of the Quantity input for this Choreo. 
          # 
          # @param Integer - (required, integer) Enter the quantity of the product you have for sale. The quantity must be a whole number, and should be greater than zero.
          ###

          def set_Quantity(value)
            set_input("Quantity", value)
          end
          #### 
          # Set the value of the SKU input for this Choreo. 
          # 
          # @param String - (required, string) A SKU is a "Stock Keeping Unit" which you can assign to your products to track your inventory. Provide the SKU that you want to modify.
          ###

          def set_SKU(value)
            set_input("SKU", value)
          end
          #### 
          # Set the value of the TimeToWait input for this Choreo. 
          # 
          # @param Integer - (optional, integer) By default, the Choreo will wait for 10 minutes to see if the report is ready for retrieval. Max is 120 minutes.
          ###

          def set_TimeToWait(value)
            set_input("TimeToWait", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the UpdatePriceAndQuantity Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class UpdatePriceAndQuantityResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "ProcessingStatus" output from this Choreo execution
        	#
        	# @return String - (string) The processing status of the feed submission which is parsed from the Amazon response.
        	####
        	def get_ProcessingStatus()
        	  return @outputs["ProcessingStatus"]
        	end
        	####
        	# Retrieve the value for the "SubmissionId" output from this Choreo execution
        	#
        	# @return String - (integer) The submission id parsed from the Amazon response.
        	####
        	def get_SubmissionId()
        	  return @outputs["SubmissionId"]
        	end
        	####
        	# Retrieve the value for the "SubmissionResult" output from this Choreo execution
        	#
        	# @return String - (string) The submission result returned from Amazon.
        	####
        	def get_SubmissionResult()
        	  return @outputs["SubmissionResult"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (xml) The response from Amazon after submitting the feed.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class UpdatePriceAndQuantity




    end # module Feeds

    module Inventory



      ##############################################################################
      #
      # ListInventorySupplyByDateRange
      #
      # Returns information about the availability of a seller's inventory using a given date range.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class ListInventorySupplyByDateRange < Choreography

        ####
        #  Create a new instance of the ListInventorySupplyByDateRange Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Inventory/ListInventorySupplyByDateRange")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return ListInventorySupplyByDateRangeInputSet
        ####
        def new_input_set()
          return ListInventorySupplyByDateRangeInputSet.new()
        end

        def make_result_set()
          return ListInventorySupplyByDateRangeResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = ListInventorySupplyByDateRangeResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the ListInventorySupplyByDateRange
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class ListInventorySupplyByDateRangeInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the PageToken input for this Choreo. 
          # 
          # @param String - (conditional, string) The value returned in the NextPageToken output of this Choreo when there are multiple pages of inventory items to retrieve. Required unless providing QueryStartDateTime.
          ###

          def set_PageToken(value)
            set_input("PageToken", value)
          end
          #### 
          # Set the value of the QueryStartDateTime input for this Choreo. 
          # 
          # @param String - (conditional, date) A date used for selecting items that have had changes in inventory availability after (or at) a specified time, in ISO 8601 date format (i.e. 2012-01-01). Required unless providing PageToken.
          ###

          def set_QueryStartDateTime(value)
            set_input("QueryStartDateTime", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end
          #### 
          # Set the value of the ResponseGroup input for this Choreo. 
          # 
          # @param String - (optional, string) Indicates whether or not to return the SupplyDetail element in the response. Valid values are: "Basic" (does not include SupplyDetail), and "Detailed" (includes SupplyDetail). Defaults to "Basic".
          ###

          def set_ResponseGroup(value)
            set_input("ResponseGroup", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the ListInventorySupplyByDateRange Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class ListInventorySupplyByDateRangeResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NextPageToken" output from this Choreo execution
        	#
        	# @return String - (string) A token used to retrieve the next page of results. If a token is not returned, there are no more results to retrieve. This token can be passed to the PageToken input of this Choreo.
        	####
        	def get_NextPageToken()
        	  return @outputs["NextPageToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class ListInventorySupplyByDateRange



      ##############################################################################
      #
      # ListInventorySupplyBySKU
      #
      # Returns information about the availability of a seller's inventory using a given SellerSKU.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class ListInventorySupplyBySKU < Choreography

        ####
        #  Create a new instance of the ListInventorySupplyBySKU Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Inventory/ListInventorySupplyBySKU")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return ListInventorySupplyBySKUInputSet
        ####
        def new_input_set()
          return ListInventorySupplyBySKUInputSet.new()
        end

        def make_result_set()
          return ListInventorySupplyBySKUResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = ListInventorySupplyBySKUResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the ListInventorySupplyBySKU
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class ListInventorySupplyBySKUInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end
          #### 
          # Set the value of the ResponseGroup input for this Choreo. 
          # 
          # @param String - (optional, string) Indicates whether or not to return the SupplyDetail element in the response. Valid values are: "Basic" (does not include SupplyDetail), and "Detailed" (includes SupplyDetail). Defaults to "Basic".
          ###

          def set_ResponseGroup(value)
            set_input("ResponseGroup", value)
          end
          #### 
          # Set the value of the SellerSKU input for this Choreo. 
          # 
          # @param String - (required, string) A seller SKU for an item that you want inventory availability information about.
          ###

          def set_SellerSKU(value)
            set_input("SellerSKU", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the ListInventorySupplyBySKU Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class ListInventorySupplyBySKUResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class ListInventorySupplyBySKU




    end # module Inventory

    module Orders



      ##############################################################################
      #
      # GetOrder
      #
      # Returns orders based on the AmazonOrderId values that you specify.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetOrder < Choreography

        ####
        #  Create a new instance of the GetOrder Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Orders/GetOrder")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetOrderInputSet
        ####
        def new_input_set()
          return GetOrderInputSet.new()
        end

        def make_result_set()
          return GetOrderResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetOrderResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetOrder
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetOrderInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the AmazonOrderId input for this Choreo. 
          # 
          # @param String - (required, string) One or more AmazonOrderId values separated by commas used to retrieve orders.
          ###

          def set_AmazonOrderId(value)
            set_input("AmazonOrderId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetOrder Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetOrderResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetOrder



      ##############################################################################
      #
      # GetServiceStatus
      #
      # Returns the operational status of the Orders API section.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetServiceStatus < Choreography

        ####
        #  Create a new instance of the GetServiceStatus Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Orders/GetServiceStatus")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetServiceStatusInputSet
        ####
        def new_input_set()
          return GetServiceStatusInputSet.new()
        end

        def make_result_set()
          return GetServiceStatusResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetServiceStatusResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetServiceStatus
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetServiceStatusInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetServiceStatus Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetServiceStatusResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetServiceStatus



      ##############################################################################
      #
      # ListOrderItems
      #
      # Returns order items based on a specified AmazonOrderId.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class ListOrderItems < Choreography

        ####
        #  Create a new instance of the ListOrderItems Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Orders/ListOrderItems")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return ListOrderItemsInputSet
        ####
        def new_input_set()
          return ListOrderItemsInputSet.new()
        end

        def make_result_set()
          return ListOrderItemsResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = ListOrderItemsResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the ListOrderItems
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class ListOrderItemsInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the AmazonOrderId input for this Choreo. 
          # 
          # @param String - (required, string) An Amazon-defined order identifier.
          ###

          def set_AmazonOrderId(value)
            set_input("AmazonOrderId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the PageToken input for this Choreo. 
          # 
          # @param String - (optional, string) The value returned in the NextPageToken output of this Choreo when there are multiple pages of order items to retrieve.
          ###

          def set_PageToken(value)
            set_input("PageToken", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the ListOrderItems Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class ListOrderItemsResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NextPageToken" output from this Choreo execution
        	#
        	# @return String - (string) A token used to retrieve the next page of results. If a token is not returned, there are no more results to retrieve. This token can be passed to the PageToken input of this Choreo.
        	####
        	def get_NextPageToken()
        	  return @outputs["NextPageToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class ListOrderItems



      ##############################################################################
      #
      # ListOrders
      #
      # Returns orders created during a time frame that you specify.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class ListOrders < Choreography

        ####
        #  Create a new instance of the ListOrders Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Orders/ListOrders")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return ListOrdersInputSet
        ####
        def new_input_set()
          return ListOrdersInputSet.new()
        end

        def make_result_set()
          return ListOrdersResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = ListOrdersResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the ListOrders
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class ListOrdersInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the CreatedAfter input for this Choreo. 
          # 
          # @param String - (optional, date) A date used for selecting orders created after (or at) a specified time, in ISO 8601 date format (i.e. 2012-01-01). Defaults to today's date if not provided.
          ###

          def set_CreatedAfter(value)
            set_input("CreatedAfter", value)
          end
          #### 
          # Set the value of the CreatedBefore input for this Choreo. 
          # 
          # @param String - (optional, date) A date used for selecting orders created before (or at) a specified time, in ISO 8601 date format (i.e. 2012-01-01).
          ###

          def set_CreatedBefore(value)
            set_input("CreatedBefore", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the FullfillmentChannel input for this Choreo. 
          # 
          # @param String - (optional, string) A string indicating how an order was fulfilled. Use "AFN" for Amazon fulfilled orders, and "MFN" for seller fulfilled orders.
          ###

          def set_FullfillmentChannel(value)
            set_input("FullfillmentChannel", value)
          end
          #### 
          # Set the value of the LastUpdatedAfter input for this Choreo. 
          # 
          # @param String - (optional, date) A date used for selecting orders that were last updated after (or at) a specified time, in ISO 8601 date format (i.e. 2012-01-01). Cannot be specified if CreatedAfter is specified.
          ###

          def set_LastUpdatedAfter(value)
            set_input("LastUpdatedAfter", value)
          end
          #### 
          # Set the value of the LastUpdatedBefore input for this Choreo. 
          # 
          # @param String - (optional, date) A date used for selecting orders that were last updated before (or at) a specified time, in ISO 8601 date format (i.e. 2012-01-01). Cannot be specified if CreatedAfter is specified.
          ###

          def set_LastUpdatedBefore(value)
            set_input("LastUpdatedBefore", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the MaxResultsPerPage input for this Choreo. 
          # 
          # @param Integer - (optional, integer) A number that indicates the maximum number of orders that can be returned per page. Valid values are: 1-100.
          ###

          def set_MaxResultsPerPage(value)
            set_input("MaxResultsPerPage", value)
          end
          #### 
          # Set the value of the OrderStatus input for this Choreo. 
          # 
          # @param String - (optional, string) One or more OrderStatus values separated by commas. This options selects only orders with a certain status (e.g. Pending, Unshipped, PartiallyShipped, Shipped, Canceled, Unfulfillable, etc).
          ###

          def set_OrderStatus(value)
            set_input("OrderStatus", value)
          end
          #### 
          # Set the value of the PageToken input for this Choreo. 
          # 
          # @param String - (optional, string) The value returned in the NextPageToken output of this Choreo when there are multiple pages of orders to retrieve.
          ###

          def set_PageToken(value)
            set_input("PageToken", value)
          end
          #### 
          # Set the value of the PaymentMethod input for this Choreo. 
          # 
          # @param String - (optional, string) Used to select only orders of a certain payment type. Valid values are: COD (cash on delivery), CVS (convenience store payment), or Other (Any payment method other than COD or CVS).
          ###

          def set_PaymentMethod(value)
            set_input("PaymentMethod", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the ListOrders Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class ListOrdersResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NextPageToken" output from this Choreo execution
        	#
        	# @return String - (string) A token used to retrieve the next page of results. If a token is not returned, there are no more results to retrieve. This token can be passed to the PageToken input of this Choreo.
        	####
        	def get_NextPageToken()
        	  return @outputs["NextPageToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class ListOrders



      ##############################################################################
      #
      # ListOrdersWithBuyerEmail
      #
      # Returns orders associated with a buyer's email address that you specify.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class ListOrdersWithBuyerEmail < Choreography

        ####
        #  Create a new instance of the ListOrdersWithBuyerEmail Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Orders/ListOrdersWithBuyerEmail")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return ListOrdersWithBuyerEmailInputSet
        ####
        def new_input_set()
          return ListOrdersWithBuyerEmailInputSet.new()
        end

        def make_result_set()
          return ListOrdersWithBuyerEmailResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = ListOrdersWithBuyerEmailResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the ListOrdersWithBuyerEmail
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class ListOrdersWithBuyerEmailInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the BuyerEmail input for this Choreo. 
          # 
          # @param String - (required, string) The e-mail address of a buyer. Used to select only the orders that contain the specified e-mail address.
          ###

          def set_BuyerEmail(value)
            set_input("BuyerEmail", value)
          end
          #### 
          # Set the value of the CreatedAfter input for this Choreo. 
          # 
          # @param String - (optional, date) A date used for selecting orders created after (or at) a specified time, in ISO 8601 date format (i.e. 2012-01-01). Defaults to today's date if not provided.
          ###

          def set_CreatedAfter(value)
            set_input("CreatedAfter", value)
          end
          #### 
          # Set the value of the CreatedBefore input for this Choreo. 
          # 
          # @param String - (optional, date) A date used for selecting orders created before (or at) a specified time, in ISO 8601 date format (i.e. 2012-01-01).
          ###

          def set_CreatedBefore(value)
            set_input("CreatedBefore", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the MaxResultsPerPage input for this Choreo. 
          # 
          # @param Integer - (optional, integer) A number that indicates the maximum number of orders that can be returned per page. Valid values are: 1-100.
          ###

          def set_MaxResultsPerPage(value)
            set_input("MaxResultsPerPage", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the ListOrdersWithBuyerEmail Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class ListOrdersWithBuyerEmailResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class ListOrdersWithBuyerEmail



      ##############################################################################
      #
      # ListOrdersWithSellerOrderId
      #
      # Returns orders associated with a seller order id that you specify.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class ListOrdersWithSellerOrderId < Choreography

        ####
        #  Create a new instance of the ListOrdersWithSellerOrderId Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Orders/ListOrdersWithSellerOrderId")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return ListOrdersWithSellerOrderIdInputSet
        ####
        def new_input_set()
          return ListOrdersWithSellerOrderIdInputSet.new()
        end

        def make_result_set()
          return ListOrdersWithSellerOrderIdResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = ListOrdersWithSellerOrderIdResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the ListOrdersWithSellerOrderId
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class ListOrdersWithSellerOrderIdInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the CreatedAfter input for this Choreo. 
          # 
          # @param String - (optional, date) A date used for selecting orders created after (or at) a specified time, in ISO 8601 date format (i.e. 2012-01-01). Defaults to today's date if not provided.
          ###

          def set_CreatedAfter(value)
            set_input("CreatedAfter", value)
          end
          #### 
          # Set the value of the CreatedBefore input for this Choreo. 
          # 
          # @param String - (optional, date) A date used for selecting orders created before (or at) a specified time, in ISO 8601 date format (i.e. 2012-01-01).
          ###

          def set_CreatedBefore(value)
            set_input("CreatedBefore", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the MaxResultsPerPage input for this Choreo. 
          # 
          # @param Integer - (optional, integer) A number that indicates the maximum number of orders that can be returned per page. Valid values are: 1-100.
          ###

          def set_MaxResultsPerPage(value)
            set_input("MaxResultsPerPage", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end
          #### 
          # Set the value of the SellerOrderId input for this Choreo. 
          # 
          # @param String - (required, string) An order identifier that is specified by the seller.
          ###

          def set_SellerOrderId(value)
            set_input("SellerOrderId", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the ListOrdersWithSellerOrderId Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class ListOrdersWithSellerOrderIdResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class ListOrdersWithSellerOrderId




    end # module Orders

    module OutboundShipments



      ##############################################################################
      #
      # CancelFulfillmentOrder
      #
      # Makes a requests to Amazon to cancel an existing fulfillment order.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class CancelFulfillmentOrder < Choreography

        ####
        #  Create a new instance of the CancelFulfillmentOrder Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/OutboundShipments/CancelFulfillmentOrder")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return CancelFulfillmentOrderInputSet
        ####
        def new_input_set()
          return CancelFulfillmentOrderInputSet.new()
        end

        def make_result_set()
          return CancelFulfillmentOrderResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = CancelFulfillmentOrderResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the CancelFulfillmentOrder
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class CancelFulfillmentOrderInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end
          #### 
          # Set the value of the SellerFulfillmentOrderId input for this Choreo. 
          # 
          # @param String - (required, string) The fulfillment order id that you submitted when creating the order.
          ###

          def set_SellerFulfillmentOrderId(value)
            set_input("SellerFulfillmentOrderId", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the CancelFulfillmentOrder Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class CancelFulfillmentOrderResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (xml) Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class CancelFulfillmentOrder



      ##############################################################################
      #
      # ListAllFulfillmentOrders
      #
      # Returns a list of fulfillment orders fulfilled after (or at) a specified date or by fulfillment method.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class ListAllFulfillmentOrders < Choreography

        ####
        #  Create a new instance of the ListAllFulfillmentOrders Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/OutboundShipments/ListAllFulfillmentOrders")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return ListAllFulfillmentOrdersInputSet
        ####
        def new_input_set()
          return ListAllFulfillmentOrdersInputSet.new()
        end

        def make_result_set()
          return ListAllFulfillmentOrdersResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = ListAllFulfillmentOrdersResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the ListAllFulfillmentOrders
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class ListAllFulfillmentOrdersInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the FulfillmentMethod input for this Choreo. 
          # 
          # @param String - (optional, string) A value used for selecting fulfillment orders based on their fulfillment method. "Consumer" indicates a customer order, and "Removal" indicates that the inventory should be returned to the specified.
          ###

          def set_FulfillmentMethod(value)
            set_input("FulfillmentMethod", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the PageToken input for this Choreo. 
          # 
          # @param String - (optional, string) The value returned in the NextPageToken output of this Choreo when there are multiple pages of orders to retrieve.
          ###

          def set_PageToken(value)
            set_input("PageToken", value)
          end
          #### 
          # Set the value of the QueryStartDateTime input for this Choreo. 
          # 
          # @param String - (optional, date) A date used for selecting items that have had changes in inventory availability after (or at) a specified time, in ISO 8601 date format (i.e. 2012-01-01).
          ###

          def set_QueryStartDateTime(value)
            set_input("QueryStartDateTime", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the ListAllFulfillmentOrders Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class ListAllFulfillmentOrdersResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "NextPageToken" output from this Choreo execution
        	#
        	# @return String - (string) A token used to retrieve the next page of results. If a token is not returned, there are no more results to retrieve. This token can be passed to the PageToken input of this Choreo.
        	####
        	def get_NextPageToken()
        	  return @outputs["NextPageToken"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (xml) Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class ListAllFulfillmentOrders




    end # module OutboundShipments

    module Products



      ##############################################################################
      #
      # GetCompetitivePricingForASIN
      #
      # Returns the current competitive pricing of products, based on  ASIN values and the MarketplaceId that you specify.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetCompetitivePricingForASIN < Choreography

        ####
        #  Create a new instance of the GetCompetitivePricingForASIN Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Products/GetCompetitivePricingForASIN")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetCompetitivePricingForASINInputSet
        ####
        def new_input_set()
          return GetCompetitivePricingForASINInputSet.new()
        end

        def make_result_set()
          return GetCompetitivePricingForASINResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetCompetitivePricingForASINResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetCompetitivePricingForASIN
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetCompetitivePricingForASINInputSet < Choreography::InputSet

          #### 
          # Set the value of the ASIN input for this Choreo. 
          # 
          # @param String - (required, string) A comma-separated list of up to 20 ASIN values used to identify products in the given marketplace.
          ###

          def set_ASIN(value)
            set_input("ASIN", value)
          end
          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetCompetitivePricingForASIN Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetCompetitivePricingForASINResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetCompetitivePricingForASIN



      ##############################################################################
      #
      # GetCompetitivePricingForSKU
      #
      # Returns the current competitive pricing of products, based on SellerSKU values and the MarketplaceId that you specify.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetCompetitivePricingForSKU < Choreography

        ####
        #  Create a new instance of the GetCompetitivePricingForSKU Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Products/GetCompetitivePricingForSKU")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetCompetitivePricingForSKUInputSet
        ####
        def new_input_set()
          return GetCompetitivePricingForSKUInputSet.new()
        end

        def make_result_set()
          return GetCompetitivePricingForSKUResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetCompetitivePricingForSKUResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetCompetitivePricingForSKU
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetCompetitivePricingForSKUInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end
          #### 
          # Set the value of the SellerSKU input for this Choreo. 
          # 
          # @param String - (required, string) A comma-separated list of up to 20 SellerSKU values used to identify products in the given marketplace.
          ###

          def set_SellerSKU(value)
            set_input("SellerSKU", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetCompetitivePricingForSKU Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetCompetitivePricingForSKUResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetCompetitivePricingForSKU



      ##############################################################################
      #
      # GetLowestOfferListingsForASIN
      #
      # Returns the lowest price offer listings for specific products by item condition. This method uses a MarketplaceId and ASIN values to uniquely identify products.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetLowestOfferListingsForASIN < Choreography

        ####
        #  Create a new instance of the GetLowestOfferListingsForASIN Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Products/GetLowestOfferListingsForASIN")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetLowestOfferListingsForASINInputSet
        ####
        def new_input_set()
          return GetLowestOfferListingsForASINInputSet.new()
        end

        def make_result_set()
          return GetLowestOfferListingsForASINResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetLowestOfferListingsForASINResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetLowestOfferListingsForASIN
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetLowestOfferListingsForASINInputSet < Choreography::InputSet

          #### 
          # Set the value of the ASIN input for this Choreo. 
          # 
          # @param String - (required, string) A comma-separated list of up to 20 ASIN values used to identify products in the given marketplace.
          ###

          def set_ASIN(value)
            set_input("ASIN", value)
          end
          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the ItemCondition input for this Choreo. 
          # 
          # @param String - (optional, string) Filters the offer listings to be considered based on item condition. Valid values: New, Used, Collectible, Refurbished, Club.
          ###

          def set_ItemCondition(value)
            set_input("ItemCondition", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetLowestOfferListingsForASIN Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetLowestOfferListingsForASINResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetLowestOfferListingsForASIN



      ##############################################################################
      #
      # GetLowestOfferListingsForSKU
      #
      # Returns the lowest price offer listings for specific products by item condition. This method uses a MarketplaceId and SellerSKU values to uniquely identify products.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetLowestOfferListingsForSKU < Choreography

        ####
        #  Create a new instance of the GetLowestOfferListingsForSKU Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Products/GetLowestOfferListingsForSKU")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetLowestOfferListingsForSKUInputSet
        ####
        def new_input_set()
          return GetLowestOfferListingsForSKUInputSet.new()
        end

        def make_result_set()
          return GetLowestOfferListingsForSKUResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetLowestOfferListingsForSKUResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetLowestOfferListingsForSKU
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetLowestOfferListingsForSKUInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the ExcludeMe input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) Excludes your own offer listings from the offer listings that are returned. Set to "true" to exclude your own offer listings from the results. Defaults to "false".
          ###

          def set_ExcludeMe(value)
            set_input("ExcludeMe", value)
          end
          #### 
          # Set the value of the ItemCondition input for this Choreo. 
          # 
          # @param String - (optional, string) Filters the offer listings to be considered based on item condition. Valid values: New, Used, Collectible, Refurbished, Club.
          ###

          def set_ItemCondition(value)
            set_input("ItemCondition", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end
          #### 
          # Set the value of the SellerSKU input for this Choreo. 
          # 
          # @param String - (required, string) A comma-separated list of up to 20 SellerSKU values used to identify products in the given marketplace.
          ###

          def set_SellerSKU(value)
            set_input("SellerSKU", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetLowestOfferListingsForSKU Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetLowestOfferListingsForSKUResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetLowestOfferListingsForSKU



      ##############################################################################
      #
      # GetMatchingProduct
      #
      # Returns a list of products and their attributes, based on ASIN values that you specify.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetMatchingProduct < Choreography

        ####
        #  Create a new instance of the GetMatchingProduct Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Products/GetMatchingProduct")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetMatchingProductInputSet
        ####
        def new_input_set()
          return GetMatchingProductInputSet.new()
        end

        def make_result_set()
          return GetMatchingProductResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetMatchingProductResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetMatchingProduct
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetMatchingProductInputSet < Choreography::InputSet

          #### 
          # Set the value of the ASIN input for this Choreo. 
          # 
          # @param String - (required, string) A comma-separated list of up to 10 ASIN values used to identify products in the given marketplace.
          ###

          def set_ASIN(value)
            set_input("ASIN", value)
          end
          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetMatchingProduct Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetMatchingProductResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (xml) Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetMatchingProduct



      ##############################################################################
      #
      # GetProductCategoriesForASIN
      #
      # Returns the product categories that a product belongs to, including parent categories back to the root for the marketplace. This method uses a MarketplaceId and an ASIN to uniquely identify a product.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetProductCategoriesForASIN < Choreography

        ####
        #  Create a new instance of the GetProductCategoriesForASIN Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Products/GetProductCategoriesForASIN")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetProductCategoriesForASINInputSet
        ####
        def new_input_set()
          return GetProductCategoriesForASINInputSet.new()
        end

        def make_result_set()
          return GetProductCategoriesForASINResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetProductCategoriesForASINResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetProductCategoriesForASIN
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetProductCategoriesForASINInputSet < Choreography::InputSet

          #### 
          # Set the value of the ASIN input for this Choreo. 
          # 
          # @param String - (required, string) An ASIN value used to identify a product in the given marketplace.
          ###

          def set_ASIN(value)
            set_input("ASIN", value)
          end
          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetProductCategoriesForASIN Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetProductCategoriesForASINResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (xml) Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetProductCategoriesForASIN



      ##############################################################################
      #
      # GetProductCategoriesForSKU
      #
      # Returns the product categories that a product belongs to, including parent categories back to the root for the marketplace. This method uses a MarketplaceId and a SellerSKU to uniquely identify a product.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetProductCategoriesForSKU < Choreography

        ####
        #  Create a new instance of the GetProductCategoriesForSKU Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Products/GetProductCategoriesForSKU")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetProductCategoriesForSKUInputSet
        ####
        def new_input_set()
          return GetProductCategoriesForSKUInputSet.new()
        end

        def make_result_set()
          return GetProductCategoriesForSKUResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetProductCategoriesForSKUResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetProductCategoriesForSKU
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetProductCategoriesForSKUInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end
          #### 
          # Set the value of the SellerSKU input for this Choreo. 
          # 
          # @param String - (required, string) A SellerSKU value used to identify a product in the given marketplace.
          ###

          def set_SellerSKU(value)
            set_input("SellerSKU", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetProductCategoriesForSKU Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetProductCategoriesForSKUResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (xml) Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetProductCategoriesForSKU



      ##############################################################################
      #
      # GetServiceStatus
      #
      # This is the standard method following MWS API GetServiceStatus standard. It can return a GREEN, GREEN_I, YELLOW or RED status.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetServiceStatus < Choreography

        ####
        #  Create a new instance of the GetServiceStatus Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Products/GetServiceStatus")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetServiceStatusInputSet
        ####
        def new_input_set()
          return GetServiceStatusInputSet.new()
        end

        def make_result_set()
          return GetServiceStatusResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetServiceStatusResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetServiceStatus
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetServiceStatusInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetServiceStatus Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetServiceStatusResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Status" output from this Choreo execution
        	#
        	# @return String - (string) The service status parsed from the Amazon response.
        	####
        	def get_Status()
        	  return @outputs["Status"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (xml) Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetServiceStatus



      ##############################################################################
      #
      # ListMatchingProducts
      #
      # Returns a list of products and their attributes, ordered by relevancy, based on a search query that you specify.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class ListMatchingProducts < Choreography

        ####
        #  Create a new instance of the ListMatchingProducts Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Products/ListMatchingProducts")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return ListMatchingProductsInputSet
        ####
        def new_input_set()
          return ListMatchingProductsInputSet.new()
        end

        def make_result_set()
          return ListMatchingProductsResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = ListMatchingProductsResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the ListMatchingProducts
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class ListMatchingProductsInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the Query input for this Choreo. 
          # 
          # @param String - (required, string) A search string used to search for products.
          ###

          def set_Query(value)
            set_input("Query", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the ListMatchingProducts Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class ListMatchingProductsResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (xml) Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class ListMatchingProducts




    end # module Products

    module Reports



      ##############################################################################
      #
      # CancelReportRequest
      #
      # Cancels one or more report requests.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class CancelReportRequest < Choreography

        ####
        #  Create a new instance of the CancelReportRequest Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Reports/CancelReportRequest")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return CancelReportRequestInputSet
        ####
        def new_input_set()
          return CancelReportRequestInputSet.new()
        end

        def make_result_set()
          return CancelReportRequestResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = CancelReportRequestResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the CancelReportRequest
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class CancelReportRequestInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the ReportProcessingStatus input for this Choreo. 
          # 
          # @param String - (optional, string) A report processing status by which to filter report requests. Valid values are: _SUBMITTED_, _IN_PROGRESS_, _CANCELLED_, _DONE_, _DONE_NO_DATA_.
          ###

          def set_ReportProcessingStatus(value)
            set_input("ReportProcessingStatus", value)
          end
          #### 
          # Set the value of the ReportRequestId input for this Choreo. 
          # 
          # @param String - (optional, string) A ReportRequestId value. If you pass in a ReportRequestId value, other query conditions are ignored.
          ###

          def set_ReportRequestId(value)
            set_input("ReportRequestId", value)
          end
          #### 
          # Set the value of the ReportType input for this Choreo. 
          # 
          # @param String - (optional, string) A ReportType enumeration value (i.e. GET_ORDERS_DATA_).
          ###

          def set_ReportType(value)
            set_input("ReportType", value)
          end
          #### 
          # Set the value of the RequestedFromDate input for this Choreo. 
          # 
          # @param String - (optional, date) The start of the date range used for selecting the data to report, in ISO8601 date format (i.e. 2012-01-01).
          ###

          def set_RequestedFromDate(value)
            set_input("RequestedFromDate", value)
          end
          #### 
          # Set the value of the RequestedToDate input for this Choreo. 
          # 
          # @param String - (optional, date) The end of the date range used for selecting the data to report, in ISO8601 date format (i.e. 2012-01-01).
          ###

          def set_RequestedToDate(value)
            set_input("RequestedToDate", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the CancelReportRequest Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class CancelReportRequestResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Count" output from this Choreo execution
        	#
        	# @return String - (integer) A non-negative integer that represents the total number of report requests that were cancelled.
        	####
        	def get_Count()
        	  return @outputs["Count"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class CancelReportRequest



      ##############################################################################
      #
      # FlatFileOrderReport
      #
      # Returns a tab-delimited flat file order report. The report shows orders from the previous 60 days.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class FlatFileOrderReport < Choreography

        ####
        #  Create a new instance of the FlatFileOrderReport Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Reports/FlatFileOrderReport")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return FlatFileOrderReportInputSet
        ####
        def new_input_set()
          return FlatFileOrderReportInputSet.new()
        end

        def make_result_set()
          return FlatFileOrderReportResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = FlatFileOrderReportResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the FlatFileOrderReport
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class FlatFileOrderReportInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the EndDate input for this Choreo. 
          # 
          # @param String - (optional, date) The end of a date range used for selecting the data to report, in ISO8601 date format (i.e. 2012-01-01).
          ###

          def set_EndDate(value)
            set_input("EndDate", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the StartDate input for this Choreo. 
          # 
          # @param String - (optional, date) The start of a date range used for selecting the data to report, in ISO8601 date format (i.e. 2012-01-01).
          ###

          def set_StartDate(value)
            set_input("StartDate", value)
          end
          #### 
          # Set the value of the TimeToWait input for this Choreo. 
          # 
          # @param Integer - (optional, integer) By default, the Choreo will wait for 5 minutes to see if the report is ready for retrieval. Max is 120 minutes.
          ###

          def set_TimeToWait(value)
            set_input("TimeToWait", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the FlatFileOrderReport Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class FlatFileOrderReportResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Report" output from this Choreo execution
        	#
        	# @return String - (multiline) The report contents.
        	####
        	def get_Report()
        	  return @outputs["Report"]
        	end
        	####
        	# Retrieve the value for the "GeneratedReportId" output from this Choreo execution
        	#
        	# @return String - (integer) The GeneratedReportId parsed from the Amazon response.
        	####
        	def get_GeneratedReportId()
        	  return @outputs["GeneratedReportId"]
        	end
        	####
        	# Retrieve the value for the "ReportProcessingStatus" output from this Choreo execution
        	#
        	# @return String - (string) The status of the report request parsed from the Amazon response.
        	####
        	def get_ReportProcessingStatus()
        	  return @outputs["ReportProcessingStatus"]
        	end
        	####
        	# Retrieve the value for the "ReportRequestId" output from this Choreo execution
        	#
        	# @return String - (integer) The ReportRequestId parsed from the Amazon response. This id is used in GetReportRequestList.
        	####
        	def get_ReportRequestId()
        	  return @outputs["ReportRequestId"]
        	end
        end

      end # class FlatFileOrderReport



      ##############################################################################
      #
      # GetReportById
      #
      # Returns the contents of a report with a given report id.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetReportById < Choreography

        ####
        #  Create a new instance of the GetReportById Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Reports/GetReportById")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetReportByIdInputSet
        ####
        def new_input_set()
          return GetReportByIdInputSet.new()
        end

        def make_result_set()
          return GetReportByIdResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetReportByIdResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetReportById
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetReportByIdInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the ReportId input for this Choreo. 
          # 
          # @param Integer - (required, integer) The id of the report to retrieve.
          ###

          def set_ReportId(value)
            set_input("ReportId", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetReportById Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetReportByIdResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "ContentMD5Header" output from this Choreo execution
        	#
        	# @return String - (string) 
        	####
        	def get_ContentMD5Header()
        	  return @outputs["ContentMD5Header"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - The response from Amazon which contains the contents of the report requested. This is typically a flat file or XML information.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetReportById



      ##############################################################################
      #
      # GetReportCount
      #
      # Retrieves the number of your available Amazon Marketplace reports, ready for download, that were generated in the last 90 days.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetReportCount < Choreography

        ####
        #  Create a new instance of the GetReportCount Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Reports/GetReportCount")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetReportCountInputSet
        ####
        def new_input_set()
          return GetReportCountInputSet.new()
        end

        def make_result_set()
          return GetReportCountResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetReportCountResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetReportCount
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetReportCountInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Acknowledged input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) A Boolean value that indicates if an order report has been acknowledged by a prior call to UpdateReportAcknowledgements. Set to "true" to list order reports that have been acknowledged.
          ###

          def set_Acknowledged(value)
            set_input("Acknowledged", value)
          end
          #### 
          # Set the value of the AvailableFromDate input for this Choreo. 
          # 
          # @param String - (optional, date) The earliest date you are looking for, in ISO8601 date format (i.e. 2012-01-01).
          ###

          def set_AvailableFromDate(value)
            set_input("AvailableFromDate", value)
          end
          #### 
          # Set the value of the AvailableToDate input for this Choreo. 
          # 
          # @param String - (optional, date) The most recent date you are looking for, in ISO8601 date format (i.e. 2012-01-01).
          ###

          def set_AvailableToDate(value)
            set_input("AvailableToDate", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the ReportType input for this Choreo. 
          # 
          # @param String - (optional, string) A ReportType enumeration value (i.e. _GET_FLAT_FILE_OPEN_LISTINGS_DATA_).
          ###

          def set_ReportType(value)
            set_input("ReportType", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetReportCount Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetReportCountResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Count" output from this Choreo execution
        	#
        	# @return String - (integer) A non-negative integer. parsed from the Amazon response, that represents the total number of reports available to download.
        	####
        	def get_Count()
        	  return @outputs["Count"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetReportCount



      ##############################################################################
      #
      # GetReportList
      #
      # Returns a list of reports that were created in the previous 90 days.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetReportList < Choreography

        ####
        #  Create a new instance of the GetReportList Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Reports/GetReportList")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetReportListInputSet
        ####
        def new_input_set()
          return GetReportListInputSet.new()
        end

        def make_result_set()
          return GetReportListResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetReportListResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetReportList
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetReportListInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Acknowledged input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) A Boolean value that indicates if an order report has been acknowledged by a prior call to UpdateReportAcknowledgements. Set to "true" to list order reports that have been acknowledged.
          ###

          def set_Acknowledged(value)
            set_input("Acknowledged", value)
          end
          #### 
          # Set the value of the AvailableFromDate input for this Choreo. 
          # 
          # @param String - (optional, date) The earliest date you are looking for, in ISO8601 date format (i.e. 2012-01-01).
          ###

          def set_AvailableFromDate(value)
            set_input("AvailableFromDate", value)
          end
          #### 
          # Set the value of the AvailableToDate input for this Choreo. 
          # 
          # @param String - (optional, date) The most recent date you are looking for, in ISO8601 date format (i.e. 2012-01-01).
          ###

          def set_AvailableToDate(value)
            set_input("AvailableToDate", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the MaxCount input for this Choreo. 
          # 
          # @param Integer - (optional, integer) A non-negative integer that represents the maximum number of report requests to return. Defaults to 10. Max is 100.
          ###

          def set_MaxCount(value)
            set_input("MaxCount", value)
          end
          #### 
          # Set the value of the ReportRequestId input for this Choreo. 
          # 
          # @param Integer - (optional, integer) A ReportRequestId value. If you pass a ReportRequestId value, other query conditions are ignored.
          ###

          def set_ReportRequestId(value)
            set_input("ReportRequestId", value)
          end
          #### 
          # Set the value of the ReportType input for this Choreo. 
          # 
          # @param String - (optional, string) A ReportType enumeration value (i.e. GET_ORDERS_DATA_).
          ###

          def set_ReportType(value)
            set_input("ReportType", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetReportList Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetReportListResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "ReportId" output from this Choreo execution
        	#
        	# @return String - (integer) The report id parsed from the Amazon response. If multiple records are returned, this output variable will contain the first id in the list.
        	####
        	def get_ReportId()
        	  return @outputs["ReportId"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetReportList



      ##############################################################################
      #
      # GetReportRequestList
      #
      # Returns a list of report requests that you can use to get the ReportProcessingStatus and ReportId in order to retrieve a report.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class GetReportRequestList < Choreography

        ####
        #  Create a new instance of the GetReportRequestList Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Reports/GetReportRequestList")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return GetReportRequestListInputSet
        ####
        def new_input_set()
          return GetReportRequestListInputSet.new()
        end

        def make_result_set()
          return GetReportRequestListResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = GetReportRequestListResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the GetReportRequestList
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class GetReportRequestListInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the MaxCount input for this Choreo. 
          # 
          # @param Integer - (optional, integer) A non-negative integer that represents the maximum number of report requests to return. Defaults to 10. Max is 100.
          ###

          def set_MaxCount(value)
            set_input("MaxCount", value)
          end
          #### 
          # Set the value of the ReportProcessingStatusList input for this Choreo. 
          # 
          # @param String - (optional, string) A comma separated list of up to three ReportProcessingStatuses by which to filter report requests.
          ###

          def set_ReportProcessingStatusList(value)
            set_input("ReportProcessingStatusList", value)
          end
          #### 
          # Set the value of the ReportRequestIdList input for this Choreo. 
          # 
          # @param String - (optional, string) A comma separated list of up to three ReportRequestId values. If you pass in a ReportRequestId values, other query conditions are ignored.
          ###

          def set_ReportRequestIdList(value)
            set_input("ReportRequestIdList", value)
          end
          #### 
          # Set the value of the ReportTypeList input for this Choreo. 
          # 
          # @param String - (optional, string) A comma separated list of up to three ReportType enumeration values.
          ###

          def set_ReportTypeList(value)
            set_input("ReportTypeList", value)
          end
          #### 
          # Set the value of the RequestedFromDate input for this Choreo. 
          # 
          # @param String - (optional, date) The start of the date range used for selecting the data to report, in ISO8601 date format (i.e. 2012-01-01).
          ###

          def set_RequestedFromDate(value)
            set_input("RequestedFromDate", value)
          end
          #### 
          # Set the value of the RequestedToDate input for this Choreo. 
          # 
          # @param String - (optional, date) The end of the date range used for selecting the data to report, in ISO8601 date format (i.e. 2012-01-01).
          ###

          def set_RequestedToDate(value)
            set_input("RequestedToDate", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the GetReportRequestList Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class GetReportRequestListResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "GeneratedReportId" output from this Choreo execution
        	#
        	# @return String - (integer) The GeneratedReportId parsed from the Amazon response. If multiple records are returned, this output variable will contain the first id in the list.
        	####
        	def get_GeneratedReportId()
        	  return @outputs["GeneratedReportId"]
        	end
        	####
        	# Retrieve the value for the "ReportProcessingStatus" output from this Choreo execution
        	#
        	# @return String - (string) The report status parsed from the Amazon response. If multiple records are returned, this output variable will contain the report status in the list.
        	####
        	def get_ReportProcessingStatus()
        	  return @outputs["ReportProcessingStatus"]
        	end
        	####
        	# Retrieve the value for the "ReportRequestId" output from this Choreo execution
        	#
        	# @return String - (integer) The report request id parsed from the Amazon response. If multiple records are returned, this output variable will contain the first id in the list.
        	####
        	def get_ReportRequestId()
        	  return @outputs["ReportRequestId"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class GetReportRequestList



      ##############################################################################
      #
      # ListInventoryReport
      #
      # Returns a tab-delimited report of open listings. The report contains the SKU, ASIN, Price, and Quantity fields for inventory listings.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class ListInventoryReport < Choreography

        ####
        #  Create a new instance of the ListInventoryReport Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Reports/ListInventoryReport")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return ListInventoryReportInputSet
        ####
        def new_input_set()
          return ListInventoryReportInputSet.new()
        end

        def make_result_set()
          return ListInventoryReportResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = ListInventoryReportResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the ListInventoryReport
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class ListInventoryReportInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the TimeToWait input for this Choreo. 
          # 
          # @param Integer - (optional, integer) By default, the Choreo will wait for 5 minutes to see if the report is ready for retrieval. Max is 120 minutes.
          ###

          def set_TimeToWait(value)
            set_input("TimeToWait", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the ListInventoryReport Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class ListInventoryReportResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Report" output from this Choreo execution
        	#
        	# @return String - (multiline) The report contents.
        	####
        	def get_Report()
        	  return @outputs["Report"]
        	end
        	####
        	# Retrieve the value for the "GeneratedReportId" output from this Choreo execution
        	#
        	# @return String - (integer) The GeneratedReportId parsed from the Amazon response.
        	####
        	def get_GeneratedReportId()
        	  return @outputs["GeneratedReportId"]
        	end
        	####
        	# Retrieve the value for the "ReportProcessingStatus" output from this Choreo execution
        	#
        	# @return String - (string) The status of the report request parsed from the Amazon response.
        	####
        	def get_ReportProcessingStatus()
        	  return @outputs["ReportProcessingStatus"]
        	end
        	####
        	# Retrieve the value for the "ReportRequestId" output from this Choreo execution
        	#
        	# @return String - (integer) The ReportRequestId parsed from the Amazon response. This id is used in GetReportRequestList.
        	####
        	def get_ReportRequestId()
        	  return @outputs["ReportRequestId"]
        	end
        end

      end # class ListInventoryReport



      ##############################################################################
      #
      # MerchantListingsLiteReport
      #
      # Returns a tab-delimited flat file active listings report that contains only the SKU, ASIN, Price, and Quantity fields for items that have a quantity greater than zero.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class MerchantListingsLiteReport < Choreography

        ####
        #  Create a new instance of the MerchantListingsLiteReport Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Reports/MerchantListingsLiteReport")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return MerchantListingsLiteReportInputSet
        ####
        def new_input_set()
          return MerchantListingsLiteReportInputSet.new()
        end

        def make_result_set()
          return MerchantListingsLiteReportResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = MerchantListingsLiteReportResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the MerchantListingsLiteReport
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class MerchantListingsLiteReportInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the TimeToWait input for this Choreo. 
          # 
          # @param Integer - (optional, integer) By default, the Choreo will wait for 5 minutes to see if the report is ready for retrieval. Max is 120 minutes.
          ###

          def set_TimeToWait(value)
            set_input("TimeToWait", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the MerchantListingsLiteReport Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class MerchantListingsLiteReportResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Report" output from this Choreo execution
        	#
        	# @return String - (multiline) The report contents.
        	####
        	def get_Report()
        	  return @outputs["Report"]
        	end
        	####
        	# Retrieve the value for the "GeneratedReportId" output from this Choreo execution
        	#
        	# @return String - (integer) The GeneratedReportId parsed from the Amazon response.
        	####
        	def get_GeneratedReportId()
        	  return @outputs["GeneratedReportId"]
        	end
        	####
        	# Retrieve the value for the "ReportProcessingStatus" output from this Choreo execution
        	#
        	# @return String - (string) The status of the report request parsed from the Amazon response.
        	####
        	def get_ReportProcessingStatus()
        	  return @outputs["ReportProcessingStatus"]
        	end
        	####
        	# Retrieve the value for the "ReportRequestId" output from this Choreo execution
        	#
        	# @return String - (integer) The ReportRequestId parsed from the Amazon response. This id is used in GetReportRequestList.
        	####
        	def get_ReportRequestId()
        	  return @outputs["ReportRequestId"]
        	end
        end

      end # class MerchantListingsLiteReport



      ##############################################################################
      #
      # MerchantListingsReport
      #
      # Returns a tab-delimited report of active listings.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class MerchantListingsReport < Choreography

        ####
        #  Create a new instance of the MerchantListingsReport Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Reports/MerchantListingsReport")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return MerchantListingsReportInputSet
        ####
        def new_input_set()
          return MerchantListingsReportInputSet.new()
        end

        def make_result_set()
          return MerchantListingsReportResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = MerchantListingsReportResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the MerchantListingsReport
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class MerchantListingsReportInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the TimeToWait input for this Choreo. 
          # 
          # @param Integer - (optional, integer) By default, the Choreo will wait for 5 minutes to see if the report is ready for retrieval. Max is 120 minutes.
          ###

          def set_TimeToWait(value)
            set_input("TimeToWait", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the MerchantListingsReport Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class MerchantListingsReportResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Report" output from this Choreo execution
        	#
        	# @return String - (multiline) The report contents.
        	####
        	def get_Report()
        	  return @outputs["Report"]
        	end
        	####
        	# Retrieve the value for the "GeneratedReportId" output from this Choreo execution
        	#
        	# @return String - (integer) The GeneratedReportId parsed from the Amazon response.
        	####
        	def get_GeneratedReportId()
        	  return @outputs["GeneratedReportId"]
        	end
        	####
        	# Retrieve the value for the "ReportProcessingStatus" output from this Choreo execution
        	#
        	# @return String - (string) The status of the report request parsed from the Amazon response.
        	####
        	def get_ReportProcessingStatus()
        	  return @outputs["ReportProcessingStatus"]
        	end
        	####
        	# Retrieve the value for the "ReportRequestId" output from this Choreo execution
        	#
        	# @return String - (integer) The ReportRequestId parsed from the Amazon response. This id is used in GetReportRequestList.
        	####
        	def get_ReportRequestId()
        	  return @outputs["ReportRequestId"]
        	end
        end

      end # class MerchantListingsReport



      ##############################################################################
      #
      # RequestReport
      #
      # Creates a report request and submits the request to Amazon MWS.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class RequestReport < Choreography

        ####
        #  Create a new instance of the RequestReport Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Reports/RequestReport")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return RequestReportInputSet
        ####
        def new_input_set()
          return RequestReportInputSet.new()
        end

        def make_result_set()
          return RequestReportResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = RequestReportResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the RequestReport
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class RequestReportInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the EndDate input for this Choreo. 
          # 
          # @param String - (optional, date) The end of a date range used for selecting the data to report, in ISO8601 date format (i.e. 2012-01-01).
          ###

          def set_EndDate(value)
            set_input("EndDate", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the ReportOptions input for this Choreo. 
          # 
          # @param String - (optional, string) A Boolean value that shows or hides an additional column of information on several order reports. When set to ShowSalesChannel=true, an additional column is added showing the sales channel.
          ###

          def set_ReportOptions(value)
            set_input("ReportOptions", value)
          end
          #### 
          # Set the value of the ReportType input for this Choreo. 
          # 
          # @param String - (optional, string) A ReportType enumeration value. Defaults to _GET_FLAT_FILE_OPEN_LISTINGS_DATA_.
          ###

          def set_ReportType(value)
            set_input("ReportType", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end
          #### 
          # Set the value of the StartDate input for this Choreo. 
          # 
          # @param String - (optional, date) The start of a date range used for selecting the data to report, in ISO8601 date format (i.e. 2012-01-01).
          ###

          def set_StartDate(value)
            set_input("StartDate", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the RequestReport Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class RequestReportResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "ReportProcessingStatus" output from this Choreo execution
        	#
        	# @return String - (string) The status of the report request parsed from the Amazon response.
        	####
        	def get_ReportProcessingStatus()
        	  return @outputs["ReportProcessingStatus"]
        	end
        	####
        	# Retrieve the value for the "ReportRequestId" output from this Choreo execution
        	#
        	# @return String - (integer) The ReportRequestId parsed from the Amazon response. This id is used in GetReportRequestList.
        	####
        	def get_ReportRequestId()
        	  return @outputs["ReportRequestId"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class RequestReport



      ##############################################################################
      #
      # RetrieveReport
      #
      # Creates a report request of any report type, polls for the status of the report, and downloads the report when it's available.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class RetrieveReport < Choreography

        ####
        #  Create a new instance of the RetrieveReport Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Reports/RetrieveReport")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return RetrieveReportInputSet
        ####
        def new_input_set()
          return RetrieveReportInputSet.new()
        end

        def make_result_set()
          return RetrieveReportResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = RetrieveReportResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the RetrieveReport
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class RetrieveReportInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the EndDate input for this Choreo. 
          # 
          # @param String - (optional, date) The end of a date range used for selecting the data to report, in ISO8601 date format (i.e. 2012-01-01).
          ###

          def set_EndDate(value)
            set_input("EndDate", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the ReportType input for this Choreo. 
          # 
          # @param String - (optional, string) A ReportType enumeration value. Defaults to _GET_FLAT_FILE_OPEN_LISTINGS_DATA_.
          ###

          def set_ReportType(value)
            set_input("ReportType", value)
          end
          #### 
          # Set the value of the StartDate input for this Choreo. 
          # 
          # @param String - (optional, date) The start of a date range used for selecting the data to report, in ISO8601 date format (i.e. 2012-01-01).
          ###

          def set_StartDate(value)
            set_input("StartDate", value)
          end
          #### 
          # Set the value of the TimeToWait input for this Choreo. 
          # 
          # @param Integer - (optional, integer) By default, the Choreo will wait for 10 minutes to see if the report is ready for retrieval. Max is 120 minutes.
          ###

          def set_TimeToWait(value)
            set_input("TimeToWait", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the RetrieveReport Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class RetrieveReportResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Report" output from this Choreo execution
        	#
        	# @return String - The report contents.
        	####
        	def get_Report()
        	  return @outputs["Report"]
        	end
        	####
        	# Retrieve the value for the "GeneratedReportId" output from this Choreo execution
        	#
        	# @return String - (integer) The GeneratedReportId parsed from the Amazon response.
        	####
        	def get_GeneratedReportId()
        	  return @outputs["GeneratedReportId"]
        	end
        	####
        	# Retrieve the value for the "ReportProcessingStatus" output from this Choreo execution
        	#
        	# @return String - (string) The status of the report request parsed from the Amazon response.
        	####
        	def get_ReportProcessingStatus()
        	  return @outputs["ReportProcessingStatus"]
        	end
        	####
        	# Retrieve the value for the "ReportRequestId" output from this Choreo execution
        	#
        	# @return String - (integer) The ReportRequestId parsed from the Amazon response. This id is used in GetReportRequestList.
        	####
        	def get_ReportRequestId()
        	  return @outputs["ReportRequestId"]
        	end
        end

      end # class RetrieveReport



      ##############################################################################
      #
      # UnshippedOrdersReport
      #
      # Returns a tab-delimited flat file report that contains only orders that are not confirmed as shipped.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class UnshippedOrdersReport < Choreography

        ####
        #  Create a new instance of the UnshippedOrdersReport Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Reports/UnshippedOrdersReport")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return UnshippedOrdersReportInputSet
        ####
        def new_input_set()
          return UnshippedOrdersReportInputSet.new()
        end

        def make_result_set()
          return UnshippedOrdersReportResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = UnshippedOrdersReportResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the UnshippedOrdersReport
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class UnshippedOrdersReportInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the TimeToWait input for this Choreo. 
          # 
          # @param Integer - (optional, integer) By default, the Choreo will wait for 5 minutes to see if the report is ready for retrieval. Max is 120 minutes.
          ###

          def set_TimeToWait(value)
            set_input("TimeToWait", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the UnshippedOrdersReport Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class UnshippedOrdersReportResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Report" output from this Choreo execution
        	#
        	# @return String - (multiline) The report contents.
        	####
        	def get_Report()
        	  return @outputs["Report"]
        	end
        	####
        	# Retrieve the value for the "GeneratedReportId" output from this Choreo execution
        	#
        	# @return String - (integer) The GeneratedReportId parsed from the Amazon response.
        	####
        	def get_GeneratedReportId()
        	  return @outputs["GeneratedReportId"]
        	end
        	####
        	# Retrieve the value for the "ReportProcessingStatus" output from this Choreo execution
        	#
        	# @return String - (string) The status of the report request parsed from the Amazon response.
        	####
        	def get_ReportProcessingStatus()
        	  return @outputs["ReportProcessingStatus"]
        	end
        	####
        	# Retrieve the value for the "ReportRequestId" output from this Choreo execution
        	#
        	# @return String - (integer) The ReportRequestId parsed from the Amazon response. This id is used in GetReportRequestList.
        	####
        	def get_ReportRequestId()
        	  return @outputs["ReportRequestId"]
        	end
        end

      end # class UnshippedOrdersReport



      ##############################################################################
      #
      # UpdateReportAcknowledgements
      #
      # Updates the acknowledged status of a report.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class UpdateReportAcknowledgements < Choreography

        ####
        #  Create a new instance of the UpdateReportAcknowledgements Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Amazon/Marketplace/Reports/UpdateReportAcknowledgements")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return UpdateReportAcknowledgementsInputSet
        ####
        def new_input_set()
          return UpdateReportAcknowledgementsInputSet.new()
        end

        def make_result_set()
          return UpdateReportAcknowledgementsResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = UpdateReportAcknowledgementsResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the UpdateReportAcknowledgements
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class UpdateReportAcknowledgementsInputSet < Choreography::InputSet

          #### 
          # Set the value of the AWSAccessKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
          ###

          def set_AWSAccessKeyId(value)
            set_input("AWSAccessKeyId", value)
          end
          #### 
          # Set the value of the AWSMarketplaceId input for this Choreo. 
          # 
          # @param String - (required, string) The Marketplace ID provided by Amazon Web Services.
          ###

          def set_AWSMarketplaceId(value)
            set_input("AWSMarketplaceId", value)
          end
          #### 
          # Set the value of the AWSMerchantId input for this Choreo. 
          # 
          # @param String - (required, string) The Merchant ID provided by Amazon Web Services.
          ###

          def set_AWSMerchantId(value)
            set_input("AWSMerchantId", value)
          end
          #### 
          # Set the value of the AWSSecretKeyId input for this Choreo. 
          # 
          # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
          ###

          def set_AWSSecretKeyId(value)
            set_input("AWSSecretKeyId", value)
          end
          #### 
          # Set the value of the Acknowledged input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) A Boolean value that indicates if an order report has been acknowledged by a prior call to UpdateReportAcknowledgements. Set to true to list order reports that have been acknowledged.
          ###

          def set_Acknowledged(value)
            set_input("Acknowledged", value)
          end
          #### 
          # Set the value of the Endpoint input for this Choreo. 
          # 
          # @param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
          ###

          def set_Endpoint(value)
            set_input("Endpoint", value)
          end
          #### 
          # Set the value of the MWSAuthToken input for this Choreo. 
          # 
          # @param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
          ###

          def set_MWSAuthToken(value)
            set_input("MWSAuthToken", value)
          end
          #### 
          # Set the value of the ReportId input for this Choreo. 
          # 
          # @param Integer - (required, integer) The id of the report to acknowledge.
          ###

          def set_ReportId(value)
            set_input("ReportId", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the UpdateReportAcknowledgements Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class UpdateReportAcknowledgementsResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - Stores the response from Amazon.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class UpdateReportAcknowledgements




    end # module Reports

  end # module Marketplace

  module RDS



    ##############################################################################
    #
    # AuthorizeDBSecurityGroupIngress
    #
    # Allows restricted access to your database instance by adding EC2 Security Groups to the DBSecurityGroup or by specifying an allowed IP range.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class AuthorizeDBSecurityGroupIngress < Choreography

      ####
      #  Create a new instance of the AuthorizeDBSecurityGroupIngress Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/RDS/AuthorizeDBSecurityGroupIngress")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AuthorizeDBSecurityGroupIngressInputSet
      ####
      def new_input_set()
        return AuthorizeDBSecurityGroupIngressInputSet.new()
      end

      def make_result_set()
        return AuthorizeDBSecurityGroupIngressResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AuthorizeDBSecurityGroupIngressResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the AuthorizeDBSecurityGroupIngress
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AuthorizeDBSecurityGroupIngressInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the CIDRIP input for this Choreo. 
        # 
        # @param String - (conditional, string) IP range that should have access. Required unless EC2SecurityGroupName and EC2SecurityGroupOwnerId are used.
        ###

        def set_CIDRIP(value)
          set_input("CIDRIP", value)
        end
        #### 
        # Set the value of the DBSecurityGroupName input for this Choreo. 
        # 
        # @param String - (required, string) A unique name for the security group you want to authorize.
        ###

        def set_DBSecurityGroupName(value)
          set_input("DBSecurityGroupName", value)
        end
        #### 
        # Set the value of the EC2SecurityGroupId input for this Choreo. 
        # 
        # @param String - (conditional, string) The ID of the EC2 security group to authorize. For VPC DB security groups, this is required. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided.
        ###

        def set_EC2SecurityGroupId(value)
          set_input("EC2SecurityGroupId", value)
        end
        #### 
        # Set the value of the EC2SecurityGroupName input for this Choreo. 
        # 
        # @param String - (conditional, string) The EC2 security group to authorize. This and EC2SecurityGroupOwnerId are required if CIDRIP is not used.
        ###

        def set_EC2SecurityGroupName(value)
          set_input("EC2SecurityGroupName", value)
        end
        #### 
        # Set the value of the EC2SecurityGroupOwnerId input for this Choreo. 
        # 
        # @param String - (conditional, string) The AWS account number for the security group owner. This and EC2SecurityGroupName are required if CIDRIP is not used.
        ###

        def set_EC2SecurityGroupOwnerId(value)
          set_input("EC2SecurityGroupOwnerId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the RDS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the AuthorizeDBSecurityGroupIngress Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AuthorizeDBSecurityGroupIngressResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class AuthorizeDBSecurityGroupIngress



    ##############################################################################
    #
    # CreateDBInstance
    #
    # Creates a new database instance.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateDBInstance < Choreography

      ####
      #  Create a new instance of the CreateDBInstance Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/RDS/CreateDBInstance")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateDBInstanceInputSet
      ####
      def new_input_set()
        return CreateDBInstanceInputSet.new()
      end

      def make_result_set()
        return CreateDBInstanceResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateDBInstanceResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateDBInstance
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateDBInstanceInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AllocatedStorage input for this Choreo. 
        # 
        # @param Integer - (required, integer) Storage amount (in gigabytes) to be configured for the DB. Use 5 to 1024 for MySQL , 10 to 1024 for Oracle, or 200 to 1024 for SQLServer.
        ###

        def set_AllocatedStorage(value)
          set_input("AllocatedStorage", value)
        end
        #### 
        # Set the value of the AutoMinorVersionUpgrade input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Indicates that minor engine upgrades will be applied to the DB Instance automatically during the maintenance window.
        ###

        def set_AutoMinorVersionUpgrade(value)
          set_input("AutoMinorVersionUpgrade", value)
        end
        #### 
        # Set the value of the AvailabilityZone input for this Choreo. 
        # 
        # @param String - (optional, string) The EC2 Availability Zone that the database instance will be created in (e.g. us-east-1a, us-east-1b, us-east-1c).
        ###

        def set_AvailabilityZone(value)
          set_input("AvailabilityZone", value)
        end
        #### 
        # Set the value of the BackupRetentionPeriod input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The number of days for which automated backups are retained. When set to a positive number, backups are enabled. Set to 0 to disable automated backups.
        ###

        def set_BackupRetentionPeriod(value)
          set_input("BackupRetentionPeriod", value)
        end
        #### 
        # Set the value of the CharacterSetName input for this Choreo. 
        # 
        # @param String - (optional, string) Indicates that the DB Instance should be associated with the specified CharacterSet.
        ###

        def set_CharacterSetName(value)
          set_input("CharacterSetName", value)
        end
        #### 
        # Set the value of the DBInstanceClass input for this Choreo. 
        # 
        # @param String - (required, string) Capacity for the DB instance.  (db.t1.micro, db.m1.small, db.m1.large, db.m1.xlarge, db.m2.xlarge, db.m2.2xlarge, or db.m2.4xlarge).
        ###

        def set_DBInstanceClass(value)
          set_input("DBInstanceClass", value)
        end
        #### 
        # Set the value of the DBInstanceIdentifier input for this Choreo. 
        # 
        # @param String - (required, string) The DB Instance identifier. Should be in all lowercase.
        ###

        def set_DBInstanceIdentifier(value)
          set_input("DBInstanceIdentifier", value)
        end
        #### 
        # Set the value of the DBName input for this Choreo. 
        # 
        # @param String - (conditional, string) For MySQL, this is the name of the db that is created on the instance. For Oracle, it refers to the SID. Must be null for SQLServer.
        ###

        def set_DBName(value)
          set_input("DBName", value)
        end
        #### 
        # Set the value of the DBParameterGroupName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the DB Parameter Group to associate with this DB instance. If this argument is omitted, the default DBParameterGroup for the specified engine will be used.
        ###

        def set_DBParameterGroupName(value)
          set_input("DBParameterGroupName", value)
        end
        #### 
        # Set the value of the DBSecurityGroups input for this Choreo. 
        # 
        # @param String - (optional, string) A comma separated list of up to 10 DB Security Groups to associate with this DB Instance.
        ###

        def set_DBSecurityGroups(value)
          set_input("DBSecurityGroups", value)
        end
        #### 
        # Set the value of the DBSubnetGroupName input for this Choreo. 
        # 
        # @param String - (optional, string) A DB Subnet Group to associate with this DB Instance. When not specified, it indicates that this is a non-VPC DB instance.
        ###

        def set_DBSubnetGroupName(value)
          set_input("DBSubnetGroupName", value)
        end
        #### 
        # Set the value of the Engine input for this Choreo. 
        # 
        # @param String - (required, string) The name of the database engine to use for the instance. Options are: MySQL, oracle-se1, oracle-se, oracle-ee, sqlserver-ee, sqlserver-se, sqlserver-ex, sqlserver-web.
        ###

        def set_Engine(value)
          set_input("Engine", value)
        end
        #### 
        # Set the value of the EngineVersion input for this Choreo. 
        # 
        # @param String - (optional, string) The version number of the database engine to use.
        ###

        def set_EngineVersion(value)
          set_input("EngineVersion", value)
        end
        #### 
        # Set the value of the Iops input for this Choreo. 
        # 
        # @param String - (optional, string) The amount of provisioned input/output operations per second to be initially allocated for the DB Instance.
        ###

        def set_Iops(value)
          set_input("Iops", value)
        end
        #### 
        # Set the value of the LicenseModel input for this Choreo. 
        # 
        # @param String - (optional, string) License model information for this DB Instance. Valid values are: license-included, bring-your-own-license, general-public-license.
        ###

        def set_LicenseModel(value)
          set_input("LicenseModel", value)
        end
        #### 
        # Set the value of the MasterUserPassword input for this Choreo. 
        # 
        # @param String - (required, password) The master password for the DB instance.
        ###

        def set_MasterUserPassword(value)
          set_input("MasterUserPassword", value)
        end
        #### 
        # Set the value of the MasterUsername input for this Choreo. 
        # 
        # @param String - (required, string) The master username for the DB instance.
        ###

        def set_MasterUsername(value)
          set_input("MasterUsername", value)
        end
        #### 
        # Set the value of the MultiAZ input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Specifies if the DB Instance is a Multi-AZ deployment. You cannot set the AvailabilityZone parameter if the MultiAZ parameter is set to true.
        ###

        def set_MultiAZ(value)
          set_input("MultiAZ", value)
        end
        #### 
        # Set the value of the OptionGroupName input for this Choreo. 
        # 
        # @param String - (optional, string) Indicates that the DB Instance should be associated with the specified option group.
        ###

        def set_OptionGroupName(value)
          set_input("OptionGroupName", value)
        end
        #### 
        # Set the value of the Port input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The port number on which the database accepts connections. Valid range for MySQL is 1150-65535. Valid range for Oracle is 1150-65535. Valid range for SQLServer is 1150-65535 except for 1434 and 3389.
        ###

        def set_Port(value)
          set_input("Port", value)
        end
        #### 
        # Set the value of the PreferredBackupWindow input for this Choreo. 
        # 
        # @param String - (optional, string) The daily time range during which automated backups are created if automated backups are enabled, using the BackupRetentionPeriod parameter. Must be in the format hh24:mi-hh24:mi (in UTC).
        ###

        def set_PreferredBackupWindow(value)
          set_input("PreferredBackupWindow", value)
        end
        #### 
        # Set the value of the PreferredMaintenanceWindow input for this Choreo. 
        # 
        # @param String - (optional, string) The weekly time range (in UTC) during which system maintenance can occur. Format: ddd:hh24:mi-ddd:hh24:mi.
        ###

        def set_PreferredMaintenanceWindow(value)
          set_input("PreferredMaintenanceWindow", value)
        end
        #### 
        # Set the value of the PubliclyAccessible input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Specifies the accessibility options for the DB Instance. The default behavior varies depending on whether a VPC has been requested or not.
        ###

        def set_PubliclyAccessible(value)
          set_input("PubliclyAccessible", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the RDS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the VpcSecurityGroupIds input for this Choreo. 
        # 
        # @param String - (optional, string) A comma separated list of up to 10 EC2 VPC Security Groups to associate with this DB Instance.
        ###

        def set_VpcSecurityGroupIds(value)
          set_input("VpcSecurityGroupIds", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateDBInstance Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateDBInstanceResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateDBInstance



    ##############################################################################
    #
    # CreateDBSecurityGroup
    #
    # Creates a new database security group which you can use to control the access to the database instance.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateDBSecurityGroup < Choreography

      ####
      #  Create a new instance of the CreateDBSecurityGroup Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/RDS/CreateDBSecurityGroup")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateDBSecurityGroupInputSet
      ####
      def new_input_set()
        return CreateDBSecurityGroupInputSet.new()
      end

      def make_result_set()
        return CreateDBSecurityGroupResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateDBSecurityGroupResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateDBSecurityGroup
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateDBSecurityGroupInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the DBSecurityGroupDescription input for this Choreo. 
        # 
        # @param String - (required, string) A description for the security group you're creating.
        ###

        def set_DBSecurityGroupDescription(value)
          set_input("DBSecurityGroupDescription", value)
        end
        #### 
        # Set the value of the DBSecurityGroupName input for this Choreo. 
        # 
        # @param String - (required, string) A unique name for the security group you want to create.
        ###

        def set_DBSecurityGroupName(value)
          set_input("DBSecurityGroupName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the RDS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateDBSecurityGroup Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateDBSecurityGroupResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateDBSecurityGroup



    ##############################################################################
    #
    # CreateDBSnapshot
    #
    # Creates a snapshot of an existing database instance.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateDBSnapshot < Choreography

      ####
      #  Create a new instance of the CreateDBSnapshot Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/RDS/CreateDBSnapshot")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateDBSnapshotInputSet
      ####
      def new_input_set()
        return CreateDBSnapshotInputSet.new()
      end

      def make_result_set()
        return CreateDBSnapshotResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateDBSnapshotResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateDBSnapshot
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateDBSnapshotInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the DBInstanceIdentifier input for this Choreo. 
        # 
        # @param String - (required, string) The DB Instance identifier. Should be in all lowercase.
        ###

        def set_DBInstanceIdentifier(value)
          set_input("DBInstanceIdentifier", value)
        end
        #### 
        # Set the value of the DBSnapshotIdentifier input for this Choreo. 
        # 
        # @param String - (required, string) The unique identifier for the db snapshot you're creating.
        ###

        def set_DBSnapshotIdentifier(value)
          set_input("DBSnapshotIdentifier", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the RDS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateDBSnapshot Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateDBSnapshotResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateDBSnapshot



    ##############################################################################
    #
    # DeleteDBInstance
    #
    # Deletes a specified database instance.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteDBInstance < Choreography

      ####
      #  Create a new instance of the DeleteDBInstance Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/RDS/DeleteDBInstance")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteDBInstanceInputSet
      ####
      def new_input_set()
        return DeleteDBInstanceInputSet.new()
      end

      def make_result_set()
        return DeleteDBInstanceResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteDBInstanceResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteDBInstance
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteDBInstanceInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the DBInstanceIdentifier input for this Choreo. 
        # 
        # @param String - (required, string) The ID for the DB instance to delete.
        ###

        def set_DBInstanceIdentifier(value)
          set_input("DBInstanceIdentifier", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the RDS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteDBInstance Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteDBInstanceResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteDBInstance



    ##############################################################################
    #
    # DeleteDBSecurityGroup
    #
    # Deletes a specified database security group.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteDBSecurityGroup < Choreography

      ####
      #  Create a new instance of the DeleteDBSecurityGroup Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/RDS/DeleteDBSecurityGroup")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteDBSecurityGroupInputSet
      ####
      def new_input_set()
        return DeleteDBSecurityGroupInputSet.new()
      end

      def make_result_set()
        return DeleteDBSecurityGroupResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteDBSecurityGroupResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteDBSecurityGroup
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteDBSecurityGroupInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the DBSecurityGroupName input for this Choreo. 
        # 
        # @param String - (required, string) The name for the security group you want to delete.
        ###

        def set_DBSecurityGroupName(value)
          set_input("DBSecurityGroupName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the RDS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteDBSecurityGroup Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteDBSecurityGroupResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (string) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteDBSecurityGroup



    ##############################################################################
    #
    # DeleteDBSnapshot
    #
    # Deletes a specified database snapshot.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteDBSnapshot < Choreography

      ####
      #  Create a new instance of the DeleteDBSnapshot Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/RDS/DeleteDBSnapshot")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteDBSnapshotInputSet
      ####
      def new_input_set()
        return DeleteDBSnapshotInputSet.new()
      end

      def make_result_set()
        return DeleteDBSnapshotResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteDBSnapshotResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteDBSnapshot
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteDBSnapshotInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the DBSnapshotIdentifier input for this Choreo. 
        # 
        # @param String - (required, string) A unique identifier for the snapshot you want to delete.
        ###

        def set_DBSnapshotIdentifier(value)
          set_input("DBSnapshotIdentifier", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the RDS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteDBSnapshot Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteDBSnapshotResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteDBSnapshot



    ##############################################################################
    #
    # DescribeDBInstances
    #
    # Returns information about privisioned database instances.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeDBInstances < Choreography

      ####
      #  Create a new instance of the DescribeDBInstances Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/RDS/DescribeDBInstances")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeDBInstancesInputSet
      ####
      def new_input_set()
        return DescribeDBInstancesInputSet.new()
      end

      def make_result_set()
        return DescribeDBInstancesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeDBInstancesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeDBInstances
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeDBInstancesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the DBInstanceIdentifier input for this Choreo. 
        # 
        # @param String - (optional, string) The DB Instance identifier. Should be in all lowercase.
        ###

        def set_DBInstanceIdentifier(value)
          set_input("DBInstanceIdentifier", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param Integer - (optional, integer) If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxRecords input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The max number of results to return in the response. Defaults to 100. Minimum is 20.
        ###

        def set_MaxRecords(value)
          set_input("MaxRecords", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the RDS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeDBInstances Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeDBInstancesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeDBInstances



    ##############################################################################
    #
    # DescribeDBSecurityGroup
    #
    # Returns a list of DBSecurityGroup descriptions. The list will can be filtered by specifying a DBSecurityGroupName.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeDBSecurityGroup < Choreography

      ####
      #  Create a new instance of the DescribeDBSecurityGroup Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/RDS/DescribeDBSecurityGroup")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeDBSecurityGroupInputSet
      ####
      def new_input_set()
        return DescribeDBSecurityGroupInputSet.new()
      end

      def make_result_set()
        return DescribeDBSecurityGroupResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeDBSecurityGroupResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeDBSecurityGroup
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeDBSecurityGroupInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the DBSecurityGroupName input for this Choreo. 
        # 
        # @param String - (optional, string) The name for the security group you want to retrieve information for.
        ###

        def set_DBSecurityGroupName(value)
          set_input("DBSecurityGroupName", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param Integer - (optional, integer) If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxRecords input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The max number of results to return in the response. Defaults to 100. Minimum is 20.
        ###

        def set_MaxRecords(value)
          set_input("MaxRecords", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the RDS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeDBSecurityGroup Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeDBSecurityGroupResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeDBSecurityGroup



    ##############################################################################
    #
    # DescribeDBSnapshot
    #
    # Returns information about DB Snapshots.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeDBSnapshot < Choreography

      ####
      #  Create a new instance of the DescribeDBSnapshot Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/RDS/DescribeDBSnapshot")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeDBSnapshotInputSet
      ####
      def new_input_set()
        return DescribeDBSnapshotInputSet.new()
      end

      def make_result_set()
        return DescribeDBSnapshotResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeDBSnapshotResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeDBSnapshot
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeDBSnapshotInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the DBInstanceIdentifier input for this Choreo. 
        # 
        # @param String - (optional, string) The DB Instance identifier. Should be in all lowercase.
        ###

        def set_DBInstanceIdentifier(value)
          set_input("DBInstanceIdentifier", value)
        end
        #### 
        # Set the value of the DBSnapshotIdentifier input for this Choreo. 
        # 
        # @param String - (optional, string) The unique identifier for the db snapshot you're retrieving information for.
        ###

        def set_DBSnapshotIdentifier(value)
          set_input("DBSnapshotIdentifier", value)
        end
        #### 
        # Set the value of the MaxRecords input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The max number of results to return in the response. Defaults to 100. Minimum is 20.
        ###

        def set_MaxRecords(value)
          set_input("MaxRecords", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the RDS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeDBSnapshot Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeDBSnapshotResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeDBSnapshot



    ##############################################################################
    #
    # DescribeEvents
    #
    # Returns events related to DB Instances, DB Security Groups, DB Snapshots and DB Parameter Groups for the past 14 days.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DescribeEvents < Choreography

      ####
      #  Create a new instance of the DescribeEvents Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/RDS/DescribeEvents")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DescribeEventsInputSet
      ####
      def new_input_set()
        return DescribeEventsInputSet.new()
      end

      def make_result_set()
        return DescribeEventsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DescribeEventsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DescribeEvents
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DescribeEventsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Duration input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The number of minutes to retrieve events for. Defaults to 60.
        ###

        def set_Duration(value)
          set_input("Duration", value)
        end
        #### 
        # Set the value of the EndTime input for this Choreo. 
        # 
        # @param String - (optional, date) The end of the time interval for which to retrieve events, specified in ISO 8601 format (i.e. 2009-07-08T18:00Z).
        ###

        def set_EndTime(value)
          set_input("EndTime", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param Integer - (optional, integer) If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxRecords input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The maximum number of records to include in the response. If more records exist, a marker is included in the response so that the remaining results may be retrieved. Defaults to max (100). Min is 20.
        ###

        def set_MaxRecords(value)
          set_input("MaxRecords", value)
        end
        #### 
        # Set the value of the SourceIdentifier input for this Choreo. 
        # 
        # @param String - (optional, string) The identifier of the event source for which events will be returned. If not specified, then all sources are included in the response.
        ###

        def set_SourceIdentifier(value)
          set_input("SourceIdentifier", value)
        end
        #### 
        # Set the value of the SourceType input for this Choreo. 
        # 
        # @param String - (optional, string) The event source to retrieve events for. If no value is specified, all events are returned. Valid values are: db-instance | db-parameter-group | db-security-group | db-snapshot.
        ###

        def set_SourceType(value)
          set_input("SourceType", value)
        end
        #### 
        # Set the value of the StartTime input for this Choreo. 
        # 
        # @param String - (optional, date) The beginning of the time interval to retrieve events for, specified in ISO 8601 format (i.e. 2009-07-08T18:00Z)
        ###

        def set_StartTime(value)
          set_input("StartTime", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the RDS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DescribeEvents Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DescribeEventsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DescribeEvents



    ##############################################################################
    #
    # ModifyDBInstance
    #
    # Modify settings for a DB Instance. You can change one or more database configuration parameters by specifying values for the Choreo inputs.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ModifyDBInstance < Choreography

      ####
      #  Create a new instance of the ModifyDBInstance Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/RDS/ModifyDBInstance")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ModifyDBInstanceInputSet
      ####
      def new_input_set()
        return ModifyDBInstanceInputSet.new()
      end

      def make_result_set()
        return ModifyDBInstanceResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ModifyDBInstanceResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ModifyDBInstance
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ModifyDBInstanceInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AllocatedStorage input for this Choreo. 
        # 
        # @param Integer - (required, integer) Storage amount (in gigabytes) to be configured for the DB. Use 5 to 1024 for MySQL or 10 to 1024 for Oracle. Value supplied must be at least 10% greater than the current value
        ###

        def set_AllocatedStorage(value)
          set_input("AllocatedStorage", value)
        end
        #### 
        # Set the value of the AllowMajorVersionUpgrade input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Indicates that major version upgrades are allowed. Defaults to 0 (false).
        ###

        def set_AllowMajorVersionUpgrade(value)
          set_input("AllowMajorVersionUpgrade", value)
        end
        #### 
        # Set the value of the ApplyImmediately input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Specifies whether or not the modifications applied as soon as possible, regardless of the PreferredMaintenanceWindow setting for the DB Instance. Defaults to 0 (false).
        ###

        def set_ApplyImmediately(value)
          set_input("ApplyImmediately", value)
        end
        #### 
        # Set the value of the AutoMinorVersionUpgrade input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Indicates that minor version upgrades will be applied automatically to the DB Instance during the maintenance window. Defaults to 0 (false).
        ###

        def set_AutoMinorVersionUpgrade(value)
          set_input("AutoMinorVersionUpgrade", value)
        end
        #### 
        # Set the value of the BackupRetentionPeriod input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Number of days to retain automated backups. Setting to a positive number enables backups. Setting to 0 disables automated backups. Must be a value from 0 to 8. Defaults to 0 (disabled).
        ###

        def set_BackupRetentionPeriod(value)
          set_input("BackupRetentionPeriod", value)
        end
        #### 
        # Set the value of the DBInstanceClass input for this Choreo. 
        # 
        # @param String - (required, string) Capacity for the DB instance.  (db.m1.small, db.m1.large, db.m1.xlarge, db.m2.xlarge, db.m2.2xlarge, or db.m2.4xlarge).
        ###

        def set_DBInstanceClass(value)
          set_input("DBInstanceClass", value)
        end
        #### 
        # Set the value of the DBInstanceIdentifier input for this Choreo. 
        # 
        # @param String - (required, string) The DB Instance identifier. Should be in all lowercase.
        ###

        def set_DBInstanceIdentifier(value)
          set_input("DBInstanceIdentifier", value)
        end
        #### 
        # Set the value of the DBParameterGroupName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the DB Parameter Group to apply to this DB Instance.
        ###

        def set_DBParameterGroupName(value)
          set_input("DBParameterGroupName", value)
        end
        #### 
        # Set the value of the DBSecurityGroup input for this Choreo. 
        # 
        # @param String - (optional, string) A DB Security Groups to authorize on this DB Instance.
        ###

        def set_DBSecurityGroup(value)
          set_input("DBSecurityGroup", value)
        end
        #### 
        # Set the value of the EngineVersion input for this Choreo. 
        # 
        # @param String - (optional, string) The version number of the database engine to upgrade to.
        ###

        def set_EngineVersion(value)
          set_input("EngineVersion", value)
        end
        #### 
        # Set the value of the MasterUserPassword input for this Choreo. 
        # 
        # @param String - (required, string) The new password for the DB Instance master user.
        ###

        def set_MasterUserPassword(value)
          set_input("MasterUserPassword", value)
        end
        #### 
        # Set the value of the MultiAZ input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Specifies if the DB Instance is a Multi-AZ deployment.
        ###

        def set_MultiAZ(value)
          set_input("MultiAZ", value)
        end
        #### 
        # Set the value of the PreferredBackupWindow input for this Choreo. 
        # 
        # @param String - (optional, string) The daily time range during which automated backups are created. Format: hh24:mi-hh24:mi (in UTC). Must be at least 30 minutes. Can not conflict with PreferredMaintenanceWindow setting.
        ###

        def set_PreferredBackupWindow(value)
          set_input("PreferredBackupWindow", value)
        end
        #### 
        # Set the value of the PreferredMaintenanceWindow input for this Choreo. 
        # 
        # @param String - (optional, string) The weekly time range (in UTC) during which system maintenance can occur, which may result in an outage. Format: ddd:hh24:mi-ddd:hh24:mi. Valid Days: Mon | Tue | Wed | Thu | Fri | Sat | Sun.
        ###

        def set_PreferredMaintenanceWindow(value)
          set_input("PreferredMaintenanceWindow", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the RDS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ModifyDBInstance Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ModifyDBInstanceResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ModifyDBInstance



    ##############################################################################
    #
    # RebootDBInstance
    #
    # Reboots a specified database instance.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RebootDBInstance < Choreography

      ####
      #  Create a new instance of the RebootDBInstance Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/RDS/RebootDBInstance")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RebootDBInstanceInputSet
      ####
      def new_input_set()
        return RebootDBInstanceInputSet.new()
      end

      def make_result_set()
        return RebootDBInstanceResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RebootDBInstanceResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RebootDBInstance
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RebootDBInstanceInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the DBInstanceIdentifier input for this Choreo. 
        # 
        # @param String - (required, string) The ID for the DB instance to reboot.
        ###

        def set_DBInstanceIdentifier(value)
          set_input("DBInstanceIdentifier", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the RDS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RebootDBInstance Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RebootDBInstanceResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class RebootDBInstance



    ##############################################################################
    #
    # RestoreDBInstanceFromDBSnapshot
    #
    # Creates a new DB Instance from a DB snapshot.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RestoreDBInstanceFromDBSnapshot < Choreography

      ####
      #  Create a new instance of the RestoreDBInstanceFromDBSnapshot Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/RDS/RestoreDBInstanceFromDBSnapshot")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RestoreDBInstanceFromDBSnapshotInputSet
      ####
      def new_input_set()
        return RestoreDBInstanceFromDBSnapshotInputSet.new()
      end

      def make_result_set()
        return RestoreDBInstanceFromDBSnapshotResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RestoreDBInstanceFromDBSnapshotResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RestoreDBInstanceFromDBSnapshot
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RestoreDBInstanceFromDBSnapshotInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AutoMinorVersionUpgrade input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Indicates that minor version upgrades will be applied automatically to the DB Instance during the maintenance window. Defaults to 0 (false).
        ###

        def set_AutoMinorVersionUpgrade(value)
          set_input("AutoMinorVersionUpgrade", value)
        end
        #### 
        # Set the value of the AvailabilityZone input for this Choreo. 
        # 
        # @param String - (optional, string) The EC2 Availability Zone that the database instance will be created in. A random one is chose if not provided. Can not be specified if the MultiAZ parameter is set to 1 (true).
        ###

        def set_AvailabilityZone(value)
          set_input("AvailabilityZone", value)
        end
        #### 
        # Set the value of the DBInstanceClass input for this Choreo. 
        # 
        # @param String - (optional, string) The compute and memory capacity of the Amazon RDS DB instance. Valid Values: db.m1.small | db.m1.large | db.m1.xlarge | db.m2.2xlarge | db.m2.4xlarge.
        ###

        def set_DBInstanceClass(value)
          set_input("DBInstanceClass", value)
        end
        #### 
        # Set the value of the DBInstanceIdentifier input for this Choreo. 
        # 
        # @param String - (required, string) The identifier for the new DB instance that will be created from the specified Snapshot.
        ###

        def set_DBInstanceIdentifier(value)
          set_input("DBInstanceIdentifier", value)
        end
        #### 
        # Set the value of the DBName input for this Choreo. 
        # 
        # @param String - (optional, string) The database name for the restored DB Instance. Note that this parameter doesn't apply to the MySQL engine.
        ###

        def set_DBName(value)
          set_input("DBName", value)
        end
        #### 
        # Set the value of the DBSnapshotIdentifier input for this Choreo. 
        # 
        # @param String - (required, string) The name of the DB Snapshot to use.
        ###

        def set_DBSnapshotIdentifier(value)
          set_input("DBSnapshotIdentifier", value)
        end
        #### 
        # Set the value of the Engine input for this Choreo. 
        # 
        # @param String - (optional, string) The database engine to use for the new instance. Valid Values: MySQL | oracle-se1 | oracle-se | oracle-ee.
        ###

        def set_Engine(value)
          set_input("Engine", value)
        end
        #### 
        # Set the value of the LicenseModel input for this Choreo. 
        # 
        # @param String - (optional, string) License model information for the restored DB Instance. Valid values: license-included | bring-your-own-license | general-public-license.
        ###

        def set_LicenseModel(value)
          set_input("LicenseModel", value)
        end
        #### 
        # Set the value of the MultiAZ input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Specifies if the DB Instance is a Multi-AZ deployment. Do not specify the AvailabilityZone parameter if the MultiAZ parameter is set to 1 (true).
        ###

        def set_MultiAZ(value)
          set_input("MultiAZ", value)
        end
        #### 
        # Set the value of the Port input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The port number on which the database accepts connections.
        ###

        def set_Port(value)
          set_input("Port", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the RDS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RestoreDBInstanceFromDBSnapshot Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RestoreDBInstanceFromDBSnapshotResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class RestoreDBInstanceFromDBSnapshot



    ##############################################################################
    #
    # RestoreDBInstanceToPointInTime
    #
    # Restores a DB Instance to an specified point-in-time.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RestoreDBInstanceToPointInTime < Choreography

      ####
      #  Create a new instance of the RestoreDBInstanceToPointInTime Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/RDS/RestoreDBInstanceToPointInTime")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RestoreDBInstanceToPointInTimeInputSet
      ####
      def new_input_set()
        return RestoreDBInstanceToPointInTimeInputSet.new()
      end

      def make_result_set()
        return RestoreDBInstanceToPointInTimeResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RestoreDBInstanceToPointInTimeResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RestoreDBInstanceToPointInTime
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RestoreDBInstanceToPointInTimeInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AutoMinorVersionUpgrade input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Indicates that minor version upgrades will be applied automatically to the DB Instance during the maintenance window. Defaults to 0 (false).
        ###

        def set_AutoMinorVersionUpgrade(value)
          set_input("AutoMinorVersionUpgrade", value)
        end
        #### 
        # Set the value of the AvailabilityZone input for this Choreo. 
        # 
        # @param String - (optional, string) The EC2 Availability Zone that the database instance will be created in. A random one is chose if not provided. Can not be specified if the MultiAZ parameter is set to 1 (true).
        ###

        def set_AvailabilityZone(value)
          set_input("AvailabilityZone", value)
        end
        #### 
        # Set the value of the DBInstanceClass input for this Choreo. 
        # 
        # @param String - (optional, string) The compute and memory capacity of the Amazon RDS DB instance. Valid Values: db.m1.small | db.m1.large | db.m1.xlarge | db.m2.2xlarge | db.m2.4xlarge.
        ###

        def set_DBInstanceClass(value)
          set_input("DBInstanceClass", value)
        end
        #### 
        # Set the value of the DBName input for this Choreo. 
        # 
        # @param String - (optional, string) The database name for the restored DB Instance. Note that this parameter doesn't apply to the MySQL engine.
        ###

        def set_DBName(value)
          set_input("DBName", value)
        end
        #### 
        # Set the value of the Engine input for this Choreo. 
        # 
        # @param String - (optional, string) The database engine to use for the new instance. Valid Values: MySQL | oracle-se1 | oracle-se | oracle-ee.
        ###

        def set_Engine(value)
          set_input("Engine", value)
        end
        #### 
        # Set the value of the LicenseModel input for this Choreo. 
        # 
        # @param String - (optional, string) License model information for the restored DB Instance. Valid values: license-included | bring-your-own-license | general-public-license.
        ###

        def set_LicenseModel(value)
          set_input("LicenseModel", value)
        end
        #### 
        # Set the value of the MultiAZ input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Specifies if the DB Instance is a Multi-AZ deployment. Do not specify the AvailabilityZone parameter if the MultiAZ parameter is set to 1 (true).
        ###

        def set_MultiAZ(value)
          set_input("MultiAZ", value)
        end
        #### 
        # Set the value of the Port input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The port number on which the database accepts connections.
        ###

        def set_Port(value)
          set_input("Port", value)
        end
        #### 
        # Set the value of the RestoreTime input for this Choreo. 
        # 
        # @param String - (optional, date) The date and time to restore from in UTC. Cannot be specified if UseLatestRestorableTime parameter is set to 1. (format: 2009-09-07T23:45:00Z).
        ###

        def set_RestoreTime(value)
          set_input("RestoreTime", value)
        end
        #### 
        # Set the value of the SourceDBInstanceIdentifier input for this Choreo. 
        # 
        # @param String - (required, string) The identifier of the source DB Instance from which to restore.
        ###

        def set_SourceDBInstanceIdentifier(value)
          set_input("SourceDBInstanceIdentifier", value)
        end
        #### 
        # Set the value of the TargetDBInstanceIdentifier input for this Choreo. 
        # 
        # @param String - (required, string) The name of the new database instance to be created.
        ###

        def set_TargetDBInstanceIdentifier(value)
          set_input("TargetDBInstanceIdentifier", value)
        end
        #### 
        # Set the value of the UseLatestRestorableTime input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Specifies whether or not the DB Instance is restored from the latest backup time. Defaults to 0 (false).
        ###

        def set_UseLatestRestorableTime(value)
          set_input("UseLatestRestorableTime", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the RDS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RestoreDBInstanceToPointInTime Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RestoreDBInstanceToPointInTimeResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class RestoreDBInstanceToPointInTime



    ##############################################################################
    #
    # RevokeDBSecurityGroupIngress
    #
    # Revokes access from a DBSecurityGroup for previously authorized IP ranges or EC2 Security Groups.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RevokeDBSecurityGroupIngress < Choreography

      ####
      #  Create a new instance of the RevokeDBSecurityGroupIngress Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/RDS/RevokeDBSecurityGroupIngress")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RevokeDBSecurityGroupIngressInputSet
      ####
      def new_input_set()
        return RevokeDBSecurityGroupIngressInputSet.new()
      end

      def make_result_set()
        return RevokeDBSecurityGroupIngressResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RevokeDBSecurityGroupIngressResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RevokeDBSecurityGroupIngress
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RevokeDBSecurityGroupIngressInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the CIDRIP input for this Choreo. 
        # 
        # @param String - (conditional, string) IP range that should be revoked. Required unless EC2SecurityGroupName and EC2SecurityGroupOwnerId are used.
        ###

        def set_CIDRIP(value)
          set_input("CIDRIP", value)
        end
        #### 
        # Set the value of the DBSecurityGroupName input for this Choreo. 
        # 
        # @param String - (required, string) A unique name for the security group you want to revoke ingress from.
        ###

        def set_DBSecurityGroupName(value)
          set_input("DBSecurityGroupName", value)
        end
        #### 
        # Set the value of the EC2SecurityGroupName input for this Choreo. 
        # 
        # @param String - (conditional, string) The EC2 security group to revoke. This and EC2SecurityGroupOwnerId are required if CIDRIP is not used.
        ###

        def set_EC2SecurityGroupName(value)
          set_input("EC2SecurityGroupName", value)
        end
        #### 
        # Set the value of the EC2SecurityGroupOwnerId input for this Choreo. 
        # 
        # @param String - (conditional, string) The account number for the security group owner to revoke. This and EC2SecurityGroupName are required if CIDRIP is not used.
        ###

        def set_EC2SecurityGroupOwnerId(value)
          set_input("EC2SecurityGroupOwnerId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the RDS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RevokeDBSecurityGroupIngress Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RevokeDBSecurityGroupIngressResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class RevokeDBSecurityGroupIngress




  end # module RDS

  module S3



    ##############################################################################
    #
    # CopyObject
    #
    # Makes a copy of an existing object in S3 Storage.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CopyObject < Choreography

      ####
      #  Create a new instance of the CopyObject Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/CopyObject")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CopyObjectInputSet
      ####
      def new_input_set()
        return CopyObjectInputSet.new()
      end

      def make_result_set()
        return CopyObjectResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CopyObjectResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CopyObject
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CopyObjectInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket that will be the file destination.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the CannedACL input for this Choreo. 
        # 
        # @param String - (optional, string) By default all objects are private (only owner has full access control). Valid values: private, public-read, public-read-write, authenticated-read, bucket-owner-read, bucket-owner-full-control.
        ###

        def set_CannedACL(value)
          set_input("CannedACL", value)
        end
        #### 
        # Set the value of the ContentType input for this Choreo. 
        # 
        # @param String - (optional, string) ContentType. Default is application/octet-stream.
        ###

        def set_ContentType(value)
          set_input("ContentType", value)
        end
        #### 
        # Set the value of the FileToCopy input for this Choreo. 
        # 
        # @param String - (required, string) The name of the file to copy.
        ###

        def set_FileToCopy(value)
          set_input("FileToCopy", value)
        end
        #### 
        # Set the value of the IfMatch input for this Choreo. 
        # 
        # @param String - (optional, string) Copies the object if its entity tag (ETag) matches the specified tag; otherwise returns a 412 HTTP status code error (failed precondition).
        ###

        def set_IfMatch(value)
          set_input("IfMatch", value)
        end
        #### 
        # Set the value of the IfModifiedSince input for this Choreo. 
        # 
        # @param String - (optional, date) Copies if it has been modified since the specified time; otherwise returns a 412 HTTP status code error (failed precondition). Must be valid HTTP date. Can be used with IfMatch only.
        ###

        def set_IfModifiedSince(value)
          set_input("IfModifiedSince", value)
        end
        #### 
        # Set the value of the IfNoneMatch input for this Choreo. 
        # 
        # @param String - (optional, string) Copies the object if its entity tag (ETag) is different from the specified tag; otherwise returns a 412 HTTP status code error (failed precondition).
        ###

        def set_IfNoneMatch(value)
          set_input("IfNoneMatch", value)
        end
        #### 
        # Set the value of the IfUnmodifiedSince input for this Choreo. 
        # 
        # @param String - (optional, date) Copies if it hasn't been modified since the specified time; otherwise returns a 412 HTTP status code error (failed precondition). Must be valid HTTP date. Can be used with IfMatch or IfNoneMatch only.
        ###

        def set_IfUnmodifiedSince(value)
          set_input("IfUnmodifiedSince", value)
        end
        #### 
        # Set the value of the NewFileName input for this Choreo. 
        # 
        # @param String - (required, string) The file name for the new copy.
        ###

        def set_NewFileName(value)
          set_input("NewFileName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the SSECAlgorithm input for this Choreo. 
        # 
        # @param String - (optional, string) Specifies the server-side encryption with customer-provided encryption keys (SSE-C) algorithm to use when Amazon S3 creates the target object. Valid value: AES256.
        ###

        def set_SSECAlgorithm(value)
          set_input("SSECAlgorithm", value)
        end
        #### 
        # Set the value of the SSECKey input for this Choreo. 
        # 
        # @param String - (optional, string) The customer-provided AES-256 256-bit (32-byte) encryption key for Amazon S3 to use to encrypt or decrypt your copied data object.
        ###

        def set_SSECKey(value)
          set_input("SSECKey", value)
        end
        #### 
        # Set the value of the SSECSourceAlgorithm input for this Choreo. 
        # 
        # @param String - (optional, string) Specifies the server-side encryption with customer-provided encryption keys (SSE-C) algorithm to use to decrypt the Amazon S3 source object being copied. Valid value: AES256.
        ###

        def set_SSECSourceAlgorithm(value)
          set_input("SSECSourceAlgorithm", value)
        end
        #### 
        # Set the value of the SSECSourceKey input for this Choreo. 
        # 
        # @param String - (optional, string) The customer-provided AES-256 256-bit (32-byte) encryption key for Amazon S3 to use to decrypt the copy source object.
        ###

        def set_SSECSourceKey(value)
          set_input("SSECSourceKey", value)
        end
        #### 
        # Set the value of the ServerSideEncryption input for this Choreo. 
        # 
        # @param String - (optional, string) Specifies the server-side encryption algorithm to use when Amazon S3 creates the target object. Valid value: AES256.
        ###

        def set_ServerSideEncryption(value)
          set_input("ServerSideEncryption", value)
        end
        #### 
        # Set the value of the StorageClass input for this Choreo. 
        # 
        # @param String - (optional, string) Enables RRS customers to store their noncritical, reproducible data at lower levels of redundancy than Amazon S3's standard storage. Valid Values: STANDARD (default), REDUCED_REDUNDANCY.
        ###

        def set_StorageClass(value)
          set_input("StorageClass", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the WebsiteRedirectLocation input for this Choreo. 
        # 
        # @param String - (optional, string) If the bucket is configured as a website, redirects requests for this object to another object in the same bucket or to an external URL. Ex: /anotherPage.html, http://www.page.com. Length limit: 2 K.
        ###

        def set_WebsiteRedirectLocation(value)
          set_input("WebsiteRedirectLocation", value)
        end
        #### 
        # Set the value of the VaultFile input for this Choreo. 
        # 
        # @param TembooPath - (optional, vault file) The path to a vault file that you want to upload to an Amazon S3 bucket. Required unless using the FileContents input variable.
        ###

        def set_VaultFile(value)
          set_alias("VaultFile", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CopyObject Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CopyObjectResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CopyObject



    ##############################################################################
    #
    # DeleteBucket
    #
    # Deletes a bucket from your Amazon S3 account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteBucket < Choreography

      ####
      #  Create a new instance of the DeleteBucket Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/DeleteBucket")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteBucketInputSet
      ####
      def new_input_set()
        return DeleteBucketInputSet.new()
      end

      def make_result_set()
        return DeleteBucketResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteBucketResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteBucket
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteBucketInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket that will be deleted.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteBucket Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteBucketResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon. Note that no content is returned for successful deletions.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteBucket



    ##############################################################################
    #
    # DeleteBucketCORS
    #
    # Deletes the CORS (Cross-Origin Resource Sharing) configuration information set for the specified bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteBucketCORS < Choreography

      ####
      #  Create a new instance of the DeleteBucketCORS Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/DeleteBucketCORS")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteBucketCORSInputSet
      ####
      def new_input_set()
        return DeleteBucketCORSInputSet.new()
      end

      def make_result_set()
        return DeleteBucketCORSResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteBucketCORSResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteBucketCORS
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteBucketCORSInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket that the CORS configuration should be removed from.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteBucketCORS Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteBucketCORSResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon. Note that for a successful exection, this API operation returns an empty 204 response.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteBucketCORS



    ##############################################################################
    #
    # DeleteBucketLifecycle
    #
    # Deletes the lifecycle configuration from the specified bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteBucketLifecycle < Choreography

      ####
      #  Create a new instance of the DeleteBucketLifecycle Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/DeleteBucketLifecycle")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteBucketLifecycleInputSet
      ####
      def new_input_set()
        return DeleteBucketLifecycleInputSet.new()
      end

      def make_result_set()
        return DeleteBucketLifecycleResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteBucketLifecycleResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteBucketLifecycle
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteBucketLifecycleInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket associated with the lifecycle you want to delete.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteBucketLifecycle Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteBucketLifecycleResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - Stores the response from Amazon. Note that for a successful delete operation, no content is returned, and this output variable should be empty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteBucketLifecycle



    ##############################################################################
    #
    # DeleteBucketPolicy
    #
    # Deletes the policy on a specified bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteBucketPolicy < Choreography

      ####
      #  Create a new instance of the DeleteBucketPolicy Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/DeleteBucketPolicy")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteBucketPolicyInputSet
      ####
      def new_input_set()
        return DeleteBucketPolicyInputSet.new()
      end

      def make_result_set()
        return DeleteBucketPolicyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteBucketPolicyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteBucketPolicy
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteBucketPolicyInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket associated with the policy you want to delete.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteBucketPolicy Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteBucketPolicyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - Stores the response from Amazon. Note that for a successful delete operation, no content is returned, and this output variable should be empty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteBucketPolicy



    ##############################################################################
    #
    # DeleteBucketTagging
    #
    # Removes a billing tag set from the specified bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteBucketTagging < Choreography

      ####
      #  Create a new instance of the DeleteBucketTagging Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/DeleteBucketTagging")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteBucketTaggingInputSet
      ####
      def new_input_set()
        return DeleteBucketTaggingInputSet.new()
      end

      def make_result_set()
        return DeleteBucketTaggingResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteBucketTaggingResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteBucketTagging
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteBucketTaggingInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket to remove tags from.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteBucketTagging Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteBucketTaggingResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon. A successful execution returns an empty 204 response.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteBucketTagging



    ##############################################################################
    #
    # DeleteBucketWebsite
    #
    # Deletes the website configuration for the specified bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteBucketWebsite < Choreography

      ####
      #  Create a new instance of the DeleteBucketWebsite Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/DeleteBucketWebsite")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteBucketWebsiteInputSet
      ####
      def new_input_set()
        return DeleteBucketWebsiteInputSet.new()
      end

      def make_result_set()
        return DeleteBucketWebsiteResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteBucketWebsiteResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteBucketWebsite
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteBucketWebsiteInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket associated with the website configuration you want to delete.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteBucketWebsite Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteBucketWebsiteResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - Stores the response from Amazon. Note that for a successful delete operation, no content is returned and this output variable is empty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteBucketWebsite



    ##############################################################################
    #
    # DeleteMultipleObjects
    #
    # Deletes multiple objects from an S3 Bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteMultipleObjects < Choreography

      ####
      #  Create a new instance of the DeleteMultipleObjects Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/DeleteMultipleObjects")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteMultipleObjectsInputSet
      ####
      def new_input_set()
        return DeleteMultipleObjectsInputSet.new()
      end

      def make_result_set()
        return DeleteMultipleObjectsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteMultipleObjectsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteMultipleObjects
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteMultipleObjectsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The the name of the bucket that contains the objects that you want to delete.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the FileNames input for this Choreo. 
        # 
        # @param String - (required, string) A list of file names to delete (separated by commas).
        ###

        def set_FileNames(value)
          set_input("FileNames", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteMultipleObjects Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteMultipleObjectsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon. Note that no content is returned for a successful delete operation.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteMultipleObjects



    ##############################################################################
    #
    # DeleteObject
    #
    # Deletes a specified item from an Amazon S3 bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteObject < Choreography

      ####
      #  Create a new instance of the DeleteObject Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/DeleteObject")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteObjectInputSet
      ####
      def new_input_set()
        return DeleteObjectInputSet.new()
      end

      def make_result_set()
        return DeleteObjectResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteObjectResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteObject
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteObjectInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The the name of the bucket that contains the object that you want to delete.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the FileName input for this Choreo. 
        # 
        # @param String - (required, string) The file name that you want to delete.
        ###

        def set_FileName(value)
          set_input("FileName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteObject Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteObjectResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon. Note that no content is returned for a successful delete operation.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteObject



    ##############################################################################
    #
    # GetBase64EncodedObject
    #
    # Retrieves a specified item from an Amazon S3 bucket, returns the file content as base64-encoded data, and returns the values of key response headers as output variables if available.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetBase64EncodedObject < Choreography

      ####
      #  Create a new instance of the GetBase64EncodedObject Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/GetBase64EncodedObject")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetBase64EncodedObjectInputSet
      ####
      def new_input_set()
        return GetBase64EncodedObjectInputSet.new()
      end

      def make_result_set()
        return GetBase64EncodedObjectResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetBase64EncodedObjectResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetBase64EncodedObject
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetBase64EncodedObjectInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket that contains the object to retrieve.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the FileName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the file to retrieve.
        ###

        def set_FileName(value)
          set_input("FileName", value)
        end
        #### 
        # Set the value of the IfMatch input for this Choreo. 
        # 
        # @param String - (optional, string) Returns the object only if its entity tag (ETag) is the same as the one specified, otherwise returns a 412 (precondition failed) error.
        ###

        def set_IfMatch(value)
          set_input("IfMatch", value)
        end
        #### 
        # Set the value of the IfModifiedSince input for this Choreo. 
        # 
        # @param String - (optional, date) Returns the object only if it has been modified since the specific time, otherwise returns a 304 (not modified) error.
        ###

        def set_IfModifiedSince(value)
          set_input("IfModifiedSince", value)
        end
        #### 
        # Set the value of the IfNoneMatch input for this Choreo. 
        # 
        # @param String - (optional, string) Returns the object only if its entity tag (ETag) is different from the one specified, otherwise retuns a 304 (not modified) error. Will not work correctly with IfModifiedSince.
        ###

        def set_IfNoneMatch(value)
          set_input("IfNoneMatch", value)
        end
        #### 
        # Set the value of the IfUnmodifiedSince input for this Choreo. 
        # 
        # @param String - (optional, date) Returns the object only if it has not been modified since the specified time, otherwise returns a 412 (precondition failed) error.
        ###

        def set_IfUnmodifiedSince(value)
          set_input("IfUnmodifiedSince", value)
        end
        #### 
        # Set the value of the Range input for this Choreo. 
        # 
        # @param String - (optional, string) Downloads the specific range of bytes of an object. Ex: 0-9 (returns the first 10 bytes of an object), 100-1000, etc. If the range value exceeds the end of file, it will return up to the end of file.
        ###

        def set_Range(value)
          set_input("Range", value)
        end
        #### 
        # Set the value of the SSECAlgorithm input for this Choreo. 
        # 
        # @param String - (optional, string) Specifies the server-side encryption with customer-provided encryption keys (SSE-C) algorithm used when Amazon S3 created the target object. Valid value: AES256.
        ###

        def set_SSECAlgorithm(value)
          set_input("SSECAlgorithm", value)
        end
        #### 
        # Set the value of the SSECKey input for this Choreo. 
        # 
        # @param String - (optional, string) The customer-provided AES-256 256-bit (32-byte) encryption key for Amazon S3 to use to encrypt or decrypt your data.
        ###

        def set_SSECKey(value)
          set_input("SSECKey", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (conditional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetBase64EncodedObject Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetBase64EncodedObjectResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "DeleteMarker" output from this Choreo execution
      	#
      	# @return String - (boolean) Returns true if the object retrieved was a Delete Marker otherwise no value.
      	####
      	def get_DeleteMarker()
      	  return @outputs["DeleteMarker"]
      	end
      	####
      	# Retrieve the value for the "ETag" output from this Choreo execution
      	#
      	# @return String - (string) The ETag string for the file.
      	####
      	def get_ETag()
      	  return @outputs["ETag"]
      	end
      	####
      	# Retrieve the value for the "Expiration" output from this Choreo execution
      	#
      	# @return String - (string) Appears if the object expiration is configured. It includes expiry-date and URL-encoded rule-id key value pairs providing object expiration information.
      	####
      	def get_Expiration()
      	  return @outputs["Expiration"]
      	end
      	####
      	# Retrieve the value for the "Restore" output from this Choreo execution
      	#
      	# @return String - (string) Provides information about the object restoration operation and expiration time of the restored object copy.
      	####
      	def get_Restore()
      	  return @outputs["Restore"]
      	end
      	####
      	# Retrieve the value for the "ServerSideEncryption" output from this Choreo execution
      	#
      	# @return String - (string) If the object is stored using server-side encryption, response includes this header with value of the encryption algorithm used. Valid Values: AES256.
      	####
      	def get_ServerSideEncryption()
      	  return @outputs["ServerSideEncryption"]
      	end
      	####
      	# Retrieve the value for the "VersionID" output from this Choreo execution
      	#
      	# @return String - (string) Returns the version ID of the retrieved object if it has a unique version ID.
      	####
      	def get_VersionID()
      	  return @outputs["VersionID"]
      	end
      	####
      	# Retrieve the value for the "WebsiteRedirectLocation" output from this Choreo execution
      	#
      	# @return String - (string) For a bucket configured as a website, this metadata can be set so the website will evaluate the request for the object as a 301 redirect to another object in the same bucket or an external URL.
      	####
      	def get_WebsiteRedirectLocation()
      	  return @outputs["WebsiteRedirectLocation"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (string) The base64-encoded contents of the file you are retrieving.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetBase64EncodedObject



    ##############################################################################
    #
    # GetBucketACL
    #
    # Returns the access control list (ACL) of a bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetBucketACL < Choreography

      ####
      #  Create a new instance of the GetBucketACL Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/GetBucketACL")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetBucketACLInputSet
      ####
      def new_input_set()
        return GetBucketACLInputSet.new()
      end

      def make_result_set()
        return GetBucketACLResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetBucketACLResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetBucketACL
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetBucketACLInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket associated with the ACL you want to retrieve.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetBucketACL Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetBucketACLResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetBucketACL



    ##############################################################################
    #
    # GetBucketCORS
    #
    # Retrieves the CORS (Cross-Origin Resource Sharing) configuration information set for the bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetBucketCORS < Choreography

      ####
      #  Create a new instance of the GetBucketCORS Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/GetBucketCORS")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetBucketCORSInputSet
      ####
      def new_input_set()
        return GetBucketCORSInputSet.new()
      end

      def make_result_set()
        return GetBucketCORSResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetBucketCORSResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetBucketCORS
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetBucketCORSInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket to retrieve the CORS configuration for.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetBucketCORS Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetBucketCORSResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetBucketCORS



    ##############################################################################
    #
    # GetBucketLifecycle
    #
    # Returns the lifecycle configuration information set on the bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetBucketLifecycle < Choreography

      ####
      #  Create a new instance of the GetBucketLifecycle Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/GetBucketLifecycle")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetBucketLifecycleInputSet
      ####
      def new_input_set()
        return GetBucketLifecycleInputSet.new()
      end

      def make_result_set()
        return GetBucketLifecycleResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetBucketLifecycleResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetBucketLifecycle
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetBucketLifecycleInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket associated with the lifecycle you want to retrieve.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetBucketLifecycle Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetBucketLifecycleResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetBucketLifecycle



    ##############################################################################
    #
    # GetBucketList
    #
    # Retrieves a list of the items that are in a specified Amazon S3 storage bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetBucketList < Choreography

      ####
      #  Create a new instance of the GetBucketList Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/GetBucketList")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetBucketListInputSet
      ####
      def new_input_set()
        return GetBucketListInputSet.new()
      end

      def make_result_set()
        return GetBucketListResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetBucketListResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetBucketList
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetBucketListInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket that contains the list of objects that you want to retrieve.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the Delimiter input for this Choreo. 
        # 
        # @param String - (optional, string) A delimiter is a character you use to group keys. All keys that contain the delimiter are grouped under a single result element, Common Prefixes. For more information see Amazon documentation.
        ###

        def set_Delimiter(value)
          set_input("Delimiter", value)
        end
        #### 
        # Set the value of the Marker input for this Choreo. 
        # 
        # @param String - (optional, string) Specifies the key to start with when listing objects in a bucket. Amazon S3 lists objects in alphabetical order.
        ###

        def set_Marker(value)
          set_input("Marker", value)
        end
        #### 
        # Set the value of the MaxKeys input for this Choreo. 
        # 
        # @param String - (optional, string) Lowers the max number of keys returned in the response from 1000 to specified value.The response will contain the key IsTruncated (true) if there are additional keys that exceed the # of MaxKeys.
        ###

        def set_MaxKeys(value)
          set_input("MaxKeys", value)
        end
        #### 
        # Set the value of the Prefix input for this Choreo. 
        # 
        # @param String - (optional, string) Limits the response to keys that begin with the specified prefix - useful for separating a bucket into different groupings of keys. Ex: specify 'test' to get a list of objects starting with 'test'.
        ###

        def set_Prefix(value)
          set_input("Prefix", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetBucketList Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetBucketListResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetBucketList



    ##############################################################################
    #
    # GetBucketLocation
    #
    # Returns the Region where the bucket is stored. 
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetBucketLocation < Choreography

      ####
      #  Create a new instance of the GetBucketLocation Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/GetBucketLocation")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetBucketLocationInputSet
      ####
      def new_input_set()
        return GetBucketLocationInputSet.new()
      end

      def make_result_set()
        return GetBucketLocationResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetBucketLocationResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetBucketLocation
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetBucketLocationInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket associated with the location you want to retrieve.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetBucketLocation Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetBucketLocationResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "LocationConstraint" output from this Choreo execution
      	#
      	# @return String - (string) The Region returned by the choreo. Valid values: blank (Default US Classic Region AKA us-east-1), EU (AKA eu-west-1), us-west-1, us-west-2, ap-southeast-1, ap-southeast-2, ap-northeast-1, sa-east-1.
      	####
      	def get_LocationConstraint()
      	  return @outputs["LocationConstraint"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetBucketLocation



    ##############################################################################
    #
    # GetBucketLogging
    #
    # Retrieves the logging status and user logging permissions for the specified bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetBucketLogging < Choreography

      ####
      #  Create a new instance of the GetBucketLogging Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/GetBucketLogging")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetBucketLoggingInputSet
      ####
      def new_input_set()
        return GetBucketLoggingInputSet.new()
      end

      def make_result_set()
        return GetBucketLoggingResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetBucketLoggingResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetBucketLogging
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetBucketLoggingInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket to retrieve logging information for.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetBucketLogging Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetBucketLoggingResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetBucketLogging



    ##############################################################################
    #
    # GetBucketNotification
    #
    # Retrieves the notification configuration of a specified bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetBucketNotification < Choreography

      ####
      #  Create a new instance of the GetBucketNotification Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/GetBucketNotification")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetBucketNotificationInputSet
      ####
      def new_input_set()
        return GetBucketNotificationInputSet.new()
      end

      def make_result_set()
        return GetBucketNotificationResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetBucketNotificationResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetBucketNotification
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetBucketNotificationInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket to retrieve notification information for.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetBucketNotification Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetBucketNotificationResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon. Note - if there is no notification configured or notifications are turned off the response will be an empty xml result set or json object (depending on ResponseFormat input).
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetBucketNotification



    ##############################################################################
    #
    # GetBucketPolicy
    #
    # Returns the policy of a specified bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetBucketPolicy < Choreography

      ####
      #  Create a new instance of the GetBucketPolicy Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/GetBucketPolicy")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetBucketPolicyInputSet
      ####
      def new_input_set()
        return GetBucketPolicyInputSet.new()
      end

      def make_result_set()
        return GetBucketPolicyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetBucketPolicyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetBucketPolicy
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetBucketPolicyInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket associated with the policy you want to retrieve.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetBucketPolicy Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetBucketPolicyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetBucketPolicy



    ##############################################################################
    #
    # GetBucketRequestPayment
    #
    # Retrieves the request payment configuration of a specified bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetBucketRequestPayment < Choreography

      ####
      #  Create a new instance of the GetBucketRequestPayment Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/GetBucketRequestPayment")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetBucketRequestPaymentInputSet
      ####
      def new_input_set()
        return GetBucketRequestPaymentInputSet.new()
      end

      def make_result_set()
        return GetBucketRequestPaymentResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetBucketRequestPaymentResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetBucketRequestPayment
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetBucketRequestPaymentInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket to retrieve request payment configuration information for.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetBucketRequestPayment Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetBucketRequestPaymentResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetBucketRequestPayment



    ##############################################################################
    #
    # GetBucketTagging
    #
    # Retrieves the billing tag set associated with the specified bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetBucketTagging < Choreography

      ####
      #  Create a new instance of the GetBucketTagging Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/GetBucketTagging")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetBucketTaggingInputSet
      ####
      def new_input_set()
        return GetBucketTaggingInputSet.new()
      end

      def make_result_set()
        return GetBucketTaggingResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetBucketTaggingResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetBucketTagging
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetBucketTaggingInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket to retrieve tagging information for.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetBucketTagging Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetBucketTaggingResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetBucketTagging



    ##############################################################################
    #
    # GetBucketVersioning
    #
    # Retrieves the versioning state of a specified bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetBucketVersioning < Choreography

      ####
      #  Create a new instance of the GetBucketVersioning Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/GetBucketVersioning")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetBucketVersioningInputSet
      ####
      def new_input_set()
        return GetBucketVersioningInputSet.new()
      end

      def make_result_set()
        return GetBucketVersioningResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetBucketVersioningResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetBucketVersioning
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetBucketVersioningInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket to retrieve versioning information for.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetBucketVersioning Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetBucketVersioningResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetBucketVersioning



    ##############################################################################
    #
    # GetBucketWebsite
    #
    # Returns the website configuration and static URL of a bucket if it is setup as a website.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetBucketWebsite < Choreography

      ####
      #  Create a new instance of the GetBucketWebsite Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/GetBucketWebsite")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetBucketWebsiteInputSet
      ####
      def new_input_set()
        return GetBucketWebsiteInputSet.new()
      end

      def make_result_set()
        return GetBucketWebsiteResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetBucketWebsiteResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetBucketWebsite
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetBucketWebsiteInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket associated with the website configuration you want to retrieve.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetBucketWebsite Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetBucketWebsiteResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "StaticURL" output from this Choreo execution
      	#
      	# @return String - (string) The URL of the Amazon static website. Note that the region code included in the URL is required for static websites.
      	####
      	def get_StaticURL()
      	  return @outputs["StaticURL"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetBucketWebsite



    ##############################################################################
    #
    # GetObjectACL
    #
    # Returns the access control list (ACL) of a file or object.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetObjectACL < Choreography

      ####
      #  Create a new instance of the GetObjectACL Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/GetObjectACL")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetObjectACLInputSet
      ####
      def new_input_set()
        return GetObjectACLInputSet.new()
      end

      def make_result_set()
        return GetObjectACLResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetObjectACLResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetObjectACL
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetObjectACLInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket associated with the ACL you want to retrieve.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the FileName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the file or object you wish to retrieve the ACL for. Ex.: filename.txt or folder/filename.txt.
        ###

        def set_FileName(value)
          set_input("FileName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetObjectACL Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetObjectACLResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetObjectACL



    ##############################################################################
    #
    # GetObjectTorrent
    #
    # Returns a base64-encoded torrent file from an Amazon S3 bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetObjectTorrent < Choreography

      ####
      #  Create a new instance of the GetObjectTorrent Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/GetObjectTorrent")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetObjectTorrentInputSet
      ####
      def new_input_set()
        return GetObjectTorrentInputSet.new()
      end

      def make_result_set()
        return GetObjectTorrentResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetObjectTorrentResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetObjectTorrent
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetObjectTorrentInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket that contains the object to retrieve.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the FileName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the torrent file to retrieve.
        ###

        def set_FileName(value)
          set_input("FileName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetObjectTorrent Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetObjectTorrentResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The retrieved file. The response is a Bencoded dictionary as defined by the BitTorrent specification, which is then Base64-encoded by Temboo. Decode to get the Bencoded dictionary.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetObjectTorrent



    ##############################################################################
    #
    # GetService
    #
    # Retrieves a list of buckets owned by the authenticated user.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetService < Choreography

      ####
      #  Create a new instance of the GetService Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/GetService")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetServiceInputSet
      ####
      def new_input_set()
        return GetServiceInputSet.new()
      end

      def make_result_set()
        return GetServiceResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetServiceResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetService
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetServiceInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetService Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetServiceResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetService



    ##############################################################################
    #
    # PutBucket
    #
    # Creates a new bucket in your Amazon S3 account.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PutBucket < Choreography

      ####
      #  Create a new instance of the PutBucket Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/PutBucket")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutBucketInputSet
      ####
      def new_input_set()
        return PutBucketInputSet.new()
      end

      def make_result_set()
        return PutBucketResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutBucketResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PutBucket
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutBucketInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket that will be created.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the CannedACL input for this Choreo. 
        # 
        # @param String - (optional, string) By default all objects are private (only owner has full access control). Valid values: private, public-read, public-read-write, authenticated-read, bucket-owner-read, bucket-owner-full-control.
        ###

        def set_CannedACL(value)
          set_input("CannedACL", value)
        end
        #### 
        # Set the value of the LocationConstraint input for this Choreo. 
        # 
        # @param String - (optional, string) The region to create the bucket in. Valid Values: EU, eu-west-1, us-west-1, us-west-2, ap-southeast-1, ap-southeast-2, ap-northeast-1, sa-east-1, empty string (Default US Classic Region).
        ###

        def set_LocationConstraint(value)
          set_input("LocationConstraint", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PutBucket Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutBucketResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon. Note that no content is returned for successful uploads.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PutBucket



    ##############################################################################
    #
    # PutBucketACL
    #
    # Sets the access control list (ACL) permissions for an existing bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PutBucketACL < Choreography

      ####
      #  Create a new instance of the PutBucketACL Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/PutBucketACL")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutBucketACLInputSet
      ####
      def new_input_set()
        return PutBucketACLInputSet.new()
      end

      def make_result_set()
        return PutBucketACLResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutBucketACLResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PutBucketACL
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutBucketACLInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AccessControlList input for this Choreo. 
        # 
        # @param String - (optional, xml) Custom Access Control List xml for advanced configuration. See description for an example, plus Amazon documentation.
        ###

        def set_AccessControlList(value)
          set_input("AccessControlList", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket to create or update a policy for.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the CannedACL input for this Choreo. 
        # 
        # @param String - (conditional, string) Most common ACL usage, required unless creating a custom policy. Values: private, public-read, public-read-write, or authenticated-read.
        ###

        def set_CannedACL(value)
          set_input("CannedACL", value)
        end
        #### 
        # Set the value of the OwnerEmailAddress input for this Choreo. 
        # 
        # @param String - (optional, string) The email address of the owner who is granting permission. Required if creating your own custom ACL policy.
        ###

        def set_OwnerEmailAddress(value)
          set_input("OwnerEmailAddress", value)
        end
        #### 
        # Set the value of the OwnerId input for this Choreo. 
        # 
        # @param String - (optional, string) The canonical user ID of the owner who is granting permission. Required if creating your own custom ACL policy.
        ###

        def set_OwnerId(value)
          set_input("OwnerId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PutBucketACL Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutBucketACLResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - Stores the response from Amazon. Note that for a successful ACL creation, no content is returned and this output variable should be empty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PutBucketACL



    ##############################################################################
    #
    # PutBucketCORS
    #
    # Sets the CORS (Cross-Origin Resource Sharing) configuration for a specified bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PutBucketCORS < Choreography

      ####
      #  Create a new instance of the PutBucketCORS Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/PutBucketCORS")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutBucketCORSInputSet
      ####
      def new_input_set()
        return PutBucketCORSInputSet.new()
      end

      def make_result_set()
        return PutBucketCORSResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutBucketCORSResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PutBucketCORS
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutBucketCORSInputSet < Choreography::InputSet

        #### 
        # Set the value of the CORSConfiguration input for this Choreo. 
        # 
        # @param String - (optional, xml) The CORS Configuration XML containing one or more CORS Rules for advanced configuration. If provided the Choreo will ignore all other inputs except your AWS Key/Secret and BucketName.
        ###

        def set_CORSConfiguration(value)
          set_input("CORSConfiguration", value)
        end
        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AllowedHeader input for this Choreo. 
        # 
        # @param String - (optional, string) Specifies which headers are allowed in a pre-flight OPTIONS request via the Access-Control-Request-Headers header.
        ###

        def set_AllowedHeader(value)
          set_input("AllowedHeader", value)
        end
        #### 
        # Set the value of the AllowedMethod input for this Choreo. 
        # 
        # @param String - (conditional, string) The HTTP verb that you want to allow the origin to execute. Valid values are: GET, PUT, HEAD, POST, DELETE.
        ###

        def set_AllowedMethod(value)
          set_input("AllowedMethod", value)
        end
        #### 
        # Set the value of the AllowedOrigin input for this Choreo. 
        # 
        # @param String - (conditional, string) An origin that you want to allow cross-domain requests from. This can contain at most one * wild character (i.e. http://*.example.com).
        ###

        def set_AllowedOrigin(value)
          set_input("AllowedOrigin", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket to set a CORS configuration for.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the ExposeHeader input for this Choreo. 
        # 
        # @param String - (optional, string) A header in the response that you want customers to be able to access from their applications.
        ###

        def set_ExposeHeader(value)
          set_input("ExposeHeader", value)
        end
        #### 
        # Set the value of the ID input for this Choreo. 
        # 
        # @param String - (optional, string) A unique identifier for the rule. The ID value can be up to 255 characters long.
        ###

        def set_ID(value)
          set_input("ID", value)
        end
        #### 
        # Set the value of the MaxAgeSeconds input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The time in seconds that your browser is to cache the preflight response for the specified resource.
        ###

        def set_MaxAgeSeconds(value)
          set_input("MaxAgeSeconds", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PutBucketCORS Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutBucketCORSResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon. Note that for a successful exection, this API operation returns an empty 200 response.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PutBucketCORS



    ##############################################################################
    #
    # PutBucketLifecycle
    #
    # Sets lifecycle configuration for your bucket. This is used to remove objects from a bucket automatically after a certain time or at a certain date.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PutBucketLifecycle < Choreography

      ####
      #  Create a new instance of the PutBucketLifecycle Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/PutBucketLifecycle")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutBucketLifecycleInputSet
      ####
      def new_input_set()
        return PutBucketLifecycleInputSet.new()
      end

      def make_result_set()
        return PutBucketLifecycleResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutBucketLifecycleResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PutBucketLifecycle
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutBucketLifecycleInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket to create or update a policy for.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the CustomLifecycleConfiguration input for this Choreo. 
        # 
        # @param String - (optional, xml) Write a custom LifecycleConfiguration xml request for advanced customization. Note - this will overwrite all other inputs other than the AWS AccessKeyId, SecretKeyId, and BucketName.
        ###

        def set_CustomLifecycleConfiguration(value)
          set_input("CustomLifecycleConfiguration", value)
        end
        #### 
        # Set the value of the DateOfExpiration input for this Choreo. 
        # 
        # @param String - (optional, date) Date when the rule takes effect. You can specify either DateOfExpiration OR NumberOfDays. The date value must be in ISO 8601 format, time is always midnight UTC. Ex: 2013-04-24T00:00:00.000Z.
        ###

        def set_DateOfExpiration(value)
          set_input("DateOfExpiration", value)
        end
        #### 
        # Set the value of the LifecycleId input for this Choreo. 
        # 
        # @param String - (optional, string) A unique ID for this lifecycle (i.e. delete-logs-in-30-days-rule).
        ###

        def set_LifecycleId(value)
          set_input("LifecycleId", value)
        end
        #### 
        # Set the value of the NumberOfDays input for this Choreo. 
        # 
        # @param Integer - (conditional, integer) The number of days to wait until the lifecycle expiration kicks in. Required unless you specify DateOfExpiration or a CustomLifecycleConfiguration instead.
        ###

        def set_NumberOfDays(value)
          set_input("NumberOfDays", value)
        end
        #### 
        # Set the value of the Prefix input for this Choreo. 
        # 
        # @param String - (optional, string) Indicating that objects with this prefix will expire and be removed after the number of days specified. If not specified this lifecycle will apply to all objects in the bucket.
        ###

        def set_Prefix(value)
          set_input("Prefix", value)
        end
        #### 
        # Set the value of the Status input for this Choreo. 
        # 
        # @param String - (optional, string) The lifecycle status. Accepted values are: "Enabled" or "Disabled". Defaults to "Enabled".
        ###

        def set_Status(value)
          set_input("Status", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PutBucketLifecycle Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutBucketLifecycleResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - Stores the response from Amazon. Note that for a successful lifecycle creation, no content is returned and this output variable should be empty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PutBucketLifecycle



    ##############################################################################
    #
    # PutBucketLogging
    #
    # Sets the logging parameters for a bucket and specifies permissions for who can view and modify the logging parameters. Can also be used to disable logging.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PutBucketLogging < Choreography

      ####
      #  Create a new instance of the PutBucketLogging Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/PutBucketLogging")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutBucketLoggingInputSet
      ####
      def new_input_set()
        return PutBucketLoggingInputSet.new()
      end

      def make_result_set()
        return PutBucketLoggingResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutBucketLoggingResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PutBucketLogging
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutBucketLoggingInputSet < Choreography::InputSet

        #### 
        # Set the value of the BucketLoggingStatus input for this Choreo. 
        # 
        # @param String - (optional, any) An XML file that allows custom config, this can be used as an alternative to the other bucket logging inputs. If provided, the Choreo will ignore all inputs except your AWS Key/Secret and BucketName.
        ###

        def set_BucketLoggingStatus(value)
          set_input("BucketLoggingStatus", value)
        end
        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket that you are setting the logging for.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the EmailAddress input for this Choreo. 
        # 
        # @param String - (conditional, string) The email address of the person being granted logging permissions.
        ###

        def set_EmailAddress(value)
          set_input("EmailAddress", value)
        end
        #### 
        # Set the value of the Permission input for this Choreo. 
        # 
        # @param String - (conditional, string) The logging permissions given to the Grantee for the bucket. Valid values are: FULL_CONTROL, READ, or WRITE.
        ###

        def set_Permission(value)
          set_input("Permission", value)
        end
        #### 
        # Set the value of the TargetBucket input for this Choreo. 
        # 
        # @param String - (conditional, string) The name of the target bucket. To disable logging, just leave this blank.
        ###

        def set_TargetBucket(value)
          set_input("TargetBucket", value)
        end
        #### 
        # Set the value of the TargetPrefix input for this Choreo. 
        # 
        # @param String - (conditional, string) Lets you specify a prefix for the keys that the log files will be stored under. Defaults to "/logs"
        ###

        def set_TargetPrefix(value)
          set_input("TargetPrefix", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PutBucketLogging Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutBucketLoggingResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon. A successful execution returns an empty 200 response.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PutBucketLogging



    ##############################################################################
    #
    # PutBucketNotification
    #
    # Enables Amazon SNS notifications of specified events for a bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PutBucketNotification < Choreography

      ####
      #  Create a new instance of the PutBucketNotification Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/PutBucketNotification")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutBucketNotificationInputSet
      ####
      def new_input_set()
        return PutBucketNotificationInputSet.new()
      end

      def make_result_set()
        return PutBucketNotificationResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutBucketNotificationResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PutBucketNotification
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutBucketNotificationInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket to create a notification for.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the Event input for this Choreo. 
        # 
        # @param String - (optional, string) A bucket event for which to send notifications. Valid value:  "s3:ReducedRedundancyLostObject" (The default and currently only supported notification event).
        ###

        def set_Event(value)
          set_input("Event", value)
        end
        #### 
        # Set the value of the Topic input for this Choreo. 
        # 
        # @param String - (conditional, string) The Amazon SNS topic arn that  Amazon S3 will publish a message to report the specified events for the bucket. If this is not supplied, notifications will be turned off.
        ###

        def set_Topic(value)
          set_input("Topic", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PutBucketNotification Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutBucketNotificationResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (string) Stores the response from Amazon. Note that for a successful execution, no content is returned and this output variable should be empty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PutBucketNotification



    ##############################################################################
    #
    # PutBucketPolicy
    #
    # Allows you to add to or replace a policy on a bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PutBucketPolicy < Choreography

      ####
      #  Create a new instance of the PutBucketPolicy Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/PutBucketPolicy")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutBucketPolicyInputSet
      ####
      def new_input_set()
        return PutBucketPolicyInputSet.new()
      end

      def make_result_set()
        return PutBucketPolicyResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutBucketPolicyResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PutBucketPolicy
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutBucketPolicyInputSet < Choreography::InputSet

        #### 
        # Set the value of the Policy input for this Choreo. 
        # 
        # @param String - (required, json) A JSON string containing the policy information.  See Choreo documentation for a sample JSON policy.
        ###

        def set_Policy(value)
          set_input("Policy", value)
        end
        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket to create or update a policy for.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PutBucketPolicy Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutBucketPolicyResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - Stores the response from Amazon. Note that for a successful policy creation, no content is returned and this output variable is empty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PutBucketPolicy



    ##############################################################################
    #
    # PutBucketRequestPayment
    #
    # Sets the request payment configuration of a bucket. 
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PutBucketRequestPayment < Choreography

      ####
      #  Create a new instance of the PutBucketRequestPayment Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/PutBucketRequestPayment")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutBucketRequestPaymentInputSet
      ####
      def new_input_set()
        return PutBucketRequestPaymentInputSet.new()
      end

      def make_result_set()
        return PutBucketRequestPaymentResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutBucketRequestPaymentResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PutBucketRequestPayment
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutBucketRequestPaymentInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket to create a request payment configuration for.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the Payer input for this Choreo. 
        # 
        # @param String - (required, string) Specifies who pays for the download and request fees. Valid values:  Requester or BucketOwner.
        ###

        def set_Payer(value)
          set_input("Payer", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PutBucketRequestPayment Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutBucketRequestPaymentResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - Stores the response from Amazon. Note that for a successful execution, no content is returned and this output variable should be empty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PutBucketRequestPayment



    ##############################################################################
    #
    # PutBucketTagging
    #
    # Adds a set of billing tags to an existing bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PutBucketTagging < Choreography

      ####
      #  Create a new instance of the PutBucketTagging Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/PutBucketTagging")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutBucketTaggingInputSet
      ####
      def new_input_set()
        return PutBucketTaggingInputSet.new()
      end

      def make_result_set()
        return PutBucketTaggingResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutBucketTaggingResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PutBucketTagging
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutBucketTaggingInputSet < Choreography::InputSet

        #### 
        # Set the value of the Tags input for this Choreo. 
        # 
        # @param String - (optional, xml) An XML file describing the key/values for the tag set. Note - if you use this input, the Key and Value input variables will be ignored.
        ###

        def set_Tags(value)
          set_input("Tags", value)
        end
        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket to add tags to.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the Key input for this Choreo. 
        # 
        # @param String - (conditional, string) The tag name.
        ###

        def set_Key(value)
          set_input("Key", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the Value input for this Choreo. 
        # 
        # @param String - (conditional, string) The tag value.
        ###

        def set_Value(value)
          set_input("Value", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PutBucketTagging Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutBucketTaggingResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - Stores the response from Amazon. Note that for a successful execution, no content is returned and this output variable should be empty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PutBucketTagging



    ##############################################################################
    #
    # PutBucketVersioning
    #
    # Sets the versioning state of an existing bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PutBucketVersioning < Choreography

      ####
      #  Create a new instance of the PutBucketVersioning Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/PutBucketVersioning")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutBucketVersioningInputSet
      ####
      def new_input_set()
        return PutBucketVersioningInputSet.new()
      end

      def make_result_set()
        return PutBucketVersioningResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutBucketVersioningResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PutBucketVersioning
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutBucketVersioningInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket to create a notification for.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the Status input for this Choreo. 
        # 
        # @param String - (required, string) Indicates whether or not the bucket has versioning enabled. Valid values are: Enabled or Suspended (case-sensitive).
        ###

        def set_Status(value)
          set_input("Status", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PutBucketVersioning Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutBucketVersioningResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - Stores the response from Amazon. Note that for a successful execution, no content is returned and this output variable should be empty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PutBucketVersioning



    ##############################################################################
    #
    # PutBucketWebsiteRedirect
    #
    # Configures the specified bucket as a website and sets the web request redirects to a designated endpoint.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PutBucketWebsiteRedirect < Choreography

      ####
      #  Create a new instance of the PutBucketWebsiteRedirect Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/PutBucketWebsiteRedirect")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutBucketWebsiteRedirectInputSet
      ####
      def new_input_set()
        return PutBucketWebsiteRedirectInputSet.new()
      end

      def make_result_set()
        return PutBucketWebsiteRedirectResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutBucketWebsiteRedirectResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PutBucketWebsiteRedirect
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutBucketWebsiteRedirectInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket that you wish to configure.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the CustomWebsiteRedirection input for this Choreo. 
        # 
        # @param String - (optional, xml) A custom xml file for adding advanced website redirection rule(s). See description and Amazon  docs for details. Note - inputting a custom xml file will overwrite all other optional input values.
        ###

        def set_CustomWebsiteRedirection(value)
          set_input("CustomWebsiteRedirection", value)
        end
        #### 
        # Set the value of the ErrorDocument input for this Choreo. 
        # 
        # @param String - (optional, string) The object key name to use when a 4XX class error occurs. Returns specified page when such an error occurs. Ex.: Error.html.
        ###

        def set_ErrorDocument(value)
          set_input("ErrorDocument", value)
        end
        #### 
        # Set the value of the HostName input for this Choreo. 
        # 
        # @param String - (optional, string) Name of the host where requests will be redirected. Used when setting redirect rules, optional if specifying ReplaceKeyPrefixWith or ReplaceKeyWith input variables). Ex.: example.com.
        ###

        def set_HostName(value)
          set_input("HostName", value)
        end
        #### 
        # Set the value of the HttpErrorCodeReturnedEquals input for this Choreo. 
        # 
        # @param String - (optional, string) The HTTP error code condition for which a redirect occurs. If there's an error and the error code equals this value, then the specified redirect is applied. Can use with KeyPrefixEquals. Ex:  404.
        ###

        def set_HttpErrorCodeReturnedEquals(value)
          set_input("HttpErrorCodeReturnedEquals", value)
        end
        #### 
        # Set the value of the HttpRedirectCode input for this Choreo. 
        # 
        # @param String - (optional, string) The HTTP redirect code to use on the response.
        ###

        def set_HttpRedirectCode(value)
          set_input("HttpRedirectCode", value)
        end
        #### 
        # Set the value of the KeyPrefixEquals input for this Choreo. 
        # 
        # @param String - (optional, string) The name or prefix condition of the object that will trigger the redirect action. Can use with HttpErrorCodeReturnedEquals. Ex:  Single page: ExamplePage.html, All pages with prefix: /images.
        ###

        def set_KeyPrefixEquals(value)
          set_input("KeyPrefixEquals", value)
        end
        #### 
        # Set the value of the Protocol input for this Choreo. 
        # 
        # @param String - (optional, string) Sets protocol to use when redirecting requests. Optional if you are specifying either ReplaceKeyPrefixWith or ReplaceKeyWith optional inputs. Possible values: http, https.
        ###

        def set_Protocol(value)
          set_input("Protocol", value)
        end
        #### 
        # Set the value of the ReplaceKeyPrefixWith input for this Choreo. 
        # 
        # @param String - (optional, string) The object key prefix to use in the redirect request. Redirects requests to the specified prefix. Cannot be used with ReplaceKeyWith. Ex.: /documents.
        ###

        def set_ReplaceKeyPrefixWith(value)
          set_input("ReplaceKeyPrefixWith", value)
        end
        #### 
        # Set the value of the ReplaceKeyWith input for this Choreo. 
        # 
        # @param String - (optional, string) The specific object key to use in the redirect request. Cannot be used with ReplaceKeyPrefixWith. Ex.: error.html.
        ###

        def set_ReplaceKeyWith(value)
          set_input("ReplaceKeyWith", value)
        end
        #### 
        # Set the value of the Suffix input for this Choreo. 
        # 
        # @param String - (optional, string) The default page returned when there is a request to a directory. I.e.: if you input index.html, a request for /images/ will return the data for the object '/images/index.html'. Default is index.html.
        ###

        def set_Suffix(value)
          set_input("Suffix", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PutBucketWebsiteRedirect Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutBucketWebsiteRedirectResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - Stores the response from Amazon. Note that for a successful website configuration request, no content is returned and this output variable will be empty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PutBucketWebsiteRedirect



    ##############################################################################
    #
    # PutBucketWebsiteRedirectAll
    #
    # Configures the specified bucket as a website and redirects all web requests to the designated hostname.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PutBucketWebsiteRedirectAll < Choreography

      ####
      #  Create a new instance of the PutBucketWebsiteRedirectAll Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/PutBucketWebsiteRedirectAll")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutBucketWebsiteRedirectAllInputSet
      ####
      def new_input_set()
        return PutBucketWebsiteRedirectAllInputSet.new()
      end

      def make_result_set()
        return PutBucketWebsiteRedirectAllResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutBucketWebsiteRedirectAllResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PutBucketWebsiteRedirectAll
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutBucketWebsiteRedirectAllInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket that you wish to configure.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the HostName input for this Choreo. 
        # 
        # @param String - (required, string) Name of the host where requests will be redirected. Ex.: example.com
        ###

        def set_HostName(value)
          set_input("HostName", value)
        end
        #### 
        # Set the value of the Protocol input for this Choreo. 
        # 
        # @param String - (optional, string) Protocol to use (http, https) when redirecting requests. The default is http.
        ###

        def set_Protocol(value)
          set_input("Protocol", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PutBucketWebsiteRedirectAll Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutBucketWebsiteRedirectAllResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - Stores the response from Amazon. Note that for a successful website configuration request, no content is returned and this output variable will be empty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PutBucketWebsiteRedirectAll



    ##############################################################################
    #
    # PutObject
    #
    # Uploads a file to your Amazon S3 storage bucket.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PutObject < Choreography

      ####
      #  Create a new instance of the PutObject Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/PutObject")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutObjectInputSet
      ####
      def new_input_set()
        return PutObjectInputSet.new()
      end

      def make_result_set()
        return PutObjectResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutObjectResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PutObject
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutObjectInputSet < Choreography::InputSet

        #### 
        # Set the value of the FileContents input for this Choreo. 
        # 
        # @param String - (required, string) The Base64-encoded file contents that you want to upload to an AmazonS3 bucket. This is required unless providing a URL to a hosted file to upload, using the UploadSourceURL input.
        ###

        def set_FileContents(value)
          set_input("FileContents", value)
        end
        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket that will be the file destination.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the CannedACL input for this Choreo. 
        # 
        # @param String - (optional, string) By default all objects are private (only owner has full access control). Valid values: private, public-read, public-read-write, authenticated-read, bucket-owner-read, bucket-owner-full-control.
        ###

        def set_CannedACL(value)
          set_input("CannedACL", value)
        end
        #### 
        # Set the value of the ContentType input for this Choreo. 
        # 
        # @param String - (optional, string) Sets the content-type (text/html, image/jpeg, etc.). Default is application/octet-stream.
        ###

        def set_ContentType(value)
          set_input("ContentType", value)
        end
        #### 
        # Set the value of the FileName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the file to put in S3 Storage. Ex.: file.txt or folder/file.txt
        ###

        def set_FileName(value)
          set_input("FileName", value)
        end
        #### 
        # Set the value of the SSECAlgorithm input for this Choreo. 
        # 
        # @param String - (optional, string) Specifies the server-side encryption with customer-provided encryption keys (SSE-C) algorithm to use when Amazon S3 creates the target object. Valid value: AES256.
        ###

        def set_SSECAlgorithm(value)
          set_input("SSECAlgorithm", value)
        end
        #### 
        # Set the value of the SSECKey input for this Choreo. 
        # 
        # @param String - (optional, string) The customer-provided AES-256 256-bit (32-byte) encryption key for Amazon S3 to use to encrypt or decrypt your data.
        ###

        def set_SSECKey(value)
          set_input("SSECKey", value)
        end
        #### 
        # Set the value of the ServerSideEncryption input for this Choreo. 
        # 
        # @param String - (optional, string) Specifies the server-side encryption algorithm to use when Amazon S3 creates the target object. Valid value: AES256.
        ###

        def set_ServerSideEncryption(value)
          set_input("ServerSideEncryption", value)
        end
        #### 
        # Set the value of the StorageClass input for this Choreo. 
        # 
        # @param String - (optional, string) Enables RRS customers to store their noncritical, reproducible data at lower levels of redundancy than Amazon S3's standard storage. Valid Values: STANDARD (default), REDUCED_REDUNDANCY.
        ###

        def set_StorageClass(value)
          set_input("StorageClass", value)
        end
        #### 
        # Set the value of the UploadSourcePassword input for this Choreo. 
        # 
        # @param String - (optional, string) The password to use when Basic Authentiation is required to access a file located at the URL specified in the UploadSourceURL input.
        ###

        def set_UploadSourcePassword(value)
          set_input("UploadSourcePassword", value)
        end
        #### 
        # Set the value of the UploadSourceURL input for this Choreo. 
        # 
        # @param String - (optional, string) A URL to a hosted file that should be uploaded. This is required unless providing a Base64 encoded file for the FileContents input.
        ###

        def set_UploadSourceURL(value)
          set_input("UploadSourceURL", value)
        end
        #### 
        # Set the value of the UploadSourceUsername input for this Choreo. 
        # 
        # @param String - (optional, string) The username to use when Basic Authentiation is required to access a file located at the URL specified in the UploadSourceURL input.
        ###

        def set_UploadSourceUsername(value)
          set_input("UploadSourceUsername", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (conditional, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the WebsiteRedirectLocation input for this Choreo. 
        # 
        # @param String - (optional, string) If the bucket is configured as a website, redirects requests for this object to another object in the same bucket or to an external URL. Ex: /anotherPage.html, http://www.page.com. Max length: 2 K.
        ###

        def set_WebsiteRedirectLocation(value)
          set_input("WebsiteRedirectLocation", value)
        end
        #### 
        # Set the value of the VaultFile input for this Choreo. 
        # 
        # @param TembooPath - (optional, vault file) The path to a vault file that you want to upload to an Amazon S3 bucket. Required unless using the FileContents input variable.
        ###

        def set_VaultFile(value)
          set_alias("VaultFile", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PutObject Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutObjectResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon. Note that no content is returned for successful uploads.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PutObject



    ##############################################################################
    #
    # PutObjectACL
    #
    # Sets the access control list (ACL) permissions for an existing object.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PutObjectACL < Choreography

      ####
      #  Create a new instance of the PutObjectACL Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/PutObjectACL")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutObjectACLInputSet
      ####
      def new_input_set()
        return PutObjectACLInputSet.new()
      end

      def make_result_set()
        return PutObjectACLResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutObjectACLResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PutObjectACL
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutObjectACLInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AccessControlList input for this Choreo. 
        # 
        # @param String - (optional, xml) Custom Access Control List xml for advanced configuration. See description for an example, plus Amazon documentation.
        ###

        def set_AccessControlList(value)
          set_input("AccessControlList", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket that contains the object that you want to create or update a policy for.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the CannedACL input for this Choreo. 
        # 
        # @param String - (conditional, string) Most common ACL usage, required unless creating a custom policy. Values: private, public-read, public-read-write, authenticated-read, bucket-owner-read, or bucket-owner-full-control.
        ###

        def set_CannedACL(value)
          set_input("CannedACL", value)
        end
        #### 
        # Set the value of the FileName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the file or object that you want to put access controls on in S3. Ex.: file.txt or folder/file.txt.
        ###

        def set_FileName(value)
          set_input("FileName", value)
        end
        #### 
        # Set the value of the OwnerEmailAddress input for this Choreo. 
        # 
        # @param String - (optional, string) The email address of the owner who is granting permission. Required if creating your own custom ACL policy.
        ###

        def set_OwnerEmailAddress(value)
          set_input("OwnerEmailAddress", value)
        end
        #### 
        # Set the value of the OwnerId input for this Choreo. 
        # 
        # @param String - (optional, string) The canonical user id of the owner who is granting permission. Required if creating your own custom ACL policy.
        ###

        def set_OwnerId(value)
          set_input("OwnerId", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PutObjectACL Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutObjectACLResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - Stores the response from Amazon. Note that for a successful ACL creation, no content is returned and this output variable is empty.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class PutObjectACL



    ##############################################################################
    #
    # ZipBucket
    #
    # Creates a zip file containing all objects within the specified bucket and returns a download link for the new compressed file.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ZipBucket < Choreography

      ####
      #  Create a new instance of the ZipBucket Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/ZipBucket")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ZipBucketInputSet
      ####
      def new_input_set()
        return ZipBucketInputSet.new()
      end

      def make_result_set()
        return ZipBucketResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ZipBucketResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ZipBucket
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ZipBucketInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket that contains the list of objects that you want to zip.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the CannedACL input for this Choreo. 
        # 
        # @param String - (conditional, string) This sets the permissions for the newly created zip file. Valid values are: private, public-read, public-read-write, authenticated-read, bucket-owner-read, or bucket-owner-full-control.
        ###

        def set_CannedACL(value)
          set_input("CannedACL", value)
        end
        #### 
        # Set the value of the Delimiter input for this Choreo. 
        # 
        # @param String - (optional, string) A delimiter is a character you use to group keys. All keys that contain the delimiter are grouped under a single result element, Common Prefixes. For more information see Amazon documentation.
        ###

        def set_Delimiter(value)
          set_input("Delimiter", value)
        end
        #### 
        # Set the value of the Prefix input for this Choreo. 
        # 
        # @param String - (optional, string) Limits the response to keys that begin with the specified prefix - useful for separating a bucket into different groupings of keys. Ex: specify 'test' to get a list of objects starting with 'test'.
        ###

        def set_Prefix(value)
          set_input("Prefix", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the ZipFileLocation input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the bucket to put the new zip file in. When not specified, the zip file will be put in the bucket that contains the files being zipped.
        ###

        def set_ZipFileLocation(value)
          set_input("ZipFileLocation", value)
        end
        #### 
        # Set the value of the ZipFileName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the zip file that will be created. If not specified, the original bucket name will be used with .zip extension.
        ###

        def set_ZipFileName(value)
          set_input("ZipFileName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ZipBucket Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ZipBucketResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "URL" output from this Choreo execution
      	#
      	# @return String - (string) The URL location of the new zip file.
      	####
      	def get_URL()
      	  return @outputs["URL"]
      	end
      end

    end # class ZipBucket



    ##############################################################################
    #
    # ZipObject
    #
    # Creates a zipped version of the specified S3 file and returns a download link for the new compressed file.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ZipObject < Choreography

      ####
      #  Create a new instance of the ZipObject Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/S3/ZipObject")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ZipObjectInputSet
      ####
      def new_input_set()
        return ZipObjectInputSet.new()
      end

      def make_result_set()
        return ZipObjectResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ZipObjectResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ZipObject
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ZipObjectInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the BucketName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the bucket that contains the object to retrieve and zip.
        ###

        def set_BucketName(value)
          set_input("BucketName", value)
        end
        #### 
        # Set the value of the CannedACL input for this Choreo. 
        # 
        # @param String - (conditional, string) This sets the permissions for the newly created zip file. Valid values are: private, public-read, public-read-write, authenticated-read, bucket-owner-read, or bucket-owner-full-control.
        ###

        def set_CannedACL(value)
          set_input("CannedACL", value)
        end
        #### 
        # Set the value of the FileName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the file to retrieve and zip.
        ###

        def set_FileName(value)
          set_input("FileName", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (required, string) The AWS region that corresponds to the S3 endpoint you wish to access. The default region is "us-east-1".
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the ZipFileLocation input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the bucket to put the new zip file in. When not specified, the zip file will be put in the bucket where the original uncompressed file is located.
        ###

        def set_ZipFileLocation(value)
          set_input("ZipFileLocation", value)
        end
        #### 
        # Set the value of the ZipFileName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the zip file that will be created. If not specified, the original file name will be used with .zip extension.
        ###

        def set_ZipFileName(value)
          set_input("ZipFileName", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ZipObject Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ZipObjectResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "URL" output from this Choreo execution
      	#
      	# @return String - (string) The URL location of the new zip file.
      	####
      	def get_URL()
      	  return @outputs["URL"]
      	end
      end

    end # class ZipObject




  end # module S3

  module SNS



    ##############################################################################
    #
    # AddPermission
    #
    # Creates a statement for a topic's access control policy which allows an AWS account to have access to the specified Amazon SNS actions.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class AddPermission < Choreography

      ####
      #  Create a new instance of the AddPermission Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SNS/AddPermission")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AddPermissionInputSet
      ####
      def new_input_set()
        return AddPermissionInputSet.new()
      end

      def make_result_set()
        return AddPermissionResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AddPermissionResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the AddPermission
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AddPermissionInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSAccountId input for this Choreo. 
        # 
        # @param Integer - (required, integer) The AWS account number of the user that will be granted access to a specified action. Enter account number omitting any dashes.
        ###

        def set_AWSAccountId(value)
          set_input("AWSAccountId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ActionName input for this Choreo. 
        # 
        # @param String - (required, string) The action you want to allow for a specified user (i.e. DeleteTopic, Publish, GetTopicAttributes, etc).
        ###

        def set_ActionName(value)
          set_input("ActionName", value)
        end
        #### 
        # Set the value of the Label input for this Choreo. 
        # 
        # @param String - (required, string) The unique identifier for the new policy statement.
        ###

        def set_Label(value)
          set_input("Label", value)
        end
        #### 
        # Set the value of the TopicArn input for this Choreo. 
        # 
        # @param String - (required, string) The ARN of the topic whos access control policy you want to adjust.
        ###

        def set_TopicArn(value)
          set_input("TopicArn", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SNS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the AddPermission Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AddPermissionResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class AddPermission



    ##############################################################################
    #
    # ConfirmSubscription
    #
    # Verifies that the endpoint owner wishes to receive messages by verifying the token sent during the Subscribe action.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ConfirmSubscription < Choreography

      ####
      #  Create a new instance of the ConfirmSubscription Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SNS/ConfirmSubscription")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ConfirmSubscriptionInputSet
      ####
      def new_input_set()
        return ConfirmSubscriptionInputSet.new()
      end

      def make_result_set()
        return ConfirmSubscriptionResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ConfirmSubscriptionResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ConfirmSubscription
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ConfirmSubscriptionInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AuthenticateOnUnsubscribed input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Indicates that you want to disable the ability to unsubscribe from the subscription without authenticating. Specify 1 to enable this flag.
        ###

        def set_AuthenticateOnUnsubscribed(value)
          set_input("AuthenticateOnUnsubscribed", value)
        end
        #### 
        # Set the value of the Token input for this Choreo. 
        # 
        # @param String - (required, string) The short-lived token sent to an endpoint during the Subscribe action.
        ###

        def set_Token(value)
          set_input("Token", value)
        end
        #### 
        # Set the value of the TopicArn input for this Choreo. 
        # 
        # @param String - (required, string) The ARN of the topic you want to confirm a subscription for.
        ###

        def set_TopicArn(value)
          set_input("TopicArn", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SNS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ConfirmSubscription Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ConfirmSubscriptionResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ConfirmSubscription



    ##############################################################################
    #
    # CreateTopic
    #
    # Creates a new topic that notifications can be published to.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateTopic < Choreography

      ####
      #  Create a new instance of the CreateTopic Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SNS/CreateTopic")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateTopicInputSet
      ####
      def new_input_set()
        return CreateTopicInputSet.new()
      end

      def make_result_set()
        return CreateTopicResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateTopicResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateTopic
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateTopicInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Name input for this Choreo. 
        # 
        # @param String - (required, string) The name of the topic you want to create.
        ###

        def set_Name(value)
          set_input("Name", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SNS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateTopic Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateTopicResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateTopic



    ##############################################################################
    #
    # DeleteTopic
    #
    # Deletes a specified topic and all its subscriptions.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteTopic < Choreography

      ####
      #  Create a new instance of the DeleteTopic Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SNS/DeleteTopic")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteTopicInputSet
      ####
      def new_input_set()
        return DeleteTopicInputSet.new()
      end

      def make_result_set()
        return DeleteTopicResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteTopicResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteTopic
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteTopicInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the TopicArn input for this Choreo. 
        # 
        # @param String - (required, string) The ARN of the topic you want to delete.
        ###

        def set_TopicArn(value)
          set_input("TopicArn", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SNS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteTopic Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteTopicResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteTopic



    ##############################################################################
    #
    # GetTopicAttributes
    #
    # Returns properties for a specified topic.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetTopicAttributes < Choreography

      ####
      #  Create a new instance of the GetTopicAttributes Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SNS/GetTopicAttributes")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetTopicAttributesInputSet
      ####
      def new_input_set()
        return GetTopicAttributesInputSet.new()
      end

      def make_result_set()
        return GetTopicAttributesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetTopicAttributesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetTopicAttributes
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetTopicAttributesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the TopicArn input for this Choreo. 
        # 
        # @param String - (required, string) The ARN of the topic you want to retrieve attributes for.
        ###

        def set_TopicArn(value)
          set_input("TopicArn", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SNS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetTopicAttributes Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetTopicAttributesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetTopicAttributes



    ##############################################################################
    #
    # ListSubscriptions
    #
    # Returns a list of the user's subscriptions. Each call returns a limited list of subscriptions, up to 100.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListSubscriptions < Choreography

      ####
      #  Create a new instance of the ListSubscriptions Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SNS/ListSubscriptions")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListSubscriptionsInputSet
      ####
      def new_input_set()
        return ListSubscriptionsInputSet.new()
      end

      def make_result_set()
        return ListSubscriptionsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListSubscriptionsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListSubscriptions
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListSubscriptionsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the NextToken input for this Choreo. 
        # 
        # @param String - (optional, string) The token returned from a previous LIstSubscriptions request.
        ###

        def set_NextToken(value)
          set_input("NextToken", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SNS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListSubscriptions Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListSubscriptionsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListSubscriptions



    ##############################################################################
    #
    # ListSubscriptionsByTopic
    #
    # Returns a list of the subscriptions for a specified topic.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListSubscriptionsByTopic < Choreography

      ####
      #  Create a new instance of the ListSubscriptionsByTopic Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SNS/ListSubscriptionsByTopic")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListSubscriptionsByTopicInputSet
      ####
      def new_input_set()
        return ListSubscriptionsByTopicInputSet.new()
      end

      def make_result_set()
        return ListSubscriptionsByTopicResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListSubscriptionsByTopicResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListSubscriptionsByTopic
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListSubscriptionsByTopicInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the NextToken input for this Choreo. 
        # 
        # @param String - (optional, string) The token returned from a previous LIstSubscriptionsByTopic request.
        ###

        def set_NextToken(value)
          set_input("NextToken", value)
        end
        #### 
        # Set the value of the TopicArn input for this Choreo. 
        # 
        # @param String - (required, string) The ARN of the topic that you want to find subscriptions for.
        ###

        def set_TopicArn(value)
          set_input("TopicArn", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SNS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListSubscriptionsByTopic Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListSubscriptionsByTopicResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListSubscriptionsByTopic



    ##############################################################################
    #
    # ListTopics
    #
    # Returns a list of the user's topics.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListTopics < Choreography

      ####
      #  Create a new instance of the ListTopics Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SNS/ListTopics")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListTopicsInputSet
      ####
      def new_input_set()
        return ListTopicsInputSet.new()
      end

      def make_result_set()
        return ListTopicsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListTopicsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListTopics
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListTopicsInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the NextToken input for this Choreo. 
        # 
        # @param String - (optional, string) The token returned from a previous LIstTopics request.
        ###

        def set_NextToken(value)
          set_input("NextToken", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SNS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListTopics Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListTopicsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListTopics



    ##############################################################################
    #
    # Publish
    #
    # Sends a message to a topic's subscribed endpoints.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Publish < Choreography

      ####
      #  Create a new instance of the Publish Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SNS/Publish")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PublishInputSet
      ####
      def new_input_set()
        return PublishInputSet.new()
      end

      def make_result_set()
        return PublishResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PublishResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Publish
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PublishInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Message input for this Choreo. 
        # 
        # @param String - (required, string) The text for the message you want to send to the topic.
        ###

        def set_Message(value)
          set_input("Message", value)
        end
        #### 
        # Set the value of the MessageStructure input for this Choreo. 
        # 
        # @param String - (optional, string) Can be set to 'json' if you are providing a valid JSON object for the Message input variable.
        ###

        def set_MessageStructure(value)
          set_input("MessageStructure", value)
        end
        #### 
        # Set the value of the Subject input for this Choreo. 
        # 
        # @param String - (optional, string) The "Subject" line of the message when the message is delivered to e-mail endpoints or as a JSON message.
        ###

        def set_Subject(value)
          set_input("Subject", value)
        end
        #### 
        # Set the value of the TopicArn input for this Choreo. 
        # 
        # @param String - (required, string) The ARN of the topic you want to publish to.
        ###

        def set_TopicArn(value)
          set_input("TopicArn", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SNS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Publish Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PublishResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Publish



    ##############################################################################
    #
    # RemovePermission
    #
    # Removes the statement from a topic's access control policy that was created with the AddPermission action.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RemovePermission < Choreography

      ####
      #  Create a new instance of the RemovePermission Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SNS/RemovePermission")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RemovePermissionInputSet
      ####
      def new_input_set()
        return RemovePermissionInputSet.new()
      end

      def make_result_set()
        return RemovePermissionResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RemovePermissionResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RemovePermission
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RemovePermissionInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Label input for this Choreo. 
        # 
        # @param String - (required, string) The unique identifier for the policy statement that you want to delete.
        ###

        def set_Label(value)
          set_input("Label", value)
        end
        #### 
        # Set the value of the TopicArn input for this Choreo. 
        # 
        # @param String - (required, string) The ARN of the topic that has an access control policy you want to adjust.
        ###

        def set_TopicArn(value)
          set_input("TopicArn", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SNS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RemovePermission Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RemovePermissionResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class RemovePermission



    ##############################################################################
    #
    # SetTopicAttributes
    #
    # Allows a topic owner to update the attribute of a topic to a new value.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class SetTopicAttributes < Choreography

      ####
      #  Create a new instance of the SetTopicAttributes Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SNS/SetTopicAttributes")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return SetTopicAttributesInputSet
      ####
      def new_input_set()
        return SetTopicAttributesInputSet.new()
      end

      def make_result_set()
        return SetTopicAttributesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = SetTopicAttributesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the SetTopicAttributes
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class SetTopicAttributesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AttributeName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the attribute you want to modify. Valid values are: Policy and DisplayName.
        ###

        def set_AttributeName(value)
          set_input("AttributeName", value)
        end
        #### 
        # Set the value of the AttributeValue input for this Choreo. 
        # 
        # @param String - (required, string) The new value for the attribute that you want to update.
        ###

        def set_AttributeValue(value)
          set_input("AttributeValue", value)
        end
        #### 
        # Set the value of the TopicArn input for this Choreo. 
        # 
        # @param String - (required, string) The ARN of the topic that has an attribute that you want to set.
        ###

        def set_TopicArn(value)
          set_input("TopicArn", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SNS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the SetTopicAttributes Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class SetTopicAttributesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class SetTopicAttributes



    ##############################################################################
    #
    # Subscribe
    #
    # Sends the endpoint a confirmation message in preparation for subscribing an endpoint.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Subscribe < Choreography

      ####
      #  Create a new instance of the Subscribe Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SNS/Subscribe")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return SubscribeInputSet
      ####
      def new_input_set()
        return SubscribeInputSet.new()
      end

      def make_result_set()
        return SubscribeResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = SubscribeResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Subscribe
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class SubscribeInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Endpoint input for this Choreo. 
        # 
        # @param String - (required, string) The endpoint that will receive the notifications. Can be an email address, URL, or the ARN of an Amazon SQS queue depending on the protocol specified.
        ###

        def set_Endpoint(value)
          set_input("Endpoint", value)
        end
        #### 
        # Set the value of the Protocol input for this Choreo. 
        # 
        # @param String - (required, string) The protocol you want to use. Accepted values are: http, https, email, email-json, or sqs.
        ###

        def set_Protocol(value)
          set_input("Protocol", value)
        end
        #### 
        # Set the value of the TopicArn input for this Choreo. 
        # 
        # @param String - (required, string) The ARN of the topic you want to subscribe to.
        ###

        def set_TopicArn(value)
          set_input("TopicArn", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SNS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Subscribe Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class SubscribeResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Subscribe



    ##############################################################################
    #
    # Unsubscribe
    #
    # Deletes a specified subscription.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Unsubscribe < Choreography

      ####
      #  Create a new instance of the Unsubscribe Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SNS/Unsubscribe")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UnsubscribeInputSet
      ####
      def new_input_set()
        return UnsubscribeInputSet.new()
      end

      def make_result_set()
        return UnsubscribeResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UnsubscribeResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Unsubscribe
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UnsubscribeInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the SubscriptionArn input for this Choreo. 
        # 
        # @param String - (required, string) The ARN of the subscription you want to delete.
        ###

        def set_SubscriptionArn(value)
          set_input("SubscriptionArn", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SNS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Unsubscribe Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UnsubscribeResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (xml) The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Unsubscribe




  end # module SNS

  module SQS



    ##############################################################################
    #
    # AddPermission
    #
    # Adds a permission to a queue for a specific principal user.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class AddPermission < Choreography

      ####
      #  Create a new instance of the AddPermission Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SQS/AddPermission")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AddPermissionInputSet
      ####
      def new_input_set()
        return AddPermissionInputSet.new()
      end

      def make_result_set()
        return AddPermissionResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AddPermissionResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the AddPermission
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AddPermissionInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSAccountId input for this Choreo. 
        # 
        # @param Integer - (required, integer) The AWS account number of the queue owner. Enter account number omitting any dashes.
        ###

        def set_AWSAccountId(value)
          set_input("AWSAccountId", value)
        end
        #### 
        # Set the value of the AWSAccountId1 input for this Choreo. 
        # 
        # @param Integer - (required, integer) The AWS account number of the user that will be granted access to a specified action. Enter account number omitting any dashes.
        ###

        def set_AWSAccountId1(value)
          set_input("AWSAccountId1", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the ActionName input for this Choreo. 
        # 
        # @param String - (required, string) The action to allow for a specified user. Valid values: SendMessage, ReceiveMessage, DeleteMessage,ChangeMessageVisibility, GetQueueAttributes.
        ###

        def set_ActionName(value)
          set_input("ActionName", value)
        end
        #### 
        # Set the value of the Label input for this Choreo. 
        # 
        # @param String - (required, string) The unique identifier for the new permission that is being set.
        ###

        def set_Label(value)
          set_input("Label", value)
        end
        #### 
        # Set the value of the QueueName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the queue that you're granting access to.
        ###

        def set_QueueName(value)
          set_input("QueueName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SQS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the AddPermission Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AddPermissionResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class AddPermission



    ##############################################################################
    #
    # ChangeMessageVisibility
    #
    # Updates the visibility timeout parameter of a message.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ChangeMessageVisibility < Choreography

      ####
      #  Create a new instance of the ChangeMessageVisibility Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SQS/ChangeMessageVisibility")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ChangeMessageVisibilityInputSet
      ####
      def new_input_set()
        return ChangeMessageVisibilityInputSet.new()
      end

      def make_result_set()
        return ChangeMessageVisibilityResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ChangeMessageVisibilityResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ChangeMessageVisibility
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ChangeMessageVisibilityInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSAccountId input for this Choreo. 
        # 
        # @param Integer - (required, integer) The AWS account id associated with the queue. Enter account number omitting any dashes.
        ###

        def set_AWSAccountId(value)
          set_input("AWSAccountId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the QueueName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the queue that contains the message.
        ###

        def set_QueueName(value)
          set_input("QueueName", value)
        end
        #### 
        # Set the value of the ReceiptHandle input for this Choreo. 
        # 
        # @param String - (required, string) The receipt handle associated with the message you want to modify. This is returned in the RecieveMessage request.
        ###

        def set_ReceiptHandle(value)
          set_input("ReceiptHandle", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SQS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the VisibilityTimeout input for this Choreo. 
        # 
        # @param Integer - (required, integer) The new value for the visibility timeout of the message (in seconds).
        ###

        def set_VisibilityTimeout(value)
          set_input("VisibilityTimeout", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ChangeMessageVisibility Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ChangeMessageVisibilityResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ChangeMessageVisibility



    ##############################################################################
    #
    # CreateQueue
    #
    # Creates a new queue with a specified queue name.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CreateQueue < Choreography

      ####
      #  Create a new instance of the CreateQueue Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SQS/CreateQueue")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CreateQueueInputSet
      ####
      def new_input_set()
        return CreateQueueInputSet.new()
      end

      def make_result_set()
        return CreateQueueResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CreateQueueResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CreateQueue
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CreateQueueInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the DefaultVisibilityTimeout input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The visibility timeout for the queue. An integer from 0 to 43200 (12 hours). The default for this attribute is 30.
        ###

        def set_DefaultVisibilityTimeout(value)
          set_input("DefaultVisibilityTimeout", value)
        end
        #### 
        # Set the value of the MaximumMessageSize input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The limit of how many bytes a message can contain before Amazon SQS rejects it. An integer from 1024 bytes (1 KiB) up to 262144 bytes (256 KiB)
        ###

        def set_MaximumMessageSize(value)
          set_input("MaximumMessageSize", value)
        end
        #### 
        # Set the value of the MessageRetentionPeriod input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The number of seconds Amazon SQS retains a message. Integer representing seconds, from 60 (1 minute) to 1209600 (14 days). The default for this attribute is 345600 (4 days).
        ###

        def set_MessageRetentionPeriod(value)
          set_input("MessageRetentionPeriod", value)
        end
        #### 
        # Set the value of the Policy input for this Choreo. 
        # 
        # @param String - (optional, json) The queue's policy.
        ###

        def set_Policy(value)
          set_input("Policy", value)
        end
        #### 
        # Set the value of the QueueName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the queue you want to create.
        ###

        def set_QueueName(value)
          set_input("QueueName", value)
        end
        #### 
        # Set the value of the ReceiveMessageWaitTimeSeconds input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The time for which a ReceiveMessage call will wait for a message to arrive. An integer from 0 to 20 (seconds). The default for this attribute is 0.
        ###

        def set_ReceiveMessageWaitTimeSeconds(value)
          set_input("ReceiveMessageWaitTimeSeconds", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SQS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CreateQueue Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CreateQueueResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class CreateQueue



    ##############################################################################
    #
    # DeleteMessage
    #
    # Deletes a particular message from a specified queue.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteMessage < Choreography

      ####
      #  Create a new instance of the DeleteMessage Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SQS/DeleteMessage")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteMessageInputSet
      ####
      def new_input_set()
        return DeleteMessageInputSet.new()
      end

      def make_result_set()
        return DeleteMessageResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteMessageResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteMessage
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteMessageInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSAccountId input for this Choreo. 
        # 
        # @param Integer - (required, integer) The AWS account id associated with the queue. Enter account number omitting any dashes.
        ###

        def set_AWSAccountId(value)
          set_input("AWSAccountId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the QueueName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the queue that contains the message you want to delete.
        ###

        def set_QueueName(value)
          set_input("QueueName", value)
        end
        #### 
        # Set the value of the ReceiptHandle input for this Choreo. 
        # 
        # @param String - (required, string) The receipt handle associated with the message you want to delete. This is returned in the RecieveMessage request.
        ###

        def set_ReceiptHandle(value)
          set_input("ReceiptHandle", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SQS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteMessage Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteMessageResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteMessage



    ##############################################################################
    #
    # DeleteQueue
    #
    # Deletes a queue with a specified queue URL.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteQueue < Choreography

      ####
      #  Create a new instance of the DeleteQueue Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SQS/DeleteQueue")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteQueueInputSet
      ####
      def new_input_set()
        return DeleteQueueInputSet.new()
      end

      def make_result_set()
        return DeleteQueueResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteQueueResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteQueue
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteQueueInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSAccountId input for this Choreo. 
        # 
        # @param Integer - (required, integer) The id for the AWS account associated with the queue you're deleting a message from (remove all dashes in the account number).
        ###

        def set_AWSAccountId(value)
          set_input("AWSAccountId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the QueueName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the queue you want to delete.
        ###

        def set_QueueName(value)
          set_input("QueueName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SQS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteQueue Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteQueueResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class DeleteQueue



    ##############################################################################
    #
    # GetQueueAttributes
    #
    # Retrieves one or all attributes of a queue.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetQueueAttributes < Choreography

      ####
      #  Create a new instance of the GetQueueAttributes Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SQS/GetQueueAttributes")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetQueueAttributesInputSet
      ####
      def new_input_set()
        return GetQueueAttributesInputSet.new()
      end

      def make_result_set()
        return GetQueueAttributesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetQueueAttributesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetQueueAttributes
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetQueueAttributesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSAccountId input for this Choreo. 
        # 
        # @param Integer - (required, integer) The AWS account number of the queue owner. Enter account number omitting any dashes.
        ###

        def set_AWSAccountId(value)
          set_input("AWSAccountId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AttributeName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the attribute that you want to retrieve for the specified queue. Defaults to 'All'.
        ###

        def set_AttributeName(value)
          set_input("AttributeName", value)
        end
        #### 
        # Set the value of the QueueName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the queue to retrieve attributes for.
        ###

        def set_QueueName(value)
          set_input("QueueName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SQS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetQueueAttributes Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetQueueAttributesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetQueueAttributes



    ##############################################################################
    #
    # ListQueues
    #
    # Returns a list of your queues.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ListQueues < Choreography

      ####
      #  Create a new instance of the ListQueues Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SQS/ListQueues")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ListQueuesInputSet
      ####
      def new_input_set()
        return ListQueuesInputSet.new()
      end

      def make_result_set()
        return ListQueuesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ListQueuesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ListQueues
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ListQueuesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the QueueNamePrefix input for this Choreo. 
        # 
        # @param String - (optional, string) A string used to filter the list of queues.
        ###

        def set_QueueNamePrefix(value)
          set_input("QueueNamePrefix", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SQS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ListQueues Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ListQueuesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ListQueues



    ##############################################################################
    #
    # ReceiveMessage
    #
    # Returns one or more messages from the specified queue.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ReceiveMessage < Choreography

      ####
      #  Create a new instance of the ReceiveMessage Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SQS/ReceiveMessage")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ReceiveMessageInputSet
      ####
      def new_input_set()
        return ReceiveMessageInputSet.new()
      end

      def make_result_set()
        return ReceiveMessageResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ReceiveMessageResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ReceiveMessage
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ReceiveMessageInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSAccountId input for this Choreo. 
        # 
        # @param Integer - (required, integer) The id for the AWS account associated with the queue you're retrieving a message from (remove all dashes in the account number).
        ###

        def set_AWSAccountId(value)
          set_input("AWSAccountId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AttributeName input for this Choreo. 
        # 
        # @param String - (optional, string) The attribute you wish to return. Values are: All (default), SenderId, SentTimestamp, ApproximateReceiveCount, or ApproximateFirstReceiveTimestamp.
        ###

        def set_AttributeName(value)
          set_input("AttributeName", value)
        end
        #### 
        # Set the value of the MaxNumberOfMessages input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The maximum number of messages to return. Defaults to 1.
        ###

        def set_MaxNumberOfMessages(value)
          set_input("MaxNumberOfMessages", value)
        end
        #### 
        # Set the value of the MessageAttributeName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of a message attribute to return. You can return all of the attributes by specifying "All".
        ###

        def set_MessageAttributeName(value)
          set_input("MessageAttributeName", value)
        end
        #### 
        # Set the value of the QueueName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the queue you want to retrieve a message from.
        ###

        def set_QueueName(value)
          set_input("QueueName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SQS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end
        #### 
        # Set the value of the VisibilityTimeout input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The duration (in seconds) that the received messages are hidden from future retrieve requests after a ReceiveMessage request (max is 43200).
        ###

        def set_VisibilityTimeout(value)
          set_input("VisibilityTimeout", value)
        end
        #### 
        # Set the value of the WaitTimeSeconds input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The duration (in seconds) for which the call will wait for a message to arrive in the queue before returning. If a message is available, the call will return sooner than WaitTimeSeconds.
        ###

        def set_WaitTimeSeconds(value)
          set_input("WaitTimeSeconds", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ReceiveMessage Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ReceiveMessageResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Body" output from this Choreo execution
      	#
      	# @return String - (string) The body of the latest message.
      	####
      	def get_Body()
      	  return @outputs["Body"]
      	end
      	####
      	# Retrieve the value for the "MessageId" output from this Choreo execution
      	#
      	# @return String - (string) A unique identifier for the latest message.
      	####
      	def get_MessageId()
      	  return @outputs["MessageId"]
      	end
      	####
      	# Retrieve the value for the "ReceiptHandle" output from this Choreo execution
      	#
      	# @return String - (string) An identifier associated with the act of receiving the message. A new receipt handle is returned every time you receive a message. Provide the last received receipt handle to delete the message.
      	####
      	def get_ReceiptHandle()
      	  return @outputs["ReceiptHandle"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ReceiveMessage



    ##############################################################################
    #
    # RemovePermission
    #
    # Removes any permission in the queue policy by specifying the permission label.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RemovePermission < Choreography

      ####
      #  Create a new instance of the RemovePermission Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SQS/RemovePermission")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RemovePermissionInputSet
      ####
      def new_input_set()
        return RemovePermissionInputSet.new()
      end

      def make_result_set()
        return RemovePermissionResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RemovePermissionResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RemovePermission
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RemovePermissionInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSAccountId input for this Choreo. 
        # 
        # @param Integer - (required, integer) The AWS account number of the queue owner. Enter account number omitting any dashes.
        ###

        def set_AWSAccountId(value)
          set_input("AWSAccountId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the Label input for this Choreo. 
        # 
        # @param String - (required, string) The unique identifier for the permission that is being removed.
        ###

        def set_Label(value)
          set_input("Label", value)
        end
        #### 
        # Set the value of the QueueName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the queue that that has the policy you want to adjust.
        ###

        def set_QueueName(value)
          set_input("QueueName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SQS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RemovePermission Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RemovePermissionResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class RemovePermission



    ##############################################################################
    #
    # SendMessage
    #
    # Sends up to ten messages to the specified queue.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class SendMessage < Choreography

      ####
      #  Create a new instance of the SendMessage Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SQS/SendMessage")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return SendMessageInputSet
      ####
      def new_input_set()
        return SendMessageInputSet.new()
      end

      def make_result_set()
        return SendMessageResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = SendMessageResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the SendMessage
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class SendMessageInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSAccountId input for this Choreo. 
        # 
        # @param Integer - (required, integer) The id for the AWS account associated with the queue you're sending a message to (remove all dashes in the account number).
        ###

        def set_AWSAccountId(value)
          set_input("AWSAccountId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the DelaySeconds input for this Choreo. 
        # 
        # @param String - (optional, string) The number of seconds (0 to 900 - 15 minutes) to delay a specific message.
        ###

        def set_DelaySeconds(value)
          set_input("DelaySeconds", value)
        end
        #### 
        # Set the value of the MessageAttributes input for this Choreo. 
        # 
        # @param String - (optional, json) A JSON array of message attributes. See Choreo notes for formatting details.
        ###

        def set_MessageAttributes(value)
          set_input("MessageAttributes", value)
        end
        #### 
        # Set the value of the MessageBody input for this Choreo. 
        # 
        # @param String - (required, string) The message to send. Maximum size is 64 KB.
        ###

        def set_MessageBody(value)
          set_input("MessageBody", value)
        end
        #### 
        # Set the value of the QueueName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the queue you want to send a messages to.
        ###

        def set_QueueName(value)
          set_input("QueueName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SQS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the SendMessage Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class SendMessageResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class SendMessage



    ##############################################################################
    #
    # SendMessageBatch
    #
    # Sends up to ten messages to the specified queue.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class SendMessageBatch < Choreography

      ####
      #  Create a new instance of the SendMessageBatch Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SQS/SendMessageBatch")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return SendMessageBatchInputSet
      ####
      def new_input_set()
        return SendMessageBatchInputSet.new()
      end

      def make_result_set()
        return SendMessageBatchResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = SendMessageBatchResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the SendMessageBatch
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class SendMessageBatchInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSAccountId input for this Choreo. 
        # 
        # @param Integer - (required, integer) The id for the AWS account associated with the queue you're sending a message to (remove all dashes in the account number).
        ###

        def set_AWSAccountId(value)
          set_input("AWSAccountId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the MessageEntries input for this Choreo. 
        # 
        # @param String - (required, json) A JSON array of message entries. Each object in the array must contain properties for MessageBody and Id. See Choreo notes for formatting details.
        ###

        def set_MessageEntries(value)
          set_input("MessageEntries", value)
        end
        #### 
        # Set the value of the QueueName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the queue you want to send a messages to.
        ###

        def set_QueueName(value)
          set_input("QueueName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SQS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the SendMessageBatch Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class SendMessageBatchResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class SendMessageBatch



    ##############################################################################
    #
    # SetQueueAttributes
    #
    # Sets an attribute of a specified queue.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class SetQueueAttributes < Choreography

      ####
      #  Create a new instance of the SetQueueAttributes Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Amazon/SQS/SetQueueAttributes")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return SetQueueAttributesInputSet
      ####
      def new_input_set()
        return SetQueueAttributesInputSet.new()
      end

      def make_result_set()
        return SetQueueAttributesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = SetQueueAttributesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the SetQueueAttributes
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class SetQueueAttributesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AWSAccessKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Access Key ID provided by Amazon Web Services.
        ###

        def set_AWSAccessKeyId(value)
          set_input("AWSAccessKeyId", value)
        end
        #### 
        # Set the value of the AWSAccountId input for this Choreo. 
        # 
        # @param Integer - (required, integer) The AWS account number of the queue owner. Enter account number omitting any dashes.
        ###

        def set_AWSAccountId(value)
          set_input("AWSAccountId", value)
        end
        #### 
        # Set the value of the AWSSecretKeyId input for this Choreo. 
        # 
        # @param String - (required, string) The Secret Key ID provided by Amazon Web Services.
        ###

        def set_AWSSecretKeyId(value)
          set_input("AWSSecretKeyId", value)
        end
        #### 
        # Set the value of the AttributeName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the attribute that you want to set. Valid values are: VisibilityTimeout, Policy, MaximumMessageSize, or MessageRetentionPeriod.
        ###

        def set_AttributeName(value)
          set_input("AttributeName", value)
        end
        #### 
        # Set the value of the AttributeValue input for this Choreo. 
        # 
        # @param String - (required, string) The value of the attribute you want to set. Corresponds to the AttributeName you specify.
        ###

        def set_AttributeValue(value)
          set_input("AttributeValue", value)
        end
        #### 
        # Set the value of the QueueName input for this Choreo. 
        # 
        # @param String - (required, string) The name of the queue you want to set attributes for.
        ###

        def set_QueueName(value)
          set_input("QueueName", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the UserRegion input for this Choreo. 
        # 
        # @param String - (optional, string) The AWS region that corresponds to the SQS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
        ###

        def set_UserRegion(value)
          set_input("UserRegion", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the SetQueueAttributes Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class SetQueueAttributesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Amazon.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class SetQueueAttributes




  end # module SQS

end # module Amazon